(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    654152,      17939]
NotebookOptionsPosition[    640011,      17463]
NotebookOutlinePosition[    640471,      17481]
CellTagsIndexPosition[    640428,      17478]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Nonlinear Correlation Spectroscopy (NLCS)\[LineSeparator]Theory -> NO flow \
case\
\>", "Title",
 CellChangeTimes->{{3.519033555595779*^9, 3.5190335614517727`*^9}, {
  3.519387583843833*^9, 3.5193875888418493`*^9}, {3.519533117144858*^9, 
  3.519533117474408*^9}, {3.519533371563425*^9, 3.5195333763451567`*^9}}],

Cell["\<\
Stefan Geissbuehler, Matthias Geissbuehler and Theo Lasser\
\>", "Subtitle",
 CellChangeTimes->{{3.5195331259062347`*^9, 3.519533170937517*^9}}],

Cell["\<\
Laboratoire d\[CloseCurlyQuote]Optique Biom\[EAcute]dicale LOB, Ecole \
Polytechnique F\[EAcute]d\[EAcute]rale de Lausanne (EPFL), CH-1015 Lausanne, \
Switzerland\
\>", "Subsubtitle",
 CellChangeTimes->{3.5195331750397577`*^9}],

Cell["\<\
This theory file is a complement to the Thesis of M. Geissbuehler. The \
derivation is too lengthy to be included in this form in the thesis.\
\>", "Subsubsection",
 CellChangeTimes->{{3.519533194161002*^9, 3.51953325281363*^9}}],

Cell["\<\
For further explenations of the derivation please refer to the thesis of M. \
Geissbuehler \[Dash] \[OpenCurlyDoubleQuote]Novel Concepts for Functional \
High Resolution Microscopy\[CloseCurlyDoubleQuote], Ecole Polytechnique F\
\[EAcute]d\[EAcute]rale de Lausanne (EPFL), \
2011.\[LineSeparator]http://library.epfl.ch/theses/\
\>", "Subsubsection",
 CellChangeTimes->{{3.519533260909927*^9, 3.519533337818719*^9}, {
  3.519534897725713*^9, 3.519534906331523*^9}, {3.519534952115242*^9, 
  3.5195349656731586`*^9}}],

Cell["\<\
Contact: matthias.geissbuehler@a3.epfl.ch\
\>", "Subsubsection",
 CellChangeTimes->{{3.519533359665743*^9, 3.5195333664738007`*^9}}],

Cell[CellGroupData[{

Cell["Definitions", "Subtitle",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.517625660816598*^9, 3.517625668892295*^9}, {
  3.517656513555011*^9, 3.517656515106162*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Aq", "[", 
   RowBox[{"x_", ",", " ", "y_", ",", " ", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Aq0", "*", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x", "^", "2"}], " ", "+", " ", 
        RowBox[{"y", "^", "2"}]}], ")"}]}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"w0", "^", "2"}], "/", "q"}], ")"}]}], "]"}], "*", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"z", "^", "2"}], ")"}]}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z0", "^", "2"}], "/", "q"}], ")"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.517625697447448*^9, 3.51762569898687*^9}, 
   3.517625766023983*^9, {3.517637123006424*^9, 3.517637123174074*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g1int", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z1_", ",", "z2_", ",", "z3_", ",", "z4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"chi", "^", "4"}], "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["cm", "3"], 
       RowBox[{"2", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Pi]", "*", 
           StyleBox["Dd", "TI"], 
           StyleBox["*", "TI"], "\[Tau]"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}]}]], 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z1", "-", "z3"}], ")"}], "^", "2"}]}], 
         RowBox[{"4", "*", 
          StyleBox["Dd", "TI"], 
          StyleBox["*", "TI"], "\[Tau]"}]]}], "]"}]}], ")"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x1", ",", "y1", ",", "z1"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x2", ",", "y2", ",", "z2"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x3", ",", "y3", ",", "z3"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x4", ",", "y4", ",", "z4"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z1"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z2"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z3"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z4"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517739350432007*^9, 3.5177394024035873`*^9}, 
   3.517739432995417*^9, {3.517741326758668*^9, 3.517741326882741*^9}, {
   3.51789658842332*^9, 3.5178965948603277`*^9}, {3.519098133080041*^9, 
   3.519098136264786*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"32", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x1", "2"]}], "-", 
         SuperscriptBox["y1", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x2", "2"]}], "-", 
         SuperscriptBox["y2", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x3", "2"]}], "-", 
         SuperscriptBox["y3", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x4", "2"]}], "-", 
         SuperscriptBox["y4", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z1", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z2", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z3", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z4", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z1", "-", "z3"}], ")"}], "2"]}], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z1", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z1", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z2", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z3", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z4", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.5177394869112453`*^9, 3.517741344212332*^9, 
  3.517896605935178*^9, 3.519036956316136*^9, 3.519098734712201*^9, 
  3.519106748657338*^9, 3.5191071238839617`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g2int", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z1_", ",", "z2_", ",", "z3_", ",", "z4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"chi", "^", "4"}], "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["cm", "2"], 
        RowBox[{"DiracDelta", "[", 
         RowBox[{
          RowBox[{"x1", "-", "x2"}], ",", 
          RowBox[{"y1", "-", "y2"}], ",", 
          RowBox[{"z1", "-", "z2"}]}], "]"}]}], 
       RowBox[{"2", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Pi]", "*", 
           StyleBox["Dd", "TI"], 
           StyleBox["*", "TI"], "\[Tau]"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}]}]], 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z1", "-", "z3"}], ")"}], "^", "2"}]}], 
         RowBox[{"4", 
          StyleBox["Dd", "TI"], 
          StyleBox["*", "TI"], "\[Tau]"}]]}], "]"}]}], ")"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x1", ",", "y1", ",", "z1"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x2", ",", "y2", ",", "z2"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x3", ",", "y3", ",", "z3"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x4", ",", "y4", ",", "z4"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z1"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z2"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z3"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z4"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.51773949613105*^9, 3.517739517582049*^9}, 
   3.517741330479536*^9, 3.517896618935719*^9, {3.519098125042769*^9, 
   3.519098128542161*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"32", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x1", "2"]}], "-", 
         SuperscriptBox["y1", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x2", "2"]}], "-", 
         SuperscriptBox["y2", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x3", "2"]}], "-", 
         SuperscriptBox["y3", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x4", "2"]}], "-", 
         SuperscriptBox["y4", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z1", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z2", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z3", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z4", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z1", "-", "z3"}], ")"}], "2"]}], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z1", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z1", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z2", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z3", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z4", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{
     RowBox[{"x1", "-", "x2"}], ",", 
     RowBox[{"y1", "-", "y2"}], ",", 
     RowBox[{"z1", "-", "z2"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5177395267774*^9, 3.517741350083202*^9, 
  3.517896624601677*^9, 3.519036956347492*^9, 3.519098734747005*^9, 
  3.519106748689521*^9, 3.5191071240089607`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g3int", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z1_", ",", "z2_", ",", "z3_", ",", "z4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"chi", "^", "4"}], "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", "*", "\[Pi]", "*", 
          StyleBox["Dd", "TI"], 
          StyleBox["*", "TI"], "\[Tau]"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"3", "/", "2"}], ")"}]}]], "cm", "*", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{
        RowBox[{"x1", "-", "x2"}], ",", 
        RowBox[{"y1", "-", "y2"}], ",", 
        RowBox[{"z1", "-", "z2"}]}], "]"}], 
      RowBox[{"DiracDelta", "[", 
       RowBox[{
        RowBox[{"x3", "-", "x4"}], ",", 
        RowBox[{"y3", "-", "y4"}], ",", 
        RowBox[{"z3", "-", "z4"}]}], "]"}], 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z1", "-", "z3"}], ")"}], "^", "2"}]}], 
         RowBox[{"4", 
          StyleBox["Dd", "TI"], 
          StyleBox["*", "TI"], "\[Tau]"}]]}], "]"}]}], ")"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x1", ",", "y1", ",", "z1"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x2", ",", "y2", ",", "z2"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x3", ",", "y3", ",", "z3"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x4", ",", "y4", ",", "z4"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z1"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z2"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z3"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z4"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517739534067135*^9, 3.5177395553979673`*^9}, 
   3.5177413324679193`*^9, {3.517896633108755*^9, 3.5178966397322493`*^9}, {
   3.51909811674541*^9, 3.519098119922235*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"128", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x1", "2"]}], "-", 
         SuperscriptBox["y1", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x2", "2"]}], "-", 
         SuperscriptBox["y2", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x3", "2"]}], "-", 
         SuperscriptBox["y3", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x4", "2"]}], "-", 
         SuperscriptBox["y4", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z1", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z2", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z3", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z4", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z1", "-", "z3"}], ")"}], "2"]}], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z1", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z1", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z2", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z3", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z4", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{
     RowBox[{"x1", "-", "x2"}], ",", 
     RowBox[{"y1", "-", "y2"}], ",", 
     RowBox[{"z1", "-", "z2"}]}], "]"}], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{
     RowBox[{"x3", "-", "x4"}], ",", 
     RowBox[{"y3", "-", "y4"}], ",", 
     RowBox[{"z3", "-", "z4"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5177395590746803`*^9, 3.517741350333251*^9, 
  3.517896647109189*^9, 3.519036956393388*^9, 3.519098734796955*^9, 
  3.5191067487234583`*^9, 3.519107124133959*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g4int", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z1_", ",", "z2_", ",", "z3_", ",", "z4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"chi", "^", "4"}], "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["cm", "2"], 
       RowBox[{"32", 
        SuperscriptBox["\[Pi]", "3"], 
        SuperscriptBox[
         StyleBox["Dd", "TI"], "3"], 
        SuperscriptBox["\[Tau]", "3"]}]], 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z1", "-", "z3"}], ")"}], "^", "2"}]}], 
         RowBox[{"4", 
          StyleBox["Dd", "TI"], 
          StyleBox["*", "TI"], "\[Tau]"}]]}], "]"}], 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x2", "-", "x4"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y2", "-", "y4"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z2", "-", "z4"}], ")"}], "^", "2"}]}], 
         RowBox[{"4", 
          StyleBox["Dd", "TI"], 
          StyleBox["*", "TI"], "\[Tau]"}]]}], "]"}]}], ")"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x1", ",", "y1", ",", "z1"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x2", ",", "y2", ",", "z2"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x3", ",", "y3", ",", "z3"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x4", ",", "y4", ",", "z4"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z1"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z2"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z3"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z4"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517739565059408*^9, 3.517739576185101*^9}, 
   3.517741334264599*^9, {3.517896652783433*^9, 3.517896663550927*^9}, {
   3.519098104154313*^9, 3.5190981086983147`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"512", " ", 
    SuperscriptBox["Dd", "3"], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["\[Tau]", "3"]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x1", "2"]}], "-", 
         SuperscriptBox["y1", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x2", "2"]}], "-", 
         SuperscriptBox["y2", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x3", "2"]}], "-", 
         SuperscriptBox["y3", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x4", "2"]}], "-", 
         SuperscriptBox["y4", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z1", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z2", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z3", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z4", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z1", "-", "z3"}], ")"}], "2"]}], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x2", "-", "x4"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y2", "-", "y4"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z2", "-", "z4"}], ")"}], "2"]}], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z1", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z1", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z2", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z3", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z4", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.5177395794695063`*^9, 3.517741350427519*^9, 
  3.517896666220254*^9, 3.5190369564261637`*^9, 3.519098734848068*^9, 
  3.519106748758523*^9, 3.519107124477704*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The mean intensity Imean according to B7 simplified\
\>", "Section",
 CellChangeTimes->{{3.519036404523033*^9, 3.51903643347304*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"imeanint", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "y1_", ",", "y2_", ",", "z1_", ",", "z2_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"chi", "^", "2"}], "*", 
    RowBox[{"cm", "^", "2"}], "*", 
    RowBox[{"Aq", "[", 
     RowBox[{"x1", ",", "y1", ",", "z1"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x2", ",", "y2", ",", "z2"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z1"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z2"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519098704547945*^9, 3.5190987071267*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  SuperscriptBox["Aq0", "2"], " ", 
  SuperscriptBox["chi", "2"], " ", 
  SuperscriptBox["cm", "2"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    FractionBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x1", "2"]}], "-", 
        SuperscriptBox["y1", "2"]}], ")"}]}], 
     SuperscriptBox["w0", "2"]], "+", 
    FractionBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x2", "2"]}], "-", 
        SuperscriptBox["y2", "2"]}], ")"}]}], 
     SuperscriptBox["w0", "2"]], "-", 
    FractionBox[
     RowBox[{"q", " ", 
      SuperscriptBox["z1", "2"]}], 
     SuperscriptBox["z0", "2"]], "-", 
    FractionBox[
     RowBox[{"q", " ", 
      SuperscriptBox["z2", "2"]}], 
     SuperscriptBox["z0", "2"]]}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "z1", " ", "\[Kappa]"}]], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "z1", " ", "\[Kappa]"}]]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "z2", " ", "\[Kappa]"}]], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5190369564599047`*^9, 3.5190987348934803`*^9, 
  3.5191067488401337`*^9, 3.51910712482145*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"imeanint2", "[", 
   RowBox[{"x1_", ",", "y1_", ",", "z1_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"chi", "^", "2"}], "*", "cm", "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Aq", "[", 
       RowBox[{"x1", ",", "y1", ",", "z1"}], "]"}], ")"}], "^", "2"}], "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Kappa]", "*", "z1"}], "]"}], ")"}], "^", "2"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5190987130491743`*^9, 3.5190987158684072`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  SuperscriptBox["Aq0", "2"], " ", 
  SuperscriptBox["chi", "2"], " ", "cm", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x1", "2"]}], "-", 
        SuperscriptBox["y1", "2"]}], ")"}]}], 
     SuperscriptBox["w0", "2"]], "-", 
    FractionBox[
     RowBox[{"2", " ", "q", " ", 
      SuperscriptBox["z1", "2"]}], 
     SuperscriptBox["z0", "2"]]}]], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z1", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z1", " ", "\[Kappa]"}]]}], ")"}], 
   "2"]}]], "Output",
 CellChangeTimes->{3.5190369565049877`*^9, 3.519098734947557*^9, 
  3.5191067488715067`*^9, 3.5191071252276945`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assumptions", "Section",
 CellChangeTimes->{{3.519097759869207*^9, 3.5190977785960703`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Element", "[", 
     RowBox[{"w0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"b", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"Aq0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Tau]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"cm", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"Dd", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"q", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Kappa]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Dd", ">", "0"}], "&&", 
    RowBox[{"\[Tau]", ">", "0"}], "&&", 
    RowBox[{"w0", ">", "0"}], "&&", 
    RowBox[{"z0", ">", "0"}], "&&", 
    RowBox[{"Aq0", ">", "0"}], "&&", 
    RowBox[{"q", "\[GreaterEqual]", "1"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.519097780783361*^9, 3.519097783919778*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"b", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Aq0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"\[Tau]", "\[Element]", "Reals"}], "&&", 
   RowBox[{"cm", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Dd", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"q", "\[Element]", "Reals"}], "&&", 
   RowBox[{"\[Kappa]", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Dd", ">", "0"}], "&&", 
   RowBox[{"\[Tau]", ">", "0"}], "&&", 
   RowBox[{"w0", ">", "0"}], "&&", 
   RowBox[{"z0", ">", "0"}], "&&", 
   RowBox[{"Aq0", ">", "0"}], "&&", 
   RowBox[{"q", "\[GreaterEqual]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{3.519097785842445*^9, 3.519098734981737*^9, 
  3.519106748907379*^9, 3.5191071253839426`*^9, 3.519235330531033*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute g1", "Section",
 CellChangeTimes->{{3.517712163185369*^9, 3.5177121650259*^9}, 
   3.517739251246941*^9}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[CellGroupData[{

Cell["z Integration", "Subsection",
 CellChangeTimes->{{3.517721610471263*^9, 3.5177216121251574`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11z1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z2_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"g1int", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z1", ",", "z2", ",", "z3", ",", "z4", ",", "\[Tau]"}],
       "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.51763303819493*^9, {3.517633099950801*^9, 3.51763311391716*^9}, {
   3.51763466699538*^9, 3.5176346678836727`*^9}, {3.5176354194384413`*^9, 
   3.5176354226762*^9}, {3.517635454414604*^9, 3.517635457311709*^9}, 
   3.517719723321267*^9, 3.5177392473741903`*^9, {3.517741365354589*^9, 
   3.517741393930015*^9}, {3.519097802058515*^9, 3.5190978157242823`*^9}, 
   3.519106295595005*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"16", " ", "Dd", " ", "\[Pi]", " ", "\[Tau]", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "-", 
           RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["y1", "2"], "-", 
           RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
           SuperscriptBox["y3", "2"], "-", 
           RowBox[{
           "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z3", " ", "\[Kappa]", 
            " ", "\[Tau]"}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
       FractionBox[
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y1", "2"], "+", 
              SuperscriptBox["y2", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x1", "2"], " ", 
               SuperscriptBox["z0", "2"]}], "-", 
              RowBox[{"2", " ", "x1", " ", "x3", " ", 
               SuperscriptBox["z0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["x3", "2"], " ", 
               SuperscriptBox["z0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["y1", "2"], " ", 
               SuperscriptBox["z0", "2"]}], "-", 
              RowBox[{"2", " ", "y1", " ", "y3", " ", 
               SuperscriptBox["z0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["y3", "2"], " ", 
               SuperscriptBox["z0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["z2", "2"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["z3", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["z4", "2"]}], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["z2", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["z4", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
          ")"}]}], 
        SuperscriptBox["w0", "2"]]}], 
      RowBox[{"4", " ", 
       SuperscriptBox["z0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z2", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z3", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z4", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["z0", "2"], " ", "z3", " ", "\[Kappa]"}], 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]}], ")"}], 
   " ", "z0"}]}]], "Output",
 CellChangeTimes->{3.5176330865836887`*^9, 3.5176346634287243`*^9, 
  3.517635414307756*^9, 3.517635448818797*^9, 3.517635809040265*^9, 
  3.517637596707975*^9, 3.5176424646560287`*^9, 3.5177216588898983`*^9, 
  3.5177394821171627`*^9, 3.5177417600076*^9, 3.517897050767387*^9, 
  3.519037047444858*^9, 3.519098899004342*^9, 3.519106867967887*^9, 
  3.51910737442763*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11z2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint11z1", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z2", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"z2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517636187272016*^9, 3.517636267436021*^9}, {
   3.519097829422256*^9, 3.519097836626338*^9}, 3.519106299058486*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", "Dd", " ", 
    SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
    SqrtBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y1", "2"], "+", 
              SuperscriptBox["y2", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "-", 
              RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["y1", "2"], "-", 
              RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
              SuperscriptBox["y3", "2"], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["z3", "2"]}], "+", 
              SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}]}], 
        SuperscriptBox["w0", "2"]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
       FractionBox[
        RowBox[{"16", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x1", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["x2", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["x3", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["x4", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["y1", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["y2", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["y3", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["y4", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z3", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z4", "2"]}]}], ")"}], " ", "\[Tau]"}], 
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "2"]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "-", 
           RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["y1", "2"], "-", 
           RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
           SuperscriptBox["y3", "2"], "-", 
           RowBox[{
           "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z3", " ", "\[Kappa]", 
            " ", "\[Tau]"}], "+", 
           RowBox[{"8", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
        RowBox[{"Dd", " ", "\[Tau]"}]]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z3", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z4", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["z0", "2"], " ", "z3", " ", "\[Kappa]"}], 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]}], ")"}], 
   " ", 
   SuperscriptBox["z0", "2"]}]}]], "Output",
 CellChangeTimes->{3.517636295580174*^9, 3.517637618818699*^9, 
  3.51764340506273*^9, 3.517721682228327*^9, 3.51774177919895*^9, 
  3.517897070026525*^9, 3.519037067899403*^9, 3.519099024040762*^9, 
  3.5191068807670813`*^9, 3.5191075131758537`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11z3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint11z2", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z3", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517636311248352*^9, 3.517636335586735*^9}, {
   3.519097841347066*^9, 3.519097847679796*^9}, 3.5191063027768507`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
    SqrtBox[
     RowBox[{"2", "+", 
      FractionBox[
       RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}], 
       SuperscriptBox["z0", "2"]]}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"3", " ", "Dd", " ", 
        SuperscriptBox["w0", "2"], " ", 
        SuperscriptBox["z0", "8"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
       RowBox[{"32", " ", 
        SuperscriptBox["Dd", "3"], " ", 
        SuperscriptBox["q", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x1", "2"], " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["x2", "2"], " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["x3", "2"], " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["x4", "2"], " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["y1", "2"], " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["y2", "2"], " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["y3", "2"], " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["y4", "2"], " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z4", "2"]}]}], ")"}], " ", 
        SuperscriptBox["\[Tau]", "3"]}], "+", 
       RowBox[{"q", " ", 
        SuperscriptBox["w0", "2"], " ", 
        SuperscriptBox["z0", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "-", 
          RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
          SuperscriptBox["x3", "2"], "+", 
          SuperscriptBox["y1", "2"], "-", 
          RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
          SuperscriptBox["y3", "2"], "+", 
          RowBox[{
          "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", "\[Kappa]", 
           " ", "\[Tau]"}], "+", 
          RowBox[{"18", " ", 
           SuperscriptBox["Dd", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["Dd", "2"], " ", 
        SuperscriptBox["q", "3"], " ", 
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Tau]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}], " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "-", 
             RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["y1", "2"], "-", 
             RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
             SuperscriptBox["y3", "2"], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["z4", "2"]}], "+", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", "\[Kappa]",
               " ", "\[Tau]"}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", "Dd", " ", 
        SuperscriptBox["q", "2"], " ", 
        SuperscriptBox["z0", "4"], " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}], " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["x1", "2"]}], "-", 
             RowBox[{"6", " ", "x1", " ", "x3"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["x3", "2"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["y1", "2"]}], "-", 
             RowBox[{"6", " ", "y1", " ", "y3"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["y3", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["z4", "2"]}], "+", 
             RowBox[{
             "12", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
              "\[Kappa]", " ", "\[Tau]"}], "+", 
             RowBox[{"16", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"], " ", 
              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
      RowBox[{"4", " ", "Dd", " ", "q", " ", 
       SuperscriptBox["w0", "2"], " ", 
       SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["Dd", "2"], " ", "q", " ", 
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        SuperscriptBox["\[Tau]", "2"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
       RowBox[{"2", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
    ")"}], " ", 
   SuperscriptBox["z0", "2"]}]}]], "Output",
 CellChangeTimes->{3.51763637560223*^9, 3.517637644961411*^9, 
  3.517643435903845*^9, 3.517721707258626*^9, 3.517741804872692*^9, 
  3.517897095339232*^9, 3.51903710176648*^9, 3.519099199041984*^9, 
  3.5191077568914843`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11z4", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint11z3", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z4", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517636540235422*^9, 3.5176365690334044`*^9}, {
  3.5190978540412607`*^9, 3.519097858883366*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["q", 
     RowBox[{"3", "/", "2"}]], " ", "\[Tau]", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y1", "2"], "+", 
            SuperscriptBox["y2", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"5", "+", 
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["2", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
              
              FractionBox["1", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
             ")"}]}]}], ")"}]}], "q"]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["Dd", "2"], " ", "q", " ", 
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        SuperscriptBox["\[Tau]", "2"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
       RowBox[{"2", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
    ")"}], " ", 
   SqrtBox["\[Pi]"], " ", 
   SuperscriptBox["z0", "4"]}]}]], "Output",
 CellChangeTimes->{3.517636555073791*^9, 3.51763659919344*^9, 
  3.517637673037059*^9, 3.51764347218535*^9, 3.517721735289556*^9, 
  3.517741833113982*^9, 3.517897123561556*^9, 3.519037143715172*^9, 
  3.519099302893367*^9, 3.519108058575123*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y Integration", "Subsection",
 CellChangeTimes->{{3.517721620517411*^9, 3.517721622277459*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11y1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y2_", ",", "y3_", ",", 
    "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint11z4", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5176366094794903`*^9, 3.517636627910242*^9}, {
   3.519097863245084*^9, 3.51909786881468*^9}, 3.519106308248249*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "3"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            SuperscriptBox["x2", "2"], "-", 
            RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y2", "2"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["y3", "2"]}], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"16", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y2", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "4"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "\[Pi]", " ", "w0", " ", 
     SuperscriptBox["z0", "4"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SqrtBox["2"], " ", 
     SuperscriptBox["q", 
      RowBox[{"3", "/", "2"}]], " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "3"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", "Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["y3", "2"]}], "+", 
               SuperscriptBox["y4", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "3"], " ", 
          SuperscriptBox["q", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y2", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "3"]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["y3", "2"]}], "+", 
               SuperscriptBox["y4", "2"], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "\[Pi]", " ", "w0", " ", 
     SuperscriptBox["z0", "4"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SqrtBox["2"], " ", 
     SuperscriptBox["q", 
      RowBox[{"3", "/", "2"}]], " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.5176366724376574`*^9, 3.517637711807805*^9, 
  3.51764352306616*^9, 3.517721780603376*^9, 3.517741872514039*^9, 
  3.517897162751515*^9, 3.519037236149064*^9, 3.5190994478117523`*^9, 
  3.519108252760137*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11y2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y3_", ",", "y4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint11y1", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y2", ",", "y3", ",", "y4", 
       ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517636680141523*^9, 3.5176366968168507`*^9}, {
   3.519097873037465*^9, 3.519097877841151*^9}, 3.519106311055794*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "3"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            SuperscriptBox["x2", "2"], "-", 
            RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["y3", "2"]}], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"16", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "4"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", 
     SuperscriptBox["\[Pi]", 
      RowBox[{"3", "/", "2"}]], " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "4"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SqrtBox["2"], " ", 
     SuperscriptBox["q", "2"], " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "3"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", "Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["y3", "2"]}], "+", 
               SuperscriptBox["y4", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "3"], " ", 
          SuperscriptBox["q", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "3"]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["y3", "2"]}], "+", 
               SuperscriptBox["y4", "2"], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", 
     SuperscriptBox["\[Pi]", 
      RowBox[{"3", "/", "2"}]], " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "4"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SqrtBox["2"], " ", 
     SuperscriptBox["q", "2"], " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.517636727325078*^9, 3.5176377304696093`*^9, 
  3.517721804675577*^9, 3.517741891188109*^9, 3.51789718180632*^9, 
  3.519037276279558*^9, 3.5190994595070753`*^9, 3.5191083347590876`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11y3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint11y2", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y3", ",", "y4", ",", 
       "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y3", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.51763673699617*^9, 3.517636746056753*^9}, {
   3.519097881629058*^9, 3.519097889396885*^9}, 3.519106314655726*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "4"], " ", 
    SqrtBox[
     FractionBox["1", 
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "2"]}]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "3"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"2", " ", "Dd", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "-", 
            RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
            SuperscriptBox["x3", "2"], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", 
     SuperscriptBox["\[Pi]", "2"], " ", 
     SuperscriptBox["w0", "3"], " ", 
     SuperscriptBox["z0", "4"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox["q", "2"], " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.51763676849699*^9, 3.517637758310746*^9, 
  3.517721833135168*^9, 3.517741919469*^9, 3.517897208577386*^9, 
  3.519037307630803*^9, 3.5190994664571877`*^9, 3.519108409805002*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11y4", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}],
   "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint11y3", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y4", ",", "\[Tau]"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y4", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517636780401519*^9, 3.517636790711196*^9}, {
  3.519097895613007*^9, 3.519097900930365*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"], "+", 
          SuperscriptBox["x3", "2"], "+", 
          SuperscriptBox["x4", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{
        RowBox[{"2", " ", "q", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]]}], ")"}], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"5", "/", "2"}]], " ", 
   SuperscriptBox["w0", "4"], " ", 
   SuperscriptBox["z0", "4"]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["q", 
    RowBox[{"5", "/", "2"}]], " ", 
   SqrtBox[
    RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
      ")"}]}]]}]]], "Output",
 CellChangeTimes->{3.51763680533506*^9, 3.517637768735571*^9, 
  3.517721843387409*^9, 3.517741930244686*^9, 3.5178972203600483`*^9, 
  3.519037331954183*^9, 3.519099478134754*^9, 3.5191084826634445`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x Integration", "Subsection",
 CellChangeTimes->{{3.517721631965609*^9, 3.517721633861856*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11x1", "[", 
   RowBox[{"x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint11y4", "[", 
      RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.51763702885286*^9, 3.517637044085169*^9}, {
   3.5190979091571217`*^9, 3.51909791429643*^9}, 3.519106323884988*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["q", "2"], " ", 
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x2", "2"], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["x3", "2"]}], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["w0", "4"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}]}], 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           SuperscriptBox["x3", "2"], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           RowBox[{"q", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
          "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["x3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["w0", "2"], " ", 
               SuperscriptBox["z0", "2"]}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]}], 
             ")"}]}], 
           RowBox[{"Dd", " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
          "-", 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"4", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x2", "2"], "+", 
                 SuperscriptBox["x3", "2"], "+", 
                 SuperscriptBox["x4", "2"]}], ")"}]}], 
              SuperscriptBox["w0", "2"]], "+", 
             FractionBox[
              RowBox[{"2", " ", 
               SuperscriptBox["x3", "2"]}], 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
            ")"}]}]}], ")"}]}]]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "5"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["q", 
     RowBox[{"5", "/", "2"}]], " ", 
    SqrtBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "4"], "+", 
        RowBox[{"6", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["Dd", "2"], " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.517637069901671*^9, 3.517637790217033*^9, 
  3.517721864829615*^9, 3.517741951830454*^9, 3.5178905531788197`*^9, 
  3.517897242081526*^9, 3.519037384710588*^9, 3.519100510203484*^9, 
  3.5191085288347282`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11x2", "[", 
   RowBox[{"x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint11x1", "[", 
      RowBox[{"x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5176419665398483`*^9, 3.517641979452293*^9}, {
   3.519097919478857*^9, 3.519097924102199*^9}, 3.51910632725484*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["x3", "2"]}], "+", 
           SuperscriptBox["x4", "2"]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["w0", "4"], " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["q", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}]}], 
       RowBox[{"q", " ", 
        SuperscriptBox["w0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"7", "/", "2"}]], " ", 
    SuperscriptBox["w0", "6"], " ", 
    SuperscriptBox["z0", "4"]}], 
   RowBox[{
    SuperscriptBox["q", "3"], " ", 
    SqrtBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "4"], "+", 
        RowBox[{"6", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["Dd", "2"], " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "3"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            SuperscriptBox["z0", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"16", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{"2", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", 
     SuperscriptBox["\[Pi]", 
      RowBox[{"7", "/", "2"}]], " ", 
     SuperscriptBox["w0", "6"], " ", 
     SuperscriptBox["z0", "4"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["q", "3"], " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "4"], "+", 
         RowBox[{"6", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}], ")"}]}]}]], "Output",\

 CellChangeTimes->{3.517642001500123*^9, 3.517721882616865*^9, 
  3.517741969809967*^9, 3.517897258304069*^9, 3.519037406208791*^9, 
  3.519100599769169*^9, 3.519108574865389*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11x3", "[", 
   RowBox[{"x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint11x2", "[", 
      RowBox[{"x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x3", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517642026806909*^9, 3.517642042110222*^9}, {
   3.5190979284213247`*^9, 3.5190979351357527`*^9}, 3.51910633064662*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["x4", "2"], " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["q", "3"], " ", 
         SuperscriptBox["x4", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}]}], 
       RowBox[{"2", " ", "q", " ", 
        SuperscriptBox["w0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["w0", "7"], " ", 
    SuperscriptBox["z0", "4"]}], 
   RowBox[{
    SqrtBox["2"], " ", 
    SuperscriptBox["q", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         SuperscriptBox["x4", "2"]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"]}]], " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["w0", "7"], " ", 
    SuperscriptBox["z0", "4"]}], 
   RowBox[{
    SqrtBox["2"], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["q", "8"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], "2"], 
      " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
       ")"}]}]]}]]}]], "Output",
 CellChangeTimes->{3.519108615208623*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        SuperscriptBox["x4", "2"]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "q"]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{
        RowBox[{"2", " ", "q", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]]}], ")"}], " ", 
   SuperscriptBox["\[Pi]", "4"], " ", 
   SuperscriptBox["w0", "7"], " ", 
   SuperscriptBox["z0", "4"]}], 
  RowBox[{
   SqrtBox["2"], " ", 
   SuperscriptBox["q", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["w0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]], "Input",
 CellChangeTimes->{{3.5191017868537617`*^9, 3.519101795215662*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        SuperscriptBox["x4", "2"]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "q"]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{
        RowBox[{"2", " ", "q", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]]}], ")"}], " ", 
   SuperscriptBox["\[Pi]", "4"], " ", 
   SuperscriptBox["w0", "7"], " ", 
   SuperscriptBox["z0", "4"]}], 
  RowBox[{
   SqrtBox["2"], " ", 
   SuperscriptBox["q", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["w0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]], "Output",
 CellChangeTimes->{3.5191086153023715`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11x4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint11x3", "[", 
      RowBox[{"x4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x4", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517642065395732*^9, 3.517642077000885*^9}, {
   3.519097941920683*^9, 3.519097947882566*^9}, 3.519106350853632*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "4"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
      RowBox[{"2", " ", "q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "4"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
       RowBox[{"2", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
    ")"}], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"9", "/", "2"}]], " ", 
   SuperscriptBox["w0", "8"], " ", 
   SuperscriptBox["z0", "4"]}], 
  RowBox[{
   SqrtBox["2"], " ", 
   SuperscriptBox["q", 
    RowBox[{"9", "/", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["w0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]], "Output",
 CellChangeTimes->{3.5176420836307287`*^9, 3.5177218973655157`*^9, 
  3.5177419840325336`*^9, 3.517897273011977*^9, 3.519037426339655*^9, 
  3.519100620261445*^9, 3.519108629020946*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g1", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"myint11x4", "[", "\[Tau]", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517643533519837*^9, 3.51764356603941*^9}, 
   3.5177414543318853`*^9, 3.519097955181872*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "4"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
      RowBox[{"2", " ", "q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "4"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
       RowBox[{"2", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
    ")"}], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"9", "/", "2"}]], " ", 
   SuperscriptBox["w0", "8"], " ", 
   SuperscriptBox["z0", "4"]}], 
  RowBox[{
   SqrtBox["2"], " ", 
   SuperscriptBox["q", 
    RowBox[{"9", "/", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["w0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]], "Output",
 CellChangeTimes->{3.517643569733617*^9, 3.517721943401599*^9, 
  3.517741985192861*^9, 3.5178972740083923`*^9, 3.5190374274499617`*^9, 
  3.519100620327722*^9, 3.5191086320834064`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute g2", "Section",
 CellChangeTimes->{{3.517707100647127*^9, 3.517707115708559*^9}, {
  3.517711985271744*^9, 3.5177120204075327`*^9}, {3.517742099244213*^9, 
  3.5177421015289297`*^9}}],

Cell[CellGroupData[{

Cell["z Integration", "Subsection",
 CellChangeTimes->{{3.5177073652592087`*^9, 3.517707367322884*^9}, 
   3.5177120318157253`*^9, 3.517742159347653*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2z1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z2_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"g2int", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z1", ",", "z2", ",", "z3", ",", "z4", ",", "\[Tau]"}],
       "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517707126778647*^9, 3.517707186958552*^9}, {
   3.5177074575839643`*^9, 3.5177074584079113`*^9}, {3.5177077003425093`*^9, 
   3.517707718625432*^9}, {3.517718867619732*^9, 3.517718879308165*^9}, 
   3.517719304970758*^9, 3.517742105944983*^9, {3.517742170858178*^9, 
   3.517742218463476*^9}, {3.5177422690729027`*^9, 3.5177422695843773`*^9}, {
   3.5190979668051157`*^9, 3.519097971831358*^9}, {3.519098064055744*^9, 
   3.5190980775258512`*^9}, 3.519106355119066*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"32", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"(", 
      RowBox[{"z2", "+", "z3", "+", "z4"}], ")"}], " ", "\[Kappa]"}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x1", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "-", 
             RowBox[{"2", " ", "x1", " ", "x3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["x3", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["y1", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "-", 
             RowBox[{"2", " ", "y1", " ", "y3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["y3", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["z2", "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["z0", "2"], " ", "z2", " ", "z3"}], "+", 
             RowBox[{
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["z3", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z2", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "-", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", "Dd", " ", 
              SuperscriptBox["z0", "2"], " ", "z2", " ", "\[Kappa]", " ", 
              "\[Tau]"}]}], ")"}]}]}], 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x1", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "-", 
             RowBox[{"2", " ", "x1", " ", "x3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["x3", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["y1", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "-", 
             RowBox[{"2", " ", "y1", " ", "y3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["y3", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["z2", "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["z0", "2"], " ", "z2", " ", "z3"}], "+", 
             RowBox[{
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["z3", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z2", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", "Dd", " ", 
              SuperscriptBox["z0", "2"], " ", "z2", " ", "\[Kappa]", " ", 
              "\[Tau]"}]}], ")"}]}]}], 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.517707439600347*^9, 3.517707651823756*^9, 
  3.517707733375701*^9, 3.5177188983366423`*^9, 3.517719320273962*^9, 
  3.517742231545885*^9, 3.517742277566556*^9, 3.517901450315584*^9, 
  3.5190374364566708`*^9, 3.519100644391066*^9, 3.519108645255113*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2z2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2z1", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z2", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"z2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517707436850107*^9, 3.517707438662883*^9}, {
   3.5177076656099043`*^9, 3.517707692330924*^9}, {3.5177077330531263`*^9, 
   3.517707761029437*^9}, {3.517707809587075*^9, 3.5177078102618847`*^9}, {
   3.517707887882419*^9, 3.517707914077277*^9}, {3.517707975483398*^9, 
   3.517707990453388*^9}, 3.517718908052795*^9, {3.517742237592198*^9, 
   3.5177423026726437`*^9}, {3.517742627763577*^9, 3.51774263595721*^9}, {
   3.519097975567315*^9, 3.519097981743099*^9}, 3.5190980255635157`*^9, {
   3.519098062864303*^9, 3.519098082797646*^9}, 3.519106357823009*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"32", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"(", 
         RowBox[{"z3", "+", "z4"}], ")"}], " ", "\[Kappa]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            SqrtBox[
             RowBox[{"Dd", " ", "\[Tau]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]],
             ")"}]}], 
          RowBox[{"2", " ", "Dd", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             FractionBox["1", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"4", " ", "q", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["x1", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["x2", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["x3", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["x4", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["y1", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["y2", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["y3", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["y4", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["w0", "2"], " ", 
                    SuperscriptBox["z3", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["w0", "2"], " ", 
                    SuperscriptBox["z4", "2"]}]}], ")"}]}], 
                 RowBox[{
                  SuperscriptBox["w0", "2"], " ", 
                  SuperscriptBox["z0", "2"]}]]}], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["x1", "2"], "-", 
                 RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
                 SuperscriptBox["x3", "2"], "+", 
                 SuperscriptBox["y1", "2"], "-", 
                 RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
                 SuperscriptBox["y3", "2"], "+", 
                 SuperscriptBox["z3", "2"]}], 
                RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["z0", "2"], " ", 
                 SuperscriptBox["z3", "2"]}], 
                RowBox[{
                 RowBox[{"Dd", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", 
                  SuperscriptBox["Dd", "2"], " ", "q", " ", 
                  SuperscriptBox["\[Tau]", "2"]}]}]]}], ")"}]}]], " ", 
           SqrtBox["\[Pi]"], " ", "z0", " ", "\[Tau]", " ", 
           RowBox[{"DiracDelta", "[", 
            RowBox[{"x1", "-", "x2"}], "]"}], " ", 
           RowBox[{"DiracDelta", "[", 
            RowBox[{"y1", "-", "y2"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"Erf", "[", 
              FractionBox[
               RowBox[{"z0", " ", "z3"}], 
               RowBox[{"2", " ", 
                SqrtBox[
                 RowBox[{"Dd", " ", "\[Tau]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}]]}]], "]"}]}], ")"}]}]}]}], "+", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"z3", "-", 
                 RowBox[{
                 "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                  "\[Tau]"}]}], ")"}], "2"]}], 
             RowBox[{"Dd", " ", "\[Tau]"}]]], ")"}]}], 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x1", "2"], "+", 
                 SuperscriptBox["x2", "2"], "+", 
                 SuperscriptBox["x3", "2"], "+", 
                 SuperscriptBox["x4", "2"], "+", 
                 SuperscriptBox["y1", "2"], "+", 
                 SuperscriptBox["y2", "2"], "+", 
                 SuperscriptBox["y3", "2"], "+", 
                 SuperscriptBox["y4", "2"]}], ")"}], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}],
               "+", 
              RowBox[{
               SuperscriptBox["w0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "-", 
                 RowBox[{"2", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
                 RowBox[{"16", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"12", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"4", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", "\[ImaginaryI]", " ", "Dd", " ", 
                  SuperscriptBox["z0", "4"], " ", "z3", " ", "\[Kappa]", " ", 
                  "\[Tau]"}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["z0", "4"], " ", 
                  SuperscriptBox["\[Kappa]", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "-", 
                 RowBox[{"2", " ", "x1", " ", "x3", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  SuperscriptBox["x3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
                ")"}]}]}], 
             RowBox[{"4", " ", "Dd", " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]]}]], " ", 
          SqrtBox["\[Pi]"], " ", "z0", " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"x1", "-", "x2"}], "]"}], " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"y1", "-", "y2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z3", "-", 
                RowBox[{
                "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                 "\[Tau]"}]}], ")"}], "2"]], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z3", "-", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                "\[Tau]"}]}], ")"}], " ", 
             RowBox[{"Erf", "[", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"z3", "-", 
                    RowBox[{
                    "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", 
                    " ", "\[Tau]"}]}], ")"}], "2"]}], 
                 RowBox[{"Dd", " ", "\[Tau]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}]]]}], "]"}]}]}], ")"}]}]}], "+", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"z3", "+", 
                 RowBox[{
                 "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                  "\[Tau]"}]}], ")"}], "2"]}], 
             RowBox[{"Dd", " ", "\[Tau]"}]]], ")"}]}], 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x1", "2"], "+", 
                 SuperscriptBox["x2", "2"], "+", 
                 SuperscriptBox["x3", "2"], "+", 
                 SuperscriptBox["x4", "2"], "+", 
                 SuperscriptBox["y1", "2"], "+", 
                 SuperscriptBox["y2", "2"], "+", 
                 SuperscriptBox["y3", "2"], "+", 
                 SuperscriptBox["y4", "2"]}], ")"}], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}],
               "+", 
              RowBox[{
               SuperscriptBox["w0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "-", 
                 RowBox[{"2", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
                 RowBox[{"16", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"12", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"4", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "-", 
                 RowBox[{"8", " ", "\[ImaginaryI]", " ", "Dd", " ", 
                  SuperscriptBox["z0", "4"], " ", "z3", " ", "\[Kappa]", " ", 
                  "\[Tau]"}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["z0", "4"], " ", 
                  SuperscriptBox["\[Kappa]", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "-", 
                 RowBox[{"2", " ", "x1", " ", "x3", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  SuperscriptBox["x3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
                ")"}]}]}], 
             RowBox[{"4", " ", "Dd", " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]]}]], " ", 
          SqrtBox["\[Pi]"], " ", "z0", " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"x1", "-", "x2"}], "]"}], " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"y1", "-", "y2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z3", "+", 
                RowBox[{
                "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                 "\[Tau]"}]}], ")"}], "2"]], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z3", "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                "\[Tau]"}]}], ")"}], " ", 
             RowBox[{"Erf", "[", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"z3", "+", 
                    RowBox[{
                    "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", 
                    " ", "\[Tau]"}]}], ")"}], "2"]}], 
                 RowBox[{"Dd", " ", "\[Tau]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}]]]}], "]"}]}]}], ")"}]}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"(", 
         RowBox[{"z3", "+", "z4"}], ")"}], " ", "\[Kappa]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           SqrtBox[
            RowBox[{"Dd", " ", "\[Tau]", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
           ")"}]}], 
         RowBox[{"2", " ", "Dd", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            FractionBox["1", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"4", " ", "q", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["x1", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["x2", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["x3", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["x4", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["y1", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["y2", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["y3", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["y4", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["w0", "2"], " ", 
                    SuperscriptBox["z3", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["w0", "2"], " ", 
                    SuperscriptBox["z4", "2"]}]}], ")"}]}], 
                RowBox[{
                 SuperscriptBox["w0", "2"], " ", 
                 SuperscriptBox["z0", "2"]}]]}], "-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["x1", "2"], "-", 
                RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
                SuperscriptBox["x3", "2"], "+", 
                SuperscriptBox["y1", "2"], "-", 
                RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
                SuperscriptBox["y3", "2"], "+", 
                SuperscriptBox["z3", "2"]}], 
               RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
              FractionBox[
               RowBox[{
                SuperscriptBox["z0", "2"], " ", 
                SuperscriptBox["z3", "2"]}], 
               RowBox[{
                RowBox[{"Dd", " ", 
                 SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                RowBox[{"8", " ", 
                 SuperscriptBox["Dd", "2"], " ", "q", " ", 
                 SuperscriptBox["\[Tau]", "2"]}]}]]}], ")"}]}]], " ", 
          SqrtBox["\[Pi]"], " ", "z0", " ", "\[Tau]", " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"x1", "-", "x2"}], "]"}], " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"y1", "-", "y2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"Erf", "[", 
             FractionBox[
              RowBox[{"z0", " ", "z3"}], 
              RowBox[{"2", " ", 
               SqrtBox[
                RowBox[{"Dd", " ", "\[Tau]", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["z0", "2"], "+", 
                   RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                  ")"}]}]]}]], "]"}]}], ")"}]}]}], "+", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"z3", "-", 
                 RowBox[{
                 "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                  "\[Tau]"}]}], ")"}], "2"]}], 
             RowBox[{"Dd", " ", "\[Tau]"}]]], ")"}]}], 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x1", "2"], "+", 
                 SuperscriptBox["x2", "2"], "+", 
                 SuperscriptBox["x3", "2"], "+", 
                 SuperscriptBox["x4", "2"], "+", 
                 SuperscriptBox["y1", "2"], "+", 
                 SuperscriptBox["y2", "2"], "+", 
                 SuperscriptBox["y3", "2"], "+", 
                 SuperscriptBox["y4", "2"]}], ")"}], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}],
               "+", 
              RowBox[{
               SuperscriptBox["w0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "-", 
                 RowBox[{"2", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
                 RowBox[{"16", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"12", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"4", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", "\[ImaginaryI]", " ", "Dd", " ", 
                  SuperscriptBox["z0", "4"], " ", "z3", " ", "\[Kappa]", " ", 
                  "\[Tau]"}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["z0", "4"], " ", 
                  SuperscriptBox["\[Kappa]", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "-", 
                 RowBox[{"2", " ", "x1", " ", "x3", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  SuperscriptBox["x3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
                ")"}]}]}], 
             RowBox[{"4", " ", "Dd", " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]]}]], " ", 
          SqrtBox["\[Pi]"], " ", "z0", " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"x1", "-", "x2"}], "]"}], " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"y1", "-", "y2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z3", "-", 
                RowBox[{
                "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                 "\[Tau]"}]}], ")"}], "2"]], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z3", "-", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                "\[Tau]"}]}], ")"}], " ", 
             RowBox[{"Erf", "[", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"z3", "-", 
                    RowBox[{
                    "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", 
                    " ", "\[Tau]"}]}], ")"}], "2"]}], 
                 RowBox[{"Dd", " ", "\[Tau]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}]]]}], "]"}]}]}], ")"}]}]}], "+", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"z3", "+", 
                 RowBox[{
                 "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                  "\[Tau]"}]}], ")"}], "2"]}], 
             RowBox[{"Dd", " ", "\[Tau]"}]]], ")"}]}], 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x1", "2"], "+", 
                 SuperscriptBox["x2", "2"], "+", 
                 SuperscriptBox["x3", "2"], "+", 
                 SuperscriptBox["x4", "2"], "+", 
                 SuperscriptBox["y1", "2"], "+", 
                 SuperscriptBox["y2", "2"], "+", 
                 SuperscriptBox["y3", "2"], "+", 
                 SuperscriptBox["y4", "2"]}], ")"}], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}],
               "+", 
              RowBox[{
               SuperscriptBox["w0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "-", 
                 RowBox[{"2", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
                 RowBox[{"16", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"12", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"4", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "-", 
                 RowBox[{"8", " ", "\[ImaginaryI]", " ", "Dd", " ", 
                  SuperscriptBox["z0", "4"], " ", "z3", " ", "\[Kappa]", " ", 
                  "\[Tau]"}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["z0", "4"], " ", 
                  SuperscriptBox["\[Kappa]", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "-", 
                 RowBox[{"2", " ", "x1", " ", "x3", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  SuperscriptBox["x3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
                ")"}]}]}], 
             RowBox[{"4", " ", "Dd", " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]]}]], " ", 
          SqrtBox["\[Pi]"], " ", "z0", " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"x1", "-", "x2"}], "]"}], " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"y1", "-", "y2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z3", "+", 
                RowBox[{
                "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                 "\[Tau]"}]}], ")"}], "2"]], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z3", "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                "\[Tau]"}]}], ")"}], " ", 
             RowBox[{"Erf", "[", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"z3", "+", 
                    RowBox[{
                    "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", 
                    " ", "\[Tau]"}]}], ")"}], "2"]}], 
                 RowBox[{"Dd", " ", "\[Tau]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}]]]}], "]"}]}]}], ")"}]}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.517707806644844*^9, 3.5177078447251368`*^9, 
  3.517707945042571*^9, 3.51770802769462*^9, 3.5177189188241663`*^9, 
  3.517719334468026*^9, 3.51774261847016*^9, 3.517742779870541*^9, 
  3.517901595761839*^9, 3.519037708112177*^9, 3.519103665763278*^9, 
  3.5191091287645493`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2z3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2z2", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z3", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517707781107938*^9, 3.51770778501499*^9}, {
   3.51770782098004*^9, 3.5177078402536793`*^9}, {3.5177423181997232`*^9, 
   3.517742332801095*^9}, {3.5190981875121117`*^9, 3.519098194025169*^9}, 
   3.519106363398776*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"32", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "Dd", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"Dd", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "6"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["q", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z4", "2"]}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{"3", " ", "q", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["y1", "2"], "-", 
               RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
               SuperscriptBox["y3", "2"], "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                "\[Kappa]", " ", "\[Tau]"}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
            RowBox[{"4", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], "+", 
                  SuperscriptBox["x2", "2"], "+", 
                  SuperscriptBox["x3", "2"], "+", 
                  SuperscriptBox["x4", "2"], "+", 
                  SuperscriptBox["y1", "2"], "+", 
                  SuperscriptBox["y2", "2"], "+", 
                  SuperscriptBox["y3", "2"], "+", 
                  SuperscriptBox["y4", "2"]}], ")"}], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["x1", "2"]}], "-", 
                  RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["x3", "2"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["y1", "2"]}], "-", 
                  RowBox[{"4", " ", "y1", " ", "y3"}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["y3", "2"]}], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["z4", "2"]}], "+", 
                  RowBox[{
                  "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                   "\[Kappa]", " ", "\[Tau]"}]}], ")"}]}]}], ")"}]}]}], 
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["z0", "2"]}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
             ")"}]}]]}]], " ", "\[Pi]", " ", 
        SuperscriptBox["z0", "4"], " ", "\[Tau]", " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"x1", "-", "x2"}], "]"}], " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"y1", "-", "y2"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Erfi", "[", 
            FractionBox[
             RowBox[{"z0", " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "-", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             
             RowBox[{"2", " ", 
              SqrtBox[
               RowBox[{"q", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["z0", "4"]}], "+", 
                  RowBox[{"32", " ", "Dd", " ", "q", " ", 
                   SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                  RowBox[{"64", " ", 
                   SuperscriptBox["Dd", "2"], " ", 
                   SuperscriptBox["q", "2"], " ", 
                   SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], "]"}]}]}], 
         ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{"Dd", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "q"]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"16", " ", 
        SuperscriptBox["Dd", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"Dd", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "6"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["q", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z4", "2"]}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{"3", " ", "q", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["y1", "2"], "-", 
               RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
               SuperscriptBox["y3", "2"], "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                "\[Kappa]", " ", "\[Tau]"}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
            RowBox[{"4", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], "+", 
                  SuperscriptBox["x2", "2"], "+", 
                  SuperscriptBox["x3", "2"], "+", 
                  SuperscriptBox["x4", "2"], "+", 
                  SuperscriptBox["y1", "2"], "+", 
                  SuperscriptBox["y2", "2"], "+", 
                  SuperscriptBox["y3", "2"], "+", 
                  SuperscriptBox["y4", "2"]}], ")"}], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["x1", "2"]}], "-", 
                  RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["x3", "2"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["y1", "2"]}], "-", 
                  RowBox[{"4", " ", "y1", " ", "y3"}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["y3", "2"]}], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["z4", "2"]}], "+", 
                  RowBox[{
                  "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                   "\[Kappa]", " ", "\[Tau]"}]}], ")"}]}]}], ")"}]}]}], 
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["z0", "2"]}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
             ")"}]}]]}]], " ", "\[Pi]", " ", 
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Tau]", "2"], " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"x1", "-", "x2"}], "]"}], " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"y1", "-", "y2"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Erfi", "[", 
            FractionBox[
             RowBox[{"z0", " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "-", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             
             RowBox[{"2", " ", 
              SqrtBox[
               RowBox[{"q", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["z0", "4"]}], "+", 
                  RowBox[{"32", " ", "Dd", " ", "q", " ", 
                   SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                  RowBox[{"64", " ", 
                   SuperscriptBox["Dd", "2"], " ", 
                   SuperscriptBox["q", "2"], " ", 
                   SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], "]"}]}]}], 
         ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{"Dd", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "q"]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "Dd", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"Dd", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "6"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["q", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z4", "2"]}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{"3", " ", "q", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["y1", "2"], "-", 
               RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
               SuperscriptBox["y3", "2"], "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                "\[Kappa]", " ", "\[Tau]"}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
            RowBox[{"4", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], "+", 
                  SuperscriptBox["x2", "2"], "+", 
                  SuperscriptBox["x3", "2"], "+", 
                  SuperscriptBox["x4", "2"], "+", 
                  SuperscriptBox["y1", "2"], "+", 
                  SuperscriptBox["y2", "2"], "+", 
                  SuperscriptBox["y3", "2"], "+", 
                  SuperscriptBox["y4", "2"]}], ")"}], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["x1", "2"]}], "-", 
                  RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["x3", "2"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["y1", "2"]}], "-", 
                  RowBox[{"4", " ", "y1", " ", "y3"}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["y3", "2"]}], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["z4", "2"]}], "+", 
                  RowBox[{
                  "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                   "\[Kappa]", " ", "\[Tau]"}]}], ")"}]}]}], ")"}]}]}], 
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["z0", "2"]}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
             ")"}]}]]}]], " ", "\[Pi]", " ", 
        SuperscriptBox["z0", "4"], " ", "\[Tau]", " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"x1", "-", "x2"}], "]"}], " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"y1", "-", "y2"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Erfi", "[", 
            FractionBox[
             RowBox[{"z0", " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "-", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             
             RowBox[{"2", " ", 
              SqrtBox[
               RowBox[{"q", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["z0", "4"]}], "+", 
                  RowBox[{"32", " ", "Dd", " ", "q", " ", 
                   SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                  RowBox[{"64", " ", 
                   SuperscriptBox["Dd", "2"], " ", 
                   SuperscriptBox["q", "2"], " ", 
                   SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], "]"}]}]}], 
         ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{"Dd", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "q"]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"16", " ", 
        SuperscriptBox["Dd", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"Dd", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "6"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["q", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z4", "2"]}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{"3", " ", "q", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["y1", "2"], "-", 
               RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
               SuperscriptBox["y3", "2"], "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                "\[Kappa]", " ", "\[Tau]"}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
            RowBox[{"4", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], "+", 
                  SuperscriptBox["x2", "2"], "+", 
                  SuperscriptBox["x3", "2"], "+", 
                  SuperscriptBox["x4", "2"], "+", 
                  SuperscriptBox["y1", "2"], "+", 
                  SuperscriptBox["y2", "2"], "+", 
                  SuperscriptBox["y3", "2"], "+", 
                  SuperscriptBox["y4", "2"]}], ")"}], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["x1", "2"]}], "-", 
                  RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["x3", "2"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["y1", "2"]}], "-", 
                  RowBox[{"4", " ", "y1", " ", "y3"}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["y3", "2"]}], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["z4", "2"]}], "+", 
                  RowBox[{
                  "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                   "\[Kappa]", " ", "\[Tau]"}]}], ")"}]}]}], ")"}]}]}], 
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["z0", "2"]}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
             ")"}]}]]}]], " ", "\[Pi]", " ", 
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Tau]", "2"], " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"x1", "-", "x2"}], "]"}], " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"y1", "-", "y2"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Erfi", "[", 
            FractionBox[
             RowBox[{"z0", " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "-", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             
             RowBox[{"2", " ", 
              SqrtBox[
               RowBox[{"q", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["z0", "4"]}], "+", 
                  RowBox[{"32", " ", "Dd", " ", "q", " ", 
                   SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                  RowBox[{"64", " ", 
                   SuperscriptBox["Dd", "2"], " ", 
                   SuperscriptBox["q", "2"], " ", 
                   SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], "]"}]}]}], 
         ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{"Dd", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "q"]]}], ")"}]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z4", "2"]}]}], ")"}]}], 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"]}]]}], "-", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}], 
          "-", 
          FractionBox[
           SuperscriptBox["x1", "2"], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
          FractionBox[
           RowBox[{"2", " ", "x1", " ", "x3"}], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
          FractionBox[
           SuperscriptBox["x3", "2"], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
          FractionBox[
           SuperscriptBox["y1", "2"], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
          FractionBox[
           RowBox[{"2", " ", "y1", " ", "y3"}], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
          FractionBox[
           SuperscriptBox["y3", "2"], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
          FractionBox[
           RowBox[{"8", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], 
           RowBox[{
            RowBox[{"3", " ", "q", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]}], ")"}]}]], " ", 
      "\[Pi]", " ", 
      SuperscriptBox["z0", "2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{"Dd", " ", "\[Tau]"}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Erfi", "[", 
          FractionBox[
           RowBox[{"z0", " ", "\[Kappa]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           RowBox[{"2", " ", 
            SqrtBox[
             RowBox[{"q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["z0", "4"]}], "+", 
                RowBox[{"32", " ", "Dd", " ", "q", " ", 
                 SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                RowBox[{"64", " ", 
                 SuperscriptBox["Dd", "2"], " ", 
                 SuperscriptBox["q", "2"], " ", 
                 SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], "]"}]}]}], 
       ")"}]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z4", "2"]}]}], ")"}]}], 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"]}]]}], "-", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}], 
          "-", 
          FractionBox[
           SuperscriptBox["x1", "2"], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
          FractionBox[
           RowBox[{"2", " ", "x1", " ", "x3"}], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
          FractionBox[
           SuperscriptBox["x3", "2"], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
          FractionBox[
           SuperscriptBox["y1", "2"], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
          FractionBox[
           RowBox[{"2", " ", "y1", " ", "y3"}], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
          FractionBox[
           SuperscriptBox["y3", "2"], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
          FractionBox[
           RowBox[{"8", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], 
           RowBox[{
            RowBox[{"3", " ", "q", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]}], ")"}]}]], " ", 
      "\[Pi]", " ", 
      SuperscriptBox["z0", "2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{"Dd", " ", "\[Tau]"}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Erfi", "[", 
          FractionBox[
           RowBox[{"z0", " ", "\[Kappa]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           RowBox[{"2", " ", 
            SqrtBox[
             RowBox[{"q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["z0", "4"]}], "+", 
                RowBox[{"32", " ", "Dd", " ", "q", " ", 
                 SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                RowBox[{"64", " ", 
                 SuperscriptBox["Dd", "2"], " ", 
                 SuperscriptBox["q", "2"], " ", 
                 SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], "]"}]}]}], 
       ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "Dd", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"4", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z4", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", "Dd", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"q", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["y1", "2"], "-", 
               RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
               SuperscriptBox["y3", "2"], "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                "\[Kappa]", " ", "\[Tau]"}]}], ")"}]}]}], 
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", "\[Pi]", " ", 
        SuperscriptBox["z0", "4"], " ", "\[Tau]", " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"x1", "-", "x2"}], "]"}], " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"y1", "-", "y2"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Erfi", "[", 
            FractionBox[
             RowBox[{"z0", " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             
             RowBox[{"2", " ", 
              SqrtBox[
               RowBox[{"q", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["z0", "4"]}], "+", 
                  RowBox[{"32", " ", "Dd", " ", "q", " ", 
                   SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                  RowBox[{"64", " ", 
                   SuperscriptBox["Dd", "2"], " ", 
                   SuperscriptBox["q", "2"], " ", 
                   SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], "]"}]}]}], 
         ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{"Dd", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "q"]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"16", " ", 
        SuperscriptBox["Dd", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"4", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z4", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", "Dd", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"q", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["y1", "2"], "-", 
               RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
               SuperscriptBox["y3", "2"], "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                "\[Kappa]", " ", "\[Tau]"}]}], ")"}]}]}], 
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", "\[Pi]", " ", 
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Tau]", "2"], " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"x1", "-", "x2"}], "]"}], " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"y1", "-", "y2"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Erfi", "[", 
            FractionBox[
             RowBox[{"z0", " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             
             RowBox[{"2", " ", 
              SqrtBox[
               RowBox[{"q", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["z0", "4"]}], "+", 
                  RowBox[{"32", " ", "Dd", " ", "q", " ", 
                   SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                  RowBox[{"64", " ", 
                   SuperscriptBox["Dd", "2"], " ", 
                   SuperscriptBox["q", "2"], " ", 
                   SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], "]"}]}]}], 
         ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{"Dd", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "q"]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "Dd", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"4", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z4", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", "Dd", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"q", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["y1", "2"], "-", 
               RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
               SuperscriptBox["y3", "2"], "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                "\[Kappa]", " ", "\[Tau]"}]}], ")"}]}]}], 
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", "\[Pi]", " ", 
        SuperscriptBox["z0", "4"], " ", "\[Tau]", " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"x1", "-", "x2"}], "]"}], " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"y1", "-", "y2"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Erfi", "[", 
            FractionBox[
             RowBox[{"z0", " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             
             RowBox[{"2", " ", 
              SqrtBox[
               RowBox[{"q", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["z0", "4"]}], "+", 
                  RowBox[{"32", " ", "Dd", " ", "q", " ", 
                   SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                  RowBox[{"64", " ", 
                   SuperscriptBox["Dd", "2"], " ", 
                   SuperscriptBox["q", "2"], " ", 
                   SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], "]"}]}]}], 
         ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{"Dd", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "q"]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"16", " ", 
        SuperscriptBox["Dd", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"4", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["x4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y1", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y2", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y3", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["y4", "2"], " ", 
                SuperscriptBox["z0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z4", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", "Dd", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"q", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["y1", "2"], "-", 
               RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
               SuperscriptBox["y3", "2"], "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                "\[Kappa]", " ", "\[Tau]"}]}], ")"}]}]}], 
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", "\[Pi]", " ", 
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Tau]", "2"], " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"x1", "-", "x2"}], "]"}], " ", 
        RowBox[{"DiracDelta", "[", 
         RowBox[{"y1", "-", "y2"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Erfi", "[", 
            FractionBox[
             RowBox[{"z0", " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             
             RowBox[{"2", " ", 
              SqrtBox[
               RowBox[{"q", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["z0", "4"]}], "+", 
                  RowBox[{"32", " ", "Dd", " ", "q", " ", 
                   SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                  RowBox[{"64", " ", 
                   SuperscriptBox["Dd", "2"], " ", 
                   SuperscriptBox["q", "2"], " ", 
                   SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], "]"}]}]}], 
         ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{"Dd", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "q"]]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.5177080479373283`*^9, 3.517718933028844*^9, 
  3.517719372984586*^9, 3.517742831076674*^9, 3.5179016453754883`*^9, 
  3.519037843395463*^9, 3.519103666209175*^9, 3.519109701257221*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2z4", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2z3", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z4", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517742340974523*^9, 3.517742353996542*^9}, {
  3.519098199855296*^9, 3.5190982050944033`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y1", "2"], "+", 
           SuperscriptBox["y2", "2"], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
    SuperscriptBox["z0", "5"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}], 
   RowBox[{"4", " ", "Dd", " ", 
    SuperscriptBox["q", 
     RowBox[{"3", "/", "2"}]], " ", "\[Tau]", " ", 
    SqrtBox[
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "q"], "+", 
      RowBox[{"8", " ", "Dd", " ", "\[Tau]"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y1", "2"], "+", 
           SuperscriptBox["y2", "2"], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{
        RowBox[{"3", " ", "q", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]}]], " ", 
    SuperscriptBox["z0", "5"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}], 
   RowBox[{"4", " ", "Dd", " ", 
    SuperscriptBox["q", 
     RowBox[{"3", "/", "2"}]], " ", "\[Tau]", " ", 
    SqrtBox[
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "q"], "+", 
      RowBox[{"8", " ", "Dd", " ", "\[Tau]"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"3", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]}], ")"}]}]], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}], 
   RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y1", "2"], "+", 
           SuperscriptBox["y2", "2"], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y1", "2"], "+", 
           SuperscriptBox["y2", "2"], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{
        RowBox[{"3", " ", "q", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]}]], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]}]], "Output",
 CellChangeTimes->{3.517742868915729*^9, 3.5179016958885307`*^9, 
  3.519037957176519*^9, 3.519103666313442*^9, 3.519110824930338*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y Integration", "Subsection",
 CellChangeTimes->{{3.5177120430240726`*^9, 3.51771204546321*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2y1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y2_", ",", "y3_", ",", 
    "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2z4", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5177423766146393`*^9, 3.517742388617363*^9}, {
   3.519098211728489*^9, 3.519098218073687*^9}, 3.519106368926238*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"q", " ", 
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "-", 
           RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}]}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["y2", "2"]}], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}]}], 
       RowBox[{"4", " ", "Dd", " ", "q", " ", 
        SuperscriptBox["w0", "2"], " ", "\[Tau]"}]]}]], " ", 
    SuperscriptBox["z0", "5"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}], 
   RowBox[{"4", " ", "Dd", " ", 
    SuperscriptBox["q", 
     RowBox[{"3", "/", "2"}]], " ", "\[Tau]", " ", 
    SqrtBox[
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "q"], "+", 
      RowBox[{"8", " ", "Dd", " ", "\[Tau]"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["q", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["y2", "2"]}], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "-", 
             RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}], " ", 
           SuperscriptBox["z0", "2"]}], "-", 
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "-", 
             RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}], " ", 
           "\[Tau]"}], "+", 
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}]}], 
         RowBox[{"Dd", " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
       RowBox[{"4", " ", "q"}]]], " ", 
     SuperscriptBox["z0", "5"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", "Dd", " ", 
     SuperscriptBox["q", 
      RowBox[{"3", "/", "2"}]], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "q"], "+", 
       RowBox[{"8", " ", "Dd", " ", "\[Tau]"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], ")"}]}], 
  "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["y2", "2"]}], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "-", 
            RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}], " ", 
          SuperscriptBox["z0", "2"]}], "-", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "-", 
            RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}], " ", 
          "\[Tau]"}], "+", 
         RowBox[{"2", " ", "Dd", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}]}], 
        RowBox[{"Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
      RowBox[{"4", " ", "q"}]]], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"q", " ", 
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "-", 
           RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}]}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["y2", "2"]}], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}]}], 
       RowBox[{"4", " ", "Dd", " ", "q", " ", 
        SuperscriptBox["w0", "2"], " ", "\[Tau]"}]]}]], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{"2", " ", 
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["y2", "2"]}], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "-", 
            RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}], " ", 
          SuperscriptBox["z0", "2"]}], "-", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "-", 
            RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}], " ", 
          "\[Tau]"}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}]}], 
        RowBox[{"Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
      RowBox[{"4", " ", "q"}]]], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.5177428768502398`*^9, 3.5179017039476748`*^9, 
  3.519037966123234*^9, 3.5191036669658213`*^9, 3.5191108656798162`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2y2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y3_", ",", "y4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2y1", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y2", ",", "y3", ",", "y4", 
       ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517742399157131*^9, 3.517742416923222*^9}, {
   3.519098221928165*^9, 3.51909822693351*^9}, 3.519106372158415*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y3", "2"]}], "+", 
               SuperscriptBox["y4", "2"]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"256", " ", 
          SuperscriptBox["Dd", "3"], " ", 
          SuperscriptBox["q", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "3"]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x1", "2"]}], "-", 
               RowBox[{"6", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               RowBox[{"16", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x2", "2"]}], "-", 
               RowBox[{"12", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x4", "2"]}], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["y3", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y4", "2"]}], "+", 
               RowBox[{"32", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", 
     SqrtBox["\[Pi]"], " ", "w0", " ", 
     SuperscriptBox["z0", "3"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"4", " ", 
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", "Dd", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            SuperscriptBox["x2", "2"], "-", 
            RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["y3", "2"]}], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "4"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", 
     SqrtBox["\[Pi]"], " ", "w0", " ", 
     SuperscriptBox["z0", "3"], " ", "\[Tau]", " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"4", " ", 
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", "Dd", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y3", "2"]}], "+", 
               SuperscriptBox["y4", "2"]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"256", " ", 
          SuperscriptBox["Dd", "3"], " ", 
          SuperscriptBox["q", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "3"]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x1", "2"]}], "-", 
               RowBox[{"6", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               RowBox[{"32", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x2", "2"]}], "-", 
               RowBox[{"12", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x4", "2"]}], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["y3", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y4", "2"]}], "+", 
               RowBox[{"64", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", 
     SqrtBox["\[Pi]"], " ", "w0", " ", 
     SuperscriptBox["z0", "3"], " ", "\[Tau]", " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            SuperscriptBox["x2", "2"], "-", 
            RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["y3", "2"]}], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "4"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", 
     SqrtBox["\[Pi]"], " ", "w0", " ", 
     SuperscriptBox["z0", "5"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox["q", 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
       "q"]]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y3", "2"]}], "+", 
               SuperscriptBox["y4", "2"]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"256", " ", 
          SuperscriptBox["Dd", "3"], " ", 
          SuperscriptBox["q", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "3"]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x1", "2"]}], "-", 
               RowBox[{"6", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               RowBox[{"32", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x2", "2"]}], "-", 
               RowBox[{"12", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x4", "2"]}], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["y3", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y4", "2"]}], "+", 
               RowBox[{"64", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", 
     SqrtBox["\[Pi]"], " ", "w0", " ", 
     SuperscriptBox["z0", "5"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox["q", 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
       "q"]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.517742918437899*^9, 3.51790174531531*^9, 
  3.519038061438312*^9, 3.519103671084178*^9, 3.519111225565835*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2y3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2y2", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y3", ",", "y4", ",", 
       "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y3", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517742427571549*^9, 3.51774243700349*^9}, {
   3.519098230872177*^9, 3.519098236563574*^9}, 3.519106378669799*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", "\[Pi]", " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "5"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["q", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x1", "2"]}], "-", 
            RowBox[{"6", " ", "x1", " ", "x3"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "\[Pi]", " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "5"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox["q", 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["w0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x1", "2"]}], "-", 
            RowBox[{"6", " ", "x1", " ", "x3"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "\[Pi]", " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "3"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["w0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", "Dd", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", "\[Pi]", " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "3"], " ", "\[Tau]", " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"4", " ", 
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", "Dd", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x1", "2"]}], "-", 
            RowBox[{"6", " ", "x1", " ", "x3"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "\[Pi]", " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "3"], " ", "\[Tau]", " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["w0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.517742939838188*^9, 3.517901766816791*^9, 
  3.5190380951749763`*^9, 3.519103692996504*^9, 3.519111371017098*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2y4", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}],
   "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2y3", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y4", ",", "\[Tau]"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y4", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517742446002479*^9, 3.517742457383566*^9}, {
  3.519098240852285*^9, 3.519098246678747*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "5"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{
        RowBox[{"3", " ", "q", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "5"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", "Dd", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "3"], " ", "\[Tau]", " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}], 
   RowBox[{"q", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", "Dd", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{
        RowBox[{"3", " ", "q", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "3"], " ", "\[Tau]", " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}], 
   RowBox[{"q", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"3", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]}], ")"}]}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}], 
   RowBox[{
    SuperscriptBox["q", 
     RowBox[{"3", "/", "2"}]], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
       ")"}]}]]}]]}]], "Output",
 CellChangeTimes->{3.517742950880053*^9, 3.5179017778526773`*^9, 
  3.519038119654882*^9, 3.519103774733335*^9, 3.519111488296847*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x Integration", "Subsection",
 CellChangeTimes->{{3.517712055584053*^9, 3.517712057343378*^9}, 
   3.517742163353998*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2x1", "[", 
   RowBox[{"x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2y4", "[", 
      RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517742489376445*^9, 3.5177425003032503`*^9}, {
   3.5190982499292088`*^9, 3.5190982543679943`*^9}, 3.519106387213081*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["x2", "2"]}], "+", 
          SuperscriptBox["x3", "2"], "+", 
          SuperscriptBox["x4", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x2", "-", "x3"}], ")"}], "2"], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{
        RowBox[{"3", " ", "q", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "4"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}]}],
     ")"}], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["w0", "3"], " ", 
   SuperscriptBox["z0", "3"]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["q", 
    RowBox[{"3", "/", "2"}]], " ", 
   SqrtBox[
    RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
      ")"}]}]]}]]], "Output",
 CellChangeTimes->{3.517742956685525*^9, 3.517901783694124*^9, 
  3.519038130140254*^9, 3.519111516702733*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2x2", "[", 
   RowBox[{"x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2x1", "[", 
      RowBox[{"x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517742508642894*^9, 3.517742520418755*^9}, {
   3.519098258081046*^9, 3.5190982642811413`*^9}, 3.519106390644915*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"]}], "-", 
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["x3", "2"], "+", 
          SuperscriptBox["x4", "2"]}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["x3", "2"]}], 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{
        RowBox[{"3", " ", "q", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "4"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}]}],
     ")"}], " ", 
   SuperscriptBox["\[Pi]", "2"], " ", 
   SuperscriptBox["w0", "4"], " ", 
   SuperscriptBox["z0", "3"]}], 
  RowBox[{
   SuperscriptBox["q", 
    RowBox[{"3", "/", "2"}]], " ", 
   SqrtBox[
    RowBox[{"q", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
      ")"}]}]]}]]], "Output",
 CellChangeTimes->{3.517742979346457*^9, 3.5179018061057863`*^9, 
  3.519038139452578*^9, 3.519111535718115*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2x3", "[", 
   RowBox[{"x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2x2", "[", 
      RowBox[{"x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x3", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517742530253129*^9, 3.517742537725638*^9}, {
   3.51909826884978*^9, 3.51909827431437*^9}, 3.519106393276577*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        SuperscriptBox["x4", "2"]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "q"]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{
        RowBox[{"3", " ", "q", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "4"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}]}],
     ")"}], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"5", "/", "2"}]], " ", 
   SuperscriptBox["w0", "5"], " ", 
   SuperscriptBox["z0", "3"]}], 
  RowBox[{
   SuperscriptBox["q", 
    RowBox[{"5", "/", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["w0", "2"]}], "+", 
     RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["z0", "2"]}], "+", 
     RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]], "Output",
 CellChangeTimes->{3.5177429882741613`*^9, 3.517901815427566*^9, 
  3.51903814672935*^9, 3.519111563155264*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2x4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2x3", "[", 
      RowBox[{"x4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x4", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5177425476972933`*^9, 3.5177425566648197`*^9}, {
   3.519098278786147*^9, 3.519098284748097*^9}, 3.51910639850025*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "q"]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{
        RowBox[{"3", " ", "q", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "4"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}]}],
     ")"}], " ", 
   SuperscriptBox["\[Pi]", "3"], " ", 
   SuperscriptBox["w0", "6"], " ", 
   SuperscriptBox["z0", "3"]}], 
  RowBox[{
   SuperscriptBox["q", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["w0", "2"]}], "+", 
     RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["z0", "2"]}], "+", 
     RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]], "Output",
 CellChangeTimes->{3.517742994790627*^9, 3.517901821762847*^9, 
  3.5190381493086233`*^9, 3.519111568248948*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g2", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"myint2x4", "[", "\[Tau]", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517711702800435*^9, 3.517711728387665*^9}, {
   3.517742564771495*^9, 3.5177425690024557`*^9}, 3.517742599172182*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "q"]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}]}], 
       ")"}]}]}], ")"}], " ", 
   SuperscriptBox["\[Pi]", "3"], " ", 
   SuperscriptBox["w0", "6"], " ", 
   SuperscriptBox["z0", "3"]}], 
  RowBox[{
   SuperscriptBox["q", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["w0", "2"]}], "+", 
     RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["z0", "2"]}], "+", 
     RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]], "Output",
 CellChangeTimes->{3.517711734359661*^9, 3.5177201020180187`*^9, 
  3.517721138631971*^9, 3.517742995940958*^9, 3.517901822851325*^9, 
  3.519038150280826*^9, 3.5191115741082487`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute g3", "Section",
 CellChangeTimes->{{3.517712244605625*^9, 3.517712246731595*^9}, {
  3.517743037922456*^9, 3.517743042681806*^9}, {3.5180897812388887`*^9, 
  3.518089781618937*^9}}],

Cell[CellGroupData[{

Cell["g3", "Subsection",
 CellChangeTimes->{{3.517724213366851*^9, 3.517724229845232*^9}, {
  3.5177430973968267`*^9, 3.517743098730826*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3z1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z2_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"g3int", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z1", ",", "z2", ",", "z3", ",", "z4", ",", "\[Tau]"}],
       "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.519033779064073*^9, 3.519033853986814*^9}, 
   3.519036619103786*^9, {3.519098293220059*^9, 3.519098298614792*^9}, 
   3.519106402941757*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"128", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"(", 
      RowBox[{"z2", "+", "z3", "+", "z4"}], ")"}], " ", "\[Kappa]"}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x1", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "-", 
             RowBox[{"2", " ", "x1", " ", "x3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["x3", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["y1", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "-", 
             RowBox[{"2", " ", "y1", " ", "y3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["y3", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["z2", "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["z0", "2"], " ", "z2", " ", "z3"}], "+", 
             RowBox[{
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["z3", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z2", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "-", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", "Dd", " ", 
              SuperscriptBox["z0", "2"], " ", "z2", " ", "\[Kappa]", " ", 
              "\[Tau]"}]}], ")"}]}]}], 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x1", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "-", 
             RowBox[{"2", " ", "x1", " ", "x3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["x3", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["y1", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "-", 
             RowBox[{"2", " ", "y1", " ", "y3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["y3", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["z2", "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["z0", "2"], " ", "z2", " ", "z3"}], "+", 
             RowBox[{
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["z3", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z2", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", "Dd", " ", 
              SuperscriptBox["z0", "2"], " ", "z2", " ", "\[Kappa]", " ", 
              "\[Tau]"}]}], ")"}]}]}], 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{
     RowBox[{"x3", "-", "x4"}], ",", 
     RowBox[{"y3", "-", "y4"}], ",", 
     RowBox[{"z3", "-", "z4"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.519033859300933*^9, 3.51903416167703*^9, 
  3.5190381589135933`*^9, 3.5191115869205847`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3z2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint3z1", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z2", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"z2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.519033927472396*^9, 3.5190339343832417`*^9}, {
   3.5190983023850813`*^9, 3.519098325358121*^9}, 3.51910640525344*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"128", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{
     RowBox[{"x3", "-", "x4"}], ",", 
     RowBox[{"y3", "-", "y4"}], ",", 
     RowBox[{"z3", "-", "z4"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"(", 
         RowBox[{"z3", "+", "z4"}], ")"}], " ", "\[Kappa]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            SqrtBox[
             RowBox[{"Dd", " ", "\[Tau]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]],
             ")"}]}], 
          RowBox[{"2", " ", "Dd", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             FractionBox["1", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"4", " ", "q", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["x1", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["x2", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["x3", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["x4", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["y1", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["y2", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["y3", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["y4", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["w0", "2"], " ", 
                    SuperscriptBox["z3", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["w0", "2"], " ", 
                    SuperscriptBox["z4", "2"]}]}], ")"}]}], 
                 RowBox[{
                  SuperscriptBox["w0", "2"], " ", 
                  SuperscriptBox["z0", "2"]}]]}], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["x1", "2"], "-", 
                 RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
                 SuperscriptBox["x3", "2"], "+", 
                 SuperscriptBox["y1", "2"], "-", 
                 RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
                 SuperscriptBox["y3", "2"], "+", 
                 SuperscriptBox["z3", "2"]}], 
                RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["z0", "2"], " ", 
                 SuperscriptBox["z3", "2"]}], 
                RowBox[{
                 RowBox[{"Dd", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", 
                  SuperscriptBox["Dd", "2"], " ", "q", " ", 
                  SuperscriptBox["\[Tau]", "2"]}]}]]}], ")"}]}]], " ", 
           SqrtBox["\[Pi]"], " ", "z0", " ", "\[Tau]", " ", 
           RowBox[{"DiracDelta", "[", 
            RowBox[{"x1", "-", "x2"}], "]"}], " ", 
           RowBox[{"DiracDelta", "[", 
            RowBox[{"y1", "-", "y2"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"Erf", "[", 
              FractionBox[
               RowBox[{"z0", " ", "z3"}], 
               RowBox[{"2", " ", 
                SqrtBox[
                 RowBox[{"Dd", " ", "\[Tau]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}]]}]], "]"}]}], ")"}]}]}]}], "+", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"z3", "-", 
                 RowBox[{
                 "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                  "\[Tau]"}]}], ")"}], "2"]}], 
             RowBox[{"Dd", " ", "\[Tau]"}]]], ")"}]}], 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x1", "2"], "+", 
                 SuperscriptBox["x2", "2"], "+", 
                 SuperscriptBox["x3", "2"], "+", 
                 SuperscriptBox["x4", "2"], "+", 
                 SuperscriptBox["y1", "2"], "+", 
                 SuperscriptBox["y2", "2"], "+", 
                 SuperscriptBox["y3", "2"], "+", 
                 SuperscriptBox["y4", "2"]}], ")"}], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}],
               "+", 
              RowBox[{
               SuperscriptBox["w0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "-", 
                 RowBox[{"2", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
                 RowBox[{"16", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"12", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"4", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", "\[ImaginaryI]", " ", "Dd", " ", 
                  SuperscriptBox["z0", "4"], " ", "z3", " ", "\[Kappa]", " ", 
                  "\[Tau]"}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["z0", "4"], " ", 
                  SuperscriptBox["\[Kappa]", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "-", 
                 RowBox[{"2", " ", "x1", " ", "x3", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  SuperscriptBox["x3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
                ")"}]}]}], 
             RowBox[{"4", " ", "Dd", " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]]}]], " ", 
          SqrtBox["\[Pi]"], " ", "z0", " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"x1", "-", "x2"}], "]"}], " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"y1", "-", "y2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z3", "-", 
                RowBox[{
                "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                 "\[Tau]"}]}], ")"}], "2"]], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z3", "-", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                "\[Tau]"}]}], ")"}], " ", 
             RowBox[{"Erf", "[", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"z3", "-", 
                    RowBox[{
                    "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", 
                    " ", "\[Tau]"}]}], ")"}], "2"]}], 
                 RowBox[{"Dd", " ", "\[Tau]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}]]]}], "]"}]}]}], ")"}]}]}], "+", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"z3", "+", 
                 RowBox[{
                 "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                  "\[Tau]"}]}], ")"}], "2"]}], 
             RowBox[{"Dd", " ", "\[Tau]"}]]], ")"}]}], 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x1", "2"], "+", 
                 SuperscriptBox["x2", "2"], "+", 
                 SuperscriptBox["x3", "2"], "+", 
                 SuperscriptBox["x4", "2"], "+", 
                 SuperscriptBox["y1", "2"], "+", 
                 SuperscriptBox["y2", "2"], "+", 
                 SuperscriptBox["y3", "2"], "+", 
                 SuperscriptBox["y4", "2"]}], ")"}], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}],
               "+", 
              RowBox[{
               SuperscriptBox["w0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "-", 
                 RowBox[{"2", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
                 RowBox[{"16", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"12", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"4", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "-", 
                 RowBox[{"8", " ", "\[ImaginaryI]", " ", "Dd", " ", 
                  SuperscriptBox["z0", "4"], " ", "z3", " ", "\[Kappa]", " ", 
                  "\[Tau]"}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["z0", "4"], " ", 
                  SuperscriptBox["\[Kappa]", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "-", 
                 RowBox[{"2", " ", "x1", " ", "x3", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  SuperscriptBox["x3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
                ")"}]}]}], 
             RowBox[{"4", " ", "Dd", " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]]}]], " ", 
          SqrtBox["\[Pi]"], " ", "z0", " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"x1", "-", "x2"}], "]"}], " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"y1", "-", "y2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z3", "+", 
                RowBox[{
                "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                 "\[Tau]"}]}], ")"}], "2"]], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z3", "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                "\[Tau]"}]}], ")"}], " ", 
             RowBox[{"Erf", "[", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"z3", "+", 
                    RowBox[{
                    "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", 
                    " ", "\[Tau]"}]}], ")"}], "2"]}], 
                 RowBox[{"Dd", " ", "\[Tau]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}]]]}], "]"}]}]}], ")"}]}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"(", 
         RowBox[{"z3", "+", "z4"}], ")"}], " ", "\[Kappa]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           SqrtBox[
            RowBox[{"Dd", " ", "\[Tau]", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
           ")"}]}], 
         RowBox[{"2", " ", "Dd", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            FractionBox["1", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"4", " ", "q", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["x1", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["x2", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["x3", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["x4", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["y1", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["y2", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["y3", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["y4", "2"], " ", 
                    SuperscriptBox["z0", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["w0", "2"], " ", 
                    SuperscriptBox["z3", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["w0", "2"], " ", 
                    SuperscriptBox["z4", "2"]}]}], ")"}]}], 
                RowBox[{
                 SuperscriptBox["w0", "2"], " ", 
                 SuperscriptBox["z0", "2"]}]]}], "-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["x1", "2"], "-", 
                RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
                SuperscriptBox["x3", "2"], "+", 
                SuperscriptBox["y1", "2"], "-", 
                RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
                SuperscriptBox["y3", "2"], "+", 
                SuperscriptBox["z3", "2"]}], 
               RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
              FractionBox[
               RowBox[{
                SuperscriptBox["z0", "2"], " ", 
                SuperscriptBox["z3", "2"]}], 
               RowBox[{
                RowBox[{"Dd", " ", 
                 SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                RowBox[{"8", " ", 
                 SuperscriptBox["Dd", "2"], " ", "q", " ", 
                 SuperscriptBox["\[Tau]", "2"]}]}]]}], ")"}]}]], " ", 
          SqrtBox["\[Pi]"], " ", "z0", " ", "\[Tau]", " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"x1", "-", "x2"}], "]"}], " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"y1", "-", "y2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"Erf", "[", 
             FractionBox[
              RowBox[{"z0", " ", "z3"}], 
              RowBox[{"2", " ", 
               SqrtBox[
                RowBox[{"Dd", " ", "\[Tau]", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["z0", "2"], "+", 
                   RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                  ")"}]}]]}]], "]"}]}], ")"}]}]}], "+", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"z3", "-", 
                 RowBox[{
                 "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                  "\[Tau]"}]}], ")"}], "2"]}], 
             RowBox[{"Dd", " ", "\[Tau]"}]]], ")"}]}], 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x1", "2"], "+", 
                 SuperscriptBox["x2", "2"], "+", 
                 SuperscriptBox["x3", "2"], "+", 
                 SuperscriptBox["x4", "2"], "+", 
                 SuperscriptBox["y1", "2"], "+", 
                 SuperscriptBox["y2", "2"], "+", 
                 SuperscriptBox["y3", "2"], "+", 
                 SuperscriptBox["y4", "2"]}], ")"}], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}],
               "+", 
              RowBox[{
               SuperscriptBox["w0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "-", 
                 RowBox[{"2", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
                 RowBox[{"16", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"12", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"4", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", "\[ImaginaryI]", " ", "Dd", " ", 
                  SuperscriptBox["z0", "4"], " ", "z3", " ", "\[Kappa]", " ", 
                  "\[Tau]"}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["z0", "4"], " ", 
                  SuperscriptBox["\[Kappa]", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "-", 
                 RowBox[{"2", " ", "x1", " ", "x3", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  SuperscriptBox["x3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
                ")"}]}]}], 
             RowBox[{"4", " ", "Dd", " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]]}]], " ", 
          SqrtBox["\[Pi]"], " ", "z0", " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"x1", "-", "x2"}], "]"}], " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"y1", "-", "y2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z3", "-", 
                RowBox[{
                "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                 "\[Tau]"}]}], ")"}], "2"]], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z3", "-", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                "\[Tau]"}]}], ")"}], " ", 
             RowBox[{"Erf", "[", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"z3", "-", 
                    RowBox[{
                    "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", 
                    " ", "\[Tau]"}]}], ")"}], "2"]}], 
                 RowBox[{"Dd", " ", "\[Tau]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}]]]}], "]"}]}]}], ")"}]}]}], "+", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"z3", "+", 
                 RowBox[{
                 "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                  "\[Tau]"}]}], ")"}], "2"]}], 
             RowBox[{"Dd", " ", "\[Tau]"}]]], ")"}]}], 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x1", "2"], "+", 
                 SuperscriptBox["x2", "2"], "+", 
                 SuperscriptBox["x3", "2"], "+", 
                 SuperscriptBox["x4", "2"], "+", 
                 SuperscriptBox["y1", "2"], "+", 
                 SuperscriptBox["y2", "2"], "+", 
                 SuperscriptBox["y3", "2"], "+", 
                 SuperscriptBox["y4", "2"]}], ")"}], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}],
               "+", 
              RowBox[{
               SuperscriptBox["w0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "-", 
                 RowBox[{"2", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "4"]}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y1", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
                 RowBox[{"16", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["y3", "2"], " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"12", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
                 RowBox[{"4", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "-", 
                 RowBox[{"8", " ", "\[ImaginaryI]", " ", "Dd", " ", 
                  SuperscriptBox["z0", "4"], " ", "z3", " ", "\[Kappa]", " ", 
                  "\[Tau]"}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z3", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["q", "2"], " ", 
                  SuperscriptBox["z4", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["z0", "4"], " ", 
                  SuperscriptBox["\[Kappa]", "2"], " ", 
                  SuperscriptBox["\[Tau]", "2"]}], "-", 
                 RowBox[{"2", " ", "x1", " ", "x3", " ", 
                  SuperscriptBox["z0", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  SuperscriptBox["x3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "4"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", 
                    SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
                ")"}]}]}], 
             RowBox[{"4", " ", "Dd", " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]]}]], " ", 
          SqrtBox["\[Pi]"], " ", "z0", " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"x1", "-", "x2"}], "]"}], " ", 
          RowBox[{"DiracDelta", "[", 
           RowBox[{"y1", "-", "y2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z3", "+", 
                RowBox[{
                "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                 "\[Tau]"}]}], ")"}], "2"]], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z3", "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
                "\[Tau]"}]}], ")"}], " ", 
             RowBox[{"Erf", "[", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"z3", "+", 
                    RowBox[{
                    "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", 
                    " ", "\[Tau]"}]}], ")"}], "2"]}], 
                 RowBox[{"Dd", " ", "\[Tau]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["z0", "2"], "+", 
                    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
                   ")"}]}]]]}], "]"}]}]}], ")"}]}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.519034433203273*^9, 3.519038429519927*^9, 
  3.5191120690237885`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3z3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint3z2", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z3", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5190339486915207`*^9, 3.519033955581791*^9}, {
   3.519098332375977*^9, 3.5190983434822407`*^9}, 3.519106409605201*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"128", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        SqrtBox[
         RowBox[{"Dd", " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        ")"}]}], 
      RowBox[{"4", " ", "Dd", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         FractionBox["1", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"4", " ", "q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x1", "2"], " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["x2", "2"], " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["x3", "2"], " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["x4", "2"], " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["y1", "2"], " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["y2", "2"], " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["y3", "2"], " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["y4", "2"], " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["w0", "2"], " ", 
                 SuperscriptBox["z4", "2"]}]}], ")"}]}], 
             RowBox[{
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"]}]]}], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["x1", "2"], "-", 
             RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["y1", "2"], "-", 
             RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["z4", "2"]}], 
            RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["z4", "2"]}], 
            RowBox[{
             RowBox[{"Dd", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["Dd", "2"], " ", "q", " ", 
              SuperscriptBox["\[Tau]", "2"]}]}]]}], ")"}]}]], " ", 
       SqrtBox["\[Pi]"], " ", "z0", " ", "\[Tau]", " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"x1", "-", "x2"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"x3", "-", "x4"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"y1", "-", "y2"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        SqrtBox[
         RowBox[{"Dd", " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        ")"}]}], 
      RowBox[{"2", " ", "Dd", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y1", "2"], "+", 
              SuperscriptBox["y2", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y1", "2"], " ", 
               SuperscriptBox["z0", "4"]}], "-", 
              RowBox[{"2", " ", "y1", " ", "y3", " ", 
               SuperscriptBox["z0", "4"]}], "+", 
              RowBox[{
               SuperscriptBox["y3", "2"], " ", 
               SuperscriptBox["z0", "4"]}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["y1", "2"], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
              RowBox[{"16", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["y3", "2"], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"16", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "-", 
              RowBox[{"8", " ", "\[ImaginaryI]", " ", "Dd", " ", 
               SuperscriptBox["z0", "4"], " ", "z4", " ", "\[Kappa]", " ", 
               "\[Tau]"}], "+", 
              RowBox[{"64", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["q", "2"], " ", 
               SuperscriptBox["z4", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}], "+", 
              RowBox[{"16", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}], "-", 
              RowBox[{"2", " ", "x1", " ", "x3", " ", 
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}],
               "+", 
              RowBox[{
               SuperscriptBox["x1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "4"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], "+", 
              
              RowBox[{
               SuperscriptBox["x3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "4"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
             ")"}]}]}], 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]],
        " ", 
       SqrtBox["\[Pi]"], " ", "z0", " ", "\[Tau]", " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"x1", "-", "x2"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"x3", "-", "x4"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"y1", "-", "y2"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        SqrtBox[
         RowBox[{"Dd", " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        ")"}]}], 
      RowBox[{"2", " ", "Dd", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y1", "2"], "+", 
              SuperscriptBox["y2", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y1", "2"], " ", 
               SuperscriptBox["z0", "4"]}], "-", 
              RowBox[{"2", " ", "y1", " ", "y3", " ", 
               SuperscriptBox["z0", "4"]}], "+", 
              RowBox[{
               SuperscriptBox["y3", "2"], " ", 
               SuperscriptBox["z0", "4"]}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["y1", "2"], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
              RowBox[{"16", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["y3", "2"], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"16", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"8", " ", "\[ImaginaryI]", " ", "Dd", " ", 
               SuperscriptBox["z0", "4"], " ", "z4", " ", "\[Kappa]", " ", 
               "\[Tau]"}], "+", 
              RowBox[{"64", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["q", "2"], " ", 
               SuperscriptBox["z4", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}], "+", 
              RowBox[{"16", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}], "-", 
              RowBox[{"2", " ", "x1", " ", "x3", " ", 
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}],
               "+", 
              RowBox[{
               SuperscriptBox["x1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "4"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], "+", 
              
              RowBox[{
               SuperscriptBox["x3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "4"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
             ")"}]}]}], 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]],
        " ", 
       SqrtBox["\[Pi]"], " ", "z0", " ", "\[Tau]", " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"x1", "-", "x2"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"x3", "-", "x4"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"y1", "-", "y2"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        SqrtBox[
         RowBox[{"Dd", " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        ")"}]}], 
      RowBox[{"2", " ", "Dd", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y1", "2"], "+", 
              SuperscriptBox["y2", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y1", "2"], " ", 
               SuperscriptBox["z0", "4"]}], "-", 
              RowBox[{"2", " ", "y1", " ", "y3", " ", 
               SuperscriptBox["z0", "4"]}], "+", 
              RowBox[{
               SuperscriptBox["y3", "2"], " ", 
               SuperscriptBox["z0", "4"]}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["y1", "2"], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
              RowBox[{"16", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["y3", "2"], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"16", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"64", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["q", "2"], " ", 
               SuperscriptBox["z4", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}], "+", 
              RowBox[{"64", " ", "\[ImaginaryI]", " ", 
               SuperscriptBox["Dd", "2"], " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", "z4", " ", "\[Kappa]", " ", 
               SuperscriptBox["\[Tau]", "2"]}], "+", 
              RowBox[{"16", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}], "-", 
              RowBox[{"2", " ", "x1", " ", "x3", " ", 
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}],
               "+", 
              RowBox[{
               SuperscriptBox["x1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "4"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], "+", 
              
              RowBox[{
               SuperscriptBox["x3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "4"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
             ")"}]}]}], 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]],
        " ", 
       SqrtBox["\[Pi]"], " ", "z0", " ", "\[Tau]", " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"x1", "-", "x2"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"x3", "-", "x4"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"y1", "-", "y2"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        SqrtBox[
         RowBox[{"Dd", " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        ")"}]}], 
      RowBox[{"2", " ", "Dd", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y1", "2"], "+", 
              SuperscriptBox["y2", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y1", "2"], " ", 
               SuperscriptBox["z0", "4"]}], "-", 
              RowBox[{"2", " ", "y1", " ", "y3", " ", 
               SuperscriptBox["z0", "4"]}], "+", 
              RowBox[{
               SuperscriptBox["y3", "2"], " ", 
               SuperscriptBox["z0", "4"]}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["y1", "2"], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
              RowBox[{"16", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["y3", "2"], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"16", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"16", " ", "\[ImaginaryI]", " ", "Dd", " ", 
               SuperscriptBox["z0", "4"], " ", "z4", " ", "\[Kappa]", " ", 
               "\[Tau]"}], "+", 
              RowBox[{"64", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["q", "2"], " ", 
               SuperscriptBox["z4", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}], "+", 
              RowBox[{"64", " ", "\[ImaginaryI]", " ", 
               SuperscriptBox["Dd", "2"], " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", "z4", " ", "\[Kappa]", " ", 
               SuperscriptBox["\[Tau]", "2"]}], "+", 
              RowBox[{"16", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}], "-", 
              RowBox[{"2", " ", "x1", " ", "x3", " ", 
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}],
               "+", 
              RowBox[{
               SuperscriptBox["x1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "4"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], "+", 
              
              RowBox[{
               SuperscriptBox["x3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "4"], "+", 
                 RowBox[{"8", " ", "Dd", " ", "q", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
             ")"}]}]}], 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]],
        " ", 
       SqrtBox["\[Pi]"], " ", "z0", " ", "\[Tau]", " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"x1", "-", "x2"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"x3", "-", "x4"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"y1", "-", "y2"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        SqrtBox[
         RowBox[{"Dd", " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        ")"}]}], 
      RowBox[{"4", " ", "Dd", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         FractionBox["1", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["x1", "2"], "-", 
              RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["y1", "2"], "-", 
              RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
              SuperscriptBox["y3", "2"], "+", 
              RowBox[{
              "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
               "\[Kappa]", " ", "\[Tau]"}]}], 
             RowBox[{"Dd", " ", "\[Tau]"}]]}], "-", 
           RowBox[{"4", " ", "q", " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{
                SuperscriptBox["x1", "2"], "+", 
                SuperscriptBox["x2", "2"], "+", 
                SuperscriptBox["x3", "2"], "+", 
                SuperscriptBox["x4", "2"], "+", 
                SuperscriptBox["y1", "2"], "+", 
                SuperscriptBox["y2", "2"], "+", 
                SuperscriptBox["y3", "2"], "+", 
                SuperscriptBox["y4", "2"]}], 
               SuperscriptBox["w0", "2"]], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["z4", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox["1", 
                  SuperscriptBox["z0", "2"]], "+", 
                 FractionBox["1", 
                  RowBox[{
                   SuperscriptBox["z0", "2"], "+", 
                   RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}]], " ", 
       SqrtBox["\[Pi]"], " ", "z0", " ", "\[Tau]", " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"x1", "-", "x2"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"x3", "-", "x4"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"y1", "-", "y2"}], "]"}], " ", 
       RowBox[{"DiracDelta", "[", 
        RowBox[{"y3", "-", "y4"}], "]"}]}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.5190344443641987`*^9, 3.519038440539783*^9, 
  3.519112140491624*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3z4", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint3z3", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z4", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.519033967134328*^9, 3.5190339952633266`*^9}, {
  3.519098356077713*^9, 3.519098365622486*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"128", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
         RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", "\[Pi]", " ", 
      SuperscriptBox["z0", "2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{"Dd", " ", "\[Tau]"}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x3", "-", "x4"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y3", "-", "y4"}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "q", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}]}], 
            SuperscriptBox["w0", "2"]]}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              FractionBox[
               SuperscriptBox["z0", "2"], 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
             ")"}]}], "q"]}], ")"}]}]], " ", "\[Pi]", " ", 
      SuperscriptBox["z0", "2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{"Dd", " ", "\[Tau]"}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x3", "-", "x4"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y3", "-", "y4"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Erfi", "[", 
          FractionBox[
           RowBox[{"z0", " ", "\[Kappa]"}], 
           RowBox[{"2", " ", 
            SqrtBox[
             FractionBox[
              RowBox[{"q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}]], 
          "]"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "q", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}]}], 
            SuperscriptBox["w0", "2"]]}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              FractionBox[
               SuperscriptBox["z0", "2"], 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
             ")"}]}], "q"]}], ")"}]}]], " ", "\[Pi]", " ", 
      SuperscriptBox["z0", "2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{"Dd", " ", "\[Tau]"}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x3", "-", "x4"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y3", "-", "y4"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Erfi", "[", 
          FractionBox[
           RowBox[{"z0", " ", "\[Kappa]"}], 
           RowBox[{"2", " ", 
            SqrtBox[
             FractionBox[
              RowBox[{"q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}]], 
          "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
         RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", "\[Pi]", " ", 
      SuperscriptBox["z0", "2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{"Dd", " ", "\[Tau]"}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x3", "-", "x4"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y3", "-", "y4"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Erfi", "[", 
          FractionBox[
           RowBox[{"z0", " ", "\[Kappa]"}], 
           SqrtBox[
            FractionBox[
             RowBox[{"q", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]], 
          "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
         RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", "\[Pi]", " ", 
      SuperscriptBox["z0", "2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{"Dd", " ", "\[Tau]"}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x3", "-", "x4"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y3", "-", "y4"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Erfi", "[", 
          FractionBox[
           RowBox[{"z0", " ", "\[Kappa]"}], 
           SqrtBox[
            FractionBox[
             RowBox[{"q", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]], 
          "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
      " ", "\[Pi]", " ", 
      SuperscriptBox["z0", "2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{"Dd", " ", "\[Tau]"}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x3", "-", "x4"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y3", "-", "y4"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Erfi", "[", 
          FractionBox[
           RowBox[{
           "4", " ", "Dd", " ", "z0", " ", "\[Kappa]", " ", "\[Tau]"}], 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             "q"]]], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
      " ", "\[Pi]", " ", 
      SuperscriptBox["z0", "2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{"Dd", " ", "\[Tau]"}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x3", "-", "x4"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y3", "-", "y4"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Erfi", "[", 
          FractionBox[
           RowBox[{
           "4", " ", "Dd", " ", "z0", " ", "\[Kappa]", " ", "\[Tau]"}], 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             "q"]]], "]"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "q", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}]}], 
            SuperscriptBox["w0", "2"]]}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              FractionBox[
               SuperscriptBox["z0", "2"], 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
             ")"}]}], "q"]}], ")"}]}]], " ", "\[Pi]", " ", 
      SuperscriptBox["z0", "2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{"Dd", " ", "\[Tau]"}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x3", "-", "x4"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y3", "-", "y4"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Erfi", "[", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], 
           RowBox[{"2", " ", 
            SqrtBox[
             RowBox[{"q", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]]}]], "]"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "q", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}]}], 
            SuperscriptBox["w0", "2"]]}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], 
           RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              FractionBox[
               SuperscriptBox["z0", "2"], 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
             ")"}]}], "q"]}], ")"}]}]], " ", "\[Pi]", " ", 
      SuperscriptBox["z0", "2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{"Dd", " ", "\[Tau]"}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x3", "-", "x4"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y3", "-", "y4"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Erfi", "[", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], 
           RowBox[{"2", " ", 
            SqrtBox[
             RowBox[{"q", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]]}]], "]"}]}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.519034572410688*^9, 3.519038571693144*^9, 
  3.51911303294895*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y Integration", "Subsection",
 CellChangeTimes->{{3.5177120430240726`*^9, 3.51771204546321*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3y1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y2_", ",", "y3_", ",", 
    "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint3z4", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5177423766146393`*^9, 3.517742388617363*^9}, {
   3.5190340024348707`*^9, 3.5190340073241253`*^9}, {3.519098376070786*^9, 
   3.519098381767736*^9}, 3.519106425308443*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"32", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "-", 
           RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}]}], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["y2", "2"]}], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}]}], 
       RowBox[{"4", " ", "Dd", " ", 
        SuperscriptBox["w0", "2"], " ", "\[Tau]"}]]}]], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"64", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"q", " ", 
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "-", 
           RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}]}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["y2", "2"]}], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}]}], 
       RowBox[{"4", " ", "Dd", " ", "q", " ", 
        SuperscriptBox["w0", "2"], " ", "\[Tau]"}]]}]], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"16", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["y2", "2"]}], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x1", "2"], "-", 
          RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
          SuperscriptBox["x3", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            FractionBox[
             SuperscriptBox["z0", "2"], 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}],
          "q"]}], ")"}]}]], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"64", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["y2", "2"]}], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
        
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y2", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "-", 
           RowBox[{"2", " ", "y2", " ", "y3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["y3", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["y2", "2"], " ", "\[Tau]"}], "-", 
           RowBox[{
           "8", " ", "Dd", " ", "q", " ", "y2", " ", "y3", " ", "\[Tau]"}], 
           "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["y3", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"16", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["x1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           "-", 
           RowBox[{"2", " ", "x1", " ", "x3", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["x3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]}], 
          ")"}]}]}], 
       RowBox[{"4", " ", "Dd", " ", 
        SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.519034598476746*^9, 3.519038597894857*^9, 
  3.519113067182887*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3y2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y3_", ",", "y4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint3y1", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y2", ",", "y3", ",", "y4", 
       ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.519034020987343*^9, 3.519034026483489*^9}, {
   3.519098387509461*^9, 3.519098393007359*^9}, 3.519106430115981*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            SuperscriptBox["x2", "2"], "-", 
            RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["y3", "2"]}], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"y3", "-", "y4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"16", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            SuperscriptBox["x2", "2"], "-", 
            RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["y3", "2"]}], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "4"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"y3", "-", "y4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"32", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{"32", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], 
          SuperscriptBox["w0", "2"]], "+", 
         FractionBox[
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["x3", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["x4", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["y3", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["y4", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"12", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["x3", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["x4", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"12", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["y3", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["y4", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"32", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"], " ", 
              SuperscriptBox["\[Tau]", "2"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["x1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             "+", 
             RowBox[{
              SuperscriptBox["x2", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             "-", 
             RowBox[{"4", " ", "x1", " ", "x3", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]}], ")"}]}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"16", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"], " ", 
              SuperscriptBox["\[Tau]", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["x1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             "-", 
             RowBox[{"2", " ", "x1", " ", "x3", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             "+", 
             RowBox[{
              SuperscriptBox["x3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]}], ")"}]}], 
          RowBox[{"Dd", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"y3", "-", "y4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"32", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"16", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y3", "2"]}], "+", 
               SuperscriptBox["y4", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"128", " ", 
          SuperscriptBox["Dd", "3"], " ", 
          SuperscriptBox["q", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "3"]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y3", "2"]}], "+", 
               SuperscriptBox["y4", "2"], "+", 
               RowBox[{"16", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"y3", "-", "y4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"8", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.519034742544281*^9, 3.5190387404601707`*^9, 
  3.51911338294447*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3y3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint3y2", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y3", ",", "y4", ",", 
       "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y3", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.519034038308049*^9, 3.519034041314868*^9}, {
   3.5190983994723177`*^9, 3.519098405833907*^9}, 3.519106435203676*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            SuperscriptBox["x2", "2"], "-", 
            RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["y4", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["y4", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"16", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            SuperscriptBox["x2", "2"], "-", 
            RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["y4", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["y4", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "4"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"32", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["y4", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x3", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["x4", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["y4", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"12", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["x3", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["x4", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"16", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["y4", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["x1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
            "+", 
            RowBox[{
             SuperscriptBox["x2", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
            "-", 
            RowBox[{"4", " ", "x1", " ", "x3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]}],
            ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["w0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"16", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["x1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
            "-", 
            RowBox[{"2", " ", "x1", " ", "x3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
            "+", 
            RowBox[{
             SuperscriptBox["x3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]}],
            ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"32", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"16", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["y4", "2"]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["y4", "2"]}]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"128", " ", 
          SuperscriptBox["Dd", "3"], " ", 
          SuperscriptBox["q", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["y4", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "3"]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"4", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["y4", "2"]}], "+", 
               RowBox[{"16", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"8", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.5190347632949467`*^9, 3.519038760817746*^9, 
  3.5191134192252555`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3y4", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}],
   "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint3y3", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y4", ",", "\[Tau]"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y4", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.51903405712321*^9, 3.5190340608902617`*^9}, {
  3.519098409162881*^9, 3.519098413974984*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], "-", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]], "-", 
      FractionBox[
       RowBox[{"4", " ", "Dd", " ", 
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], " ", 
    SqrtBox["\[Pi]"], " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    SqrtBox[
     FractionBox["1", 
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], " ", 
    
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}]}], 
   RowBox[{"64", " ", "q"}]], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"16", " ", "q"}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            FractionBox[
             SuperscriptBox["z0", "2"], 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}],
          "q"]}], ")"}]}]], " ", 
    SqrtBox["\[Pi]"], " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    SqrtBox[
     FractionBox["1", 
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], " ", 
    
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", "32"], " ", 
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"], "+", 
          SuperscriptBox["x3", "2"], "+", 
          SuperscriptBox["x4", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   SqrtBox["\[Pi]"], " ", 
   SuperscriptBox["w0", "2"], " ", 
   SuperscriptBox["z0", "2"], " ", 
   SqrtBox[
    FractionBox["1", 
     RowBox[{"Dd", " ", 
      SuperscriptBox["q", "2"], " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{"x1", "-", "x2"}], "]"}], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{"x3", "-", "x4"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "64"], " ", 
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"], "+", 
          SuperscriptBox["x3", "2"], "+", 
          SuperscriptBox["x4", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   SqrtBox["\[Pi]"], " ", 
   SuperscriptBox["w0", "2"], " ", 
   SuperscriptBox["z0", "2"], " ", 
   SqrtBox[
    FractionBox["1", 
     RowBox[{"Dd", " ", 
      SuperscriptBox["q", "2"], " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{"x1", "-", "x2"}], "]"}], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{"x3", "-", "x4"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.519034797620986*^9, 3.5190387948009567`*^9, 
  3.519113549661086*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x Integration", "Subsection",
 CellChangeTimes->{{3.517712055584053*^9, 3.517712057343378*^9}, 
   3.517742163353998*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3x1", "[", 
   RowBox[{"x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint3y4", "[", 
      RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517742489376445*^9, 3.5177425003032503`*^9}, {
   3.519034081234128*^9, 3.519034083345433*^9}, {3.519098417910344*^9, 
   3.519098424273952*^9}, 3.519106443235126*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["x2", "2"]}], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x2", "-", "x3"}], ")"}], "2"], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            FractionBox[
             SuperscriptBox["z0", "2"], 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}],
          "q"]}], ")"}]}]], " ", 
    SqrtBox["\[Pi]"], " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    SqrtBox[
     FractionBox["1", 
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], " ", 
    
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}]}], 
   RowBox[{"16", " ", "q"}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["x2", "2"]}], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x2", "2"], "-", 
          RowBox[{"2", " ", "x2", " ", "x3"}], "+", 
          SuperscriptBox["x3", "2"], "+", 
          FractionBox[
           RowBox[{"16", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]]}], ")"}]}]], " ", 
    SqrtBox["\[Pi]"], " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    SqrtBox[
     FractionBox["1", 
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], " ", 
    
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}]}], 
   RowBox[{"64", " ", "q"}]], "+", 
  RowBox[{
   FractionBox["1", "32"], " ", 
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["x2", "2"]}], "+", 
          SuperscriptBox["x3", "2"], "+", 
          SuperscriptBox["x4", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x2", "-", "x3"}], ")"}], "2"], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   SqrtBox["\[Pi]"], " ", 
   SuperscriptBox["w0", "2"], " ", 
   SuperscriptBox["z0", "2"], " ", 
   SqrtBox[
    FractionBox["1", 
     RowBox[{"Dd", " ", 
      SuperscriptBox["q", "2"], " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{"x3", "-", "x4"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "64"], " ", 
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["x2", "2"]}], "+", 
          SuperscriptBox["x3", "2"], "+", 
          SuperscriptBox["x4", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x2", "-", "x3"}], ")"}], "2"], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   SqrtBox["\[Pi]"], " ", 
   SuperscriptBox["w0", "2"], " ", 
   SuperscriptBox["z0", "2"], " ", 
   SqrtBox[
    FractionBox["1", 
     RowBox[{"Dd", " ", 
      SuperscriptBox["q", "2"], " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{"x3", "-", "x4"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.519034809466577*^9, 3.5190388065811234`*^9, 
  3.5191135720514245`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3x2", "[", 
   RowBox[{"x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint3x1", "[", 
      RowBox[{"x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.519034093521607*^9, 3.519034098176869*^9}, {
   3.51909842740593*^9, 3.519098433517777*^9}, 3.519106446617979*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["x3", "2"]}], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}], " ", "\[Tau]"}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["w0", "4"], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]"}]}]]}]], " ", "\[Pi]", " ", 
    
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}]}], 
   RowBox[{"16", " ", "q", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "4"], "+", 
        RowBox[{"12", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"], " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "+", 
         RowBox[{"16", " ", "Dd", " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            SuperscriptBox["z0", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"128", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{"4", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "\[Pi]", " ", 
     SuperscriptBox["w0", "3"], " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"8", " ", "q", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "4"], "+", 
         RowBox[{"12", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "+", 
               SuperscriptBox["x4", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "4"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", "\[Pi]", " ", 
     SuperscriptBox["w0", "3"], " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"32", " ", "q", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "4"], "+", 
         RowBox[{"12", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "q"]}], "-", 
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"]}], 
          SuperscriptBox["w0", "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["x3", "2"]}], 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}]}]],
     " ", "\[Pi]", " ", 
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}]}], 
   RowBox[{"32", " ", "q", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "4"], "+", 
        RowBox[{"12", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"], " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]]}]], "Output",
 CellChangeTimes->{3.519034884768752*^9, 3.519038881604968*^9, 
  3.519113703721614*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3x3", "[", 
   RowBox[{"x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint3x2", "[", 
      RowBox[{"x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x3", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.519034112065001*^9, 3.519034114584416*^9}, {
   3.519098438220603*^9, 3.5190984438168097`*^9}, 3.5191064503947*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "q", " ", 
           SuperscriptBox["x4", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          RowBox[{
           SuperscriptBox["w0", "4"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["w0", "2"], " ", "\[Tau]"}]}]]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], "q"]}], "-", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          SuperscriptBox["x4", "2"]}], 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "-", 
        FractionBox[
         RowBox[{"16", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["x4", "2"], " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["w0", "4"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["w0", "2"], " ", "\[Tau]"}]}]]}]], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["w0", "4"], " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"64", " ", "Dd", " ", 
            SuperscriptBox["q", "3"], " ", 
            SuperscriptBox["x4", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"256", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["q", "4"], " ", 
            SuperscriptBox["x4", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{"16", " ", 
            SuperscriptBox["q", "2"], " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
          RowBox[{"4", " ", "q", " ", 
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["x4", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["w0", "2"], "+", 
               SuperscriptBox["z0", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{"Dd", " ", 
             SuperscriptBox["w0", "4"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["q", "3"], " ", 
             SuperscriptBox["x4", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{"q", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]}]]}], ")"}], " ", "\[Pi]", " ", 
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "2"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"32", " ", "q", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "4"], "+", 
        RowBox[{"12", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"], " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.519034901534759*^9, 3.519038898325004*^9, 
  3.519113733346235*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3x4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint3x3", "[", 
      RowBox[{"x4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x4", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5190341277843647`*^9, 3.519034131727693*^9}, {
   3.5190984483583717`*^9, 3.519098452627317*^9}, 3.519106457847348*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"5", " ", 
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
      RowBox[{"4", " ", "q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"5", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"24", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
       RowBox[{"4", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"24", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
       RowBox[{"4", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
    ")"}], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["w0", "4"], " ", 
   SuperscriptBox["z0", "2"]}], 
  RowBox[{"64", " ", "q", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["w0", "2"], "+", 
     RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{"q", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
      ")"}]}]]}]]], "Output",
 CellChangeTimes->{3.519034908417387*^9, 3.519038905147339*^9, 
  3.5191137624552374`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g3", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"myint3x4", "[", "\[Tau]", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5190341398753767`*^9, 3.519034142346333*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"5", " ", 
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
      RowBox[{"4", " ", "q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"5", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"24", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
       RowBox[{"4", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"24", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
       RowBox[{"4", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
    ")"}], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["w0", "4"], " ", 
   SuperscriptBox["z0", "2"]}], 
  RowBox[{"64", " ", "q", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["w0", "2"], "+", 
     RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{"q", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
      ")"}]}]]}]]], "Output",
 CellChangeTimes->{3.519034909620016*^9, 3.5190389062379847`*^9, 
  3.519113799048519*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.519034151772365*^9, 3.5190341534895*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute g4", "Section",
 CellChangeTimes->{{3.517712244605625*^9, 3.517712246731595*^9}, {
   3.517743037922456*^9, 3.517743042681806*^9}, {3.5180897812388887`*^9, 
   3.518089781618937*^9}, 3.518089821275112*^9}],

Cell[CellGroupData[{

Cell["g4", "Subsection",
 CellChangeTimes->{{3.517731269318281*^9, 3.517731271899744*^9}, {
   3.517731408856715*^9, 3.51773141008643*^9}, 3.5177455798684883`*^9}],

Cell[CellGroupData[{

Cell["z Integration", "Subsubsection",
 CellChangeTimes->{{3.5177312790362263`*^9, 3.5177312806279383`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4z1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z2_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"g4int", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z1", ",", "z2", ",", "z3", ",", "z4", ",", "\[Tau]"}],
       "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517731395958997*^9, 3.517731418541161*^9}, {
   3.5177314672089443`*^9, 3.517731529832615*^9}, {3.517745612824994*^9, 
   3.517745628014365*^9}, 3.517745661450716*^9, {3.5190984728116407`*^9, 
   3.519098479675494*^9}, 3.519106467677431*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"256", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"5", "/", "2"}]], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          SuperscriptBox["x1", "2"]}], 
         SuperscriptBox["w0", "2"]]}], "-", 
       FractionBox[
        RowBox[{"4", " ", "q", " ", 
         SuperscriptBox["x2", "2"]}], 
        SuperscriptBox["w0", "2"]], "-", 
       FractionBox[
        RowBox[{"4", " ", "q", " ", 
         SuperscriptBox["x3", "2"]}], 
        SuperscriptBox["w0", "2"]], "-", 
       FractionBox[
        RowBox[{"4", " ", "q", " ", 
         SuperscriptBox["x4", "2"]}], 
        SuperscriptBox["w0", "2"]], "-", 
       FractionBox[
        RowBox[{"4", " ", "q", " ", 
         SuperscriptBox["y1", "2"]}], 
        SuperscriptBox["w0", "2"]], "-", 
       FractionBox[
        RowBox[{"4", " ", "q", " ", 
         SuperscriptBox["y2", "2"]}], 
        SuperscriptBox["w0", "2"]], "-", 
       FractionBox[
        RowBox[{"4", " ", "q", " ", 
         SuperscriptBox["y3", "2"]}], 
        SuperscriptBox["w0", "2"]], "-", 
       FractionBox[
        RowBox[{"4", " ", "q", " ", 
         SuperscriptBox["y4", "2"]}], 
        SuperscriptBox["w0", "2"]], "-", 
       FractionBox[
        RowBox[{"4", " ", "q", " ", 
         SuperscriptBox["z2", "2"]}], 
        SuperscriptBox["z0", "2"]], "-", 
       FractionBox[
        RowBox[{"4", " ", "q", " ", 
         SuperscriptBox["z3", "2"]}], 
        SuperscriptBox["z0", "2"]], "-", 
       FractionBox[
        RowBox[{"4", " ", "q", " ", 
         SuperscriptBox["z4", "2"]}], 
        SuperscriptBox["z0", "2"]], "-", 
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}], "-", 
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}], "-", 
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}], "-", 
       FractionBox[
        SuperscriptBox["x1", "2"], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
       FractionBox[
        SuperscriptBox["x2", "2"], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
       FractionBox[
        RowBox[{"2", " ", "x1", " ", "x3"}], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
       FractionBox[
        SuperscriptBox["x3", "2"], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
       FractionBox[
        RowBox[{"2", " ", "x2", " ", "x4"}], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
       FractionBox[
        SuperscriptBox["x4", "2"], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
       FractionBox[
        SuperscriptBox["y1", "2"], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
       FractionBox[
        SuperscriptBox["y2", "2"], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
       FractionBox[
        RowBox[{"2", " ", "y1", " ", "y3"}], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
       FractionBox[
        SuperscriptBox["y3", "2"], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
       FractionBox[
        RowBox[{"2", " ", "y2", " ", "y4"}], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
       FractionBox[
        SuperscriptBox["y4", "2"], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
       FractionBox[
        SuperscriptBox["z2", "2"], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
       FractionBox[
        SuperscriptBox["z3", "2"], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
       FractionBox[
        RowBox[{"2", " ", "z2", " ", "z4"}], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
       FractionBox[
        SuperscriptBox["z4", "2"], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z3", "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
             "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
      ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["z0", "2"], " ", "z3", " ", "\[Kappa]"}], 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]}], ")"}], 
   " ", "z0"}]}]], "Output",
 CellChangeTimes->{3.51773192794835*^9, 3.517746061079915*^9, 
  3.517902492769512*^9, 3.5190390182022953`*^9, 3.519114102544634*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4z2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint4z1", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z2", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"z2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5177319528253193`*^9, 3.5177320022583637`*^9}, {
   3.517745661499382*^9, 3.517745661546136*^9}, {3.5190984855568666`*^9, 
   3.5190984923697567`*^9}, 3.519106469995677*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"128", " ", 
    SuperscriptBox["Dd", "2"], " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"4", " ", "Dd", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"], "+", 
          SuperscriptBox["x3", "2"], "+", 
          SuperscriptBox["x4", "2"], "+", 
          SuperscriptBox["y1", "2"], "+", 
          SuperscriptBox["y2", "2"], "+", 
          SuperscriptBox["y3", "2"], "+", 
          SuperscriptBox["y4", "2"]}], ")"}], " ", 
        SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["w0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x3", "2"], " ", 
           SuperscriptBox["z0", "4"]}], "+", 
          RowBox[{
           SuperscriptBox["x4", "2"], " ", 
           SuperscriptBox["z0", "4"]}], "+", 
          RowBox[{
           SuperscriptBox["y1", "2"], " ", 
           SuperscriptBox["z0", "4"]}], "+", 
          RowBox[{
           SuperscriptBox["y2", "2"], " ", 
           SuperscriptBox["z0", "4"]}], "-", 
          RowBox[{"2", " ", "y1", " ", "y3", " ", 
           SuperscriptBox["z0", "4"]}], "+", 
          RowBox[{
           SuperscriptBox["y3", "2"], " ", 
           SuperscriptBox["z0", "4"]}], "-", 
          RowBox[{"2", " ", "y2", " ", "y4", " ", 
           SuperscriptBox["z0", "4"]}], "+", 
          RowBox[{
           SuperscriptBox["y4", "2"], " ", 
           SuperscriptBox["z0", "4"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["x3", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["x4", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["y1", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["y2", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "y1", " ", "y3", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["y3", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "-", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "y2", " ", "y4", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["y4", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["z3", "2"], " ", "\[Tau]"}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["z4", "2"], " ", "\[Tau]"}], "+", 
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "Dd", " ", 
           SuperscriptBox["z0", "4"], " ", "z3", " ", "\[Kappa]", " ", 
           "\[Tau]"}], "+", 
          RowBox[{"16", " ", 
           SuperscriptBox["Dd", "2"], " ", 
           SuperscriptBox["q", "2"], " ", 
           SuperscriptBox["z3", "2"], " ", 
           SuperscriptBox["\[Tau]", "2"]}], "+", 
          RowBox[{"16", " ", 
           SuperscriptBox["Dd", "2"], " ", 
           SuperscriptBox["q", "2"], " ", 
           SuperscriptBox["z4", "2"], " ", 
           SuperscriptBox["\[Tau]", "2"]}], "+", 
          RowBox[{"16", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", "z3", " ", "\[Kappa]", " ", 
           SuperscriptBox["\[Tau]", "2"]}], "+", 
          RowBox[{"16", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", "z4", " ", "\[Kappa]", " ", 
           SuperscriptBox["\[Tau]", "2"]}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox["Dd", "2"], " ", 
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           SuperscriptBox["\[Tau]", "2"]}], "-", 
          RowBox[{"2", " ", "x1", " ", "x3", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "-", 
          RowBox[{"2", " ", "x2", " ", "x4", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "+", 
          RowBox[{
           SuperscriptBox["x1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "4"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["x2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "4"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}]}], 
         ")"}]}]}], 
      RowBox[{"4", " ", "Dd", " ", 
       SuperscriptBox["w0", "2"], " ", 
       SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["z0", "2"], " ", "z3", " ", "\[Kappa]"}], 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["z0", "2"], " ", "z4", " ", "\[Kappa]"}], 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]}], ")"}], 
   " ", 
   SuperscriptBox["z0", "2"]}]}]], "Output",
 CellChangeTimes->{3.517732449586495*^9, 3.51774649564223*^9, 
  3.517902924859393*^9, 3.519039182539217*^9, 3.5191144709777093`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4z3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint4z2", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z3", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517732024322637*^9, 3.517732036074086*^9}, {
   3.517745661589201*^9, 3.5177456616480827`*^9}, {3.519098496002125*^9, 
   3.519098500493258*^9}, 3.519106474411126*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "6"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x1", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["x2", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["x3", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["x4", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["y1", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["y2", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["y3", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["y4", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z4", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], 
         RowBox[{
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"]}]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "-", 
            RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
            SuperscriptBox["x3", "2"], "-", 
            RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y1", "2"], "+", 
            SuperscriptBox["y2", "2"], "-", 
            RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
            SuperscriptBox["y3", "2"], "-", 
            RowBox[{"2", " ", "y2", " ", "y4"}], "+", 
            SuperscriptBox["y4", "2"], "+", 
            RowBox[{
            "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", "\[Kappa]", 
             " ", "\[Tau]"}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "-", 
               RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "-", 
               RowBox[{"2", " ", "y1", " ", "y3"}], "+", 
               SuperscriptBox["y3", "2"], "-", 
               RowBox[{"2", " ", "y2", " ", "y4"}], "+", 
               SuperscriptBox["y4", "2"], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["z4", "2"]}], "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                "\[Kappa]", " ", "\[Tau]"}]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x1", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x2", "2"]}], "-", 
               RowBox[{"6", " ", "x1", " ", "x3"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x3", "2"]}], "-", 
               RowBox[{"6", " ", "x2", " ", "x4"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["x4", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y1", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y2", "2"]}], "-", 
               RowBox[{"6", " ", "y1", " ", "y3"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y3", "2"]}], "-", 
               RowBox[{"6", " ", "y2", " ", "y4"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y4", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["z4", "2"]}], "+", 
               RowBox[{
               "16", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                "\[Kappa]", " ", "\[Tau]"}], "+", 
               RowBox[{"16", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
     ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["z0", "2"], " ", "z4", " ", "\[Kappa]"}], 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], ")"}], " ", 
    
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], " ", 
    SuperscriptBox["z0", "2"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["Dd", "2"], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["z0", "4"], "+", 
       RowBox[{"4", " ", "Dd", " ", "q", " ", 
        SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}]]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.517732491889298*^9, 3.517746538013124*^9, 
  3.517902966934539*^9, 3.5190392352172213`*^9, 3.5191149039290466`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4z4", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint4z3", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z4", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5177320482456417`*^9, 3.517732062871601*^9}, {
  3.517745661695685*^9, 3.5177456617176867`*^9}, {3.5190985042301073`*^9, 
  3.5190985096868*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"64", " ", 
    SuperscriptBox["Dd", "2"], " ", "\[Pi]", " ", "q", " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y1", "2"], "+", 
            SuperscriptBox["y2", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x2", "-", "x4"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"y2", "-", "y4"}], ")"}], "2"]}], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["2", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
              
              FractionBox["1", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
             ")"}]}]}], ")"}]}], "q"]}], ")"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], "2"], " ", 
   SuperscriptBox["z0", "4"]}]}]], "Output",
 CellChangeTimes->{3.517732644952421*^9, 3.517746690653228*^9, 
  3.517903119432439*^9, 3.5190393293670397`*^9, 3.519115384043659*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y Integration", "Subsubsection",
 CellChangeTimes->{{3.517745761444187*^9, 3.517745763219038*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4y1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y2_", ",", "y3_", ",", 
    "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint4z4", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3", 
       ",", "y4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517732083276355*^9, 3.517732100511986*^9}, {
   3.51774566175308*^9, 3.5177456617711077`*^9}, {3.519098513235175*^9, 
   3.519098518565982*^9}, 3.519106479045557*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "6"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "-", 
               RowBox[{"x2", " ", "x4"}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "-", 
               RowBox[{"y2", " ", "y4"}], "+", 
               SuperscriptBox["y4", "2"]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{"128", " ", 
          SuperscriptBox["Dd", "3"], " ", 
          SuperscriptBox["q", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y2", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "3"]}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "-", 
               RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y2", "2"], "-", 
               RowBox[{"2", " ", "y2", " ", "y4"}], "+", 
               SuperscriptBox["y4", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "4"]}], "+", 
            RowBox[{"6", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "-", 
               RowBox[{"x2", " ", "x4"}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "-", 
               RowBox[{"y2", " ", "y4"}], "+", 
               SuperscriptBox["y4", "2"], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox["w0", "2"]], "+", 
        RowBox[{"2", " ", "q", " ", 
         SuperscriptBox["z0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y2", "2"], "-", 
              RowBox[{"2", " ", "y2", " ", "y4"}], "+", 
              SuperscriptBox["y4", "2"], "+", 
              RowBox[{"8", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y2", "2"], "+", 
              SuperscriptBox["y3", "2"], "-", 
              RowBox[{"y2", " ", "y4"}], "+", 
              SuperscriptBox["y4", "2"], "+", 
              RowBox[{"12", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"16", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "-", 
               RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
               SuperscriptBox["x3", "2"], "-", 
               RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y2", "2"], "-", 
               RowBox[{"2", " ", "y2", " ", "y4"}], "+", 
               SuperscriptBox["y4", "2"], "+", 
               RowBox[{"24", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
         RowBox[{"2", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], "2"], " ", "w0", " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"32", " ", "Dd", " ", 
    SqrtBox["\[Pi]"], " ", "q", " ", "\[Tau]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5177327105182037`*^9, 3.517746755487863*^9, 
  3.517903184878088*^9, 3.519039433036276*^9, 3.5191155624041758`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4y2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y3_", ",", "y4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint4y1", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y2", ",", "y3", ",", "y4", 
       ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517732116104549*^9, 3.5177321275278187`*^9}, {
   3.517745661774592*^9, 3.517745661786536*^9}, {3.519098522335894*^9, 
   3.519098527857939*^9}, 3.519106482762341*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["w0", "4"], " ", 
         SuperscriptBox["z0", "6"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "3"], " ", 
         SuperscriptBox["q", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "3"]}], "+", 
        RowBox[{"128", " ", 
         SuperscriptBox["Dd", "4"], " ", 
         SuperscriptBox["q", "5"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "4"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["Dd", "2"], " ", 
         SuperscriptBox["q", "3"], " ", 
         SuperscriptBox["\[Tau]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["w0", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "4"]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"8", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"], "+", 
              RowBox[{"12", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"q", " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"16", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"24", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
       RowBox[{"4", " ", "Dd", " ", "q", " ", 
        SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
         RowBox[{"2", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], "2"], " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"16", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517732774628825*^9, 3.517746819768244*^9, 
  3.517903247568513*^9, 3.519039573219249*^9, 3.519115784138976*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4y3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint4y2", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y3", ",", "y4", ",", 
       "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y3", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517732145649612*^9, 3.5177321569352503`*^9}, {
   3.517745661789935*^9, 3.517745661802009*^9}, {3.519098531842122*^9, 
   3.519098537892537*^9}, 3.519106486762063*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["w0", "4"], " ", 
         SuperscriptBox["z0", "6"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "3"], " ", 
         SuperscriptBox["q", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "3"]}], "+", 
        RowBox[{"128", " ", 
         SuperscriptBox["Dd", "4"], " ", 
         SuperscriptBox["q", "5"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "4"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["Dd", "2"], " ", 
         SuperscriptBox["q", "3"], " ", 
         SuperscriptBox["\[Tau]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["w0", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "4"]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y4", "2"], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"8", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y4", "2"], "+", 
              RowBox[{"12", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"q", " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"16", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"24", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
       RowBox[{"4", " ", "Dd", " ", "q", " ", 
        SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
         RowBox[{"2", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], "2"], " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "4"], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox["w0", "4"]}], "+", 
       RowBox[{"4", " ", "Dd", " ", "\[Pi]", " ", "q", " ", 
        SuperscriptBox["w0", "2"], " ", "\[Tau]"}]}], 
      RowBox[{
       RowBox[{"2", " ", "q", " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{"4", " ", "Dd", " ", 
        SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"16", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5177328028201036`*^9, 3.5177468481594143`*^9, 
  3.517903275847896*^9, 3.5190396069517317`*^9, 3.519115847857726*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4y4", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}],
   "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint4y3", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y4", ",", "\[Tau]"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y4", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517732166673613*^9, 3.5177321820067167`*^9}, {
  3.517745661805352*^9, 3.5177456618211*^9}, {3.519098541873455*^9, 
  3.519098548159334*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x2", "-", "x4"}], ")"}], "2"]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["2", 
                 RowBox[{
                  SuperscriptBox["z0", "2"], "+", 
                  RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
               FractionBox["1", 
                RowBox[{
                 SuperscriptBox["z0", "2"], "+", 
                 RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
              ")"}]}]}], ")"}]}], "q"]}], ")"}]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
         RowBox[{"2", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], "2"], " ", "\[Pi]", " ", 
    SuperscriptBox["w0", "4"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"32", " ", "Dd", " ", 
    SuperscriptBox["q", "2"], " ", "\[Tau]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5177328272145023`*^9, 3.517746872491576*^9, 
  3.517903300490355*^9, 3.519039627145486*^9, 3.5191159443106527`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x Integration", "Subsubsection",
 CellChangeTimes->{{3.517745769179029*^9, 3.517745770898965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4x1", "[", 
   RowBox[{"x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint4y4", "[", 
      RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517732196799386*^9, 3.517732209077632*^9}, {
   3.517745661824411*^9, 3.517745661836318*^9}, {3.519098554924506*^9, 
   3.519098559812488*^9}, 3.519106493449616*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["w0", "4"], " ", 
         SuperscriptBox["z0", "6"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "3"], " ", 
         SuperscriptBox["q", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "3"]}], "+", 
        RowBox[{"128", " ", 
         SuperscriptBox["Dd", "4"], " ", 
         SuperscriptBox["q", "5"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "4"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["Dd", "2"], " ", 
         SuperscriptBox["q", "3"], " ", 
         SuperscriptBox["\[Tau]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["w0", "4"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x2", "-", "x4"}], ")"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "4"]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"8", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "-", 
              RowBox[{"x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"12", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"q", " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"16", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x2", "2"], "-", 
              RowBox[{"2", " ", "x2", " ", "x4"}], "+", 
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"24", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
       RowBox[{"4", " ", "Dd", " ", "q", " ", 
        SuperscriptBox["w0", "2"], " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
         RowBox[{"2", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], "2"], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["w0", "5"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"16", " ", 
    SuperscriptBox["q", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517732851099391*^9, 3.517746896155963*^9, 
  3.5179033248133993`*^9, 3.519039679902471*^9, 3.519116074793357*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4x2", "[", 
   RowBox[{"x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint4x1", "[", 
      RowBox[{"x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517732221026703*^9, 3.517732234736074*^9}, {
   3.517745661839507*^9, 3.517745661852439*^9}, {3.5190985651109324`*^9, 
   3.519098569611928*^9}, 3.519106496833477*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["w0", "4"], " ", 
         SuperscriptBox["z0", "6"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["Dd", "2"], " ", 
         SuperscriptBox["q", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "2"]}], "+", 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "3"], " ", 
         SuperscriptBox["q", "5"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x3", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["x4", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["q", "3"], " ", 
         SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
       RowBox[{"q", " ", 
        SuperscriptBox["w0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
         RowBox[{"2", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], "2"], " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["w0", "6"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"8", " ", 
    SuperscriptBox["q", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517732878062765*^9, 3.517746923181123*^9, 
  3.517903352768886*^9, 3.519039766443984*^9, 3.5191161868544226`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4x3", "[", 
   RowBox[{"x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint4x2", "[", 
      RowBox[{"x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x3", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5177322454178867`*^9, 3.517732258925321*^9}, {
   3.51774566185576*^9, 3.517745661871338*^9}, {3.51909857344773*^9, 
   3.519098578069272*^9}, 3.519106500169159*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["w0", "4"], " ", 
         SuperscriptBox["z0", "6"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["Dd", "2"], " ", 
         SuperscriptBox["q", "4"], " ", 
         SuperscriptBox["x4", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "2"]}], "+", 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "3"], " ", 
         SuperscriptBox["q", "5"], " ", 
         SuperscriptBox["x4", "2"], " ", 
         SuperscriptBox["\[Tau]", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x4", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["z0", "2"]}]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         SuperscriptBox["q", "3"], " ", 
         SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x4", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
       RowBox[{"q", " ", 
        SuperscriptBox["w0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
         RowBox[{"2", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], "2"], " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["w0", "6"], " ", 
    SuperscriptBox["z0", "4"], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox["w0", "4"]}], "+", 
       RowBox[{"4", " ", "Dd", " ", "\[Pi]", " ", "q", " ", 
        SuperscriptBox["w0", "2"], " ", "\[Tau]"}]}], 
      RowBox[{
       RowBox[{"2", " ", "q", " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{"4", " ", "Dd", " ", 
        SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"8", " ", 
    SuperscriptBox["q", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517732886896974*^9, 3.517746932138587*^9, 
  3.517903361734133*^9, 3.519039778697549*^9, 3.5191162206821146`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4x4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint4x3", "[", 
      RowBox[{"x4", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x4", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517732271590006*^9, 3.517732281837782*^9}, {
   3.5177456618754396`*^9, 3.517745661886105*^9}, {3.519098581502565*^9, 
   3.519098586793171*^9}, 3.519106505536833*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "4"], "+", 
         RowBox[{"6", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], "2"], " ", 
   SuperscriptBox["\[Pi]", "3"], " ", 
   SuperscriptBox["w0", "8"], " ", 
   SuperscriptBox["z0", "4"]}], 
  RowBox[{"16", " ", 
   SuperscriptBox["q", "3"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["z0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "Output",\

 CellChangeTimes->{3.51773289336174*^9, 3.517746938637725*^9, 
  3.5179033682174397`*^9, 3.519039787986353*^9, 3.519116235681923*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"myint4x4", "[", "\[Tau]", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.51773292161376*^9, 3.517732931084072*^9}, 
   3.517745661888628*^9, 3.517745779117835*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "4"], "+", 
         RowBox[{"6", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], "2"], " ", 
   SuperscriptBox["\[Pi]", "3"], " ", 
   SuperscriptBox["w0", "8"], " ", 
   SuperscriptBox["z0", "4"]}], 
  RowBox[{"16", " ", 
   SuperscriptBox["q", "3"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["z0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "Output",\

 CellChangeTimes->{3.517732933646641*^9, 3.517746939675591*^9, 
  3.517903369208128*^9, 3.51903978880338*^9, 3.5191162736501865`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["I mean", "Section",
 CellChangeTimes->{{3.517919420171873*^9, 3.517919421097612*^9}}],

Cell[CellGroupData[{

Cell["Term 1", "Subsection",
 CellChangeTimes->{{3.517919873363069*^9, 3.517919874043497*^9}}],

Cell[CellGroupData[{

Cell["z Integration", "Subsubsection",
 CellChangeTimes->{{3.517919879835125*^9, 3.5179198815867853`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myintimz1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "y1_", ",", "y2_", ",", "z2_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"imeanint", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "y1", ",", "y2", ",", "z1", ",", "z2", ",", 
       "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5179195764498997`*^9, 3.517919615279607*^9}, {
   3.519098600190875*^9, 3.519098605201848*^9}, 3.5191065170173073`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "q"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"], "+", 
          SuperscriptBox["y1", "2"], "+", 
          SuperscriptBox["y2", "2"]}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         SuperscriptBox["z2", "2"], 
         SuperscriptBox["z0", "2"]]}], ")"}]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"4", " ", "q"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   SqrtBox["\[Pi]"], " ", "z0"}], 
  RowBox[{"2", " ", 
   SqrtBox["q"]}]]], "Output",
 CellChangeTimes->{3.5179196288232403`*^9, 3.5179201616908407`*^9, 
  3.519039791214301*^9, 3.5191162885249968`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myintimz2", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "y1_", ",", "y2_", ",", "\[Tau]_"}], "]"}],
   "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myintimz1", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "y1", ",", "y2", ",", "z2", ",", "\[Tau]"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5179196371657743`*^9, 3.5179196532736387`*^9}, {
   3.519098609070817*^9, 3.519098614732396*^9}, 3.519106520082767*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"], "+", 
          SuperscriptBox["y1", "2"], "+", 
          SuperscriptBox["y2", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", "\[Pi]", " ", 
   SuperscriptBox["z0", "2"]}], "q"]], "Output",
 CellChangeTimes->{3.517919655711857*^9, 3.519039792819139*^9, 
  3.519116306227895*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myintimy1", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "y2_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myintimz2", "[", 
      RowBox[{"x1", ",", "x2", ",", "y1", ",", "y2", ",", "\[Tau]"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.51791966470299*^9, 3.517919678269909*^9}, {
   3.517919732703672*^9, 3.517919732837859*^9}, {3.519098617828985*^9, 
   3.519098623604974*^9}, 3.519106523718761*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"], "+", 
          SuperscriptBox["y2", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", "w0", " ", 
   SuperscriptBox["z0", "2"]}], 
  SuperscriptBox["q", 
   RowBox[{"3", "/", "2"}]]]], "Output",
 CellChangeTimes->{3.517919679699366*^9, 3.5179197345144987`*^9, 
  3.519039794326807*^9, 3.5191163103528423`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myintimy2", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myintimy1", "[", 
      RowBox[{"x1", ",", "x2", ",", "y2", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517919741338912*^9, 3.517919756258027*^9}, {
   3.519098627026026*^9, 3.519098632199689*^9}, 3.519106527064625*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   SuperscriptBox["\[Pi]", "2"], " ", 
   SuperscriptBox["w0", "2"], " ", 
   SuperscriptBox["z0", "2"]}], 
  SuperscriptBox["q", "2"]]], "Output",
 CellChangeTimes->{3.51791975765473*^9, 3.519039795698576*^9, 
  3.5191163140402946`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myintimx1", "[", 
   RowBox[{"x2_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myintimy2", "[", 
      RowBox[{"x1", ",", "x2", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517919771859236*^9, 3.517919783773608*^9}, {
   3.519098635732675*^9, 3.519098641644617*^9}, 3.5191065301450367`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        SuperscriptBox["x2", "2"]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"5", "/", "2"}]], " ", 
   SuperscriptBox["w0", "3"], " ", 
   SuperscriptBox["z0", "2"]}], 
  SuperscriptBox["q", 
   RowBox[{"5", "/", "2"}]]]], "Output",
 CellChangeTimes->{3.517919785845707*^9, 3.519039796815176*^9, 
  3.5191163171027555`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myintimx2", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myintimx1", "[", 
      RowBox[{"x2", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517919794747884*^9, 3.517919803961081*^9}, {
  3.519098645645355*^9, 3.5190986516245537`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   SuperscriptBox["\[Pi]", "3"], " ", 
   SuperscriptBox["w0", "4"], " ", 
   SuperscriptBox["z0", "2"]}], 
  SuperscriptBox["q", "3"]]], "Output",
 CellChangeTimes->{3.517919805364737*^9, 3.5190397978251047`*^9, 
  3.5191163199152193`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Term 2", "Subsection",
 CellChangeTimes->{{3.517919891987419*^9, 3.5179198925394373`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2imz1", "[", 
   RowBox[{"x1_", ",", "y1_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"imeanint2", "[", 
      RowBox[{"x1", ",", "y1", ",", "z1", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517919974667863*^9, 3.5179200274786654`*^9}, 
   3.517920141652252*^9, {3.519098654741681*^9, 3.5190986591968393`*^9}, 
   3.519106538080307*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["y1", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{"2", " ", "q"}]]]}], ")"}], " ", 
   SqrtBox[
    FractionBox["\[Pi]", "2"]], " ", "z0"}], 
  RowBox[{"2", " ", 
   SqrtBox["q"]}]]], "Output",
 CellChangeTimes->{3.5179200353802557`*^9, 3.519039802059594*^9, 
  3.5191163343837843`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2imy1", "[", 
   RowBox[{"x1_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2imz1", "[", 
      RowBox[{"x1", ",", "y1", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517920057230308*^9, 3.51792007146154*^9}, 
   3.517920137310356*^9, {3.519098664702592*^9, 3.5190986697962837`*^9}, 
   3.5191065415596657`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "q", " ", 
        SuperscriptBox["x1", "2"]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{"2", " ", "q"}]]]}], ")"}], " ", "\[Pi]", " ", "w0", " ", 
   "z0"}], 
  RowBox[{"4", " ", "q"}]]], "Output",
 CellChangeTimes->{3.5179200737547493`*^9, 3.519039804177793*^9, 
  3.5191163401649604`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2imx1", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2imy1", "[", 
      RowBox[{"x1", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517920084939788*^9, 3.517920093197563*^9}, 
   3.517920133815189*^9, {3.519098672962963*^9, 3.519098677365424*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{"2", " ", "q"}]]]}], ")"}], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["w0", "2"], " ", "z0"}], 
  RowBox[{"4", " ", 
   SqrtBox["2"], " ", 
   SuperscriptBox["q", 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{3.517920094783051*^9, 3.519039805965763*^9, 
  3.519116345508642*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Combine", "Subsection",
 CellChangeTimes->{{3.517920113156788*^9, 3.5179201139316072`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"imean", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"myintimx2", "[", "\[Tau]", "]"}], "+", 
    RowBox[{"myint2imx1", "[", "\[Tau]", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517920120630784*^9, 3.5179201294210052`*^9}, {
  3.517920192434314*^9, 3.5179202080878057`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["w0", "2"], " ", "z0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SqrtBox["2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{"2", " ", "q"}]]]}], ")"}], " ", 
      SuperscriptBox["q", 
       RowBox[{"3", "/", "2"}]]}], "+", 
     RowBox[{"8", " ", "cm", " ", 
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0", "2"], " ", "z0"}]}], ")"}]}], 
  RowBox[{"8", " ", 
   SuperscriptBox["q", "3"]}]]], "Output",
 CellChangeTimes->{3.517920211802293*^9, 3.519039806303409*^9, 
  3.5191163463055067`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Square", "Subsection",
 CellChangeTimes->{{3.5179202658852377`*^9, 3.5179202665281887`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"imean", "[", "\[Tau]", "]"}], "^", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.5179202715566196`*^9, 3.517920277745677*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "q"]}]], " ", 
   SuperscriptBox["\[Pi]", "3"], " ", 
   SuperscriptBox["w0", "4"], " ", 
   SuperscriptBox["z0", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], 
           RowBox[{"2", " ", "q"}]]]}], ")"}], " ", 
       SuperscriptBox["q", 
        RowBox[{"3", "/", "2"}]]}], "+", 
      RowBox[{"8", " ", "cm", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"3", "/", "2"}]], " ", 
       SuperscriptBox["w0", "2"], " ", "z0"}]}], ")"}], "2"]}], 
  RowBox[{"64", " ", 
   SuperscriptBox["q", "6"]}]]], "Output",
 CellChangeTimes->{3.5179202786855593`*^9, 3.519039806717277*^9, 
  3.5191163474461174`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["", "Section"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ALL RESULTS", "Subtitle",
 CellChangeTimes->{{3.519036663954867*^9, 3.51903666534559*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g1", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{3.519036713696754*^9, 3.519069972395586*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "4"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
      RowBox[{"2", " ", "q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "q"]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "4"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], ")"}]}], 
       RowBox[{"2", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
    ")"}], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"9", "/", "2"}]], " ", 
   SuperscriptBox["w0", "8"], " ", 
   SuperscriptBox["z0", "4"]}], 
  RowBox[{
   SqrtBox["2"], " ", 
   SuperscriptBox["q", 
    RowBox[{"9", "/", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["w0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]], "Output",
 CellChangeTimes->{3.5190367152948093`*^9, 3.519039806724391*^9, 
  3.519069988045517*^9, 3.5191163474929914`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g2", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{{3.5190366975296497`*^9, 3.519036726496673*^9}, 
   3.519069974449873*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "q"]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}]}], 
       ")"}]}]}], ")"}], " ", 
   SuperscriptBox["\[Pi]", "3"], " ", 
   SuperscriptBox["w0", "6"], " ", 
   SuperscriptBox["z0", "3"]}], 
  RowBox[{
   SuperscriptBox["q", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["w0", "2"]}], "+", 
     RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["z0", "2"]}], "+", 
     RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]]], "Output",
 CellChangeTimes->{{3.519036718722293*^9, 3.519036727455965*^9}, 
   3.5190398067297363`*^9, 3.519069989037429*^9, 3.5191163475086164`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g3", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{3.51903673416831*^9, 3.519069976865614*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"5", " ", 
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
      RowBox[{"4", " ", "q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"5", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"24", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
       RowBox[{"4", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"24", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
       RowBox[{"4", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
    ")"}], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["w0", "4"], " ", 
   SuperscriptBox["z0", "2"]}], 
  RowBox[{"64", " ", "q", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["w0", "2"], "+", 
     RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{"q", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
      ")"}]}]]}]]], "Output",
 CellChangeTimes->{3.5190367347062397`*^9, 3.5190398067379208`*^9, 
  3.519069991173057*^9, 3.5191163475242414`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g4", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{3.5190367389532213`*^9, 3.5190699787055264`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "4"], "+", 
         RowBox[{"6", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["Dd", "2"], " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], "2"], " ", 
   SuperscriptBox["\[Pi]", "3"], " ", 
   SuperscriptBox["w0", "8"], " ", 
   SuperscriptBox["z0", "4"]}], 
  RowBox[{"16", " ", 
   SuperscriptBox["q", "3"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["z0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "Output",\

 CellChangeTimes->{3.519036740447541*^9, 3.5190398067439537`*^9, 
  3.51906999578724*^9, 3.519116347539866*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"imean", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{3.519069981154244*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["w0", "2"], " ", "z0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SqrtBox["2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{"2", " ", "q"}]]]}], ")"}], " ", 
      SuperscriptBox["q", 
       RowBox[{"3", "/", "2"}]]}], "+", 
     RowBox[{"8", " ", "cm", " ", 
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0", "2"], " ", "z0"}]}], ")"}]}], 
  RowBox[{"8", " ", 
   SuperscriptBox["q", "3"]}]]], "Output",
 CellChangeTimes->{3.5190367529899073`*^9, 3.5190398067478*^9, 
  3.5190699984038258`*^9, 3.5191163475554905`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define some replacement-formulas for simplification", "Section",
 CellChangeTimes->{{3.519225761123719*^9, 3.51922576749866*^9}, {
  3.519227847963977*^9, 3.519227866401497*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"z0qexp", "=", 
  RowBox[{"{", 
   RowBox[{"z0", "\[Rule]", 
    RowBox[{"z0q", "*", 
     RowBox[{"Sqrt", "[", "q", "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"w0qexp", "=", 
  RowBox[{"{", 
   RowBox[{"w0", "\[Rule]", 
    RowBox[{"w0q", "*", 
     RowBox[{"Sqrt", "[", "q", "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Nexp", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"cm", "\[Rule]", 
     RowBox[{"N", "*", 
      RowBox[{
       RowBox[{"q", "^", 
        RowBox[{"(", 
         RowBox[{"3", "/", "2"}], ")"}]}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Pi]", "^", 
          RowBox[{"(", 
           RowBox[{"3", "/", "2"}], ")"}]}], "*", 
         RowBox[{"w0", "^", "2"}], "*", "z0"}], ")"}]}]}]}], ",", 
    RowBox[{"cm", "\[Rule]", 
     RowBox[{"N", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Pi]", "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}], "*", 
        RowBox[{"w0q", "^", "2"}], "*", "z0q"}], ")"}]}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"tauDexp", "=", 
  RowBox[{"{", 
   RowBox[{"Dd", "\[Rule]", " ", 
    RowBox[{
     RowBox[{"w0q", "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", "*", "\[Tau]Dq"}], ")"}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"sparamexp", " ", "=", 
  RowBox[{"{", 
   RowBox[{"w0q", "\[Rule]", 
    RowBox[{"z0q", "/", "Sq"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"allexp", " ", "=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{
   "z0qexp", ",", "w0qexp", ",", "Nexp", ",", "tauDexp", ",", "sparamexp"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allexpreplace", "[", "e_", "]"}], ":=", 
  RowBox[{"ReplaceRepeated", "[", 
   RowBox[{"e", ",", "allexp"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"dividerToGetToG", "=", 
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "N"}]}]}], "Input",
 CellChangeTimes->{{3.5192278796347857`*^9, 3.51922788373866*^9}, {
   3.5192280404721327`*^9, 3.5192280865816793`*^9}, {3.519228235085371*^9, 
   3.519228453356268*^9}, {3.519228486264221*^9, 3.519228543561183*^9}, {
   3.5192286432937593`*^9, 3.519228650816778*^9}, {3.519228741300831*^9, 
   3.51922874432421*^9}, {3.5192330404786386`*^9, 3.519233075199617*^9}, {
   3.51923311113347*^9, 3.519233156785954*^9}, {3.519233336131023*^9, 
   3.519233460274477*^9}, {3.519233502449368*^9, 3.5192335663150063`*^9}, {
   3.5192340194292088`*^9, 3.5192340197572527`*^9}, {3.519234120625125*^9, 
   3.519234145800989*^9}, {3.519234472314494*^9, 3.519234483344946*^9}, {
   3.519235101453726*^9, 3.519235104749152*^9}, 3.519235136013392*^9, {
   3.519235234935113*^9, 3.519235236259161*^9}, {3.519236384687229*^9, 
   3.519236384966714*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"z0", "\[Rule]", 
   RowBox[{
    SqrtBox["q"], " ", "z0q"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"w0", "\[Rule]", 
   RowBox[{
    SqrtBox["q"], " ", "w0q"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823635346*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cm", "\[Rule]", 
    FractionBox[
     RowBox[{"N", " ", 
      SuperscriptBox["q", 
       RowBox[{"3", "/", "2"}]]}], 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0", "2"], " ", "z0"}]]}], ",", 
   RowBox[{"cm", "\[Rule]", 
    FractionBox["N", 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0q", "2"], " ", "z0q"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823637475*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Dd", "\[Rule]", 
   FractionBox[
    SuperscriptBox["w0q", "2"], 
    RowBox[{"4", " ", "\[Tau]Dq"}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.5192408236393347`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"w0q", "\[Rule]", 
   FractionBox["z0q", "Sq"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823641161*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"z0", "\[Rule]", 
    RowBox[{
     SqrtBox["q"], " ", "z0q"}]}], ",", 
   RowBox[{"w0", "\[Rule]", 
    RowBox[{
     SqrtBox["q"], " ", "w0q"}]}], ",", 
   RowBox[{"cm", "\[Rule]", 
    FractionBox[
     RowBox[{"N", " ", 
      SuperscriptBox["q", 
       RowBox[{"3", "/", "2"}]]}], 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0", "2"], " ", "z0"}]]}], ",", 
   RowBox[{"cm", "\[Rule]", 
    FractionBox["N", 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0q", "2"], " ", "z0q"}]]}], ",", 
   RowBox[{"Dd", "\[Rule]", 
    FractionBox[
     SuperscriptBox["w0q", "2"], 
     RowBox[{"4", " ", "\[Tau]Dq"}]]}], ",", 
   RowBox[{"w0q", "\[Rule]", 
    FractionBox["z0q", "Sq"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823643571*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Aq0", "2"], " ", 
  SuperscriptBox["chi", "2"], " ", "N"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.5192408236453657`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Calculate the G and use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to Expand the exponential-terms (no parentheses)"
}], "Section",
 CellChangeTimes->{{3.519235012839574*^9, 3.519235015710705*^9}, {
  3.5192418783809557`*^9, 3.519241906252338*^9}, {3.519533493718915*^9, 
  3.5195335156524477`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G1t", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"allexpreplace", "[", 
    RowBox[{
     RowBox[{"g1", "[", "\[Tau]", "]"}], "/", 
     RowBox[{"dividerToGetToG", "^", "2"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G1", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"G1t", "[", "\[Tau]", "]"}], ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"FullSimplify", "[", "form", "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5192350215770197`*^9, 3.519235046070712*^9}, {
   3.519235199728877*^9, 3.519235204183591*^9}, {3.519235353834343*^9, 
   3.519235358688608*^9}, {3.519235416297687*^9, 3.5192354164971523`*^9}, {
   3.519235464190826*^9, 3.519235494573909*^9}, {3.519235861284093*^9, 
   3.5192358819629927`*^9}, 3.519235924280855*^9, {3.519235982394039*^9, 
   3.519235987273773*^9}, {3.519236415838182*^9, 3.519236421940899*^9}, {
   3.519237099206212*^9, 3.519237151254199*^9}, {3.519237188355278*^9, 
   3.519237193098537*^9}, {3.519237359047275*^9, 3.5192375066669893`*^9}, {
   3.519237635342865*^9, 3.5192376423832607`*^9}, {3.519237794155087*^9, 
   3.519237818120565*^9}, {3.519238176866815*^9, 3.519238212312895*^9}, {
   3.519238370382874*^9, 3.5192384168110237`*^9}, {3.519238488632887*^9, 
   3.519238517784412*^9}, {3.51923856374636*^9, 3.5192385831113663`*^9}, {
   3.5192388759889812`*^9, 3.519238893211856*^9}, {3.519238940131935*^9, 
   3.519238946570722*^9}, {3.519239208396803*^9, 3.51923920952271*^9}, {
   3.519239269662387*^9, 3.519239294236808*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0q", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SuperscriptBox["z0q", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
       RowBox[{"\[Tau]", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]]}], ")"}], " ", "N", 
   " ", "z0q", " ", "\[Tau]Dq"}], 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       FractionBox["\[Tau]", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.519237819780142*^9, {3.519238207218175*^9, 3.519238212999241*^9}, {
   3.519238398057691*^9, 3.519238417529151*^9}, 3.51923851916107*^9, {
   3.519238564901105*^9, 3.519238583687523*^9}, 3.519238894628579*^9, {
   3.519238942722363*^9, 3.5192389469979*^9}, 3.519239210011959*^9, 
   3.519239300287734*^9, 3.519240845977521*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]]}], ")"}], " ", 
   "N", " ", "z0q", " ", "\[Tau]Dq"}], 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       FractionBox["\[Tau]", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.519237819780142*^9, {3.519238207218175*^9, 3.519238212999241*^9}, {
   3.519238398057691*^9, 3.519238417529151*^9}, 3.51923851916107*^9, {
   3.519238564901105*^9, 3.519238583687523*^9}, 3.519238894628579*^9, {
   3.519238942722363*^9, 3.5192389469979*^9}, 3.519239210011959*^9, 
   3.519239300287734*^9, 3.5192408459815683`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G2t", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"allexpreplace", "[", 
    RowBox[{
     RowBox[{"g2", "[", "\[Tau]", "]"}], "/", 
     RowBox[{"dividerToGetToG", "^", "2"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G2", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"G2t", "[", "\[Tau]", "]"}], ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"FullSimplify", "[", "form", "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.519236441012906*^9, 3.519236444076207*^9}, {
  3.5192393545602922`*^9, 3.519239360601432*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["z0q", "2"]}], " ", 
     SuperscriptBox["\[Kappa]", "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["Sq", "2"], " ", 
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]]}]}], ")"}]}]}], 
    ")"}], " ", "z0q", " ", "\[Tau]Dq"}], 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       FractionBox[
        RowBox[{"2", " ", "\[Tau]"}], 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "\[Tau]"}], "+", 
     RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.5192364454293127`*^9, 3.519239361441655*^9, 
  3.519240848615638*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]]}], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]]}], ")"}], " ", 
   "z0q", " ", "\[Tau]Dq"}], 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       FractionBox[
        RowBox[{"2", " ", "\[Tau]"}], 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "\[Tau]"}], "+", 
     RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.5192364454293127`*^9, 3.519239361441655*^9, 
  3.519240848620151*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G3t", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"allexpreplace", "[", 
    RowBox[{
     RowBox[{"g3", "[", "\[Tau]", "]"}], "/", 
     RowBox[{"dividerToGetToG", "^", "2"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G3", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"G3t", "[", "\[Tau]", "]"}], ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"FullSimplify", "[", "form", "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.519236451300952*^9, 3.519236453467856*^9}, {
  3.519239342673381*^9, 3.519239350001796*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"5", " ", 
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]"}], "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"5", " ", 
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", "\[Tau]"}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]]}], 
     ")"}], " ", "z0q", " ", "\[Tau]Dq"}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", "N", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox["\[Tau]", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.519236454750012*^9, 3.519239363713993*^9, 
  3.519240850735854*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}]]}]}], 
    ")"}], " ", "z0q", " ", "\[Tau]Dq"}], 
  RowBox[{"64", " ", "N", " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox["\[Tau]", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}]]], "Output",
 CellChangeTimes->{3.519236454750012*^9, 3.519239363713993*^9, 
  3.519240850739875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G4t", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"allexpreplace", "[", 
    RowBox[{
     RowBox[{"g4", "[", "\[Tau]", "]"}], "/", 
     RowBox[{"dividerToGetToG", "^", "2"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"G4t", "[", "\[Tau]", "]"}], ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"FullSimplify", "[", "form", "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5192364592443943`*^9, 3.5192364620676126`*^9}, {
  3.5192393734244328`*^9, 3.519239381736796*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     SuperscriptBox["z0q", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       FractionBox[
        SuperscriptBox["\[Tau]", "2"], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}], 
      ")"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]]}], 
     ")"}], "2"], " ", 
   SuperscriptBox["Sq", "2"], " ", 
   SuperscriptBox["\[Tau]Dq", "3"]}], 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.519236463659728*^9, 3.519239382300037*^9, 
  3.519240853558776*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]]}]}], ")"}], " ", 
   SuperscriptBox["Sq", "2"], " ", 
   SuperscriptBox["\[Tau]Dq", "3"]}], 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.519236463659728*^9, 3.519239382300037*^9, 
  3.519240853563374*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Gmt", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"allexpreplace", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"imean", "[", "\[Tau]", "]"}], "^", "2"}], "/", 
     RowBox[{"dividerToGetToG", "^", "2"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Gm", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"Gmt", "[", "\[Tau]", "]"}], ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"FullSimplify", "[", "form", "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.51923646701233*^9, 3.5192364766911583`*^9}, {
   3.519239387407907*^9, 3.5192394087754517`*^9}, {3.5192409325603237`*^9, 
   3.5192409614851723`*^9}, {3.519241074040538*^9, 3.519241102397936*^9}, 
   3.5192412585967503`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "64"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["z0q", "2"]}], " ", 
    SuperscriptBox["\[Kappa]", "2"]}]], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SqrtBox["2"], "+", 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "2"]]}], "+", 
     RowBox[{"8", " ", "N"}]}], ")"}], "2"]}]], "Output",
 CellChangeTimes->{
  3.51923940953489*^9, 3.519240856229991*^9, {3.519240938440785*^9, 
   3.5192409618028316`*^9}, {3.519241077946432*^9, 3.5192411032618847`*^9}, 
   3.5192412606897907`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "32"], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["z0q", "2"]}], " ", 
      SuperscriptBox["\[Kappa]", "2"]}]], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SuperscriptBox["z0q", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]]}], "+", 
    RowBox[{"8", " ", 
     SqrtBox["2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["z0q", "2"]}], " ", 
         SuperscriptBox["\[Kappa]", "2"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}]]}], ")"}], " ", "N"}], "+", 
    RowBox[{"32", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], " ", 
     SuperscriptBox["N", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.51923940953489*^9, 3.519240856229991*^9, {3.519240938440785*^9, 
   3.5192409618028316`*^9}, {3.519241077946432*^9, 3.5192411032618847`*^9}, 
   3.519241260696274*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
NLCS without flow \[Dash]\[NonBreakingSpace]Summary of results employed in \
the thesis\
\>", "Title",
 CellFrame->{{0, 0}, {0, 3}},
 CellChangeTimes->{{3.519533817506448*^9, 3.519533842505031*^9}, {
  3.519533903655889*^9, 3.519533903814797*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"G1", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{{3.5195339351831923`*^9, 3.519533944205934*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]]}], ")"}], " ", 
   "N", " ", "z0q", " ", "\[Tau]Dq"}], 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       FractionBox["\[Tau]", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.519533944824874*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"G2", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{{3.519534071415846*^9, 3.519534076169448*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]]}], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]]}], ")"}], " ", 
   "z0q", " ", "\[Tau]Dq"}], 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       FractionBox[
        RowBox[{"2", " ", "\[Tau]"}], 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "\[Tau]"}], "+", 
     RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.5195340788811407`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"G3", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{{3.519534082610263*^9, 3.519534082697043*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}]]}]}], 
    ")"}], " ", "z0q", " ", "\[Tau]Dq"}], 
  RowBox[{"64", " ", "N", " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox["\[Tau]", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}]]], "Output",
 CellChangeTimes->{3.519534083206581*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"G4", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{{3.519534087296997*^9, 3.519534090712709*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]]}]}], ")"}], " ", 
   SuperscriptBox["Sq", "2"], " ", 
   SuperscriptBox["\[Tau]Dq", "3"]}], 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.5195340958474693`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gmt", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{{3.519534108961268*^9, 3.519534109592062*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "64"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["z0q", "2"]}], " ", 
    SuperscriptBox["\[Kappa]", "2"]}]], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SqrtBox["2"], "+", 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "2"]]}], "+", 
     RowBox[{"8", " ", "N"}]}], ")"}], "2"]}]], "Output",
 CellChangeTimes->{3.519534110391592*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1272, 922},
WindowMargins->{{181, Automatic}, {Automatic, 10}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 322, 6, 154, "Title"],
Cell[892, 30, 154, 3, 57, "Subtitle"],
Cell[1049, 35, 237, 5, 32, "Subsubtitle"],
Cell[1289, 42, 239, 4, 30, "Subsubsection"],
Cell[1531, 48, 525, 9, 54, "Subsubsection"],
Cell[2059, 59, 142, 3, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[2226, 66, 178, 3, 68, "Subtitle"],
Cell[2407, 71, 804, 24, 33, "Input"],
Cell[CellGroupData[{
Cell[3236, 99, 2040, 57, 118, "Input"],
Cell[5279, 158, 3548, 107, 108, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8864, 270, 2163, 62, 118, "Input"],
Cell[11030, 334, 3706, 111, 108, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14773, 450, 2302, 64, 191, "Input"],
Cell[17078, 516, 3853, 115, 144, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20968, 636, 2412, 69, 118, "Input"],
Cell[23383, 707, 3864, 116, 140, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27284, 828, 143, 3, 83, "Section"],
Cell[CellGroupData[{
Cell[27452, 835, 659, 18, 33, "Input"],
Cell[28114, 855, 1572, 48, 72, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29723, 908, 569, 16, 33, "Input"],
Cell[30295, 926, 984, 29, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[31328, 961, 98, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[31451, 966, 2039, 52, 129, "Input"],
Cell[33493, 1020, 1459, 31, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[35001, 1057, 119, 2, 83, "Section"],
Cell[35123, 1061, 273, 9, 7, "Text"],
Cell[CellGroupData[{
Cell[35421, 1074, 103, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[35549, 1079, 1073, 25, 53, "Input"],
Cell[36625, 1106, 5439, 137, 228, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42101, 1248, 777, 19, 53, "Input"],
Cell[42881, 1269, 5429, 145, 249, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48347, 1419, 750, 18, 53, "Input"],
Cell[49100, 1439, 7668, 200, 248, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56805, 1644, 710, 18, 53, "Input"],
Cell[57518, 1664, 3620, 102, 218, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[61187, 1772, 101, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[61313, 1777, 703, 18, 53, "Input"],
Cell[62019, 1797, 8699, 223, 419, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70755, 2025, 681, 18, 53, "Input"],
Cell[71439, 2045, 8505, 220, 360, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79981, 2270, 654, 18, 33, "Input"],
Cell[80638, 2290, 4648, 126, 307, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85323, 2421, 607, 17, 33, "Input"],
Cell[85933, 2440, 2016, 59, 138, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[87998, 2505, 101, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[88124, 2510, 592, 15, 33, "Input"],
Cell[88719, 2527, 4947, 133, 268, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93703, 2665, 564, 14, 33, "Input"],
Cell[94270, 2681, 5689, 157, 325, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99996, 2843, 543, 14, 33, "Input"],
Cell[100542, 2859, 2694, 82, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103273, 2946, 1399, 43, 116, "Input"],
Cell[104675, 2991, 1376, 43, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106088, 3039, 503, 13, 33, "Input"],
Cell[106594, 3054, 2134, 63, 135, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108765, 3122, 280, 6, 33, "Input"],
Cell[109048, 3130, 2134, 63, 135, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[111243, 3200, 197, 3, 83, "Section"],
Cell[CellGroupData[{
Cell[111465, 3207, 153, 2, 42, "Subsection"],
Cell[CellGroupData[{
Cell[111643, 3213, 1154, 25, 53, "Input"],
Cell[112800, 3240, 6633, 161, 300, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119470, 3406, 1220, 25, 53, "Input"],
Cell[120693, 3433, 36480, 849, 1233, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[157210, 4287, 850, 20, 53, "Input"],
Cell[158063, 4309, 52438, 1291, 2906, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210538, 5605, 706, 18, 53, "Input"],
Cell[211247, 5625, 9643, 280, 531, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[220939, 5911, 102, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[221066, 5916, 702, 18, 53, "Input"],
Cell[221771, 5936, 11995, 329, 764, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[233803, 6270, 676, 18, 53, "Input"],
Cell[234482, 6290, 23440, 605, 939, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[257959, 6900, 652, 18, 33, "Input"],
Cell[258614, 6920, 13363, 363, 816, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[272014, 7288, 605, 17, 33, "Input"],
Cell[272622, 7307, 9515, 279, 596, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[282186, 7592, 127, 2, 42, "Subsection"],
Cell[CellGroupData[{
Cell[282338, 7598, 596, 15, 33, "Input"],
Cell[282937, 7615, 2578, 77, 153, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[285552, 7697, 563, 14, 33, "Input"],
Cell[286118, 7713, 2673, 81, 153, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[288828, 7799, 536, 14, 33, "Input"],
Cell[289367, 7815, 2134, 64, 135, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[291538, 7884, 504, 13, 33, "Input"],
Cell[292045, 7899, 1945, 57, 135, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[294027, 7961, 304, 6, 33, "Input"],
Cell[294334, 7969, 1923, 55, 117, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[296318, 8031, 195, 3, 83, "Section"],
Cell[CellGroupData[{
Cell[296538, 8038, 141, 2, 42, "Subsection"],
Cell[CellGroupData[{
Cell[296704, 8044, 826, 21, 53, "Input"],
Cell[297533, 8067, 6615, 163, 300, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[304185, 8235, 778, 19, 53, "Input"],
Cell[304966, 8256, 36414, 850, 1289, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[341417, 9111, 750, 18, 53, "Input"],
Cell[342170, 9131, 25045, 601, 920, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[367252, 9737, 706, 18, 53, "Input"],
Cell[367961, 9757, 24767, 686, 2195, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[392777, 10449, 102, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[392904, 10454, 756, 19, 53, "Input"],
Cell[393663, 10475, 9271, 254, 590, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[402971, 10734, 677, 18, 53, "Input"],
Cell[403651, 10754, 16270, 421, 961, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[419958, 11180, 655, 18, 33, "Input"],
Cell[420616, 11200, 15467, 403, 720, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[436120, 11608, 606, 17, 33, "Input"],
Cell[436729, 11627, 6508, 193, 514, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[443286, 11826, 127, 2, 42, "Subsection"],
Cell[CellGroupData[{
Cell[443438, 11832, 642, 16, 33, "Input"],
Cell[444083, 11850, 6402, 190, 451, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[450522, 12045, 560, 14, 33, "Input"],
Cell[451085, 12061, 9711, 269, 633, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[460833, 12335, 538, 14, 33, "Input"],
Cell[461374, 12351, 6102, 158, 327, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[467513, 12514, 505, 13, 33, "Input"],
Cell[468021, 12529, 3497, 102, 153, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[471555, 12636, 232, 5, 33, "Input"],
Cell[471790, 12643, 3497, 102, 153, "Output"]
}, Open  ]],
Cell[475302, 12748, 90, 1, 33, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[475441, 12755, 219, 3, 83, "Section"],
Cell[CellGroupData[{
Cell[475685, 12762, 163, 2, 42, "Subsection"],
Cell[CellGroupData[{
Cell[475873, 12768, 108, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[476006, 12773, 926, 22, 53, "Input"],
Cell[476935, 12797, 5659, 161, 204, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[482631, 12963, 833, 20, 53, "Input"],
Cell[483467, 12985, 7591, 184, 200, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[491095, 13174, 798, 19, 53, "Input"],
Cell[491896, 13195, 9763, 250, 445, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[501696, 13450, 757, 19, 53, "Input"],
Cell[502456, 13471, 3766, 106, 252, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[506271, 13583, 104, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[506400, 13588, 751, 19, 53, "Input"],
Cell[507154, 13609, 9875, 245, 358, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[517066, 13859, 729, 19, 53, "Input"],
Cell[517798, 13880, 8860, 222, 267, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[526695, 14107, 705, 19, 33, "Input"],
Cell[527403, 14128, 9014, 228, 267, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[536454, 14361, 654, 18, 33, "Input"],
Cell[537111, 14381, 3633, 101, 306, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[540793, 14488, 104, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[540922, 14493, 640, 16, 33, "Input"],
Cell[541565, 14511, 7611, 199, 267, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[549213, 14715, 613, 15, 33, "Input"],
Cell[549829, 14732, 5826, 159, 267, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[555692, 14896, 588, 15, 33, "Input"],
Cell[556283, 14913, 5794, 158, 303, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[562114, 15076, 553, 14, 33, "Input"],
Cell[562670, 15092, 2873, 82, 131, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[565580, 15179, 277, 6, 33, "Input"],
Cell[565860, 15187, 2873, 82, 131, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[568806, 15277, 91, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[568922, 15282, 94, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[569041, 15287, 106, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[569172, 15292, 658, 18, 33, "Input"],
Cell[569833, 15312, 1243, 37, 86, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[571113, 15354, 630, 17, 33, "Input"],
Cell[571746, 15373, 833, 25, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[572616, 15403, 641, 16, 33, "Input"],
Cell[573260, 15421, 925, 28, 87, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[574222, 15454, 563, 14, 33, "Input"],
Cell[574788, 15470, 833, 26, 87, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[575658, 15501, 542, 14, 33, "Input"],
Cell[576203, 15517, 789, 25, 83, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[577029, 15547, 486, 13, 33, "Input"],
Cell[577518, 15562, 602, 18, 79, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[578181, 15587, 96, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[578302, 15592, 594, 15, 33, "Input"],
Cell[578899, 15609, 1032, 33, 106, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[579968, 15647, 571, 15, 33, "Input"],
Cell[580542, 15664, 904, 28, 99, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[581483, 15697, 509, 13, 33, "Input"],
Cell[581995, 15712, 894, 28, 98, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[582938, 15746, 97, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[583060, 15751, 356, 8, 33, "Input"],
Cell[583419, 15761, 1176, 36, 97, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[584644, 15803, 98, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[584767, 15808, 194, 4, 33, "Input"],
Cell[584964, 15814, 1220, 37, 98, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[586223, 15856, 19, 0, 83, "Section"]
}, Open  ]],
Cell[CellGroupData[{
Cell[586279, 15861, 96, 1, 57, "Subtitle"],
Cell[CellGroupData[{
Cell[586400, 15866, 124, 2, 33, "Input"],
Cell[586527, 15870, 2063, 62, 135, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[588627, 15937, 154, 3, 33, "Input"],
Cell[588784, 15942, 1879, 54, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[590700, 16001, 123, 2, 33, "Input"],
Cell[590826, 16005, 3523, 102, 153, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[594386, 16112, 128, 2, 33, "Input"],
Cell[594517, 16116, 2851, 82, 131, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[597405, 16203, 105, 2, 33, "Input"],
Cell[597513, 16207, 1200, 36, 97, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[598750, 16248, 184, 2, 83, "Section"],
Cell[CellGroupData[{
Cell[598959, 16254, 2775, 71, 171, "Input"],
Cell[601737, 16327, 709, 13, 41, "Output"],
Cell[602449, 16342, 709, 13, 41, "Output"],
Cell[603161, 16357, 1106, 26, 62, "Output"],
Cell[604270, 16385, 753, 14, 60, "Output"],
Cell[605026, 16401, 695, 12, 56, "Output"],
Cell[605724, 16415, 1466, 38, 62, "Output"],
Cell[607193, 16455, 703, 12, 38, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[607945, 16473, 329, 8, 83, "Section"],
Cell[CellGroupData[{
Cell[608299, 16485, 1953, 40, 53, "Input"],
Cell[610255, 16527, 1876, 53, 145, "Output"],
Cell[612134, 16582, 1458, 41, 145, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[613629, 16628, 992, 27, 53, "Input"],
Cell[614624, 16657, 1623, 49, 137, "Output"],
Cell[616250, 16708, 1825, 56, 145, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[618112, 16769, 990, 27, 53, "Input"],
Cell[619105, 16798, 3297, 96, 179, "Output"],
Cell[622405, 16896, 1626, 49, 153, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[624068, 16950, 996, 27, 53, "Input"],
Cell[625067, 16979, 2267, 68, 130, "Output"],
Cell[627337, 17049, 1530, 45, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[628904, 17099, 1152, 30, 53, "Input"],
Cell[630059, 17131, 754, 23, 70, "Output"],
Cell[630816, 17156, 1426, 42, 57, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[632315, 17206, 257, 6, 167, "Title"],
Cell[CellGroupData[{
Cell[632597, 17216, 128, 2, 33, "Input"],
Cell[632728, 17220, 1146, 36, 145, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[633911, 17261, 126, 2, 33, "Input"],
Cell[634040, 17265, 1778, 55, 145, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[635855, 17325, 126, 2, 33, "Input"],
Cell[635984, 17329, 1579, 48, 153, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[637600, 17382, 126, 2, 33, "Input"],
Cell[637729, 17386, 1485, 44, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[639251, 17435, 127, 2, 33, "Input"],
Cell[639381, 17439, 602, 20, 70, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
