(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1205456,      33321]
NotebookOptionsPosition[   1171471,      32230]
NotebookOutlinePosition[   1171929,      32248]
CellTagsIndexPosition[   1171886,      32245]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Nonlinear Correlation Spectroscopy (NLCS)\[LineSeparator]Theory -> WITH flow \
case\
\>", "Title",
 CellChangeTimes->{{3.519033555595779*^9, 3.5190335614517727`*^9}, {
  3.519387583843833*^9, 3.5193875888418493`*^9}, {3.519533117144858*^9, 
  3.519533117474408*^9}, {3.519533371563425*^9, 3.5195333763451567`*^9}, {
  3.519533644161047*^9, 3.519533644520018*^9}}],

Cell["\<\
Matthias Geissbuehler, Stefan Geissbuehler and Theo Lasser\
\>", "Subtitle",
 CellChangeTimes->{{3.5195331259062347`*^9, 3.519533170937517*^9}, {
  3.519534835407385*^9, 3.519534841302547*^9}}],

Cell["\<\
Laboratoire d\[CloseCurlyQuote]Optique Biom\[EAcute]dicale LOB, Ecole \
Polytechnique F\[EAcute]d\[EAcute]rale de Lausanne (EPFL), CH-1015 Lausanne, \
Switzerland\
\>", "Subsubtitle",
 CellChangeTimes->{3.5195331750397577`*^9}],

Cell["\<\
This theory file is a complement to the Thesis of M. Geissbuehler. The \
derivation is too lengthy to be included in this form in the thesis.\
\>", "Subsubsection",
 CellChangeTimes->{{3.519533194161002*^9, 3.51953325281363*^9}}],

Cell["\<\
For further explenations of the derivation please refer to the thesis of M. \
Geissbuehler \[Dash] \[OpenCurlyDoubleQuote]Novel Concepts for Functional \
High Resolution Microscopy\[CloseCurlyDoubleQuote], Ecole Polytechnique F\
\[EAcute]d\[EAcute]rale de Lausanne (EPFL), \
2011.\[LineSeparator]http://library.epfl.ch/theses/\
\>", "Subsubsection",
 CellChangeTimes->{{3.519533260909927*^9, 3.519533337818719*^9}, {
   3.519534863149001*^9, 3.519534879652451*^9}, 3.519534980338683*^9}],

Cell["\<\
Contact: matthias.geissbuehler@a3.epfl.ch\
\>", "Subsubsection",
 CellChangeTimes->{{3.519533359665743*^9, 3.5195333664738007`*^9}}],

Cell[CellGroupData[{

Cell["Definitions", "Subtitle",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.517625660816598*^9, 3.517625668892295*^9}, {
  3.517656513555011*^9, 3.517656515106162*^9}}],

Cell[CellGroupData[{

Cell["\<\
Assuming a lateral flow vr in y direction and an axial flow vz\
\>", "Subsection",
 CellChangeTimes->{{3.519070996309842*^9, 3.519071029451764*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Aq", "[", 
   RowBox[{"x_", ",", " ", "y_", ",", " ", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Aq0", "*", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x", "^", "2"}], " ", "+", " ", 
        RowBox[{"y", "^", "2"}]}], ")"}]}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"w0", "^", "2"}], "/", "q"}], ")"}]}], "]"}], "*", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"z", "^", "2"}], ")"}]}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z0", "^", "2"}], "/", "q"}], ")"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.517625697447448*^9, 3.51762569898687*^9}, 
   3.517625766023983*^9, {3.517637123006424*^9, 3.517637123174074*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g1int", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z1_", ",", "z2_", ",", "z3_", ",", "z4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"chi", "^", "4"}], "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["cm", "3"], 
       RowBox[{"2", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Pi]", "*", 
           StyleBox["Dd", "TI"], 
           StyleBox["*", "TI"], "\[Tau]"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}]}]], 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y1", "+", 
             RowBox[{"vr", "*", "\[Tau]"}], "-", "y3"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"y1", "+", 
             RowBox[{"vr", "*", "\[Tau]"}], "-", "y3"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z1", "+", 
             RowBox[{"vz", "*", "\[Tau]"}], "-", "z3"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"z1", "+", 
             RowBox[{"vz", "*", "\[Tau]"}], "-", "z3"}], ")"}]}]}], 
         RowBox[{"4", "*", 
          StyleBox["Dd", "TI"], 
          StyleBox["*", "TI"], "\[Tau]"}]]}], "]"}]}], ")"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x1", ",", "y1", ",", "z1"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x2", ",", "y2", ",", "z2"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x3", ",", "y3", ",", "z3"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x4", ",", "y4", ",", "z4"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z1"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z2"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z3"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z4"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517739350432007*^9, 3.5177394024035873`*^9}, 
   3.517739432995417*^9, {3.517741326758668*^9, 3.517741326882741*^9}, {
   3.51789658842332*^9, 3.5178965948603277`*^9}, {3.519071046792363*^9, 
   3.519071082311631*^9}, {3.519102851663879*^9, 3.519102853974863*^9}, {
   3.5193252144177103`*^9, 3.519325222360766*^9}, {3.519566607852076*^9, 
   3.519566626026485*^9}, {3.520105600267686*^9, 3.520105606546179*^9}, {
   3.5201056598644447`*^9, 3.520105673135803*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"32", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x1", "2"]}], "-", 
         SuperscriptBox["y1", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x2", "2"]}], "-", 
         SuperscriptBox["y2", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x3", "2"]}], "-", 
         SuperscriptBox["y3", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x4", "2"]}], "-", 
         SuperscriptBox["y4", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z1", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z2", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z3", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z4", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y1", "-", "y3", "+", 
          RowBox[{"vr", " ", "\[Tau]"}]}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z1", "-", "z3", "+", 
          RowBox[{"vz", " ", "\[Tau]"}]}], ")"}], "2"]}], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z1", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z1", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z2", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z3", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z4", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.5177394869112453`*^9, 3.517741344212332*^9, 
  3.517896605935178*^9, 3.519036956316136*^9, 3.519071269729247*^9, 
  3.519071595380419*^9, 3.5190737334424343`*^9, 3.519074551625266*^9, 
  3.519161689651255*^9, 3.5193258593999653`*^9, 3.5195670260622034`*^9, 
  3.5196240452259817`*^9, 3.5201127696957903`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g2int", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z1_", ",", "z2_", ",", "z3_", ",", "z4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"chi", "^", "4"}], "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["cm", "2"], 
        RowBox[{"DiracDelta", "[", 
         RowBox[{
          RowBox[{"x1", "-", "x2"}], ",", 
          RowBox[{"y1", "-", "y2"}], ",", 
          RowBox[{"z1", "-", "z2"}]}], "]"}]}], 
       RowBox[{"2", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Pi]", "*", 
           StyleBox["Dd", "TI"], 
           StyleBox["*", "TI"], "\[Tau]"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}]}]], 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y1", "+", 
             RowBox[{"vr", "*", "\[Tau]"}], "-", "y3"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"y1", "+", 
             RowBox[{"vr", "*", "\[Tau]"}], "-", "y3"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z1", "+", 
             RowBox[{"vz", "*", "\[Tau]"}], "-", "z3"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"z1", "+", 
             RowBox[{"vz", "*", "\[Tau]"}], "-", "z3"}], ")"}]}]}], 
         RowBox[{"4", 
          StyleBox["Dd", "TI"], 
          StyleBox["*", "TI"], "\[Tau]"}]]}], "]"}]}], ")"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x1", ",", "y1", ",", "z1"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x2", ",", "y2", ",", "z2"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x3", ",", "y3", ",", "z3"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x4", ",", "y4", ",", "z4"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z1"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z2"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z3"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z4"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.51773949613105*^9, 3.517739517582049*^9}, 
   3.517741330479536*^9, 3.517896618935719*^9, {3.519071107149396*^9, 
   3.519071112449847*^9}, {3.519102857958498*^9, 3.519102860718943*^9}, {
   3.5193252294096212`*^9, 3.519325231561617*^9}, {3.5195666344418993`*^9, 
   3.519566656401678*^9}, {3.520105614122554*^9, 3.520105616818568*^9}, {
   3.520105675200725*^9, 3.5201056813043118`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"32", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x1", "2"]}], "-", 
         SuperscriptBox["y1", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x2", "2"]}], "-", 
         SuperscriptBox["y2", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x3", "2"]}], "-", 
         SuperscriptBox["y3", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x4", "2"]}], "-", 
         SuperscriptBox["y4", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z1", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z2", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z3", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z4", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y1", "-", "y3", "+", 
          RowBox[{"vr", " ", "\[Tau]"}]}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z1", "-", "z3", "+", 
          RowBox[{"vz", " ", "\[Tau]"}]}], ")"}], "2"]}], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z1", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z1", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z2", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z3", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z4", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{
     RowBox[{"x1", "-", "x2"}], ",", 
     RowBox[{"y1", "-", "y2"}], ",", 
     RowBox[{"z1", "-", "z2"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5177395267774*^9, 3.517741350083202*^9, 
  3.517896624601677*^9, 3.519036956347492*^9, 3.519071269764442*^9, 
  3.519071595415012*^9, 3.519073733496999*^9, 3.519074551656541*^9, 
  3.5191616898700027`*^9, 3.5193258594937143`*^9, 3.5195670261715765`*^9, 
  3.5196240452639627`*^9, 3.520112769730422*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g3int", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z1_", ",", "z2_", ",", "z3_", ",", "z4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"chi", "^", "4"}], "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", "*", "\[Pi]", "*", 
          StyleBox["Dd", "TI"], 
          StyleBox["*", "TI"], "\[Tau]"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"3", "/", "2"}], ")"}]}]], "cm", "*", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{
        RowBox[{"x1", "-", "x2"}], ",", 
        RowBox[{"y1", "-", "y2"}], ",", 
        RowBox[{"z1", "-", "z2"}]}], "]"}], 
      RowBox[{"DiracDelta", "[", 
       RowBox[{
        RowBox[{"x3", "-", "x4"}], ",", 
        RowBox[{"y3", "-", "y4"}], ",", 
        RowBox[{"z3", "-", "z4"}]}], "]"}], 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y1", "+", 
             RowBox[{"vr", "*", "\[Tau]"}], "-", "y3"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"y1", "+", 
             RowBox[{"vr", "*", "\[Tau]"}], "-", "y3"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z1", "+", 
             RowBox[{"vz", "*", "\[Tau]"}], "-", "z3"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"z1", "+", 
             RowBox[{"vz", "*", "\[Tau]"}], "-", "z3"}], ")"}]}]}], 
         RowBox[{"4", 
          StyleBox["Dd", "TI"], 
          StyleBox["*", "TI"], "\[Tau]"}]]}], "]"}]}], ")"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x1", ",", "y1", ",", "z1"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x2", ",", "y2", ",", "z2"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x3", ",", "y3", ",", "z3"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x4", ",", "y4", ",", "z4"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z1"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z2"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z3"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z4"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517739534067135*^9, 3.5177395553979673`*^9}, 
   3.5177413324679193`*^9, {3.517896633108755*^9, 3.5178966397322493`*^9}, {
   3.519071126474318*^9, 3.519071132722725*^9}, {3.519102863710343*^9, 
   3.519102867623416*^9}, {3.519325239625889*^9, 3.5193252428818493`*^9}, {
   3.519566668071373*^9, 3.5195666842032833`*^9}, {3.520105623650741*^9, 
   3.520105627546554*^9}, {3.520105695672406*^9, 3.52010570197576*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"128", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x1", "2"]}], "-", 
         SuperscriptBox["y1", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x2", "2"]}], "-", 
         SuperscriptBox["y2", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x3", "2"]}], "-", 
         SuperscriptBox["y3", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x4", "2"]}], "-", 
         SuperscriptBox["y4", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z1", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z2", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z3", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z4", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y1", "-", "y3", "+", 
          RowBox[{"vr", " ", "\[Tau]"}]}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z1", "-", "z3", "+", 
          RowBox[{"vz", " ", "\[Tau]"}]}], ")"}], "2"]}], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z1", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z1", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z2", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z3", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z4", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{
     RowBox[{"x1", "-", "x2"}], ",", 
     RowBox[{"y1", "-", "y2"}], ",", 
     RowBox[{"z1", "-", "z2"}]}], "]"}], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{
     RowBox[{"x3", "-", "x4"}], ",", 
     RowBox[{"y3", "-", "y4"}], ",", 
     RowBox[{"z3", "-", "z4"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5177395590746803`*^9, 3.517741350333251*^9, 
  3.517896647109189*^9, 3.519036956393388*^9, 3.519071269791609*^9, 
  3.5190715954473124`*^9, 3.519073733538562*^9, 3.519074551702972*^9, 
  3.5191616900575*^9, 3.5193258595718384`*^9, 3.519567026374699*^9, 
  3.519624045305244*^9, 3.5201127697598553`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g4int", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z1_", ",", "z2_", ",", "z3_", ",", "z4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"chi", "^", "4"}], "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["cm", "2"], 
       RowBox[{"32", 
        SuperscriptBox["\[Pi]", "3"], 
        SuperscriptBox[
         StyleBox["Dd", "TI"], "3"], 
        SuperscriptBox["\[Tau]", "3"]}]], 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y1", "+", 
             RowBox[{"vr", "*", "\[Tau]"}], "-", "y3"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"y1", "+", 
             RowBox[{"vr", "*", "\[Tau]"}], "-", "y3"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z1", "+", 
             RowBox[{"vz", "*", "\[Tau]"}], "-", "z3"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"z1", "+", 
             RowBox[{"vz", "*", "\[Tau]"}], "-", "z3"}], ")"}]}]}], 
         RowBox[{"4", 
          StyleBox["Dd", "TI"], 
          StyleBox["*", "TI"], "\[Tau]"}]]}], "]"}], 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x2", "-", "x4"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y2", "+", 
             RowBox[{"vr", "*", "\[Tau]"}], "-", "y4"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"y2", "+", 
             RowBox[{"vr", "*", "\[Tau]"}], "-", "y4"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z2", "+", 
             RowBox[{"vz", "*", "\[Tau]"}], "-", "z4"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"z2", "+", 
             RowBox[{"vz", "*", "\[Tau]"}], "-", "z4"}], ")"}]}]}], 
         RowBox[{"4", 
          StyleBox["Dd", "TI"], 
          StyleBox["*", "TI"], "\[Tau]"}]]}], "]"}]}], ")"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x1", ",", "y1", ",", "z1"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x2", ",", "y2", ",", "z2"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x3", ",", "y3", ",", "z3"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x4", ",", "y4", ",", "z4"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z1"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z2"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z3"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z4"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517739565059408*^9, 3.517739576185101*^9}, 
   3.517741334264599*^9, {3.517896652783433*^9, 3.517896663550927*^9}, {
   3.519071146126729*^9, 3.5190711684464197`*^9}, {3.519102871079568*^9, 
   3.519102873707016*^9}, {3.519325248497838*^9, 3.519325256890038*^9}, {
   3.5195666902313843`*^9, 3.5195667380006866`*^9}, {3.520105638131198*^9, 
   3.5201056498991537`*^9}, {3.520105711848813*^9, 3.520105725648191*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"512", " ", 
    SuperscriptBox["Dd", "3"], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["\[Tau]", "3"]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x1", "2"]}], "-", 
         SuperscriptBox["y1", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x2", "2"]}], "-", 
         SuperscriptBox["y2", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x3", "2"]}], "-", 
         SuperscriptBox["y3", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "+", 
     FractionBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x4", "2"]}], "-", 
         SuperscriptBox["y4", "2"]}], ")"}]}], 
      SuperscriptBox["w0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z1", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z2", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z3", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["z4", "2"]}], 
      SuperscriptBox["z0", "2"]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y1", "-", "y3", "+", 
          RowBox[{"vr", " ", "\[Tau]"}]}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z1", "-", "z3", "+", 
          RowBox[{"vz", " ", "\[Tau]"}]}], ")"}], "2"]}], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x2", "-", "x4"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y2", "-", "y4", "+", 
          RowBox[{"vr", " ", "\[Tau]"}]}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z2", "-", "z4", "+", 
          RowBox[{"vz", " ", "\[Tau]"}]}], ")"}], "2"]}], 
      RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z1", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z1", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z2", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z3", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z4", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.5177395794695063`*^9, 3.517741350427519*^9, 
  3.517896666220254*^9, 3.5190369564261637`*^9, 3.519071269846532*^9, 
  3.519071595481028*^9, 3.5190737335733557`*^9, 3.5190745517421637`*^9, 
  3.519161690385621*^9, 3.5193258597749605`*^9, 3.5195670265778217`*^9, 
  3.519624045337844*^9, 3.5201127697970743`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The mean intensity Imean according to B7 simplified\
\>", "Section",
 CellChangeTimes->{{3.519036404523033*^9, 3.51903643347304*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"imeanint", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "y1_", ",", "y2_", ",", "z1_", ",", "z2_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"chi", "^", "2"}], "*", 
    RowBox[{"cm", "^", "2"}], "*", 
    RowBox[{"Aq", "[", 
     RowBox[{"x1", ",", "y1", ",", "z1"}], "]"}], 
    RowBox[{"Aq", "[", 
     RowBox[{"x2", ",", "y2", ",", "z2"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z1"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "*", "z2"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519102878200783*^9, 3.519102880201304*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  SuperscriptBox["Aq0", "2"], " ", 
  SuperscriptBox["chi", "2"], " ", 
  SuperscriptBox["cm", "2"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    FractionBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x1", "2"]}], "-", 
        SuperscriptBox["y1", "2"]}], ")"}]}], 
     SuperscriptBox["w0", "2"]], "+", 
    FractionBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x2", "2"]}], "-", 
        SuperscriptBox["y2", "2"]}], ")"}]}], 
     SuperscriptBox["w0", "2"]], "-", 
    FractionBox[
     RowBox[{"q", " ", 
      SuperscriptBox["z1", "2"]}], 
     SuperscriptBox["z0", "2"]], "-", 
    FractionBox[
     RowBox[{"q", " ", 
      SuperscriptBox["z2", "2"]}], 
     SuperscriptBox["z0", "2"]]}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "z1", " ", "\[Kappa]"}]], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "z1", " ", "\[Kappa]"}]]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "z2", " ", "\[Kappa]"}]], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5190369564599047`*^9, 3.5190712698910637`*^9, 
  3.519071595531592*^9, 3.519073733655966*^9, 3.519074551824245*^9, 
  3.5191616907606163`*^9, 3.5193258600249577`*^9, 3.519567026812194*^9, 
  3.519624045372754*^9, 3.520112769842211*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"imeanint2", "[", 
   RowBox[{"x1_", ",", "y1_", ",", "z1_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"chi", "^", "2"}], "*", "cm", "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Aq", "[", 
       RowBox[{"x1", ",", "y1", ",", "z1"}], "]"}], ")"}], "^", "2"}], "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Kappa]", "*", "z1"}], "]"}], ")"}], "^", "2"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.519102882800062*^9, 3.519102885856413*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  SuperscriptBox["Aq0", "2"], " ", 
  SuperscriptBox["chi", "2"], " ", "cm", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x1", "2"]}], "-", 
        SuperscriptBox["y1", "2"]}], ")"}]}], 
     SuperscriptBox["w0", "2"]], "-", 
    FractionBox[
     RowBox[{"2", " ", "q", " ", 
      SuperscriptBox["z1", "2"]}], 
     SuperscriptBox["z0", "2"]]}]], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z1", " ", "\[Kappa]"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z1", " ", "\[Kappa]"}]]}], ")"}], 
   "2"]}]], "Output",
 CellChangeTimes->{3.5190369565049877`*^9, 3.5190712699450703`*^9, 
  3.519071595578497*^9, 3.519073733709145*^9, 3.519074551873952*^9, 
  3.5191616911199865`*^9, 3.5193258602124553`*^9, 3.5195670269059424`*^9, 
  3.5196240454046183`*^9, 3.520112769881209*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assumptions", "Section",
 CellChangeTimes->{{3.519097759869207*^9, 3.5190977785960703`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Element", "[", 
     RowBox[{"w0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"b", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"Aq0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Tau]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"cm", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"Dd", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"q", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Kappa]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Dd", ">", "0"}], "&&", 
    RowBox[{"\[Tau]", ">", "0"}], "&&", 
    RowBox[{"w0", ">", "0"}], "&&", 
    RowBox[{"z0", ">", "0"}], "&&", 
    RowBox[{"Aq0", ">", "0"}], "&&", 
    RowBox[{"q", "\[GreaterEqual]", "1"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"vr", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"vz", ",", "Reals"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.519097780783361*^9, 3.519097783919778*^9}, 
   3.5191029105091476`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"b", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Aq0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"\[Tau]", "\[Element]", "Reals"}], "&&", 
   RowBox[{"cm", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Dd", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"q", "\[Element]", "Reals"}], "&&", 
   RowBox[{"\[Kappa]", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Dd", ">", "0"}], "&&", 
   RowBox[{"\[Tau]", ">", "0"}], "&&", 
   RowBox[{"w0", ">", "0"}], "&&", 
   RowBox[{"z0", ">", "0"}], "&&", 
   RowBox[{"Aq0", ">", "0"}], "&&", 
   RowBox[{"q", "\[GreaterEqual]", "1"}], "&&", 
   RowBox[{"vr", "\[Element]", "Reals"}], "&&", 
   RowBox[{"vz", "\[Element]", "Reals"}]}], "}"}]], "Output",
 CellChangeTimes->{3.519097785842445*^9, 3.519098734981737*^9, 
  3.5191616912762346`*^9, 3.519325860368703*^9, 3.51956702706219*^9, 
  3.5196240459598093`*^9, 3.520112769925209*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute g1", "Section",
 CellChangeTimes->{{3.517712163185369*^9, 3.5177121650259*^9}, 
   3.517739251246941*^9}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[CellGroupData[{

Cell["z Integration", "Subsection",
 CellChangeTimes->{{3.517721610471263*^9, 3.5177216121251574`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11z1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z2_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"g1int", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z1", ",", "z2", ",", "z3", ",", "z4", ",", 
        "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z1", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.51763303819493*^9, {3.517633099950801*^9, 3.51763311391716*^9}, {
   3.51763466699538*^9, 3.5176346678836727`*^9}, {3.5176354194384413`*^9, 
   3.5176354226762*^9}, {3.517635454414604*^9, 3.517635457311709*^9}, 
   3.517719723321267*^9, 3.5177392473741903`*^9, {3.517741365354589*^9, 
   3.517741393930015*^9}, {3.519097802058515*^9, 3.5190978157242823`*^9}, 
   3.519106295595005*^9, {3.520111112615732*^9, 3.520111123021789*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201130130817823`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520113113108552*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520113213702118*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520113213704336*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"16", " ", "Dd", " ", "\[Pi]", " ", "\[Tau]", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z2", "2"], "+", 
               SuperscriptBox["z3", "2"], "+", 
               SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"]}]]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
         SuperscriptBox["z3", "2"], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"vr", " ", 
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}]}], "-", 
            RowBox[{"vz", " ", "z3"}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "Dd", " ", 
             RowBox[{"(", 
              RowBox[{"z2", "+", "z3", "+", "z4"}], ")"}], " ", 
             "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], 
        RowBox[{"Dd", " ", "\[Tau]"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z3", "-", 
           RowBox[{"vz", " ", "\[Tau]"}], "+", 
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
            "\[Tau]"}]}], ")"}], "2"]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z3", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"vz", "+", 
              RowBox[{
              "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
             ")"}], " ", "\[Tau]"}]}], ")"}], "2"]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
    ")"}], " ", "z0"}]}]], "Output",
 CellChangeTimes->{3.5176330865836887`*^9, 3.5176346634287243`*^9, 
  3.517635414307756*^9, 3.517635448818797*^9, 3.517635809040265*^9, 
  3.517637596707975*^9, 3.5176424646560287`*^9, 3.5177216588898983`*^9, 
  3.5177394821171627`*^9, 3.5177417600076*^9, 3.517897050767387*^9, 
  3.519037047444858*^9, 3.519098899004342*^9, 3.519161854055401*^9, 
  3.519326403346128*^9, 3.5195672234503016`*^9, 3.520113367490376*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11z2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint11z1", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z2", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"z2", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517636187272016*^9, 3.517636267436021*^9}, {
   3.519097829422256*^9, 3.519097836626338*^9}, 3.519106299058486*^9, {
   3.5201111253596897`*^9, 3.520111128341692*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520113498536352*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", "Dd", " ", 
    SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
    SqrtBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z3", "2"], "+", 
               SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"]}]]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
         SuperscriptBox["z3", "2"], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"vr", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "y1"}], "+", "y3"}], ")"}]}], "+", 
            RowBox[{"vz", " ", "z3"}], "-", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "Dd", " ", 
             RowBox[{"(", 
              RowBox[{"z3", "+", "z4"}], ")"}], " ", "\[Kappa]"}]}], ")"}], 
          " ", "\[Tau]"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], 
        RowBox[{"Dd", " ", "\[Tau]"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z3", "-", 
           RowBox[{"vz", " ", "\[Tau]"}], "+", 
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
            "\[Tau]"}]}], ")"}], "2"]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z3", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"vz", "+", 
              RowBox[{
              "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
             ")"}], " ", "\[Tau]"}]}], ")"}], "2"]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
    ")"}], " ", 
   SuperscriptBox["z0", "2"]}]}]], "Output",
 CellChangeTimes->{3.517636295580174*^9, 3.517637618818699*^9, 
  3.51764340506273*^9, 3.517721682228327*^9, 3.51774177919895*^9, 
  3.517897070026525*^9, 3.519037067899403*^9, 3.519099024040762*^9, 
  3.5191619241638784`*^9, 3.519326574047068*^9, 3.5195673636516323`*^9, 
  3.520113571633827*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11z3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint11z2", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z3", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517636311248352*^9, 3.517636335586735*^9}, {
   3.519097841347066*^9, 3.519097847679796*^9}, 3.5191063027768507`*^9, {
   3.52011113163096*^9, 3.520111135129891*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", 
    SqrtBox["2"], " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
       FractionBox[
        RowBox[{"8", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y1", "2"], "+", 
              SuperscriptBox["y2", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z4", "2"]}]}], ")"}], " ", "\[Tau]"}], 
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["z0", "2"]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"vr", " ", 
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}]}], "+", 
              RowBox[{
              "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
               "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              RowBox[{"2", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz"}], "+", 
                 RowBox[{"3", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], 
             ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
       FractionBox[
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y1", "2"], "+", 
              SuperscriptBox["y2", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["z4", "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"vr", " ", "y1"}], "-", 
                 RowBox[{"vr", " ", "y3"}], "+", 
                 RowBox[{
                 "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
                  "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["vr", "2"], "+", 
                 SuperscriptBox["vz", "2"]}], ")"}], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"2", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], ")"}]}]}],
     ")"}], " ", 
   SuperscriptBox["z0", "3"]}]}]], "Output",
 CellChangeTimes->{3.51763637560223*^9, 3.517637644961411*^9, 
  3.517643435903845*^9, 3.517721707258626*^9, 3.517741804872692*^9, 
  3.517897095339232*^9, 3.51903710176648*^9, 3.519099199041984*^9, 
  3.5191642014628534`*^9, 3.519326901011633*^9, 3.519567581992587*^9, 
  3.520115128623447*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11z4", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint11z3", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z4", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517636540235422*^9, 3.5176365690334044`*^9}, {
  3.5190978540412607`*^9, 3.519097858883366*^9}, {3.519151470913374*^9, 
  3.5191515207505493`*^9}, {3.519151559773102*^9, 3.5191515616450157`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", "Dd", " ", 
    SuperscriptBox["q", 
     RowBox[{"3", "/", "2"}]], " ", "\[Tau]", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
       FractionBox[
        RowBox[{"8", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y1", "2"], "+", 
           SuperscriptBox["y2", "2"], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], 
        SuperscriptBox["w0", "2"]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
           RowBox[{"2", " ", "vr", " ", 
            RowBox[{"(", 
             RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                 RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], 
             ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
       FractionBox[
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y1", "2"], "+", 
              SuperscriptBox["y2", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
              RowBox[{"2", " ", "vr", " ", 
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["vr", "2"], "+", 
                 SuperscriptBox["vz", "2"]}], ")"}], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"2", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], ")"}]}]}],
     ")"}], " ", 
   SqrtBox["\[Pi]"], " ", 
   SuperscriptBox["z0", "4"]}]}]], "Output",
 CellChangeTimes->{3.517636555073791*^9, 3.51763659919344*^9, 
  3.517637673037059*^9, 3.51764347218535*^9, 3.517721735289556*^9, 
  3.517741833113982*^9, 3.517897123561556*^9, 3.519037143715172*^9, 
  3.519099302893367*^9, 3.5191643501797*^9, 3.5193306376200533`*^9, 
  3.5195678051772304`*^9, 3.5201152597471867`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y Integration", "Subsection",
 CellChangeTimes->{{3.517721620517411*^9, 3.517721622277459*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11y1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y2_", ",", "y3_", ",", 
    "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint11z4", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y1", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5176366094794903`*^9, 3.517636627910242*^9}, {
   3.519097863245084*^9, 3.51909786881468*^9}, 3.519106308248249*^9, {
   3.520111141096388*^9, 3.520111146636877*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"16", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], 
            SuperscriptBox["w0", "2"]], "+", 
           FractionBox[
            SuperscriptBox["y3", "2"], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}], 
        "+", 
        RowBox[{"4", " ", "Dd", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "\[Tau]"], "+", 
           RowBox[{
            SuperscriptBox["vr", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "-", 
           FractionBox[
            RowBox[{
            "8", " ", "Dd", " ", "q", " ", "vr", " ", "y3", " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}], 
        "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
          FractionBox[
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "q"}], " ", 
               SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
                 RowBox[{"q", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                    RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
                  "\[Tau]"}]}], ")"}]}]}], ")"}]}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["Dd", "2"]}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
        ")"}]}]}], ")"}], " ", "\[Pi]", " ", "w0", " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["q", 
     RowBox[{"3", "/", "2"}]], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5176366724376574`*^9, 3.517637711807805*^9, 
  3.51764352306616*^9, 3.517721780603376*^9, 3.517741872514039*^9, 
  3.517897162751515*^9, 3.519037236149064*^9, 3.5190994478117523`*^9, 
  3.5191645307555137`*^9, 3.519330775540163*^9, 3.519567975768797*^9, 
  3.520115405513501*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11y2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y3_", ",", "y4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint11y1", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y2", ",", "y3", ",", "y4",
         ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y2", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517636680141523*^9, 3.5176366968168507`*^9}, {
   3.519097873037465*^9, 3.519097877841151*^9}, 3.519106311055794*^9, {
   3.520111150932826*^9, 3.5201111542289543`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"16", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], 
            SuperscriptBox["w0", "2"]], "+", 
           FractionBox[
            SuperscriptBox["y3", "2"], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}], 
        "+", 
        RowBox[{"4", " ", "Dd", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "\[Tau]"], "+", 
           RowBox[{
            SuperscriptBox["vr", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "-", 
           FractionBox[
            RowBox[{
            "8", " ", "Dd", " ", "q", " ", "vr", " ", "y3", " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}], 
        "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
          FractionBox[
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "q"}], " ", 
               SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
                 RowBox[{"q", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                    RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
                  "\[Tau]"}]}], ")"}]}]}], ")"}]}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["Dd", "2"]}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
        ")"}]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["q", "2"], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517636727325078*^9, 3.5176377304696093`*^9, 
  3.517721804675577*^9, 3.517741891188109*^9, 3.51789718180632*^9, 
  3.519037276279558*^9, 3.5190994595070753`*^9, 3.519164602770217*^9, 
  3.519330865398388*^9, 3.5195680484397416`*^9, 3.520115461021723*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11y3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint11y2", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y3", ",", "y4", ",", 
        "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y3", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.51763673699617*^9, 3.517636746056753*^9}, {
   3.519097881629058*^9, 3.519097889396885*^9}, 3.519106314655726*^9, {
   3.520111158461742*^9, 3.520111162358741*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"8", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}]}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "\[Tau]"], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
          FractionBox[
           RowBox[{"2", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "q"}], " ", 
               SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
                 RowBox[{"q", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                    RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
                  "\[Tau]"}]}], ")"}]}]}], ")"}]}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"]}], 
       RowBox[{"8", " ", 
        SuperscriptBox["Dd", "2"]}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
        ")"}]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"4", " ", 
    SuperscriptBox["q", "2"], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.51763676849699*^9, 3.517637758310746*^9, 
  3.517721833135168*^9, 3.517741919469*^9, 3.517897208577386*^9, 
  3.519037307630803*^9, 3.5190994664571877`*^9, 3.519164743377792*^9, 
  3.5193310564115677`*^9, 3.5195681036890345`*^9, 3.520115597365011*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11y4", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}],
   "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint11y3", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y4", ",", "\[Tau]"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y4", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517636780401519*^9, 3.517636790711196*^9}, {
   3.519097895613007*^9, 3.519097900930365*^9}, 3.5191515768131742`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"8", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"]}], ")"}]}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "\[Tau]"], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
          FractionBox[
           RowBox[{"2", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "q"}], " ", 
               SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
                 RowBox[{"q", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                    RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
                  "\[Tau]"}]}], ")"}]}]}], ")"}]}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"]}], 
       RowBox[{"8", " ", 
        SuperscriptBox["Dd", "2"]}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
        ")"}]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox["w0", "4"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"4", " ", 
    SuperscriptBox["q", 
     RowBox[{"5", "/", "2"}]], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.51763680533506*^9, 3.517637768735571*^9, 
  3.517721843387409*^9, 3.517741930244686*^9, 3.5178972203600483`*^9, 
  3.519037331954183*^9, 3.519099478134754*^9, 3.519164837392214*^9, 
  3.519332195709485*^9, 3.5195681728443995`*^9, 3.5201156425193863`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x Integration", "Subsection",
 CellChangeTimes->{{3.517721631965609*^9, 3.517721633861856*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11x1", "[", 
   RowBox[{"x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint11y4", "[", 
       RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x1", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.51763702885286*^9, 3.517637044085169*^9}, {
   3.5190979091571217`*^9, 3.51909791429643*^9}, 3.519106323884988*^9, {
   3.520111168142964*^9, 3.5201111710435457`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "2"]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
        FractionBox[
         RowBox[{"8", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"]}], ")"}]}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"vz", "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{"2", " ", "\[ImaginaryI]"}]}], ")"}], " ", "Dd", " ", 
             "\[Kappa]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"vz", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", 
               RowBox[{"2", " ", "\[ImaginaryI]"}]}], ")"}], " ", "Dd", " ", 
             "\[Kappa]"}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "4"]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        "-", 
        FractionBox[
         RowBox[{"vz", " ", 
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{"vz", "-", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}],
            ")"}]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        "-", 
        FractionBox[
         RowBox[{"8", " ", "q", " ", 
          SuperscriptBox["x3", "2"]}], 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
        ")"}]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "5"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "3"], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517637069901671*^9, 3.517637790217033*^9, 
  3.517721864829615*^9, 3.517741951830454*^9, 3.5178905531788197`*^9, 
  3.517897242081526*^9, 3.519037384710588*^9, 3.519100510203484*^9, 
  3.519164963921844*^9, 3.519332311004884*^9, 3.5195682481559353`*^9, 
  3.5201157393736343`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11x2", "[", 
   RowBox[{"x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint11x1", "[", 
       RowBox[{"x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5176419665398483`*^9, 3.517641979452293*^9}, {
   3.519097919478857*^9, 3.519097924102199*^9}, 3.51910632725484*^9, {
   3.520111174741592*^9, 3.520111177899151*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "2"]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
        FractionBox[
         RowBox[{"8", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"]}], ")"}]}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"vz", "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{"2", " ", "\[ImaginaryI]"}]}], ")"}], " ", "Dd", " ", 
             "\[Kappa]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"vz", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", 
               RowBox[{"2", " ", "\[ImaginaryI]"}]}], ")"}], " ", "Dd", " ", 
             "\[Kappa]"}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "4"]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        "-", 
        FractionBox[
         RowBox[{"vz", " ", 
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{"vz", "-", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}],
            ")"}]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        "-", 
        FractionBox[
         RowBox[{"8", " ", "q", " ", 
          SuperscriptBox["x3", "2"]}], 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
        ")"}]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"7", "/", "2"}]], " ", 
    SuperscriptBox["w0", "6"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["q", "7"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517642001500123*^9, 3.517721882616865*^9, 
  3.517741969809967*^9, 3.517897258304069*^9, 3.519037406208791*^9, 
  3.519100599769169*^9, 3.5191650060306797`*^9, 3.51933237264472*^9, 
  3.519568295608453*^9, 3.520115774093972*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11x3", "[", 
   RowBox[{"x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint11x2", "[", 
       RowBox[{"x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x3", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517642026806909*^9, 3.517642042110222*^9}, {
   3.5190979284213247`*^9, 3.5190979351357527`*^9}, 3.51910633064662*^9, {
   3.5201111823469133`*^9, 3.520111186046379*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201159043725767`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520116004865574*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "q", " ", 
           SuperscriptBox["x4", "2"]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
         RowBox[{"Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        "+", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "Dd", " ", 
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], "+", 
          RowBox[{"q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"vz", "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", 
                RowBox[{"2", " ", "\[ImaginaryI]"}]}], ")"}], " ", "Dd", " ", 
              "\[Kappa]"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"vz", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "-", 
                RowBox[{"2", " ", "\[ImaginaryI]"}]}], ")"}], " ", "Dd", " ", 
              "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}]}], 
         RowBox[{"Dd", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
       ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
        ")"}]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["w0", "7"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["q", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.519165025749178*^9, 3.5193324276908903`*^9, 
  3.5195683386079025`*^9, 3.52011602074284*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint11x4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint11x3", "[", 
       RowBox[{"x4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x4", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517642065395732*^9, 3.517642077000885*^9}, {
   3.519097941920683*^9, 3.519097947882566*^9}, 3.519106350853632*^9, {
   3.520111197340225*^9, 3.520111200460451*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520116131273123*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520116231426548*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520116347661152*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520116347663159*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"2", " ", "Dd", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", "\[Kappa]"}]}], ")"}], 
         " ", "\[Tau]"}], "+", 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["vz", "2"], " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              RowBox[{"8", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "2"]}], "+", 
        RowBox[{"2", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vr", "2"], "+", 
           SuperscriptBox["vz", "2"]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "3"]}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
        ")"}]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"9", "/", "2"}]], " ", 
    SuperscriptBox["w0", "8"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["q", 
     RowBox[{"9", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5176420836307287`*^9, 3.5177218973655157`*^9, 
  3.5177419840325336`*^9, 3.517897273011977*^9, 3.519037426339655*^9, 
  3.519100620261445*^9, 3.5191650569362783`*^9, 3.519332450456224*^9, 
  3.5195683715606055`*^9, 3.5201168090292187`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g1", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"myint11x4", "[", "\[Tau]", "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517643533519837*^9, 3.51764356603941*^9}, 
   3.5177414543318853`*^9, 3.519097955181872*^9, 3.519151586342704*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201175107253733`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520118210866191*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.52011904489067*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520119044892776*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"2", " ", "Dd", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", "\[Kappa]"}]}], ")"}], 
         " ", "\[Tau]"}], "+", 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["vz", "2"], " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              RowBox[{"8", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "2"]}], "+", 
        RowBox[{"2", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vr", "2"], "+", 
           SuperscriptBox["vz", "2"]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "3"]}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
        ")"}]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"9", "/", "2"}]], " ", 
    SuperscriptBox["w0", "8"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["q", 
     RowBox[{"9", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517643569733617*^9, 3.517721943401599*^9, 
  3.517741985192861*^9, 3.5178972740083923`*^9, 3.5190374274499617`*^9, 
  3.519100620327722*^9, 3.5191681721620283`*^9, 3.519335877271735*^9, 
  3.519568884319667*^9, 3.5201190888869057`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute g2", "Section",
 CellChangeTimes->{{3.517707100647127*^9, 3.517707115708559*^9}, {
  3.517711985271744*^9, 3.5177120204075327`*^9}, {3.517742099244213*^9, 
  3.5177421015289297`*^9}}],

Cell[CellGroupData[{

Cell["z Integration", "Subsection",
 CellChangeTimes->{{3.5177073652592087`*^9, 3.517707367322884*^9}, 
   3.5177120318157253`*^9, 3.517742159347653*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2z1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z2_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"g2int", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z1", ",", "z2", ",", "z3", ",", "z4", ",", 
        "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z1", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517707126778647*^9, 3.517707186958552*^9}, {
   3.5177074575839643`*^9, 3.5177074584079113`*^9}, {3.5177077003425093`*^9, 
   3.517707718625432*^9}, {3.517718867619732*^9, 3.517718879308165*^9}, 
   3.517719304970758*^9, 3.517742105944983*^9, {3.517742170858178*^9, 
   3.517742218463476*^9}, {3.5177422690729027`*^9, 3.5177422695843773`*^9}, {
   3.5190979668051157`*^9, 3.519097971831358*^9}, {3.519098064055744*^9, 
   3.5190980775258512`*^9}, 3.519106355119066*^9, {3.520111207109787*^9, 
   3.520111209879925*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"z2", " ", "\[Kappa]"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"z3", " ", "\[Kappa]"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"z4", " ", "\[Kappa]"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z2", "-", "z3"}], ")"}], "2"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"vr", " ", 
                 RowBox[{"(", 
                  RowBox[{"y1", "-", "y3"}], ")"}]}], "+", 
                RowBox[{"vz", " ", 
                 RowBox[{"(", 
                  RowBox[{"z2", "-", "z3"}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x1", "2"], "+", 
                   SuperscriptBox["x2", "2"], "+", 
                   SuperscriptBox["x3", "2"], "+", 
                   SuperscriptBox["x4", "2"], "+", 
                   SuperscriptBox["y1", "2"], "+", 
                   SuperscriptBox["y2", "2"], "+", 
                   SuperscriptBox["y3", "2"], "+", 
                   SuperscriptBox["y4", "2"]}], ")"}], " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["w0", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["z2", "2"]}], "+", 
                   SuperscriptBox["z3", "2"], "+", 
                   SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", "Dd", " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "z2", " ", "\[Kappa]"}]}], 
            ")"}], " ", "\[Tau]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", 
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z2", "-", "z3"}], ")"}], "2"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"vr", " ", 
                 RowBox[{"(", 
                  RowBox[{"y1", "-", "y3"}], ")"}]}], "+", 
                RowBox[{"vz", " ", 
                 RowBox[{"(", 
                  RowBox[{"z2", "-", "z3"}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x1", "2"], "+", 
                   SuperscriptBox["x2", "2"], "+", 
                   SuperscriptBox["x3", "2"], "+", 
                   SuperscriptBox["x4", "2"], "+", 
                   SuperscriptBox["y1", "2"], "+", 
                   SuperscriptBox["y2", "2"], "+", 
                   SuperscriptBox["y3", "2"], "+", 
                   SuperscriptBox["y4", "2"]}], ")"}], " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["w0", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["z2", "2"]}], "+", 
                   SuperscriptBox["z3", "2"], "+", 
                   SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", "Dd", " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "z2", " ", "\[Kappa]"}]}], 
            ")"}], " ", "\[Tau]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", 
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.517707439600347*^9, 3.517707651823756*^9, 
  3.517707733375701*^9, 3.5177188983366423`*^9, 3.517719320273962*^9, 
  3.517742231545885*^9, 3.517742277566556*^9, 3.517901450315584*^9, 
  3.5190374364566708`*^9, 3.519100644391066*^9, 3.5191681821619*^9, 
  3.5193358872716074`*^9, 3.5195688934445505`*^9, 3.520119104372506*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2z2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint2z1", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z2", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"z2", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517707436850107*^9, 3.517707438662883*^9}, {
   3.5177076656099043`*^9, 3.517707692330924*^9}, {3.5177077330531263`*^9, 
   3.517707761029437*^9}, {3.517707809587075*^9, 3.5177078102618847`*^9}, {
   3.517707887882419*^9, 3.517707914077277*^9}, {3.517707975483398*^9, 
   3.517707990453388*^9}, 3.517718908052795*^9, {3.517742237592198*^9, 
   3.5177423026726437`*^9}, {3.517742627763577*^9, 3.51774263595721*^9}, {
   3.519097975567315*^9, 3.519097981743099*^9}, 3.5190980255635157`*^9, {
   3.519098062864303*^9, 3.519098082797646*^9}, 3.519106357823009*^9, {
   3.5201112119322023`*^9, 3.520111214799075*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201196378512087`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520119737851959*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201199194921417`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201199194942408`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", "Dd", " ", "\[Pi]", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y1", "2"], "+", 
           SuperscriptBox["y2", "2"], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", 
         SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
              SuperscriptBox["z3", "2"]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"vr", " ", 
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}], " ", 
               SuperscriptBox["z0", "2"]}], "-", 
              RowBox[{"vz", " ", 
               SuperscriptBox["z0", "2"], " ", "z3"}], "+", 
              RowBox[{"2", " ", "Dd", " ", "q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z3", "2"], "+", 
                 SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}], " ", 
            "\[Tau]"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
       RowBox[{"4", " ", "Dd", " ", 
        SuperscriptBox["w0", "2"], " ", 
        SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z3", "-", 
            RowBox[{"vz", " ", "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z3", "-", 
            RowBox[{"vz", " ", "\[Tau]"}], "+", 
            RowBox[{
            "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
             "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], " ", "z0", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"z3", " ", "\[Kappa]"}], "]"}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"z4", " ", "\[Kappa]"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", "Dd", " ", "\[Pi]", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y1", "2"], "+", 
           SuperscriptBox["y2", "2"], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", 
         SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
              SuperscriptBox["z3", "2"]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"vr", " ", 
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}], " ", 
               SuperscriptBox["z0", "2"]}], "-", 
              RowBox[{"vz", " ", 
               SuperscriptBox["z0", "2"], " ", "z3"}], "+", 
              RowBox[{"2", " ", "Dd", " ", "q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z3", "2"], "+", 
                 SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}], " ", 
            "\[Tau]"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
       RowBox[{"4", " ", "Dd", " ", 
        SuperscriptBox["w0", "2"], " ", 
        SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z3", "-", 
            RowBox[{"vz", " ", "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z3", "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"vz", "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
              ")"}], " ", "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], " ", "z0", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"z3", " ", "\[Kappa]"}], "]"}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"z4", " ", "\[Kappa]"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.517707806644844*^9, 3.5177078447251368`*^9, 
  3.517707945042571*^9, 3.51770802769462*^9, 3.5177189188241663`*^9, 
  3.517719334468026*^9, 3.51774261847016*^9, 3.517742779870541*^9, 
  3.517901595761839*^9, 3.519037708112177*^9, 3.519103665763278*^9, 
  3.51916875481082*^9, 3.5193364950607023`*^9, 3.519569220502864*^9, 
  3.520120038085705*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2z3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint2z2", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z3", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517707781107938*^9, 3.51770778501499*^9}, {
   3.51770782098004*^9, 3.5177078402536793`*^9}, {3.5177423181997232`*^9, 
   3.517742332801095*^9}, {3.5190981875121117`*^9, 3.519098194025169*^9}, 
   3.519106363398776*^9, {3.520111219410803*^9, 3.520111222730888*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "q", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "q"], "+", 
       RowBox[{"8", " ", "Dd", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"32", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z4", "2"]}]}], ")"}], " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"]}]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], ")"}]}], "+", 
            RowBox[{"6", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["vr", "2"]}], "+", 
               RowBox[{"8", " ", "Dd", " ", "\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                  RowBox[{"Dd", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["z4", "2"]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
                  RowBox[{"2", " ", "vr", " ", 
                   RowBox[{"(", 
                    RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["vr", "2"], "+", 
                    SuperscriptBox["vz", "2"]}], ")"}], " ", 
                   SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], ")"}], " ", 
    
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"z4", " ", "\[Kappa]"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"9", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"32", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z4", "2"]}]}], ")"}], " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"]}]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], ")"}]}], "+", 
            RowBox[{"6", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["vr", "2"]}], "+", 
               RowBox[{"8", " ", "Dd", " ", "\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz"}], "+", 
                  RowBox[{"3", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], 
              ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["z4", "2"]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
                  RowBox[{"2", " ", "vr", " ", 
                   RowBox[{"(", 
                    RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["vr", "2"], "+", 
                    SuperscriptBox["vz", "2"]}], ")"}], " ", 
                   SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]]}], ")"}], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"z4", " ", "\[Kappa]"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"9", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"32", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z4", "2"]}]}], ")"}], " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"]}]], "+", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
            RowBox[{"2", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["z4", "2"]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
                  RowBox[{"2", " ", "vr", " ", 
                   RowBox[{"(", 
                    RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["vr", "2"], "+", 
                    SuperscriptBox["vz", "2"]}], ")"}], " ", 
                   SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}], 
          ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"z4", " ", "\[Kappa]"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.5177080479373283`*^9, 3.517718933028844*^9, 
  3.517719372984586*^9, 3.517742831076674*^9, 3.5179016453754883`*^9, 
  3.519037843395463*^9, 3.519103666209175*^9, 3.519169303006928*^9, 
  3.5193370257101603`*^9, 3.5195697059653997`*^9, 3.5201272531775217`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2z4", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint2z3", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z4", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517742340974523*^9, 3.517742353996542*^9}, {
   3.519098199855296*^9, 3.5190982050944033`*^9}, 3.519151594437389*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"32", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y1", "2"], "+", 
            SuperscriptBox["y2", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], ")"}]}], "+", 
            RowBox[{"6", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["vr", "2"]}], "+", 
               RowBox[{"8", " ", "Dd", " ", "\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                  RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], 
              ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
               RowBox[{"2", " ", "vr", " ", 
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  SuperscriptBox["vz", "2"]}], ")"}], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], ")"}], " ", 
    
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"12", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"32", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y1", "2"], "+", 
            SuperscriptBox["y2", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], ")"}]}], "+", 
            RowBox[{"6", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["vr", "2"]}], "+", 
               RowBox[{"16", " ", "Dd", " ", "\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                  RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], 
              ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
               RowBox[{"2", " ", "vr", " ", 
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  SuperscriptBox["vz", "2"]}], ")"}], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]]}], ")"}], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"12", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"32", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y1", "2"], "+", 
            SuperscriptBox["y2", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], "2"]}], ")"}]}], "+", 
            RowBox[{"6", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["vr", "2"]}], "+", 
               RowBox[{"32", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
               RowBox[{"2", " ", "vr", " ", 
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  SuperscriptBox["vz", "2"]}], ")"}], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}], 
          ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.517742868915729*^9, 3.5179016958885307`*^9, 
  3.519037957176519*^9, 3.519103666313442*^9, 3.5191705036634345`*^9, 
  3.5193388777645783`*^9, 3.5195738490966015`*^9, 3.520127360167077*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y Integration", "Subsection",
 CellChangeTimes->{{3.5177120430240726`*^9, 3.51771204546321*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2y1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y2_", ",", "y3_", ",", 
    "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint2z4", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y1", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5177423766146393`*^9, 3.517742388617363*^9}, {
   3.519098211728489*^9, 3.519098218073687*^9}, 3.519106368926238*^9, {
   3.520111231634843*^9, 3.5201112344263372`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"32", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["y2", "2"]}], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}]}], "+", 
            RowBox[{"6", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y2", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["vr", "2"]}], "+", 
               RowBox[{"8", " ", "Dd", " ", "\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                  RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], 
              ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["y2", "2"]}], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y2", "-", "y3"}], ")"}], "2"], "+", 
               RowBox[{"2", " ", "vr", " ", 
                RowBox[{"(", 
                 RowBox[{"y2", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  SuperscriptBox["vz", "2"]}], ")"}], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], ")"}], " ", 
    
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"12", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"32", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["y2", "2"]}], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}]}], "+", 
            RowBox[{"6", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y2", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["vr", "2"]}], "+", 
               RowBox[{"16", " ", "Dd", " ", "\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                  RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], 
              ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["y2", "2"]}], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y2", "-", "y3"}], ")"}], "2"], "+", 
               RowBox[{"2", " ", "vr", " ", 
                RowBox[{"(", 
                 RowBox[{"y2", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  SuperscriptBox["vz", "2"]}], ")"}], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]]}], ")"}], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"12", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"32", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["y2", "2"]}], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y2", "-", "y3"}], ")"}], "2"]}], ")"}]}], "+", 
            RowBox[{"6", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y2", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["vr", "2"]}], "+", 
               RowBox[{"32", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["y2", "2"]}], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y2", "-", "y3"}], ")"}], "2"], "+", 
               RowBox[{"2", " ", "vr", " ", 
                RowBox[{"(", 
                 RowBox[{"y2", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  SuperscriptBox["vz", "2"]}], ")"}], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}], 
          ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.5177428768502398`*^9, 3.5179017039476748`*^9, 
  3.519037966123234*^9, 3.5191036669658213`*^9, 3.519170688754815*^9, 
  3.519338919451545*^9, 3.5195738862994037`*^9, 3.52012741432579*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2y2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y3_", ",", "y4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint2y1", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y2", ",", "y3", ",", "y4",
         ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y2", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517742399157131*^9, 3.517742416923222*^9}, {
   3.519098221928165*^9, 3.51909822693351*^9}, 3.519106372158415*^9, {
   3.520111237789307*^9, 3.52011124064191*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520127810477755*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], 
             SuperscriptBox["w0", "2"]], "+", 
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["y3", "2"]}], 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}],
          "+", 
         RowBox[{"8", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "\[Tau]"], "+", 
            RowBox[{
             SuperscriptBox["vr", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{
             SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "-", 
            FractionBox[
             RowBox[{
             "16", " ", "Dd", " ", "q", " ", "vr", " ", "y3", " ", "\[Tau]"}], 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}],
          "+", 
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"8", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["vr", "2"], " ", 
              SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
           FractionBox[
            RowBox[{"8", " ", "Dd", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", "q", " ", 
                SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
                  RowBox[{
                  "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                   "\[Tau]"}], "+", 
                  RowBox[{
                  "4", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", 
                   "\[Tau]"}]}], ")"}]}]}], ")"}]}], 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"]}], 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], ")"}], " ", 
     SqrtBox["\[Pi]"], " ", "w0", " ", 
     SuperscriptBox["z0", "3"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", "q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], 
             SuperscriptBox["w0", "2"]], "+", 
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["y3", "2"]}], 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}],
          "+", 
         RowBox[{"8", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "\[Tau]"], "+", 
            RowBox[{
             SuperscriptBox["vr", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{
             SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "-", 
            FractionBox[
             RowBox[{
             "16", " ", "Dd", " ", "q", " ", "vr", " ", "y3", " ", "\[Tau]"}], 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}],
          "+", 
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"8", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["vr", "2"], " ", 
              SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
           FractionBox[
            RowBox[{"8", " ", "Dd", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", "q", " ", 
                SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
                  RowBox[{
                  "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                   "\[Tau]"}], "+", 
                  RowBox[{
                  "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", 
                   "\[Tau]"}]}], ")"}]}]}], ")"}]}], 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"]}], 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"3", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]]}], ")"}], " ", 
     SqrtBox["\[Pi]"], " ", "w0", " ", 
     SuperscriptBox["z0", "3"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", "q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "4"]}], "+", 
            RowBox[{"16", " ", "Dd", " ", "q", " ", "vr", " ", 
             SuperscriptBox["w0", "2"], " ", "y3"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["vz", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "-", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["q", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], "+", 
                  SuperscriptBox["x2", "2"], "+", 
                  SuperscriptBox["x3", "2"], "+", 
                  SuperscriptBox["x4", "2"], "+", 
                  SuperscriptBox["y3", "2"], "+", 
                  SuperscriptBox["y4", "2"]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z0", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], 
           RowBox[{"q", " ", 
            SuperscriptBox["w0", "2"]}]]}], "+", 
         FractionBox[
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "\[Tau]"], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"vr", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "y3"}]}], ")"}], "2"], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "+", 
         FractionBox[
          RowBox[{"9", " ", 
           SuperscriptBox["vz", "2"], " ", 
           SuperscriptBox["z0", "4"]}], 
          RowBox[{
           RowBox[{"3", " ", "q", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]}], 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], " ", 
     SqrtBox["\[Pi]"], " ", "w0", " ", 
     SuperscriptBox["z0", "3"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", "q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.517742918437899*^9, 3.51790174531531*^9, 
  3.519038061438312*^9, 3.519103671084178*^9, 3.519173895823139*^9, 
  3.519339712863264*^9, 3.5195741966079335`*^9, 3.520127933128735*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2y3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint2y2", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y3", ",", "y4", ",", 
        "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y3", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517742427571549*^9, 3.51774243700349*^9}, {
   3.519098230872177*^9, 3.519098236563574*^9}, 3.519106378669799*^9, {
   3.520111244714388*^9, 3.520111248019107*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{"32", " ", 
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]], "+", 
         FractionBox[
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "\[Tau]"], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
         FractionBox[
          RowBox[{"9", " ", 
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "4"]}], 
          RowBox[{
           RowBox[{"3", " ", "q", " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", 
            SuperscriptBox["vr", "2"], " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["z0", "2"]}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           "+", 
           RowBox[{"8", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", "q", " ", 
               SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
                 RowBox[{
                 "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                  "\[Tau]"}], "+", 
                 RowBox[{
                 "4", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}],
                 ")"}]}]}], ")"}]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], ")"}], " ",
      "\[Pi]", " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "3"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", "q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["w0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{"32", " ", 
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]], "+", 
         FractionBox[
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "\[Tau]"], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
         FractionBox[
          RowBox[{"9", " ", 
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "4"]}], 
          RowBox[{
           RowBox[{"3", " ", "q", " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", 
            SuperscriptBox["vr", "2"], " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["z0", "2"]}], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           "+", 
           RowBox[{"8", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", "q", " ", 
               SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
                 RowBox[{
                 "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                  "\[Tau]"}], "+", 
                 RowBox[{
                 "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}],
                 ")"}]}]}], ")"}]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"3", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]]}], ")"}], " ", 
     "\[Pi]", " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "3"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", "q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["w0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "q", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}]}], 
           SuperscriptBox["w0", "2"]]}], "-", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
          RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "+", 
         
         FractionBox[
          RowBox[{"3", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["vr", "2"], "+", 
                SuperscriptBox["vz", "2"]}], ")"}], " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["vr", "2"], " ", 
                 SuperscriptBox["w0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["vz", "2"], " ", 
                 SuperscriptBox["z0", "2"]}]}], ")"}], " ", "\[Tau]"}]}], 
            ")"}]}], 
          RowBox[{"Dd", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        ")"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], " ", "\[Pi]", " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "3"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", "q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["w0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.517742939838188*^9, 3.517901766816791*^9, 
  3.5190380951749763`*^9, 3.519103692996504*^9, 3.519175542145816*^9, 
  3.519340371854829*^9, 3.5195742868845034`*^9, 3.5201284777046957`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2y4", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}],
   "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint2y3", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y4", ",", "\[Tau]"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y4", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517742446002479*^9, 3.517742457383566*^9}, {
   3.519098240852285*^9, 3.519098246678747*^9}, 3.5191516034602213`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox["1", "32"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "2"]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
         FractionBox[
          RowBox[{"32", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]], "-", 
         FractionBox[
          RowBox[{"8", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], 
          RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
         FractionBox[
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
         
         FractionBox[
          RowBox[{"9", " ", 
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "4"]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "q", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", 
              SuperscriptBox["q", "2"], " ", "\[Tau]"}]}], ")"}]}]], "-", 
         FractionBox[
          RowBox[{"8", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "q", " ", 
              SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
                RowBox[{
                "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                 "\[Tau]"}], "+", 
                RowBox[{
                "4", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
               ")"}]}]}], ")"}]}], 
          RowBox[{"Dd", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        ")"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], ")"}], " ", 
     SuperscriptBox["\[Pi]", 
      RowBox[{"3", "/", "2"}]], " ", 
     SuperscriptBox["w0", "3"], " ", 
     SuperscriptBox["z0", "3"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox["q", "2"], " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["w0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox["1", "32"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "2"]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
         FractionBox[
          RowBox[{"32", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]], "-", 
         FractionBox[
          RowBox[{"8", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], 
          RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
         FractionBox[
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
         
         FractionBox[
          RowBox[{"9", " ", 
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "4"]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "q", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", 
              SuperscriptBox["q", "2"], " ", "\[Tau]"}]}], ")"}]}]], "-", 
         FractionBox[
          RowBox[{"8", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "q", " ", 
              SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
                RowBox[{
                "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                 "\[Tau]"}], "+", 
                RowBox[{
                "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
               ")"}]}]}], ")"}]}], 
          RowBox[{"Dd", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        ")"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"3", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]]}], ")"}], " ", 
     SuperscriptBox["\[Pi]", 
      RowBox[{"3", "/", "2"}]], " ", 
     SuperscriptBox["w0", "3"], " ", 
     SuperscriptBox["z0", "3"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", 
     SuperscriptBox["q", "2"], " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["w0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "q", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"]}], ")"}]}], 
           SuperscriptBox["w0", "2"]]}], "-", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
          RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "+", 
         
         FractionBox[
          RowBox[{"3", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["vr", "2"], "+", 
                SuperscriptBox["vz", "2"]}], ")"}], " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["vr", "2"], " ", 
                 SuperscriptBox["w0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["vz", "2"], " ", 
                 SuperscriptBox["z0", "2"]}]}], ")"}], " ", "\[Tau]"}]}], 
            ")"}]}], 
          RowBox[{"Dd", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        ")"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], " ", 
     SuperscriptBox["\[Pi]", 
      RowBox[{"3", "/", "2"}]], " ", 
     SuperscriptBox["w0", "3"], " ", 
     SuperscriptBox["z0", "3"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", 
     SuperscriptBox["q", 
      RowBox[{"3", "/", "2"}]], " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["w0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.517742950880053*^9, 3.5179017778526773`*^9, 
  3.519038119654882*^9, 3.519103774733335*^9, 3.519176471727667*^9, 
  3.5193408984105887`*^9, 3.5195743762701855`*^9, 3.5201287604500647`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x Integration", "Subsection",
 CellChangeTimes->{{3.517712055584053*^9, 3.517712057343378*^9}, 
   3.517742163353998*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2x1", "[", 
   RowBox[{"x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint2y4", "[", 
       RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x1", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517742489376445*^9, 3.5177425003032503`*^9}, {
   3.5190982499292088`*^9, 3.5190982543679943`*^9}, 3.519106387213081*^9, {
   3.5201112551895647`*^9, 3.520111258368258*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.52012893773763*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "32"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "2"]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
        FractionBox[
         RowBox[{"32", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["x2", "2"]}], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"]}], ")"}]}], 
         SuperscriptBox["w0", "2"]], "-", 
        FractionBox[
         RowBox[{"8", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x2", "-", "x3"}], ")"}], "2"]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
        FractionBox[
         RowBox[{"8", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
        FractionBox[
         RowBox[{"9", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "4"]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "q", " ", 
             SuperscriptBox["w0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", "\[Tau]"}]}], ")"}]}]], "-", 
        FractionBox[
         RowBox[{"8", " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", "q", " ", 
             SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                "\[Tau]"}], "+", 
               RowBox[{
               "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
              ")"}]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
       ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
           "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}], 
          ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "3"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"4", " ", 
    SuperscriptBox["q", "2"], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517742956685525*^9, 3.517901783694124*^9, 
  3.519038130140254*^9, 3.519176679303135*^9, 3.519340993299999*^9, 
  3.5195744071699047`*^9, 3.520129230777835*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2x2", "[", 
   RowBox[{"x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint2x1", "[", 
       RowBox[{"x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517742508642894*^9, 3.517742520418755*^9}, {
   3.519098258081046*^9, 3.5190982642811413`*^9}, 3.519106390644915*^9, {
   3.520111260844709*^9, 3.520111263867757*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "32"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "2"]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
        FractionBox[
         RowBox[{"32", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"]}], ")"}]}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["vz", "2"]}], "-", 
            RowBox[{
            "16", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
             "\[Kappa]"}], "-", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
        FractionBox[
         RowBox[{"8", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
        FractionBox[
         RowBox[{"64", " ", "q", " ", 
          SuperscriptBox["x3", "2"]}], 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "-", 
        FractionBox[
         RowBox[{"9", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "4"]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["w0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        "+", 
        FractionBox[
         RowBox[{"3", " ", "vz", " ", 
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", "vz"}], "+", 
            RowBox[{
            "16", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
           ")"}]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
       ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
           "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}], 
          ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["w0", "4"], " ", 
    SuperscriptBox["z0", "3"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "2"], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517742979346457*^9, 3.5179018061057863`*^9, 
  3.519038139452578*^9, 3.519176882753656*^9, 3.5193412668121233`*^9, 
  3.51957444084682*^9, 3.5201294161363173`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2x3", "[", 
   RowBox[{"x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint2x2", "[", 
       RowBox[{"x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x3", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517742530253129*^9, 3.517742537725638*^9}, {
   3.51909826884978*^9, 3.51909827431437*^9}, 3.519106393276577*^9, {
   3.520111265632751*^9, 3.520111268291*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "32"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "2"]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
        FractionBox[
         RowBox[{"32", " ", "q", " ", 
          SuperscriptBox["x4", "2"]}], 
         SuperscriptBox["w0", "2"]], "-", 
        FractionBox[
         RowBox[{"8", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
        FractionBox[
         RowBox[{"9", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "4"]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "q", " ", 
             SuperscriptBox["w0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", "\[Tau]"}]}], ")"}]}]], "-", 
        FractionBox[
         RowBox[{"8", " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", "q", " ", 
             SuperscriptBox["vz", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                "\[Tau]"}], "+", 
               RowBox[{
               "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
              ")"}]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
       ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
           "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}], 
          ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox["w0", "5"], " ", 
    SuperscriptBox["z0", "3"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5177429882741613`*^9, 3.517901815427566*^9, 
  3.51903814672935*^9, 3.5191769186750712`*^9, 3.519341440309902*^9, 
  3.5195744486444435`*^9, 3.5201294689677267`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2x4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint2x3", "[", 
       RowBox[{"x4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x4", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5177425476972933`*^9, 3.5177425566648197`*^9}, {
   3.519098278786147*^9, 3.519098284748097*^9}, 3.51910639850025*^9, {
   3.520111271786992*^9, 3.520111275263674*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["vz", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "q"], "+", 
        RowBox[{"2", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", "Dd", " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["vr", "2"]}], "+", 
              RowBox[{"16", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                 RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], 
             ")"}], " ", "\[Tau]"}], "+", 
           RowBox[{"8", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["w0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
           "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}], 
          ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "6"], " ", 
    SuperscriptBox["z0", "3"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517742994790627*^9, 3.517901821762847*^9, 
  3.5190381493086233`*^9, 3.519176933549881*^9, 3.5193414951529503`*^9, 
  3.5195744533167667`*^9, 3.520129484984714*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g2", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"myint2x4", "[", "\[Tau]", "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517711702800435*^9, 3.517711728387665*^9}, {
   3.517742564771495*^9, 3.5177425690024557`*^9}, 3.517742599172182*^9, 
   3.519151610124578*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["vz", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "q"], "+", 
        RowBox[{"2", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", "Dd", " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["vr", "2"]}], "+", 
              RowBox[{"16", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                 RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], 
             ")"}], " ", "\[Tau]"}], "+", 
           RowBox[{"8", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["w0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
           "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}], 
          ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "6"], " ", 
    SuperscriptBox["z0", "3"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517711734359661*^9, 3.5177201020180187`*^9, 
  3.517721138631971*^9, 3.517742995940958*^9, 3.517901822851325*^9, 
  3.519038150280826*^9, 3.51917695590897*^9, 3.5193415916517153`*^9, 
  3.5195744615363054`*^9, 3.520129493784094*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute g3", "Section",
 CellChangeTimes->{{3.517712244605625*^9, 3.517712246731595*^9}, {
  3.517743037922456*^9, 3.517743042681806*^9}, {3.5180897812388887`*^9, 
  3.518089781618937*^9}}],

Cell[CellGroupData[{

Cell["g3", "Subsection",
 CellChangeTimes->{{3.517724213366851*^9, 3.517724229845232*^9}, {
  3.5177430973968267`*^9, 3.517743098730826*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3z1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z2_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"g3int", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z1", ",", "z2", ",", "z3", ",", "z4", ",", 
        "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z1", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519033779064073*^9, 3.519033853986814*^9}, 
   3.519036619103786*^9, {3.519098293220059*^9, 3.519098298614792*^9}, 
   3.519106402941757*^9, {3.520111279752665*^9, 3.520111283209115*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"16", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Dd", " ", "\[Tau]"}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", "cm", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"z2", " ", "\[Kappa]"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"z3", " ", "\[Kappa]"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"z4", " ", "\[Kappa]"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z2", "-", "z3"}], ")"}], "2"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"vr", " ", 
                 RowBox[{"(", 
                  RowBox[{"y1", "-", "y3"}], ")"}]}], "+", 
                RowBox[{"vz", " ", 
                 RowBox[{"(", 
                  RowBox[{"z2", "-", "z3"}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x1", "2"], "+", 
                   SuperscriptBox["x2", "2"], "+", 
                   SuperscriptBox["x3", "2"], "+", 
                   SuperscriptBox["x4", "2"], "+", 
                   SuperscriptBox["y1", "2"], "+", 
                   SuperscriptBox["y2", "2"], "+", 
                   SuperscriptBox["y3", "2"], "+", 
                   SuperscriptBox["y4", "2"]}], ")"}], " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["w0", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["z2", "2"]}], "+", 
                   SuperscriptBox["z3", "2"], "+", 
                   SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", "Dd", " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "z2", " ", "\[Kappa]"}]}], 
            ")"}], " ", "\[Tau]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", 
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z2", "-", "z3"}], ")"}], "2"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"vr", " ", 
                 RowBox[{"(", 
                  RowBox[{"y1", "-", "y3"}], ")"}]}], "+", 
                RowBox[{"vz", " ", 
                 RowBox[{"(", 
                  RowBox[{"z2", "-", "z3"}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x1", "2"], "+", 
                   SuperscriptBox["x2", "2"], "+", 
                   SuperscriptBox["x3", "2"], "+", 
                   SuperscriptBox["x4", "2"], "+", 
                   SuperscriptBox["y1", "2"], "+", 
                   SuperscriptBox["y2", "2"], "+", 
                   SuperscriptBox["y3", "2"], "+", 
                   SuperscriptBox["y4", "2"]}], ")"}], " ", 
                 SuperscriptBox["z0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["w0", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["z2", "2"]}], "+", 
                   SuperscriptBox["z3", "2"], "+", 
                   SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", "Dd", " ", 
              SuperscriptBox["w0", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "z2", " ", "\[Kappa]"}]}], 
            ")"}], " ", "\[Tau]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", 
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], 
         RowBox[{"4", " ", "Dd", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"x1", "-", "x2"}], "]"}], " ", 
      RowBox[{"DiracDelta", "[", 
       RowBox[{"y1", "-", "y2"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"DiracDelta", "[", 
    RowBox[{
     RowBox[{"x3", "-", "x4"}], ",", 
     RowBox[{"y3", "-", "y4"}], ",", 
     RowBox[{"z3", "-", "z4"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.519033859300933*^9, 3.51903416167703*^9, 
  3.5190381589135933`*^9, 3.519176965518222*^9, 3.5193416013547163`*^9, 
  3.519574470615302*^9, 3.5201295093138103`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3z2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint3z1", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z2", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"z2", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519033927472396*^9, 3.5190339343832417`*^9}, {
   3.5190983023850813`*^9, 3.519098325358121*^9}, 3.51910640525344*^9, {
   3.5201112853010073`*^9, 3.520111288893117*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520130041914977*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520130141914358*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520130244040538*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520130244042583*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"16", " ", "Dd", " ", "\[Pi]", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y1", "2"], "+", 
           SuperscriptBox["y2", "2"], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", 
         SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
              SuperscriptBox["z3", "2"]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"vr", " ", 
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}], " ", 
               SuperscriptBox["z0", "2"]}], "-", 
              RowBox[{"vz", " ", 
               SuperscriptBox["z0", "2"], " ", "z3"}], "+", 
              RowBox[{"2", " ", "Dd", " ", "q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z3", "2"], "+", 
                 SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}], " ", 
            "\[Tau]"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
       RowBox[{"4", " ", "Dd", " ", 
        SuperscriptBox["w0", "2"], " ", 
        SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z3", "-", 
            RowBox[{"vz", " ", "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z3", "-", 
            RowBox[{"vz", " ", "\[Tau]"}], "+", 
            RowBox[{
            "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
             "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], " ", "z0", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"z3", " ", "\[Kappa]"}], "]"}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"z4", " ", "\[Kappa]"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{
      RowBox[{"x3", "-", "x4"}], ",", 
      RowBox[{"y3", "-", "y4"}], ",", 
      RowBox[{"z3", "-", "z4"}]}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"16", " ", "Dd", " ", "\[Pi]", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "Dd", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y1", "2"], "+", 
           SuperscriptBox["y2", "2"], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", 
         SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
              SuperscriptBox["z3", "2"]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"vr", " ", 
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}], " ", 
               SuperscriptBox["z0", "2"]}], "-", 
              RowBox[{"vz", " ", 
               SuperscriptBox["z0", "2"], " ", "z3"}], "+", 
              RowBox[{"2", " ", "Dd", " ", "q", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["z3", "2"], "+", 
                 SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}], " ", 
            "\[Tau]"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
       RowBox[{"4", " ", "Dd", " ", 
        SuperscriptBox["w0", "2"], " ", 
        SuperscriptBox["z0", "2"], " ", "\[Tau]"}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z3", "-", 
            RowBox[{"vz", " ", "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z3", "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"vz", "+", 
               RowBox[{
               "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
              ")"}], " ", "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], " ", "z0", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"z3", " ", "\[Kappa]"}], "]"}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"z4", " ", "\[Kappa]"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{
      RowBox[{"x3", "-", "x4"}], ",", 
      RowBox[{"y3", "-", "y4"}], ",", 
      RowBox[{"z3", "-", "z4"}]}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.519034433203273*^9, 3.519038429519927*^9, 
  3.5191775375577745`*^9, 3.519342208128199*^9, 3.519574793765869*^9, 
  3.5201304838318453`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3z3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint3z2", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z3", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5190339486915207`*^9, 3.519033955581791*^9}, {
   3.519098332375977*^9, 3.5190983434822407`*^9}, 3.519106409605201*^9, {
   3.5201112922100153`*^9, 3.520111295648159*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"16", " ", "Dd", " ", "\[Pi]", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"16", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["z4", "2"], " ", "\[Tau]"}], 
        RowBox[{
         SuperscriptBox["z0", "4"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"vr", " ", 
              RowBox[{"(", 
               RowBox[{"y1", "-", "y3"}], ")"}]}], "+", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
              "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
                RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}],
            " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
      
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["z4", "2"]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"vr", " ", 
                 RowBox[{"(", 
                  RowBox[{"y1", "-", "y3"}], ")"}]}], "-", 
                RowBox[{"vz", " ", "z4"}]}], ")"}], " ", "\[Tau]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["vr", "2"], "+", 
                SuperscriptBox["vz", "2"]}], ")"}], " ", 
              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["w0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", "z0", " ", 
    SuperscriptBox[
     RowBox[{"Cos", "[", 
      RowBox[{"z4", " ", "\[Kappa]"}], "]"}], "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"16", " ", "Dd", " ", "\[Pi]", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"16", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["z4", "2"], " ", "\[Tau]"}], 
        RowBox[{
         SuperscriptBox["z0", "4"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"vr", " ", 
              RowBox[{"(", 
               RowBox[{"y1", "-", "y3"}], ")"}]}], "-", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "z4", " ", 
              "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}],
            " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
      
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["z4", "2"]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"vr", " ", 
                 RowBox[{"(", 
                  RowBox[{"y1", "-", "y3"}], ")"}]}], "-", 
                RowBox[{"vz", " ", "z4"}]}], ")"}], " ", "\[Tau]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["vr", "2"], "+", 
                SuperscriptBox["vz", "2"]}], ")"}], " ", 
              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["w0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", "z0", " ", 
    SuperscriptBox[
     RowBox[{"Cos", "[", 
      RowBox[{"z4", " ", "\[Kappa]"}], "]"}], "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", "Dd", " ", "\[Pi]", " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"16", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["z4", "2"], " ", "\[Tau]"}], 
        RowBox[{
         SuperscriptBox["z0", "4"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3", "+", 
             RowBox[{"vr", " ", "\[Tau]"}]}], ")"}], "2"]}], ")"}]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
      
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y1", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["z4", "2"]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"vr", " ", 
                 RowBox[{"(", 
                  RowBox[{"y1", "-", "y3"}], ")"}]}], "-", 
                RowBox[{"vz", " ", "z4"}]}], ")"}], " ", "\[Tau]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["vr", "2"], "+", 
                SuperscriptBox["vz", "2"]}], ")"}], " ", 
              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["w0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", "z0", " ", 
    SuperscriptBox[
     RowBox[{"Cos", "[", 
      RowBox[{"z4", " ", "\[Kappa]"}], "]"}], "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.5190344443641987`*^9, 3.519038440539783*^9, 
  3.5191776165098886`*^9, 3.5193422908302655`*^9, 3.5195748578768854`*^9, 
  3.5201306018764257`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3z4", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint3z3", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z4", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519033967134328*^9, 3.5190339952633266`*^9}, {
   3.519098356077713*^9, 3.519098365622486*^9}, 3.5191516171725597`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520133283304502*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520133983505598*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520134683634131*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520134683636375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"128", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"16", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            SuperscriptBox["y1", "2"], "+", 
            SuperscriptBox["y2", "2"], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
            RowBox[{"2", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               RowBox[{"16", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
               RowBox[{"2", " ", "vr", " ", 
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  SuperscriptBox["vz", "2"]}], ")"}], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}], 
          ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
            RowBox[{
            "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
            "+", 
            RowBox[{
            "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
           ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"128", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
            RowBox[{"2", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               RowBox[{"8", " ", "Dd", " ", "\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
                  RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], 
              ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
            "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
               RowBox[{"2", " ", "vr", " ", 
                RowBox[{"(", 
                 RowBox[{"y1", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  SuperscriptBox["vz", "2"]}], ")"}], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"q", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"vz", "+", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}],
            ")"}], "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
             RowBox[{
             "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "z0", " ", 
              "\[Tau]"}]}], ")"}], "2"], 
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", "z0", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}], "2"], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]}]]}], ")"}], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"64", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", "vr", " ", 
         RowBox[{"(", 
          RowBox[{"y1", "-", "y3"}], ")"}]}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["vz", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"12", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], "\[Tau]"], "+", 
        FractionBox[
         RowBox[{"2", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["q", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["x1", "2"], "+", 
                SuperscriptBox["x2", "2"], "+", 
                SuperscriptBox["x3", "2"], "+", 
                SuperscriptBox["x4", "2"], "+", 
                SuperscriptBox["y1", "2"], "+", 
                SuperscriptBox["y2", "2"], "+", 
                SuperscriptBox["y3", "2"], "+", 
                SuperscriptBox["y4", "2"]}], ")"}]}], 
             SuperscriptBox["w0", "2"]], "+", 
            FractionBox[
             RowBox[{
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}],
          "q"]}], 
       RowBox[{"4", " ", "Dd"}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
            "+", 
            RowBox[{
            "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
           ")"}], "2"]}], 
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
            "+", 
            RowBox[{
            "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
           ")"}], "2"]}], 
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "6"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], "+", 
          RowBox[{"16", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["q", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "-", 
             RowBox[{"32", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], 
         RowBox[{"2", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y1", "-", "y2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.519034572410688*^9, 3.519038571693144*^9, 
  3.5191789334774065`*^9, 3.519344616013889*^9, 3.519579354739339*^9, 
  3.520139316572186*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y Integration", "Subsection",
 CellChangeTimes->{{3.5177120430240726`*^9, 3.51771204546321*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3y1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y2_", ",", "y3_", ",", 
    "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint3z4", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y1", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5177423766146393`*^9, 3.517742388617363*^9}, {
   3.5190340024348707`*^9, 3.5190340073241253`*^9}, {3.519098376070786*^9, 
   3.519098381767736*^9}, 3.519106425308443*^9, {3.520111304352625*^9, 
   3.5201113074955587`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520139473022147*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520139573049471*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520139697556134*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520139697558234*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"128", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        FractionBox[
         RowBox[{"16", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["y2", "2"]}], "+", 
            SuperscriptBox["y3", "2"], "+", 
            SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y2", "-", "y3"}], ")"}], "2"], "+", 
            RowBox[{"2", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y2", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               RowBox[{"16", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["y2", "2"]}], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"y2", "-", "y3"}], ")"}], "2"], "+", 
               RowBox[{"2", " ", "vr", " ", 
                RowBox[{"(", 
                 RowBox[{"y2", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  SuperscriptBox["vz", "2"]}], ")"}], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}], 
          ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
            RowBox[{
            "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
            "+", 
            RowBox[{
            "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
           ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"128", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["y2", "2"]}], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y2", "-", "y3"}], ")"}], "2"], "+", 
          RowBox[{"2", " ", "vr", " ", 
           RowBox[{"(", 
            RowBox[{"y2", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "5"}], " ", "Dd", " ", 
           SuperscriptBox["z0", "6"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], "+", 
          RowBox[{"q", " ", 
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "-", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "-", 
             RowBox[{"48", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}], 
          "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["vz", "2"]}], "-", 
             RowBox[{"32", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], 
         RowBox[{"Dd", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
       ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "z0", " ", 
            "\[Tau]"}]}], ")"}], "2"], 
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}], 
          ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
           "+", 
           RowBox[{
           "32", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
          ")"}]}], 
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", "z0", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}], "2"], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"64", " ", "Dd", " ", 
     SqrtBox["\[Pi]"], " ", "\[Tau]", " ", 
     SqrtBox[
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"16", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["y2", "2"]}], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]]}], "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"y2", "-", "y3"}], ")"}], "2"], "+", 
            RowBox[{"2", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y2", "-", "y3"}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", "Dd", " ", 
           SuperscriptBox["z0", "6"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], "+", 
          RowBox[{"4", " ", "q", " ", 
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "-", 
             RowBox[{"32", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}], 
          "+", 
          RowBox[{"32", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", 
           SuperscriptBox["vz", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], 
         RowBox[{"Dd", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
       ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "6"], "+", 
            RowBox[{"16", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["z0", "4"], " ", "\[Tau]"}]}], ")"}]}], 
         RowBox[{"2", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "4"], " ", "\[Kappa]"}], "+", 
           RowBox[{"4", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
            "\[Tau]"}], "+", 
           RowBox[{"32", " ", "\[ImaginaryI]", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"vz", "+", 
              RowBox[{
              "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
             ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "4"], " ", "\[Kappa]"}], "+", 
           RowBox[{"4", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
            "\[Tau]"}], "-", 
           RowBox[{"32", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
              RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], " ", 
    SuperscriptBox["z0", "2"], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x1", "-", "x2"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"x3", "-", "x4"}], "]"}], " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"y3", "-", "y4"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.519034598476746*^9, 3.519038597894857*^9, 
  3.5191790127888913`*^9, 3.5193446773469095`*^9, 3.5195793864264336`*^9, 
  3.5201406878946877`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3y2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y3_", ",", "y4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint3y1", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y2", ",", "y3", ",", "y4",
         ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y2", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519034020987343*^9, 3.519034026483489*^9}, {
   3.519098387509461*^9, 3.519098393007359*^9}, 3.519106430115981*^9, {
   3.520111309624062*^9, 3.5201113127596407`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520141113692266*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520141282327498*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520141382444563*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520141382446617*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "\[Tau]"], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["vz", "2"], " ", 
           SuperscriptBox["z0", "2"], " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
         RowBox[{"\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"], "-", 
            FractionBox[
             RowBox[{"16", " ", "Dd", " ", "q", " ", "vr", " ", "y3"}], 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}],
          "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], 
             SuperscriptBox["w0", "2"]], "+", 
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["y3", "2"]}], 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
           ")"}]}]}], 
        RowBox[{"4", " ", "Dd"}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
             "+", 
             RowBox[{
             "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
            ")"}]}], 
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]]}]}], ")"}], " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"y3", "-", "y4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"64", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "4"]}], "+", 
            RowBox[{"16", " ", "Dd", " ", "q", " ", "vr", " ", 
             SuperscriptBox["w0", "2"], " ", "y3"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["vz", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "-", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["q", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], "+", 
                  SuperscriptBox["x2", "2"], "+", 
                  SuperscriptBox["x3", "2"], "+", 
                  SuperscriptBox["x4", "2"], "+", 
                  SuperscriptBox["y3", "2"], "+", 
                  SuperscriptBox["y4", "2"]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z0", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], 
           RowBox[{"q", " ", 
            SuperscriptBox["w0", "2"]}]]}], "+", 
         FractionBox[
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "\[Tau]"], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{"vz", "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], " ", "Dd", " ", 
              "\[Kappa]"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"vz", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "Dd", " ", 
              "\[Kappa]"}]}], ")"}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"vr", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "y3"}]}], ")"}], "2"], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"vz", "+", 
              RowBox[{
              "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
             ")"}], "2"]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "z0", " ", 
             "\[Tau]"}]}], ")"}], "2"], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
            "+", 
            RowBox[{
            "32", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
           ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
             RowBox[{"q", " ", "z0", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
              "\[Tau]"}]}], ")"}], "2"], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]]}]}], ")"}], " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"y3", "-", "y4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"64", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox["1", "32"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "2"]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q"}]], "+", 
         FractionBox[
          RowBox[{"16", " ", "vr", " ", "y3"}], "Dd"], "-", 
         FractionBox[
          RowBox[{"32", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["vz", "2"], " ", 
           SuperscriptBox["z0", "2"]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
         FractionBox[
          RowBox[{"8", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], 
          RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
         FractionBox[
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
         
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{"24", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"vr", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "y3"}]}], ")"}], "2"], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "+", 
         FractionBox[
          RowBox[{"32", " ", 
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        ")"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "6"], "+", 
             RowBox[{"16", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z0", "4"], " ", "\[Tau]"}]}], ")"}]}], 
          RowBox[{"2", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}],
        "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", "\[Kappa]"}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "+", 
            RowBox[{"32", " ", "\[ImaginaryI]", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"vz", "+", 
               RowBox[{
               "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
              ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", "\[Kappa]"}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "-", 
            RowBox[{"32", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"y3", "-", "y4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"32", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.519034742544281*^9, 3.5190387404601707`*^9, 
  3.519180360271643*^9, 3.519345865588689*^9, 3.5195796274389734`*^9, 
  3.5201419854271727`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3y3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint3y2", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y3", ",", "y4", ",", 
        "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y3", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519034038308049*^9, 3.519034041314868*^9}, {
   3.5190983994723177`*^9, 3.519098405833907*^9}, 3.519106435203676*^9, {
   3.520111316975258*^9, 3.5201113200220327`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.52014223169792*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520142337042522*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"]}], "-", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]], "-", 
       RowBox[{"q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           SuperscriptBox["vz", "2"], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["vr", "2"]}], 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}], 
       "-", 
       FractionBox[
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", "Dd", " ", "q", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["y4", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              RowBox[{"4", " ", "y4", " ", 
               RowBox[{"(", 
                RowBox[{"y4", "-", 
                 RowBox[{"vr", " ", "\[Tau]"}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}], 
        RowBox[{
         SuperscriptBox["w0", "4"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]"}]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
             "+", 
             RowBox[{
             "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
            ")"}]}], 
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]]}]}], ")"}], " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"64", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "4"]}], "+", 
            RowBox[{"16", " ", "Dd", " ", "q", " ", "vr", " ", 
             SuperscriptBox["w0", "2"], " ", "y4"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["vz", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"]}], "-", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["q", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x1", "2"], "+", 
                  SuperscriptBox["x2", "2"], "+", 
                  SuperscriptBox["x3", "2"], "+", 
                  SuperscriptBox["x4", "2"], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["y4", "2"]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z0", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], 
           RowBox[{"q", " ", 
            SuperscriptBox["w0", "2"]}]]}], "+", 
         FractionBox[
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], "\[Tau]"], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{"vz", "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], " ", "Dd", " ", 
              "\[Kappa]"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"vz", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "Dd", " ", 
              "\[Kappa]"}]}], ")"}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"vr", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "y4"}]}], ")"}], "2"], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"vz", "+", 
              RowBox[{
              "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
             ")"}], "2"]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "z0", " ", 
             "\[Tau]"}]}], ")"}], "2"], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
            "+", 
            RowBox[{
            "32", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
           ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
             RowBox[{"q", " ", "z0", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
              "\[Tau]"}]}], ")"}], "2"], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]]}]}], ")"}], " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"64", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox["1", "32"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "2"]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q"}]], "+", 
         FractionBox[
          RowBox[{"16", " ", "vr", " ", "y4"}], "Dd"], "-", 
         FractionBox[
          RowBox[{"32", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["y4", "2"]}]}], ")"}]}], 
          SuperscriptBox["w0", "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["vz", "2"], " ", 
           SuperscriptBox["z0", "2"]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
         FractionBox[
          RowBox[{"8", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x1", "-", "x3"}], ")"}], "2"]}], 
          RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
         FractionBox[
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
         
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{"24", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"vr", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "y4"}]}], ")"}], "2"], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "+", 
         FractionBox[
          RowBox[{"32", " ", 
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        ")"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"16", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          RowBox[{"2", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}],
        "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", "\[Kappa]"}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "+", 
            RowBox[{"32", " ", "\[ImaginaryI]", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"vz", "+", 
               RowBox[{
               "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
              ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", "\[Kappa]"}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "-", 
            RowBox[{"32", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], " ", "w0", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"32", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.5190347632949467`*^9, 3.519038760817746*^9, 
  3.5191804408018627`*^9, 3.519345928792218*^9, 3.5195796593916893`*^9, 
  3.520142361760808*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3y4", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}],
   "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint3y3", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y4", ",", "\[Tau]"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y4", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.51903405712321*^9, 3.5190340608902617`*^9}, {
   3.519098409162881*^9, 3.519098413974984*^9}, 3.519151625291333*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.52014344997822*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520144150002533*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201449867440357`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201449867461357`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "\[Tau]"], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"4", " ", "Dd", " ", 
              SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["vz", "2"], " ", "\[Tau]"}], 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
           ")"}]}]}], 
        RowBox[{"4", " ", "Dd"}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
             "+", 
             RowBox[{
             "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
            ")"}]}], 
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]]}]}], ")"}], " ", 
     SqrtBox["\[Pi]"], " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"128", " ", "q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{"32", " ", 
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]], "+", 
         FractionBox[
          RowBox[{"8", " ", "Dd", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["vr", "2"], "+", 
                SuperscriptBox["vz", "2"]}], ")"}], " ", 
              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "\[Tau]"], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["vr", "2"], " ", 
            SuperscriptBox["w0", "2"]}], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["vz", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"32", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "4"]}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
           FractionBox[
            RowBox[{"4", " ", 
             SuperscriptBox["z0", "4"], " ", 
             RowBox[{"(", 
              RowBox[{"vz", "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], " ", "Dd", " ", 
                "\[Kappa]"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"vz", "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "Dd", " ", 
                "\[Kappa]"}]}], ")"}]}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"vz", "+", 
                RowBox[{
                "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
               ")"}], "2"]}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"]}], 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "z0", " ", 
             "\[Tau]"}]}], ")"}], "2"], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
            "+", 
            RowBox[{
            "32", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
           ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
             RowBox[{"q", " ", "z0", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
              "\[Tau]"}]}], ")"}], "2"], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]]}]}], ")"}], " ", 
     SqrtBox["\[Pi]"], " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"128", " ", "q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "q", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"]}], ")"}]}], 
           SuperscriptBox["w0", "2"]]}], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], 
          RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
         
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"16", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "+", 
         FractionBox[
          RowBox[{"\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["vz", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["w0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             "+", 
             RowBox[{
              SuperscriptBox["vr", "2"], " ", 
              SuperscriptBox["w0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]}], ")"}]}], 
          RowBox[{"Dd", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        ")"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"16", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          RowBox[{"2", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}],
        "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", "\[Kappa]"}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "+", 
            RowBox[{"32", " ", "\[ImaginaryI]", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"vz", "+", 
               RowBox[{
               "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
              ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", "\[Kappa]"}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "-", 
            RowBox[{"32", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], " ", 
     SqrtBox["\[Pi]"], " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x1", "-", "x2"}], "]"}], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"64", " ", "q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.519034797620986*^9, 3.5190387948009567`*^9, 
  3.519181589334036*^9, 3.5193468888289456`*^9, 3.519579754187351*^9, 
  3.520150759732924*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x Integration", "Subsection",
 CellChangeTimes->{{3.517712055584053*^9, 3.517712057343378*^9}, 
   3.517742163353998*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3x1", "[", 
   RowBox[{"x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint3y4", "[", 
       RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x1", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517742489376445*^9, 3.5177425003032503`*^9}, {
   3.519034081234128*^9, 3.519034083345433*^9}, {3.519098417910344*^9, 
   3.519098424273952*^9}, 3.519106443235126*^9, {3.52011132754978*^9, 
   3.520111330766102*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520150905619165*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520151005645945*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520151107234661*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201511072368383`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["x2", "2"]}], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x2", "-", "x3"}], ")"}], "2"], "\[Tau]"], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"4", " ", "Dd", " ", 
              SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["vz", "2"], " ", "\[Tau]"}], 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
           ")"}]}]}], 
        RowBox[{"4", " ", "Dd"}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
             "+", 
             RowBox[{
             "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
            ")"}]}], 
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]]}]}], ")"}], " ", 
     SqrtBox["\[Pi]"], " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"128", " ", "q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{"32", " ", 
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["x2", "2"]}], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]], "+", 
         FractionBox[
          RowBox[{"8", " ", "Dd", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x2", "-", "x3"}], ")"}], "2"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["vr", "2"], "+", 
                SuperscriptBox["vz", "2"]}], ")"}], " ", 
              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "\[Tau]"], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["vr", "2"], " ", 
            SuperscriptBox["w0", "2"]}], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["vz", "2"], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"32", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "4"]}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
           FractionBox[
            RowBox[{"4", " ", 
             SuperscriptBox["z0", "4"], " ", 
             RowBox[{"(", 
              RowBox[{"vz", "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], " ", "Dd", " ", 
                "\[Kappa]"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"vz", "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "Dd", " ", 
                "\[Kappa]"}]}], ")"}]}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"vz", "+", 
                RowBox[{
                "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
               ")"}], "2"]}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"]}], 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "z0", " ", 
             "\[Tau]"}]}], ")"}], "2"], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
            "+", 
            RowBox[{
            "32", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
           ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
             RowBox[{"q", " ", "z0", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
              "\[Tau]"}]}], ")"}], "2"], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]]}]}], ")"}], " ", 
     SqrtBox["\[Pi]"], " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"128", " ", "q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "q", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["x2", "2"]}], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"]}], ")"}]}], 
           SuperscriptBox["w0", "2"]]}], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x2", "-", "x3"}], ")"}], "2"], 
          RowBox[{"Dd", " ", "\[Tau]"}]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
         
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"16", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "+", 
         FractionBox[
          RowBox[{"\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["vz", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["w0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
             "+", 
             RowBox[{
              SuperscriptBox["vr", "2"], " ", 
              SuperscriptBox["w0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
               ")"}]}]}], ")"}]}], 
          RowBox[{"Dd", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        ")"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"16", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          RowBox[{"2", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}],
        "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", "\[Kappa]"}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "+", 
            RowBox[{"32", " ", "\[ImaginaryI]", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"vz", "+", 
               RowBox[{
               "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
              ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", "\[Kappa]"}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "-", 
            RowBox[{"32", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], " ", 
     SqrtBox["\[Pi]"], " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"64", " ", "q", " ", 
     SqrtBox[
      RowBox[{"Dd", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.519034809466577*^9, 3.5190388065811234`*^9, 
  3.5191816645830727`*^9, 3.519346948375058*^9, 3.5195797791870313`*^9, 
  3.520152061138606*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3x2", "[", 
   RowBox[{"x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint3x1", "[", 
       RowBox[{"x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519034093521607*^9, 3.519034098176869*^9}, {
   3.51909842740593*^9, 3.519098433517777*^9}, 3.519106446617979*^9, {
   3.520111333838244*^9, 3.5201113368618183`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520152409214937*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201525092960978`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.52015264498593*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201526449880733`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"]}], ")"}]}], 
         SuperscriptBox["w0", "2"]]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
       FractionBox[
        RowBox[{"2", " ", "q", " ", 
         SuperscriptBox["x3", "2"]}], 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "-", 
       FractionBox[
        RowBox[{"q", " ", 
         SuperscriptBox["\[Tau]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["vz", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["vr", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]}], 
          ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "-", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
             "+", 
             RowBox[{
             "8", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
            ")"}]}], 
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]]}]}], ")"}], " ", "\[Pi]", " ", 
     SuperscriptBox["w0", "3"], " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"64", " ", "q", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox["1", "32"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "2"]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
         FractionBox[
          RowBox[{"32", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"]}], ")"}]}], 
          SuperscriptBox["w0", "2"]], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["vz", "2"], " ", 
           SuperscriptBox["z0", "2"]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q"}]], "-", 
         FractionBox[
          RowBox[{"32", " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], "q"], "-", 
         FractionBox[
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
         
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["w0", "4"]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "-", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{"vz", "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], " ", "Dd", " ", 
              "\[Kappa]"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"vz", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "Dd", " ", 
              "\[Kappa]"}]}], ")"}]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
         "-", 
         FractionBox[
          RowBox[{"64", " ", "q", " ", 
           SuperscriptBox["x3", "2"]}], 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"vz", "+", 
              RowBox[{
              "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
             ")"}], "2"]}], 
          RowBox[{
           SuperscriptBox["Dd", "2"], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
        ")"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "z0", " ", 
             "\[Tau]"}]}], ")"}], "2"], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}], 
            "+", 
            RowBox[{
            "32", " ", "Dd", " ", "q", " ", "\[Kappa]", " ", "\[Tau]"}]}], 
           ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0", "3"], " ", "\[Kappa]"}], "+", 
             RowBox[{"q", " ", "z0", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
              "\[Tau]"}]}], ")"}], "2"], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]]}]}], ")"}], " ", "\[Pi]", " ", 
     SuperscriptBox["w0", "3"], " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"64", " ", "q", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", "cm", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "6"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{"2", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
       "-", 
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"]}], 
           SuperscriptBox["w0", "2"]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["x3", "2"]}], 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}], 
       "-", 
       RowBox[{"\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"q", " ", 
            SuperscriptBox["vr", "2"], " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"q", " ", 
             SuperscriptBox["vz", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"8", " ", "Dd", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["z0", "4"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["q", "2"], " ", 
                SuperscriptBox["vz", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}],
          ")"}]}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"16", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          RowBox[{"2", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}],
        "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", "\[Kappa]"}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "+", 
            RowBox[{"32", " ", "\[ImaginaryI]", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"vz", "+", 
               RowBox[{
               "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
              ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", "\[Kappa]"}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "-", 
            RowBox[{"32", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      ")"}], " ", "\[Pi]", " ", 
     SuperscriptBox["w0", "3"], " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"DiracDelta", "[", 
      RowBox[{"x3", "-", "x4"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"32", " ", "q", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.519034884768752*^9, 3.519038881604968*^9, 
  3.519182133780192*^9, 3.5193475926168118`*^9, 3.5195799447161627`*^9, 
  3.520153188514104*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3x3", "[", 
   RowBox[{"x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint3x2", "[", 
       RowBox[{"x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x3", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519034112065001*^9, 3.519034114584416*^9}, {
   3.519098438220603*^9, 3.5190984438168097`*^9}, 3.5191064503947*^9, {
   3.5201113402705603`*^9, 3.52011134319939*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201533778319693`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.52015349498634*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201537255425053`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520153725544588*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["vr", "2"], " ", 
            SuperscriptBox["w0", "2"]}], 
           SuperscriptBox["Dd", "2"]], "-", 
          FractionBox[
           RowBox[{"32", " ", 
            SuperscriptBox["q", "2"], " ", 
            SuperscriptBox["x4", "2"]}], 
           SuperscriptBox["w0", "2"]], "-", 
          FractionBox[
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "Dd"], "-", 
          RowBox[{"16", " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}]}], "q"], "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "4"]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        "-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vz", "2"], "+", 
            RowBox[{"\[ImaginaryI]", " ", "Dd", " ", "vz", " ", "\[Kappa]"}], 
            "+", 
            RowBox[{"5", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        "-", 
        FractionBox[
         RowBox[{"32", " ", "q", " ", 
          SuperscriptBox["x4", "2"]}], 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vz", "2"], "+", 
            RowBox[{
            "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
             "\[Kappa]"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"Dd", " ", "q", " ", 
          SuperscriptBox["vz", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], 
        RowBox[{"4", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"5", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"vz", "+", 
             RowBox[{
             "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], ")"}],
            " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vz", "2"], "+", 
            RowBox[{
            "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
             "\[Kappa]"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"Dd", " ", "q", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"vz", "+", 
            RowBox[{
            "16", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], ")"}],
           " ", "\[Tau]"}]}], 
        RowBox[{"4", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "12", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"9", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"16", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", "\[Pi]", " ", 
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "2"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", "q", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.519034901534759*^9, 3.519038898325004*^9, 
  3.5191822613254347`*^9, 3.519347758552188*^9, 3.5195799737470407`*^9, 
  3.520156703562065*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint3x4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint3x3", "[", 
       RowBox[{"x4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x4", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5190341277843647`*^9, 3.519034131727693*^9}, {
   3.5190984483583717`*^9, 3.519098452627317*^9}, 3.519106457847348*^9, {
   3.520111347428646*^9, 3.5201113509728823`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520156841323547*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201569414804363`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520157041521669*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520157041523756*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "Dd", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vr", "2"], "+", 
           SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox["z0", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vz", "2"], "+", 
               RowBox[{
               "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
                "\[Kappa]"}], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["Dd", "2"]}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vz", "2"], "+", 
            RowBox[{
            "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
             "\[Kappa]"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"Dd", " ", "q", " ", 
          SuperscriptBox["vz", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], 
        RowBox[{"4", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"5", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"vz", "+", 
             RowBox[{
             "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], ")"}],
            " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vz", "2"], "+", 
            RowBox[{
            "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
             "\[Kappa]"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"Dd", " ", "q", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"vz", "+", 
            RowBox[{
            "16", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], ")"}],
           " ", "\[Tau]"}]}], 
        RowBox[{"4", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"9", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"16", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["vz", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
            RowBox[{
            "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", "\[Kappa]", 
             " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]}],
            ")"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["w0", "4"], " ", 
    SuperscriptBox["z0", "2"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"128", " ", "q", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.519034908417387*^9, 3.519038905147339*^9, 
  3.5191824780882845`*^9, 3.5193479571277714`*^9, 3.519580031449427*^9, 
  3.5201571590561523`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g3", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"myint3x4", "[", "\[Tau]", "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5190341398753767`*^9, 3.519034142346333*^9}, 
   3.5191516318739777`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520157861815526*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520158561970585*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201597653419724`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201597653442583`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "Dd", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vr", "2"], "+", 
           SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox["z0", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vz", "2"], "+", 
               RowBox[{
               "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
                "\[Kappa]"}], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["Dd", "2"]}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vz", "2"], "+", 
            RowBox[{
            "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
             "\[Kappa]"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"Dd", " ", "q", " ", 
          SuperscriptBox["vz", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], 
        RowBox[{"4", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"5", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"vz", "+", 
             RowBox[{
             "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], ")"}],
            " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vz", "2"], "+", 
            RowBox[{
            "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
             "\[Kappa]"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"Dd", " ", "q", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"vz", "+", 
            RowBox[{
            "16", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], ")"}],
           " ", "\[Tau]"}]}], 
        RowBox[{"4", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"9", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"16", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["vz", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
            RowBox[{
            "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", "\[Kappa]", 
             " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]}],
            ")"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["w0", "4"], " ", 
    SuperscriptBox["z0", "2"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"128", " ", "q", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.519034909620016*^9, 3.5190389062379847`*^9, 
  3.5191920538719635`*^9, 3.5193480397204638`*^9, 3.519580313367694*^9, 
  3.520163360580267*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute g4", "Section",
 CellChangeTimes->{{3.517712244605625*^9, 3.517712246731595*^9}, {
   3.517743037922456*^9, 3.517743042681806*^9}, {3.5180897812388887`*^9, 
   3.518089781618937*^9}, 3.518089821275112*^9}],

Cell[CellGroupData[{

Cell["g4", "Subsection",
 CellChangeTimes->{{3.517731269318281*^9, 3.517731271899744*^9}, {
   3.517731408856715*^9, 3.51773141008643*^9}, 3.5177455798684883`*^9}],

Cell[CellGroupData[{

Cell["z Integration", "Subsubsection",
 CellChangeTimes->{{3.5177312790362263`*^9, 3.5177312806279383`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4z1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z2_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"g4int", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z1", ",", "z2", ",", "z3", ",", "z4", ",", 
        "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z1", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517731395958997*^9, 3.517731418541161*^9}, {
   3.5177314672089443`*^9, 3.517731529832615*^9}, {3.517745612824994*^9, 
   3.517745628014365*^9}, 3.517745661450716*^9, {3.5190984728116407`*^9, 
   3.519098479675494*^9}, 3.519106467677431*^9, {3.5196244589788847`*^9, 
   3.5196244797704163`*^9}, 3.520111357242804*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201636266830177`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520163726710124*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520163859873727*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201638598759947`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["x1", "2"], "+", 
                SuperscriptBox["x2", "2"], "+", 
                SuperscriptBox["x3", "2"], "+", 
                SuperscriptBox["x4", "2"], "+", 
                SuperscriptBox["y1", "2"], "+", 
                SuperscriptBox["y2", "2"], "+", 
                SuperscriptBox["y3", "2"], "+", 
                SuperscriptBox["y4", "2"]}], ")"}], " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["w0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["z2", "2"], "+", 
                SuperscriptBox["z3", "2"], "+", 
                SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}]}], 
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["z0", "2"]}]]}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x2", "-", "x4"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y2", "-", "y4"}], ")"}], "2"], "+", 
          SuperscriptBox["z3", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z2", "-", "z4"}], ")"}], "2"], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"vr", " ", 
              RowBox[{"(", 
               RowBox[{"y1", "+", "y2", "-", "y3", "-", "y4"}], ")"}]}], "+", 
             
             RowBox[{"vz", " ", 
              RowBox[{"(", 
               RowBox[{"z2", "-", "z3", "-", "z4"}], ")"}]}], "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", "Dd", " ", 
              RowBox[{"(", 
               RowBox[{"z2", "+", "z3", "+", "z4"}], ")"}], " ", 
              "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], 
         RowBox[{"Dd", " ", "\[Tau]"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], 
     ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], 
     ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
     ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z3", "-", 
            RowBox[{"vz", " ", "\[Tau]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
             "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z3", "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"vz", "+", 
               RowBox[{
               "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
              ")"}], " ", "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], " ", "z0"}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"256", " ", 
    SuperscriptBox["Dd", "2"], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.51773192794835*^9, 3.517746061079915*^9, 
  3.517902492769512*^9, 3.5190390182022953`*^9, 3.5191922947751293`*^9, 
  3.51934865838442*^9, 3.519580503380886*^9, 3.519625936574253*^9, 
  3.520163878419405*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4z2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z3_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint4z1", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z2", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"z2", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5177319528253193`*^9, 3.5177320022583637`*^9}, {
   3.517745661499382*^9, 3.517745661546136*^9}, {3.5190984855568666`*^9, 
   3.5190984923697567`*^9}, 3.519106469995677*^9, {3.519624463481591*^9, 
   3.519624477482271*^9}, 3.5201113593579082`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520164158221972*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520164258231077*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"128", " ", 
    SuperscriptBox["Dd", "2"], " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["y1", "2"], "+", 
               SuperscriptBox["y2", "2"], "+", 
               SuperscriptBox["y3", "2"], "+", 
               SuperscriptBox["y4", "2"]}], ")"}], " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z3", "2"], "+", 
               SuperscriptBox["z4", "2"]}], ")"}]}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "2"]}]]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x2", "-", "x4"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"y2", "-", "y4"}], ")"}], "2"], "+", 
         SuperscriptBox["z3", "2"], "+", 
         SuperscriptBox["z4", "2"], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"vr", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "y1"}], "-", "y2", "+", "y3", "+", "y4"}], 
              ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z3", "+", "z4"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"vz", "-", 
               RowBox[{
               "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
              ")"}]}]}], ")"}], " ", "\[Tau]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vr", "2"], "+", 
            SuperscriptBox["vz", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], 
        RowBox[{"Dd", " ", "\[Tau]"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z3", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z3", "-", 
           RowBox[{"vz", " ", "\[Tau]"}], "+", 
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
            "\[Tau]"}]}], ")"}], "2"]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z3", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"vz", "+", 
              RowBox[{
              "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
             ")"}], " ", "\[Tau]"}]}], ")"}], "2"]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z4", "-", 
           RowBox[{"vz", " ", "\[Tau]"}], "+", 
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
            "\[Tau]"}]}], ")"}], "2"]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z4", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"vz", "+", 
              RowBox[{
              "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
             ")"}], " ", "\[Tau]"}]}], ")"}], "2"]}], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
    ")"}], " ", 
   SuperscriptBox["z0", "2"]}]}]], "Output",
 CellChangeTimes->{3.517732449586495*^9, 3.51774649564223*^9, 
  3.517902924859393*^9, 3.519039182539217*^9, 3.519192459913641*^9, 
  3.5193494128122635`*^9, 3.5195807936584206`*^9, 3.519626255578827*^9, 
  3.5201644353726997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4z3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "z4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint4z2", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z3", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z3", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517732024322637*^9, 3.517732036074086*^9}, {
   3.517745661589201*^9, 3.5177456616480827`*^9}, {3.519098496002125*^9, 
   3.519098500493258*^9}, 3.519106474411126*^9, {3.519624466985558*^9, 
   3.519624475338299*^9}, 3.520111362485928*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520166229214121*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520166329806081*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201664357204638`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520166435722726*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", "vr", " ", 
         RowBox[{"(", 
          RowBox[{"y1", "+", "y2", "-", "y3", "-", "y4"}], ")"}]}], "-", 
        RowBox[{"2", " ", "vz", " ", "z4"}], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["vz", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x2", "-", "x4"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y2", "-", "y4"}], ")"}], "2"], "+", 
          SuperscriptBox["z4", "2"], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["vr", "2"], " ", 
           SuperscriptBox["\[Tau]", "2"]}]}], "\[Tau]"], "+", 
        RowBox[{"Dd", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "q", " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{
                SuperscriptBox["x1", "2"], "+", 
                SuperscriptBox["x2", "2"], "+", 
                SuperscriptBox["x3", "2"], "+", 
                SuperscriptBox["x4", "2"], "+", 
                SuperscriptBox["y1", "2"], "+", 
                SuperscriptBox["y2", "2"], "+", 
                SuperscriptBox["y3", "2"], "+", 
                SuperscriptBox["y4", "2"]}], 
               SuperscriptBox["w0", "2"]], "+", 
              FractionBox[
               SuperscriptBox["z4", "2"], 
               SuperscriptBox["z0", "2"]]}], ")"}]}], "+", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Kappa]", " ", 
            RowBox[{"(", 
             RowBox[{"z4", "+", 
              FractionBox[
               RowBox[{"vz", " ", 
                SuperscriptBox["z0", "2"], " ", "\[Tau]"}], 
               RowBox[{
                SuperscriptBox["z0", "2"], "+", 
                RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
             ")"}]}]}], ")"}]}]}], 
       RowBox[{"4", " ", "Dd"}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "z4", " ", "\[Kappa]"}]]}], 
     ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z4", "-", 
            RowBox[{"vz", " ", "\[Tau]"}], "+", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]", " ", 
             "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z4", "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"vz", "+", 
               RowBox[{
               "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
              ")"}], " ", "\[Tau]"}]}], ")"}], "2"]}], 
        RowBox[{"4", " ", "Dd", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
        ")"}]}]}], ")"}], " ", 
    SuperscriptBox["z0", "3"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"128", " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["Dd", "2"], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    SqrtBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517732491889298*^9, 3.517746538013124*^9, 
  3.517902966934539*^9, 3.5190392352172213`*^9, 3.5191948380238256`*^9, 
  3.5193499028372407`*^9, 3.5195810818422318`*^9, 3.5196267709487677`*^9, 
  3.520167028916978*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4z4", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y1_", ",", "y2_", ",", 
    "y3_", ",", "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint4z3", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "z4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z4", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5177320482456417`*^9, 3.517732062871601*^9}, {
   3.517745661695685*^9, 3.5177456617176867`*^9}, {3.5190985042301073`*^9, 
   3.5190985096868*^9}, 3.5191516385958643`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"256", " ", 
    SuperscriptBox["Dd", "2"], " ", "\[Pi]", " ", "q", " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
       FractionBox[
        RowBox[{"8", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x1", "2"], "+", 
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"], "+", 
           SuperscriptBox["y1", "2"], "+", 
           SuperscriptBox["y2", "2"], "+", 
           SuperscriptBox["y3", "2"], "+", 
           SuperscriptBox["y4", "2"]}], ")"}], " ", "\[Tau]"}], 
        SuperscriptBox["w0", "2"]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x2", "-", "x4"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"y2", "-", "y4"}], ")"}], "2"], "+", 
           RowBox[{"2", " ", "vr", " ", 
            RowBox[{"(", 
             RowBox[{"y1", "+", "y2", "-", "y3", "-", "y4"}], ")"}], " ", 
            "\[Tau]"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                 RowBox[{"Dd", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
        RowBox[{"Dd", " ", "\[Tau]"}]], "+", 
       FractionBox[
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"], "+", 
              SuperscriptBox["x4", "2"], "+", 
              SuperscriptBox["y1", "2"], "+", 
              SuperscriptBox["y2", "2"], "+", 
              SuperscriptBox["y3", "2"], "+", 
              SuperscriptBox["y4", "2"]}], ")"}], " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x2", "-", "x4"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"y1", "-", "y3"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"y2", "-", "y4"}], ")"}], "2"], "+", 
              RowBox[{"2", " ", "vr", " ", 
               RowBox[{"(", 
                RowBox[{"y1", "+", "y2", "-", "y3", "-", "y4"}], ")"}], " ", 
               "\[Tau]"}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["vr", "2"], "+", 
                 SuperscriptBox["vz", "2"]}], ")"}], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
        SuperscriptBox["w0", "2"]]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
   " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "cm", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      RowBox[{"cm", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
        ")"}]}]}], ")"}], "2"], " ", 
   SuperscriptBox["z0", "4"]}]}]], "Output",
 CellChangeTimes->{3.517732644952421*^9, 3.517746690653228*^9, 
  3.517903119432439*^9, 3.5190393293670397`*^9, 3.5191958417297277`*^9, 
  3.5193539021922984`*^9, 3.5195814854308157`*^9, 3.5196268446855707`*^9, 
  3.520168784957491*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y Integration", "Subsubsection",
 CellChangeTimes->{{3.517745761444187*^9, 3.517745763219038*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4y1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y2_", ",", "y3_", ",", 
    "y4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint4z4", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y1", ",", "y2", ",", "y3",
         ",", "y4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y1", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517732083276355*^9, 3.517732100511986*^9}, {
   3.51774566175308*^9, 3.5177456617711077`*^9}, {3.519098513235175*^9, 
   3.519098518565982*^9}, 3.519106479045557*^9, {3.519624484850193*^9, 
   3.5196244876324778`*^9}, 3.520111368821786*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"8", " ", "Dd", " ", "vr", " ", 
         RowBox[{"(", 
          RowBox[{"y2", "-", "y4"}], ")"}]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y2", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], 
            SuperscriptBox["w0", "2"]], "+", 
           FractionBox[
            SuperscriptBox["y3", "2"], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}], 
        "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
          FractionBox[
           RowBox[{"8", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "Dd", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"q", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                  RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], "2"], 
               " ", "\[Tau]"}]}], ")"}]}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x2", "-", "x4"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"y2", "-", "y4"}], ")"}], "2"]}], "\[Tau]"], "+", 
           RowBox[{"2", " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"], "-", 
              FractionBox[
               RowBox[{"4", " ", "Dd", " ", "q", " ", "vr", " ", "y3"}], 
               RowBox[{
                SuperscriptBox["w0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
             ")"}]}]}], ")"}]}]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["Dd", "2"]}]]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
       RowBox[{"cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
         ")"}]}]}], ")"}], "2"], " ", "w0", " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"128", " ", "Dd", " ", 
    SqrtBox["\[Pi]"], " ", "q", " ", "\[Tau]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5177327105182037`*^9, 3.517746755487863*^9, 
  3.517903184878088*^9, 3.519039433036276*^9, 3.519196065914358*^9, 
  3.519354178876257*^9, 3.519581609522978*^9, 3.519627017032164*^9, 
  3.520169067954344*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4y2", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y3_", ",", "y4_", ",", 
    "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint4y1", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y2", ",", "y3", ",", "y4",
         ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y2", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517732116104549*^9, 3.5177321275278187`*^9}, {
   3.517745661774592*^9, 3.517745661786536*^9}, {3.519098522335894*^9, 
   3.519098527857939*^9}, 3.519106482762341*^9, {3.519624490854048*^9, 
   3.519624494640335*^9}, 3.520111371333123*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"8", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], 
            SuperscriptBox["w0", "2"]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["y3", "2"], "+", 
             SuperscriptBox["y4", "2"]}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}], 
        "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
          FractionBox[
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "Dd", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"q", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                  RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], "2"], 
               " ", "\[Tau]"}]}], ")"}]}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"], "+", 
        RowBox[{"2", " ", "Dd", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["vr", "2"], " ", "\[Tau]"}], "-", 
           FractionBox[
            RowBox[{"8", " ", "Dd", " ", "q", " ", "vr", " ", 
             RowBox[{"(", 
              RowBox[{"y3", "+", "y4"}], ")"}], " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x2", "-", "x4"}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["vz", "2"], " ", 
              SuperscriptBox["\[Tau]", "2"]}]}], "\[Tau]"]}], ")"}]}]}], 
       RowBox[{"8", " ", 
        SuperscriptBox["Dd", "2"]}]]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
         ")"}]}]}], ")"}], "2"], " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517732774628825*^9, 3.517746819768244*^9, 
  3.517903247568513*^9, 3.519039573219249*^9, 3.519196237334039*^9, 
  3.51935479030593*^9, 3.519581813082872*^9, 3.519627186372816*^9, 
  3.5201692954913797`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4y3", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "y4_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint4y2", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y3", ",", "y4", ",", 
        "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y3", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517732145649612*^9, 3.5177321569352503`*^9}, {
   3.517745661789935*^9, 3.517745661802009*^9}, {3.519098531842122*^9, 
   3.519098537892537*^9}, 3.519106486762063*^9, {3.51962449920851*^9, 
   3.5196245023507977`*^9}, 3.5201113743409157`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520169552063555*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201696521106663`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"16", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"], "+", 
             SuperscriptBox["x4", "2"], "+", 
             SuperscriptBox["y4", "2"]}], 
            SuperscriptBox["w0", "2"]], "+", 
           FractionBox[
            SuperscriptBox["y4", "2"], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}], 
        "+", 
        RowBox[{"4", " ", "Dd", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x2", "-", "x4"}], ")"}], "2"]}], "\[Tau]"], "+", 
           RowBox[{"2", " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"], "-", 
              FractionBox[
               RowBox[{"4", " ", "Dd", " ", "q", " ", "vr", " ", "y4"}], 
               RowBox[{
                SuperscriptBox["w0", "2"], "+", 
                RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
             ")"}]}]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{"8", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "Dd", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"q", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                  RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], "2"], 
               " ", "\[Tau]"}]}], ")"}]}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
          RowBox[{
           SuperscriptBox["vr", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["w0", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                FractionBox["2", 
                 RowBox[{
                  SuperscriptBox["w0", "2"], "+", 
                  RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
                FractionBox["1", 
                 RowBox[{
                  SuperscriptBox["w0", "2"], "+", 
                  RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
               ")"}]}]}], ")"}]}]}], "q"]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["Dd", "2"]}]]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
       RowBox[{"cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
         ")"}]}]}], ")"}], "2"], " ", 
    SqrtBox[
     FractionBox["\[Pi]", "2"]], " ", 
    SuperscriptBox["w0", "3"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", "Dd", " ", "q", " ", "\[Tau]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5177328028201036`*^9, 3.5177468481594143`*^9, 
  3.517903275847896*^9, 3.5190396069517317`*^9, 3.5191964239722753`*^9, 
  3.5193550076625233`*^9, 3.519581875894568*^9, 3.519627265654787*^9, 
  3.520169695537903*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4y4", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}],
   "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint4y3", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "y4", ",", "\[Tau]"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y4", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517732166673613*^9, 3.5177321820067167`*^9}, {
   3.517745661805352*^9, 3.5177456618211*^9}, {3.519098541873455*^9, 
   3.519098548159334*^9}, 3.519151645090776*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"]}], ")"}]}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         RowBox[{"Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x1", "-", "x3"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"x2", "-", "x4"}], ")"}], "2"], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "\[Tau]"], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
          FractionBox[
           RowBox[{"2", " ", "Dd", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "Dd", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"q", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                  RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], "2"], 
               " ", "\[Tau]"}]}], ")"}]}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"]}], 
       RowBox[{"4", " ", 
        SuperscriptBox["Dd", "2"]}]]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
       RowBox[{"cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
         ")"}]}]}], ")"}], "2"], " ", "\[Pi]", " ", 
    SuperscriptBox["w0", "4"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"128", " ", "Dd", " ", 
    SuperscriptBox["q", "2"], " ", "\[Tau]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5177328272145023`*^9, 3.517746872491576*^9, 
  3.517903300490355*^9, 3.519039627145486*^9, 3.5191968470762343`*^9, 
  3.519357798720547*^9, 3.519581955752921*^9, 3.5196273173723087`*^9, 
  3.5201700443802357`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x Integration", "Subsubsection",
 CellChangeTimes->{{3.517745769179029*^9, 3.517745770898965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4x1", "[", 
   RowBox[{"x2_", ",", "x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint4y4", "[", 
       RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x1", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517732196799386*^9, 3.517732209077632*^9}, {
   3.517745661824411*^9, 3.517745661836318*^9}, {3.519098554924506*^9, 
   3.519098559812488*^9}, 3.519106493449616*^9, {3.5196245083682613`*^9, 
   3.519624511951069*^9}, 3.52011138082826*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "q"]}], "-", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x2", "-", "x4"}], ")"}], "2"], 
       RowBox[{"4", " ", "Dd", " ", "\[Tau]"}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
        SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "-", 
      FractionBox[
       RowBox[{"q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["vz", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
          "+", 
          RowBox[{
           SuperscriptBox["vr", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]}], 
         ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
      
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["x2", "2"], "+", 
           SuperscriptBox["x3", "2"], "+", 
           SuperscriptBox["x4", "2"]}], 
          SuperscriptBox["w0", "2"]], "+", 
         FractionBox[
          SuperscriptBox["x3", "2"], 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}]}]],
     " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
       RowBox[{"cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
         ")"}]}]}], ")"}], "2"], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["w0", "5"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", 
    SuperscriptBox["q", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"Dd", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517732851099391*^9, 3.517746896155963*^9, 
  3.5179033248133993`*^9, 3.519039679902471*^9, 3.5191969737777376`*^9, 
  3.5193579432968216`*^9, 3.519582057845364*^9, 3.519627424418284*^9, 
  3.520170197438631*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4x2", "[", 
   RowBox[{"x3_", ",", "x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint4x1", "[", 
       RowBox[{"x2", ",", "x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517732221026703*^9, 3.517732234736074*^9}, {
   3.517745661839507*^9, 3.517745661852439*^9}, {3.5190985651109324`*^9, 
   3.519098569611928*^9}, 3.519106496833477*^9, {3.5196245146719227`*^9, 
   3.5196245174947157`*^9}, 3.520111384420219*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "Dd"]}], 
        "+", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
         RowBox[{"Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
        "-", 
        FractionBox[
         RowBox[{"8", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x3", "2"], "+", 
            SuperscriptBox["x4", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["w0", "4"], "+", 
          RowBox[{"4", " ", "Dd", " ", "q", " ", 
           SuperscriptBox["w0", "2"], " ", "\[Tau]"}]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "Dd", " ", 
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], "+", 
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"vz", "-", 
              RowBox[{
              "2", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], 
             ")"}], "2"], " ", "\[Tau]"}]}], 
         RowBox[{"Dd", " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
       ")"}]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
         ")"}]}]}], ")"}], "2"], " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["w0", "6"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"32", " ", 
    SuperscriptBox["q", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517732878062765*^9, 3.517746923181123*^9, 
  3.517903352768886*^9, 3.519039766443984*^9, 3.519197131166348*^9, 
  3.519358096857356*^9, 3.519582174015752*^9, 3.519627518832239*^9, 
  3.520170346035613*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4x3", "[", 
   RowBox[{"x4_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint4x2", "[", 
       RowBox[{"x3", ",", "x4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x3", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5177322454178867`*^9, 3.517732258925321*^9}, {
   3.51774566185576*^9, 3.517745661871338*^9}, {3.51909857344773*^9, 
   3.519098578069272*^9}, 3.519106500169159*^9, {3.519624520614636*^9, 
   3.5196245244142838`*^9}, 3.520111387363525*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "q"]}], "+", 
      FractionBox[
       RowBox[{"\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"q", " ", 
           SuperscriptBox["vr", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"w0", "-", "z0"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"w0", "+", "z0"}], ")"}], " ", "\[Tau]"}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]}], 
         ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
      
      RowBox[{"q", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vr", "2"], "+", 
             SuperscriptBox["vz", "2"]}], ")"}], " ", 
           SuperscriptBox["\[Tau]", "2"]}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "+", 
         RowBox[{
          SuperscriptBox["x4", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", 
             SuperscriptBox["w0", "2"]], "+", 
            FractionBox["1", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
           ")"}]}]}], ")"}]}]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
       RowBox[{"cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
         ")"}]}]}], ")"}], "2"], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox["w0", "7"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"32", " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["q", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.517732886896974*^9, 3.517746932138587*^9, 
  3.517903361734133*^9, 3.519039778697549*^9, 3.5191971554004126`*^9, 
  3.5193581748563576`*^9, 3.5195822148121047`*^9, 3.519627548083308*^9, 
  3.520170403709373*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint4x4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"myint4x3", "[", 
       RowBox[{"x4", ",", "\[Tau]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x4", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "100"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517732271590006*^9, 3.517732281837782*^9}, {
   3.5177456618754396`*^9, 3.517745661886105*^9}, {3.519098581502565*^9, 
   3.519098586793171*^9}, 3.519106505536833*^9, {3.5196245271821527`*^9, 
   3.519624530798169*^9}, {3.52011139573137*^9, 3.520111395891144*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520170516425414*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201706164781437`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(100.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520170740901095*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201707409031973`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{"2", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"Dd", " ", "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["vz", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "q"], "+", 
        RowBox[{"\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "Dd", " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                 RowBox[{"Dd", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}], " ", 
            "\[Tau]"}], "+", 
           RowBox[{"2", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
       RowBox[{"cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
         ")"}]}]}], ")"}], "2"], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "7"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", 
    SuperscriptBox["q", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"q", "+", 
      FractionBox[
       RowBox[{"2", " ", "Dd", " ", 
        SuperscriptBox["q", "2"], " ", "\[Tau]"}], 
       SuperscriptBox["w0", "2"]]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.51773289336174*^9, 3.517746938637725*^9, 
  3.5179033682174397`*^9, 3.519039787986353*^9, 3.5191971708064656`*^9, 
  3.5193582184964237`*^9, 3.5195822477179337`*^9, 3.519627566242723*^9, 
  3.520170758595559*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"myint4x4", "[", "\[Tau]", "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.51773292161376*^9, 3.517732931084072*^9}, 
   3.517745661888628*^9, 3.517745779117835*^9, 3.519151655353281*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520171459832612*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520172159886773*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201728611360188`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201728611382847`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{"2", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"Dd", " ", "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["vz", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "q"], "+", 
        RowBox[{"\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "Dd", " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                 RowBox[{"Dd", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}], " ", 
            "\[Tau]"}], "+", 
           RowBox[{"2", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
       RowBox[{"cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
         ")"}]}]}], ")"}], "2"], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "7"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", 
    SuperscriptBox["q", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"q", "+", 
      FractionBox[
       RowBox[{"2", " ", "Dd", " ", 
        SuperscriptBox["q", "2"], " ", "\[Tau]"}], 
       SuperscriptBox["w0", "2"]]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.517732933646641*^9, 3.517746939675591*^9, 
  3.517903369208128*^9, 3.51903978880338*^9, 3.519199361231553*^9, 
  3.519360221533285*^9, 3.5195826383223085`*^9, 3.519627566954322*^9, 
  3.520172869842124*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["I mean", "Section",
 CellChangeTimes->{{3.517919420171873*^9, 3.517919421097612*^9}}],

Cell[CellGroupData[{

Cell["Term 1", "Subsection",
 CellChangeTimes->{{3.517919873363069*^9, 3.517919874043497*^9}}],

Cell[CellGroupData[{

Cell["z Integration", "Subsubsection",
 CellChangeTimes->{{3.517919879835125*^9, 3.5179198815867853`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myintimz1", "[", 
   RowBox[{
   "x1_", ",", "x2_", ",", "y1_", ",", "y2_", ",", "z2_", ",", "\[Tau]_"}], 
   "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"imeanint", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "y1", ",", "y2", ",", "z1", ",", "z2", ",", 
       "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5179195764498997`*^9, 3.517919615279607*^9}, {
   3.519098600190875*^9, 3.519098605201848*^9}, 3.5191065170173073`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "q"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"], "+", 
          SuperscriptBox["y1", "2"], "+", 
          SuperscriptBox["y2", "2"]}], 
         SuperscriptBox["w0", "2"]], "+", 
        FractionBox[
         SuperscriptBox["z2", "2"], 
         SuperscriptBox["z0", "2"]]}], ")"}]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"4", " ", "q"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "z2", " ", "\[Kappa]"}]]}], 
    ")"}], " ", 
   SqrtBox["\[Pi]"], " ", "z0"}], 
  RowBox[{"2", " ", 
   SqrtBox["q"]}]]], "Output",
 CellChangeTimes->{3.5179196288232403`*^9, 3.5179201616908407`*^9, 
  3.519039791214301*^9, 3.5191993718407917`*^9, 3.5193602317050295`*^9, 
  3.519582648603427*^9, 3.520172876136181*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myintimz2", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "y1_", ",", "y2_", ",", "\[Tau]_"}], "]"}],
   "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myintimz1", "[", 
      RowBox[{
      "x1", ",", "x2", ",", "y1", ",", "y2", ",", "z2", ",", "\[Tau]"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5179196371657743`*^9, 3.5179196532736387`*^9}, {
   3.519098609070817*^9, 3.519098614732396*^9}, 3.519106520082767*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"], "+", 
          SuperscriptBox["y1", "2"], "+", 
          SuperscriptBox["y2", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", "\[Pi]", " ", 
   SuperscriptBox["z0", "2"]}], "q"]], "Output",
 CellChangeTimes->{3.517919655711857*^9, 3.519039792819139*^9, 
  3.519199384278133*^9, 3.519360243907998*^9, 3.5195826609001446`*^9, 
  3.5201728832521152`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myintimy1", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "y2_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myintimz2", "[", 
      RowBox[{"x1", ",", "x2", ",", "y1", ",", "y2", ",", "\[Tau]"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.51791966470299*^9, 3.517919678269909*^9}, {
   3.517919732703672*^9, 3.517919732837859*^9}, {3.519098617828985*^9, 
   3.519098623604974*^9}, 3.519106523718761*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"], "+", 
          SuperscriptBox["y2", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", "w0", " ", 
   SuperscriptBox["z0", "2"]}], 
  SuperscriptBox["q", 
   RowBox[{"3", "/", "2"}]]]], "Output",
 CellChangeTimes->{3.517919679699366*^9, 3.5179197345144987`*^9, 
  3.519039794326807*^9, 3.5191993869499736`*^9, 3.5193602464860907`*^9, 
  3.519582663540736*^9, 3.520172884842162*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myintimy2", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myintimy1", "[", 
      RowBox[{"x1", ",", "x2", ",", "y2", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517919741338912*^9, 3.517919756258027*^9}, {
   3.519098627026026*^9, 3.519098632199689*^9}, 3.519106527064625*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   SuperscriptBox["\[Pi]", "2"], " ", 
   SuperscriptBox["w0", "2"], " ", 
   SuperscriptBox["z0", "2"]}], 
  SuperscriptBox["q", "2"]]], "Output",
 CellChangeTimes->{3.51791975765473*^9, 3.519039795698576*^9, 
  3.519199389418692*^9, 3.5193602488923097`*^9, 3.5195826659938297`*^9, 
  3.5201728862850847`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myintimx1", "[", 
   RowBox[{"x2_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myintimy2", "[", 
      RowBox[{"x1", ",", "x2", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517919771859236*^9, 3.517919783773608*^9}, {
   3.519098635732675*^9, 3.519098641644617*^9}, 3.5191065301450367`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"q", " ", 
        SuperscriptBox["x2", "2"]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"5", "/", "2"}]], " ", 
   SuperscriptBox["w0", "3"], " ", 
   SuperscriptBox["z0", "2"]}], 
  SuperscriptBox["q", 
   RowBox[{"5", "/", "2"}]]]], "Output",
 CellChangeTimes->{3.517919785845707*^9, 3.519039796815176*^9, 
  3.519199391621789*^9, 3.5193602509235334`*^9, 3.519582668056303*^9, 
  3.520172887488098*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myintimx2", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myintimx1", "[", 
      RowBox[{"x2", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x2", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517919794747884*^9, 3.517919803961081*^9}, {
  3.519098645645355*^9, 3.5190986516245537`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   SuperscriptBox["\[Pi]", "3"], " ", 
   SuperscriptBox["w0", "4"], " ", 
   SuperscriptBox["z0", "2"]}], 
  SuperscriptBox["q", "3"]]], "Output",
 CellChangeTimes->{3.517919805364737*^9, 3.5190397978251047`*^9, 
  3.519199393621763*^9, 3.5193602528453836`*^9, 3.5195826699781537`*^9, 
  3.520172888636424*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Term 2", "Subsection",
 CellChangeTimes->{{3.517919891987419*^9, 3.5179198925394373`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2imz1", "[", 
   RowBox[{"x1_", ",", "y1_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"imeanint2", "[", 
      RowBox[{"x1", ",", "y1", ",", "z1", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517919974667863*^9, 3.5179200274786654`*^9}, 
   3.517920141652252*^9, {3.519098654741681*^9, 3.5190986591968393`*^9}, 
   3.519106538080307*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["y1", "2"]}], ")"}]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{"2", " ", "q"}]]]}], ")"}], " ", 
   SqrtBox[
    FractionBox["\[Pi]", "2"]], " ", "z0"}], 
  RowBox[{"2", " ", 
   SqrtBox["q"]}]]], "Output",
 CellChangeTimes->{3.5179200353802557`*^9, 3.519039802059594*^9, 
  3.5191994037622585`*^9, 3.5193602628140063`*^9, 3.5195826799311514`*^9, 
  3.5201728946333303`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2imy1", "[", 
   RowBox[{"x1_", ",", "\[Tau]_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2imz1", "[", 
      RowBox[{"x1", ",", "y1", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517920057230308*^9, 3.51792007146154*^9}, 
   3.517920137310356*^9, {3.519098664702592*^9, 3.5190986697962837`*^9}, 
   3.5191065415596657`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "q", " ", 
        SuperscriptBox["x1", "2"]}], 
       SuperscriptBox["w0", "2"]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{"2", " ", "q"}]]]}], ")"}], " ", "\[Pi]", " ", "w0", " ", 
   "z0"}], 
  RowBox[{"4", " ", "q"}]]], "Output",
 CellChangeTimes->{3.5179200737547493`*^9, 3.519039804177793*^9, 
  3.519199407699708*^9, 3.519360266595208*^9, 3.5195826837279778`*^9, 
  3.520172896913636*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"myint2imx1", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"myint2imy1", "[", 
      RowBox[{"x1", ",", "\[Tau]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.517920084939788*^9, 3.517920093197563*^9}, 
   3.517920133815189*^9, {3.519098672962963*^9, 3.519098677365424*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], 
       RowBox[{"2", " ", "q"}]]]}], ")"}], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["w0", "2"], " ", "z0"}], 
  RowBox[{"4", " ", 
   SqrtBox["2"], " ", 
   SuperscriptBox["q", 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{3.517920094783051*^9, 3.519039805965763*^9, 
  3.5191994113246613`*^9, 3.519360270126413*^9, 3.519582687243558*^9, 
  3.520172899027581*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Combine", "Subsection",
 CellChangeTimes->{{3.517920113156788*^9, 3.5179201139316072`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"imean", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"myintimx2", "[", "\[Tau]", "]"}], "+", 
    RowBox[{"myint2imx1", "[", "\[Tau]", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517920120630784*^9, 3.5179201294210052`*^9}, {
  3.517920192434314*^9, 3.5179202080878057`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["w0", "2"], " ", "z0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SqrtBox["2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{"2", " ", "q"}]]]}], ")"}], " ", 
      SuperscriptBox["q", 
       RowBox[{"3", "/", "2"}]]}], "+", 
     RowBox[{"8", " ", "cm", " ", 
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0", "2"], " ", "z0"}]}], ")"}]}], 
  RowBox[{"8", " ", 
   SuperscriptBox["q", "3"]}]]], "Output",
 CellChangeTimes->{3.517920211802293*^9, 3.519039806303409*^9, 
  3.51919941184028*^9, 3.5193602706576557`*^9, 3.519582687774801*^9, 
  3.520172899327056*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Square", "Subsection",
 CellChangeTimes->{{3.5179202658852377`*^9, 3.5179202665281887`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"imean", "[", "\[Tau]", "]"}], "^", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.5179202715566196`*^9, 3.517920277745677*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "q"]}]], " ", 
   SuperscriptBox["\[Pi]", "3"], " ", 
   SuperscriptBox["w0", "4"], " ", 
   SuperscriptBox["z0", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], 
           RowBox[{"2", " ", "q"}]]]}], ")"}], " ", 
       SuperscriptBox["q", 
        RowBox[{"3", "/", "2"}]]}], "+", 
      RowBox[{"8", " ", "cm", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"3", "/", "2"}]], " ", 
       SuperscriptBox["w0", "2"], " ", "z0"}]}], ")"}], "2"]}], 
  RowBox[{"64", " ", 
   SuperscriptBox["q", "6"]}]]], "Output",
 CellChangeTimes->{3.5179202786855593`*^9, 3.519039806717277*^9, 
  3.519199412559021*^9, 3.5193602713920217`*^9, 3.5195826884935417`*^9, 
  3.5201728997502413`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["", "Section"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ALL RESULTS", "Subtitle",
 CellChangeTimes->{{3.519036663954867*^9, 3.51903666534559*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g1", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{3.519036713696754*^9, 3.519069972395586*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "3"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "q"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"2", " ", "Dd", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", "\[Kappa]"}]}], ")"}], 
         " ", "\[Tau]"}], "+", 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["vz", "2"], " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              RowBox[{"8", " ", 
               SuperscriptBox["Dd", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "2"]}], "+", 
        RowBox[{"2", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vr", "2"], "+", 
           SuperscriptBox["vz", "2"]}], ")"}], " ", 
         SuperscriptBox["\[Tau]", "3"]}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"4", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
        ")"}]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"9", "/", "2"}]], " ", 
    SuperscriptBox["w0", "8"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["q", 
     RowBox[{"9", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5190367152948093`*^9, 3.519039806724391*^9, 
  3.519069988045517*^9, 3.519199412684019*^9, 3.51936027151702*^9, 
  3.519582688634165*^9, 3.5201728997601833`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g2", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{{3.5190366975296497`*^9, 3.519036726496673*^9}, 
   3.519069974449873*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["vz", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "q"], "+", 
        RowBox[{"2", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", "Dd", " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["vr", "2"]}], "+", 
              RowBox[{"16", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                 RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], 
             ")"}], " ", "\[Tau]"}], "+", 
           RowBox[{"8", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["w0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["z0", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", 
          SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
           RowBox[{
           "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}], 
          ")"}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "6"], " ", 
    SuperscriptBox["z0", "3"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.519036718722293*^9, 3.519036727455965*^9}, 
   3.5190398067297363`*^9, 3.519069989037429*^9, 3.519199412746518*^9, 
   3.5193602715951443`*^9, 3.519582688696664*^9, 3.520172899769557*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g3", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{3.51903673416831*^9, 3.519069976865614*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", "cm", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "Dd", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vr", "2"], "+", 
           SuperscriptBox["vz", "2"]}], ")"}], " ", "\[Tau]"}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "Dd", " ", "q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["w0", "2"], " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox["z0", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vz", "2"], "+", 
               RowBox[{
               "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
                "\[Kappa]"}], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["Dd", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}]}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], "q"]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["Dd", "2"]}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vz", "2"], "+", 
            RowBox[{
            "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
             "\[Kappa]"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"Dd", " ", "q", " ", 
          SuperscriptBox["vz", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}]}], 
        RowBox[{"4", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"5", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"vz", "+", 
             RowBox[{
             "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], ")"}],
            " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["vz", "2"], "+", 
            RowBox[{
            "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
             "\[Kappa]"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"Dd", " ", "q", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"vz", "+", 
            RowBox[{
            "16", " ", "\[ImaginaryI]", " ", "Dd", " ", "\[Kappa]"}]}], ")"}],
           " ", "\[Tau]"}]}], 
        RowBox[{"4", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "4", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"9", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"Dd", " ", "q", " ", 
           SuperscriptBox["z0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["vz", "2"], "+", 
             RowBox[{
             "8", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", 
              "\[Kappa]"}], "+", 
             RowBox[{"16", " ", 
              SuperscriptBox["Dd", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["vz", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["Dd", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
            RowBox[{
            "3", " ", "\[ImaginaryI]", " ", "Dd", " ", "vz", " ", "\[Kappa]", 
             " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z0", "2"], "+", 
               RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]}],
            ")"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
           ")"}]}]]]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["w0", "4"], " ", 
    SuperscriptBox["z0", "2"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"128", " ", "q", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"4", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5190367347062397`*^9, 3.5190398067379208`*^9, 
  3.519069991173057*^9, 3.5191994128090177`*^9, 3.5193602716732683`*^9, 
  3.519582688759163*^9, 3.5201728997806587`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g4", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{3.5190367389532213`*^9, 3.5190699787055264`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{"2", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"Dd", " ", "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["vz", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "q"], "+", 
        RowBox[{"\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "Dd", " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                 RowBox[{"Dd", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}], " ", 
            "\[Tau]"}], "+", 
           RowBox[{"2", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
    " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
       RowBox[{"cm", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "4"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
         ")"}]}]}], ")"}], "2"], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "7"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", 
    SuperscriptBox["q", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"q", "+", 
      FractionBox[
       RowBox[{"2", " ", "Dd", " ", 
        SuperscriptBox["q", "2"], " ", "\[Tau]"}], 
       SuperscriptBox["w0", "2"]]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.519036740447541*^9, 3.5190398067439537`*^9, 
  3.51906999578724*^9, 3.5191994128715167`*^9, 3.5193602717357674`*^9, 
  3.5195826888216624`*^9, 3.520172899793662*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"imean", "[", "\[Tau]", "]"}]], "Input",
 CellChangeTimes->{3.519069981154244*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "cm", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], 
      RowBox[{"2", " ", "q"}]]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["w0", "2"], " ", "z0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SqrtBox["2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}], 
          RowBox[{"2", " ", "q"}]]]}], ")"}], " ", 
      SuperscriptBox["q", 
       RowBox[{"3", "/", "2"}]]}], "+", 
     RowBox[{"8", " ", "cm", " ", 
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0", "2"], " ", "z0"}]}], ")"}]}], 
  RowBox[{"8", " ", 
   SuperscriptBox["q", "3"]}]]], "Output",
 CellChangeTimes->{3.5190367529899073`*^9, 3.5190398067478*^9, 
  3.5190699984038258`*^9, 3.519199412934016*^9, 3.5193602717982664`*^9, 
  3.5195826888997865`*^9, 3.520172899802257*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define some replacement-formulas for simplification", "Section",
 CellChangeTimes->{{3.519225761123719*^9, 3.51922576749866*^9}, {
  3.519227847963977*^9, 3.519227866401497*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"z0qexp", "=", 
  RowBox[{"{", 
   RowBox[{"z0", "\[Rule]", 
    RowBox[{"z0q", "*", 
     RowBox[{"Sqrt", "[", "q", "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"w0qexp", "=", 
  RowBox[{"{", 
   RowBox[{"w0", "\[Rule]", 
    RowBox[{"w0q", "*", 
     RowBox[{"Sqrt", "[", "q", "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Nexp", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"cm", "\[Rule]", 
     RowBox[{"N", "*", 
      RowBox[{
       RowBox[{"q", "^", 
        RowBox[{"(", 
         RowBox[{"3", "/", "2"}], ")"}]}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Pi]", "^", 
          RowBox[{"(", 
           RowBox[{"3", "/", "2"}], ")"}]}], "*", 
         RowBox[{"w0", "^", "2"}], "*", "z0"}], ")"}]}]}]}], ",", 
    RowBox[{"cm", "\[Rule]", 
     RowBox[{"N", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Pi]", "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}], "*", 
        RowBox[{"w0q", "^", "2"}], "*", "z0q"}], ")"}]}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"tauDexp", "=", 
  RowBox[{"{", 
   RowBox[{"Dd", "\[Rule]", " ", 
    RowBox[{
     RowBox[{"w0q", "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", "*", "\[Tau]Dq"}], ")"}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"sparamexp", " ", "=", 
  RowBox[{"{", 
   RowBox[{"w0q", "\[Rule]", 
    RowBox[{"z0q", "/", "Sq"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"taufrexp", "=", 
  RowBox[{"{", 
   RowBox[{"vr", "\[Rule]", 
    RowBox[{"w0", "/", "\[Tau]fr"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"taufzexp", "=", 
  RowBox[{"{", 
   RowBox[{"vz", "\[Rule]", 
    RowBox[{"z0", "/", "\[Tau]fz"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"allexp", " ", "=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{
   "z0qexp", ",", "w0qexp", ",", "Nexp", ",", "tauDexp", ",", "sparamexp", 
    ",", "taufrexp", ",", " ", "taufzexp"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allexpreplace", "[", "e_", "]"}], ":=", 
  RowBox[{"ReplaceRepeated", "[", 
   RowBox[{"e", ",", "allexp"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"dividerToGetToG", "=", 
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "N"}]}]}], "Input",
 CellChangeTimes->{{3.5192278796347857`*^9, 3.51922788373866*^9}, {
   3.5192280404721327`*^9, 3.5192280865816793`*^9}, {3.519228235085371*^9, 
   3.519228453356268*^9}, {3.519228486264221*^9, 3.519228543561183*^9}, {
   3.5192286432937593`*^9, 3.519228650816778*^9}, {3.519228741300831*^9, 
   3.51922874432421*^9}, {3.5192330404786386`*^9, 3.519233075199617*^9}, {
   3.51923311113347*^9, 3.519233156785954*^9}, {3.519233336131023*^9, 
   3.519233460274477*^9}, {3.519233502449368*^9, 3.5192335663150063`*^9}, {
   3.5192340194292088`*^9, 3.5192340197572527`*^9}, {3.519234120625125*^9, 
   3.519234145800989*^9}, {3.519234472314494*^9, 3.519234483344946*^9}, {
   3.519235101453726*^9, 3.519235104749152*^9}, 3.519235136013392*^9, {
   3.519235234935113*^9, 3.519235236259161*^9}, {3.519236384687229*^9, 
   3.519236384966714*^9}, {3.519325426318248*^9, 3.5193254362177763`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"z0", "\[Rule]", 
   RowBox[{
    SqrtBox["q"], " ", "z0q"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"w0", "\[Rule]", 
   RowBox[{
    SqrtBox["q"], " ", "w0q"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899810461*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cm", "\[Rule]", 
    FractionBox[
     RowBox[{"N", " ", 
      SuperscriptBox["q", 
       RowBox[{"3", "/", "2"}]]}], 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0", "2"], " ", "z0"}]]}], ",", 
   RowBox[{"cm", "\[Rule]", 
    FractionBox["N", 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0q", "2"], " ", "z0q"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899812101*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Dd", "\[Rule]", 
   FractionBox[
    SuperscriptBox["w0q", "2"], 
    RowBox[{"4", " ", "\[Tau]Dq"}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.52017289981376*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"w0q", "\[Rule]", 
   FractionBox["z0q", "Sq"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899815295*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"vr", "\[Rule]", 
   FractionBox["w0", "\[Tau]fr"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899816779*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"vz", "\[Rule]", 
   FractionBox["z0", "\[Tau]fz"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.5201728998182364`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"z0", "\[Rule]", 
    RowBox[{
     SqrtBox["q"], " ", "z0q"}]}], ",", 
   RowBox[{"w0", "\[Rule]", 
    RowBox[{
     SqrtBox["q"], " ", "w0q"}]}], ",", 
   RowBox[{"cm", "\[Rule]", 
    FractionBox[
     RowBox[{"N", " ", 
      SuperscriptBox["q", 
       RowBox[{"3", "/", "2"}]]}], 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0", "2"], " ", "z0"}]]}], ",", 
   RowBox[{"cm", "\[Rule]", 
    FractionBox["N", 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0q", "2"], " ", "z0q"}]]}], ",", 
   RowBox[{"Dd", "\[Rule]", 
    FractionBox[
     SuperscriptBox["w0q", "2"], 
     RowBox[{"4", " ", "\[Tau]Dq"}]]}], ",", 
   RowBox[{"w0q", "\[Rule]", 
    FractionBox["z0q", "Sq"]}], ",", 
   RowBox[{"vr", "\[Rule]", 
    FractionBox["w0", "\[Tau]fr"]}], ",", 
   RowBox[{"vz", "\[Rule]", 
    FractionBox["z0", "\[Tau]fz"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.52017289981999*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Aq0", "2"], " ", 
  SuperscriptBox["chi", "2"], " ", "N"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899822029*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Calculate the G and use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to Expand the exponential-terms (no parentheses)"
}], "Section",
 CellChangeTimes->{{3.519235012839574*^9, 3.519235015710705*^9}, {
  3.5192418783809557`*^9, 3.519241906252338*^9}, {3.519533764637437*^9, 
  3.519533773852219*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{
  3.519235283962183*^9, {3.519236374894145*^9, 3.519236380663028*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G1t", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"allexpreplace", "[", 
     RowBox[{
      RowBox[{"g1", "[", "\[Tau]", "]"}], "/", 
      RowBox[{"dividerToGetToG", "^", "2"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G1", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"G1t", "[", "\[Tau]", "]"}], ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"Simplify", "[", "form", "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5192350215770197`*^9, 3.519235046070712*^9}, {
   3.519235199728877*^9, 3.519235204183591*^9}, {3.519235353834343*^9, 
   3.519235358688608*^9}, {3.519235416297687*^9, 3.5192354164971523`*^9}, {
   3.519235464190826*^9, 3.519235494573909*^9}, {3.519235861284093*^9, 
   3.5192358819629927`*^9}, 3.519235924280855*^9, {3.519235982394039*^9, 
   3.519235987273773*^9}, {3.519236415838182*^9, 3.519236421940899*^9}, {
   3.519237099206212*^9, 3.519237151254199*^9}, {3.519237188355278*^9, 
   3.519237193098537*^9}, {3.519237359047275*^9, 3.5192375066669893`*^9}, {
   3.519237635342865*^9, 3.5192376423832607`*^9}, {3.519237794155087*^9, 
   3.519237818120565*^9}, {3.519238176866815*^9, 3.519238212312895*^9}, {
   3.519238370382874*^9, 3.5192384168110237`*^9}, {3.519238488632887*^9, 
   3.519238517784412*^9}, {3.51923856374636*^9, 3.5192385831113663`*^9}, {
   3.5192388759889812`*^9, 3.519238893211856*^9}, {3.519238940131935*^9, 
   3.519238946570722*^9}, {3.519239208396803*^9, 3.51923920952271*^9}, {
   3.519239269662387*^9, 3.519239294236808*^9}, {3.519242227450844*^9, 
   3.519242233446048*^9}, {3.519325471705011*^9, 3.519325474675932*^9}, 
   3.519325520339777*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        FractionBox["\[Tau]", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "q"}], " ", 
      SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
        FractionBox[
         SuperscriptBox["Sq", "2"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "-", 
     RowBox[{"z0q", " ", "\[Kappa]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"z0q", " ", "\[Kappa]"}], "+", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
         RowBox[{
          RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]]}],
        ")"}]}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["Sq", "2"], " ", 
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]Dq"}], 
       RowBox[{"\[Tau]", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
        "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SqrtBox["q"], " ", "\[Tau]"}], "+", 
          RowBox[{"z0q", " ", "\[Kappa]", " ", "\[Tau]fz"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
        "\[Tau]fz"}]]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
          "\[Tau]fz"}]}]]]}]}], ")"}], " ", "N", " ", "z0q", " ", 
   "\[Tau]Dq"}]}]], "Output",
 CellChangeTimes->{
  3.519237819780142*^9, {3.519238207218175*^9, 3.519238212999241*^9}, {
   3.519238398057691*^9, 3.519238417529151*^9}, 3.51923851916107*^9, {
   3.519238564901105*^9, 3.519238583687523*^9}, 3.519238894628579*^9, {
   3.519238942722363*^9, 3.5192389469979*^9}, 3.519239210011959*^9, 
   3.519239300287734*^9, 3.519240845977521*^9, 3.519242283387723*^9, 
   3.519360306391574*^9, 3.519582692509115*^9, 3.520173052570565*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        FractionBox["\[Tau]", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "+", 
       RowBox[{"q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
          FractionBox[
           SuperscriptBox["Sq", "2"], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]]}]],
      "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", 
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]Dq"}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]], "-", 
       RowBox[{"q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
          FractionBox[
           SuperscriptBox["Sq", "2"], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "-", 
       RowBox[{"z0q", " ", "\[Kappa]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"z0q", " ", "\[Kappa]"}], "+", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
           RowBox[{
            RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
             "\[Tau]fz"}]}]]}], ")"}]}]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Tau]", "2"], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"2", " ", "\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]]}]}], ")"}], " ", "N", " ", 
   "z0q", " ", "\[Tau]Dq"}]}]], "Output",
 CellChangeTimes->{
  3.519237819780142*^9, {3.519238207218175*^9, 3.519238212999241*^9}, {
   3.519238398057691*^9, 3.519238417529151*^9}, 3.51923851916107*^9, {
   3.519238564901105*^9, 3.519238583687523*^9}, 3.519238894628579*^9, {
   3.519238942722363*^9, 3.5192389469979*^9}, 3.519239210011959*^9, 
   3.519239300287734*^9, 3.519240845977521*^9, 3.519242283387723*^9, 
   3.519360306391574*^9, 3.519582692509115*^9, 3.520173052842815*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G2t", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"allexpreplace", "[", 
     RowBox[{
      RowBox[{"g2", "[", "\[Tau]", "]"}], "/", 
      RowBox[{"dividerToGetToG", "^", "2"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G2", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"G2t", "[", "\[Tau]", "]"}], ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"Simplify", "[", "form", "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.519236441012906*^9, 3.519236444076207*^9}, {
   3.5192393545602922`*^9, 3.519239360601432*^9}, {3.519242236719747*^9, 
   3.5192422446454897`*^9}, {3.519325479459919*^9, 3.519325480043906*^9}, 
   3.519325523747676*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        FractionBox[
         RowBox[{"2", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "\[Tau]"}], "+", 
      RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "q", " ", 
      SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
        FractionBox[
         SuperscriptBox["Sq", "2"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "-", 
     RowBox[{"z0q", " ", "\[Kappa]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"z0q", " ", "\[Kappa]"}], "+", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]", " ", 
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]]}],
        ")"}]}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["Sq", "2"], " ", 
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]Dq"}], 
       RowBox[{
        RowBox[{"2", " ", "\[Tau]"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
        "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SqrtBox["q"], " ", "\[Tau]"}], "+", 
          RowBox[{"z0q", " ", "\[Kappa]", " ", "\[Tau]fz"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
        "\[Tau]fz"}]]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"4", " ", "\[ImaginaryI]", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]]]}],
      "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"z0q", " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], "+", 
           
           RowBox[{"z0q", " ", "\[Kappa]", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            "\[Tau]fz"}]}], ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         "\[Tau]fz"}]]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"z0q", " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], "+", 
           
           RowBox[{"z0q", " ", "\[Kappa]", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            "\[Tau]fz"}]}], ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         "\[Tau]fz"}]]]}]}], ")"}], " ", "z0q", " ", "\[Tau]Dq"}]}]], "Output",\

 CellChangeTimes->{3.5192364454293127`*^9, 3.519239361441655*^9, 
  3.519240848615638*^9, 3.519242284872302*^9, 3.519360323938224*^9, 
  3.5195826946653376`*^9, 3.5201730606774893`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        FractionBox[
         RowBox[{"2", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "\[Tau]"}], "+", 
      RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "+", 
       RowBox[{"2", " ", "q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "\[Tau]"}], "+", 
               RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
          FractionBox[
           SuperscriptBox["Sq", "2"], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "\[Tau]"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{"4", " ", "\[ImaginaryI]", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]]}]],
      "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["Sq", "2"], " ", 
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]], "-", 
       RowBox[{"2", " ", "q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "\[Tau]"}], "+", 
              RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
          FractionBox[
           SuperscriptBox["Sq", "2"], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "\[Tau]"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "-", 
       RowBox[{"z0q", " ", "\[Kappa]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"z0q", " ", "\[Kappa]"}], "+", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
             "\[Tau]fz"}]}]]}], ")"}]}]}]], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["z0q", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{
                SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
            RowBox[{
             RowBox[{"2", " ", "\[Tau]"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "+", 
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "\[Tau]"}], "+", 
                  RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
                SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
             FractionBox[
              SuperscriptBox["Sq", "2"], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", "\[Tau]"}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
               
               SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "-", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]", " ", "\[Tau]Dq"}], 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
             "\[Tau]fz"}]}]]}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["z0q", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{
                SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
            RowBox[{
             RowBox[{"2", " ", "\[Tau]"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "+", 
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "\[Tau]"}], "+", 
                  RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
                SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
             FractionBox[
              SuperscriptBox["Sq", "2"], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", "\[Tau]"}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
               
               SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]", " ", "\[Tau]Dq"}], 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
             "\[Tau]fz"}]}]]}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["z0q", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["\[Tau]", "2"]}], "+", 
               RowBox[{"6", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
                "\[Tau]Dq"}], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["Sq", "2"], " ", 
                SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"], " ", 
             SuperscriptBox["\[Tau]fz", "2"]}], "+", 
            RowBox[{"2", " ", "q", " ", 
             SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "\[Tau]", " ", 
                SuperscriptBox["\[Tau]fz", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["Sq", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "\[Tau]", " ", 
                   SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                  RowBox[{"3", " ", "\[Tau]Dq", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "\[Tau]"}], "+", 
              RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "\[Tau]"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}]]}]]}], ")"}]}]}], ")"}], " ", 
   "z0q", " ", "\[Tau]Dq"}]}]], "Output",
 CellChangeTimes->{3.5192364454293127`*^9, 3.519239361441655*^9, 
  3.519240848615638*^9, 3.519242284872302*^9, 3.519360323938224*^9, 
  3.5195826946653376`*^9, 3.5201730611430387`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G3t", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"allexpreplace", "[", 
     RowBox[{
      RowBox[{"g3", "[", "\[Tau]", "]"}], "/", 
      RowBox[{"dividerToGetToG", "^", "2"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G3", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"G3t", "[", "\[Tau]", "]"}], ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"Simplify", "[", "form", "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.519236451300952*^9, 3.519236453467856*^9}, {
   3.519239342673381*^9, 3.519239350001796*^9}, {3.519242250901305*^9, 
   3.5192422562851667`*^9}, {3.5193254842437468`*^9, 3.519325484843418*^9}, 
   3.5193255268675747`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520173771413993*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520174472554648*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FullSimplify", "::", "time"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Time spent on a transformation exceeded \
\[NoBreak]\\!\\(700.`\\)\[NoBreak] seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/FullSimplify\\\", \
ButtonNote -> \\\"FullSimplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.520175555115386*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(FullSimplify :: time\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5201755551174097`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"128", " ", "N", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox["\[Tau]", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[Tau]"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
       RowBox[{"4", " ", "q", " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["\[Tau]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Tau]", "2"], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
              "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["Sq", "4"], " ", 
               SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}]}], 
           SuperscriptBox["\[Tau]fz", "2"]]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{"4", " ", "\[ImaginaryI]", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]Dq", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        "\[Tau]fz"]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "q", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
           RowBox[{"4", " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", "z0q", " ", "\[Kappa]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "\[Tau]"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            "\[Tau]fz"}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]]}], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "q", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", 
           SqrtBox["q"], " ", 
           SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
           "\[Tau]Dq", " ", "\[Tau]fz"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]}], ")"}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
        SuperscriptBox["\[Tau]fz", "2"]}]]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "q", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SqrtBox["q"], " ", "z0q", " ", "\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", "\[Tau]"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           "\[Tau]fz"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]}], ")"}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
        SuperscriptBox["\[Tau]fz", "2"]}]]], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", "q", " ", 
          SuperscriptBox["Sq", "4"], " ", 
          SuperscriptBox["\[Tau]Dq", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
         RowBox[{"6", " ", "\[ImaginaryI]", " ", 
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          "\[Tau]fz"}], "+", 
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", "q", " ", 
          SuperscriptBox["Sq", "4"], " ", 
          SuperscriptBox["\[Tau]Dq", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          "\[Tau]fz"}], "+", 
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "q", " ", 
          SuperscriptBox["Sq", "4"], " ", 
          SuperscriptBox["\[Tau]Dq", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
         RowBox[{"4", " ", "\[ImaginaryI]", " ", 
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          "\[Tau]fz"}], "+", 
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", "\[Tau]"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]]}]}], ")"}], " ", "z0q", " ", 
   "\[Tau]Dq"}]}]], "Output",
 CellChangeTimes->{3.519236454750012*^9, 3.519239363713993*^9, 
  3.519240850735854*^9, 3.5192422872622766`*^9, 3.519360355203449*^9, 
  3.5195826966496873`*^9, 3.520207712107595*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"128", " ", "N", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox["\[Tau]", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}]], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"q", " ", 
          SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Tau]", " ", 
             SuperscriptBox["\[Tau]fz", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Tau]", " ", 
                SuperscriptBox["\[Tau]fr", "2"]}], "+", 
               RowBox[{"\[Tau]Dq", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Tau]fr", "2"], "+", 
                  SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]]}], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", "\[Tau]fz"}], "+", 
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}], "+", 
           RowBox[{"q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Tau]", " ", 
               SuperscriptBox["\[Tau]fz", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Tau]", " ", 
                  SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                 RowBox[{"\[Tau]Dq", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fr", "2"], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", "\[Tau]fz"}], "+", 
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}], "+", 
           RowBox[{"q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Tau]", " ", 
               SuperscriptBox["\[Tau]fz", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Tau]", " ", 
                  SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                 RowBox[{"\[Tau]Dq", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fr", "2"], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Tau]", "2"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
           SqrtBox["q"], " ", 
           SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
           "\[Tau]", " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", "\[Tau]fz"}], "+", 
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["\[Tau]", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"4", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SqrtBox["q"], " ", 
           SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
           "\[Tau]", " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", "\[Tau]fz"}], "+", 
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["\[Tau]", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"4", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]]}]}], ")"}], " ", "z0q", " ", 
   "\[Tau]Dq"}]}]], "Output",
 CellChangeTimes->{3.519236454750012*^9, 3.519239363713993*^9, 
  3.519240850735854*^9, 3.5192422872622766`*^9, 3.519360355203449*^9, 
  3.5195826966496873`*^9, 3.520207712725205*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G4t", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"allexpreplace", "[", 
     RowBox[{
      RowBox[{"g4", "[", "\[Tau]", "]"}], "/", 
      RowBox[{"dividerToGetToG", "^", "2"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"G4t", "[", "\[Tau]", "]"}], ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"Simplify", "[", "form", "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5192364592443943`*^9, 3.5192364620676126`*^9}, {
   3.5192393734244328`*^9, 3.519239381736796*^9}, {3.519242259501191*^9, 
   3.519242264740828*^9}, {3.5193254882594347`*^9, 3.519325488819241*^9}, 
   3.519325530523834*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "q", " ", 
       SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
         FractionBox[
          SuperscriptBox["Sq", "2"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "-", 
      RowBox[{"z0q", " ", "\[Kappa]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"z0q", " ", "\[Kappa]"}], "+", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SqrtBox["q"], " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
          RowBox[{
           RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
            "\[Tau]fz"}]}]]}], ")"}]}]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", 
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]Dq"}], 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", "\[ImaginaryI]", " ", 
             SqrtBox["q"], " ", "\[Tau]"}], "+", 
            RowBox[{"z0q", " ", "\[Kappa]", " ", "\[Tau]fz"}]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          "\[Tau]fz"}]]], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SqrtBox["q"], " ", 
           SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
           "\[Tau]", " ", "\[Tau]Dq"}], 
          RowBox[{
           RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
            "\[Tau]fz"}]}]]]}]}], ")"}], "2"], " ", "Sq", " ", "z0q", " ", 
    SqrtBox[
     RowBox[{"2", "+", 
      FractionBox["\[Tau]", "\[Tau]Dq"]}]], " ", 
    SuperscriptBox["\[Tau]Dq", "3"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"8", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], "2"], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       SuperscriptBox["z0q", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.519236463659728*^9, 3.519239382300037*^9, 
  3.519240853558776*^9, 3.519242287871807*^9, 3.5193603742813296`*^9, 
  3.519582700399639*^9, 3.520209335657035*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[Tau]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["z0q", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "+", 
          RowBox[{"2", " ", "q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"\[Tau]", "+", 
                  RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
                SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
             FractionBox[
              SuperscriptBox["Sq", "2"], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[Tau]", "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
               
               SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "-", 
          FractionBox[
           RowBox[{"4", " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]Dq"}], 
           RowBox[{
            RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
             "\[Tau]fz"}]}]]}], ")"}]}]], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0q", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"\[Tau]", "+", 
                RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
              SuperscriptBox["\[Tau]fr", "2"], " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{"2", " ", "q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fz", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["Sq", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Tau]", " ", 
                    SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                   RowBox[{"2", " ", "\[Tau]Dq", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
             SqrtBox["q"], " ", 
             SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
             "\[Tau]Dq", " ", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"], " ", "\[Tau]fz"}], "+", 
            RowBox[{
             SuperscriptBox["z0q", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"], " ", 
             SuperscriptBox["\[Tau]fz", "2"]}], "+", 
            RowBox[{"2", " ", "q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Tau]", " ", 
                SuperscriptBox["\[Tau]fz", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["Sq", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Tau]", " ", 
                   SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                  RowBox[{"2", " ", "\[Tau]Dq", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SqrtBox["q"], " ", 
           SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
           "\[Tau]", " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", "\[Tau]fz"}], "-", 
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Tau]", "2"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "-", 
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"2", " ", "\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]", " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", "\[Tau]fz"}], "+", 
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Tau]", "2"], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
               "\[Tau]Dq"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["Sq", "2"], " ", 
               SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}], "+", 
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Tau]", " ", 
               SuperscriptBox["\[Tau]fz", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Tau]", " ", 
                  SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                 RowBox[{"2", " ", "\[Tau]Dq", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Tau]", "2"], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
               "\[Tau]Dq"}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["Sq", "2"], " ", 
               SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}], "+", 
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Tau]", " ", 
               SuperscriptBox["\[Tau]fz", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Tau]", " ", 
                  SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                 RowBox[{"2", " ", "\[Tau]Dq", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]]}]]}]}], ")"}], " ", "Sq", " ", 
    "z0q", " ", 
    SqrtBox[
     RowBox[{"2", "+", 
      FractionBox["\[Tau]", "\[Tau]Dq"]}]], " ", 
    SuperscriptBox["\[Tau]Dq", "3"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"8", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], "2"], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       SuperscriptBox["z0q", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.519236463659728*^9, 3.519239382300037*^9, 
  3.519240853558776*^9, 3.519242287871807*^9, 3.5193603742813296`*^9, 
  3.519582700399639*^9, 3.520209336152934*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Gmt", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"allexpreplace", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"imean", "[", "\[Tau]", "]"}], "^", "2"}], "/", 
      RowBox[{"dividerToGetToG", "^", "2"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Gm", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"Gmt", "[", "\[Tau]", "]"}], ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"Simplify", "[", "form", "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.51923646701233*^9, 3.5192364766911583`*^9}, {
   3.519239387407907*^9, 3.5192394087754517`*^9}, {3.5192409325603237`*^9, 
   3.5192409614851723`*^9}, {3.519241074040538*^9, 3.519241102397936*^9}, 
   3.5192412585967503`*^9, {3.519242267620858*^9, 3.519242273164742*^9}, {
   3.519325491923572*^9, 3.5193254930112123`*^9}, 3.5193255334433002`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "64"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["z0q", "2"]}], " ", 
    SuperscriptBox["\[Kappa]", "2"]}]], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SqrtBox["2"], "+", 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "2"]]}], "+", 
     RowBox[{"8", " ", "N"}]}], ")"}], "2"]}]], "Output",
 CellChangeTimes->{
  3.51923940953489*^9, 3.519240856229991*^9, {3.519240938440785*^9, 
   3.5192409618028316`*^9}, {3.519241077946432*^9, 3.5192411032618847`*^9}, 
   3.5192412606897907`*^9, 3.519242287996376*^9, 3.519360374734449*^9, 
   3.5195827006808853`*^9, 3.520209336270071*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "32"], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SuperscriptBox["z0q", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"8", " ", 
        SqrtBox["2"], " ", "N"}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"8", " ", 
        SqrtBox["2"], " ", "N"}], "+", 
       RowBox[{"32", " ", 
        SuperscriptBox["N", "2"]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.51923940953489*^9, 3.519240856229991*^9, {3.519240938440785*^9, 
   3.5192409618028316`*^9}, {3.519241077946432*^9, 3.5192411032618847`*^9}, 
   3.5192412606897907`*^9, 3.519242287996376*^9, 3.519360374734449*^9, 
   3.5195827006808853`*^9, 3.520209336287712*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Final step: manual simplification of the exponential terms to remove the \
complex exponentials\
\>", "Title",
 CellFrame->{{0, 0}, {0, 3}},
 CellChangeTimes->{{3.520310811147243*^9, 3.5203108260078993`*^9}}],

Cell["G1", "Subtitle",
 CellChangeTimes->{{3.5203108290484247`*^9, 3.520310829600667*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplification of G1", "Title",
 CellChangeTimes->{{3.520237212163966*^9, 3.5202372241859827`*^9}, 
   3.520243536270507*^9}],

Cell[CellGroupData[{

Cell["Assumptions", "Section",
 CellChangeTimes->{{3.519097759869207*^9, 3.5190977785960703`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Element", "[", 
     RowBox[{"w0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"b", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"Aq0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Tau]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"cm", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"Dd", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"q", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Kappa]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Dd", ">", "0"}], "&&", 
    RowBox[{"\[Tau]", ">", "0"}], "&&", 
    RowBox[{"w0", ">", "0"}], "&&", 
    RowBox[{"z0", ">", "0"}], "&&", 
    RowBox[{"Aq0", ">", "0"}], "&&", 
    RowBox[{"q", "\[GreaterEqual]", "1"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"vr", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"vz", ",", "Reals"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.519097780783361*^9, 3.519097783919778*^9}, 
   3.5191029105091476`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"b", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Aq0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"\[Tau]", "\[Element]", "Reals"}], "&&", 
   RowBox[{"cm", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Dd", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"q", "\[Element]", "Reals"}], "&&", 
   RowBox[{"\[Kappa]", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Dd", ">", "0"}], "&&", 
   RowBox[{"\[Tau]", ">", "0"}], "&&", 
   RowBox[{"w0", ">", "0"}], "&&", 
   RowBox[{"z0", ">", "0"}], "&&", 
   RowBox[{"Aq0", ">", "0"}], "&&", 
   RowBox[{"q", "\[GreaterEqual]", "1"}], "&&", 
   RowBox[{"vr", "\[Element]", "Reals"}], "&&", 
   RowBox[{"vz", "\[Element]", "Reals"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.519097785842445*^9, 3.519098734981737*^9, 3.5191616912762346`*^9, 
   3.519325860368703*^9, 3.51956702706219*^9, 3.5196240459598093`*^9, 
   3.520112769925209*^9, 3.520236738788871*^9, 3.5202465736559563`*^9, {
   3.520253608728065*^9, 3.5202536185491962`*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"myexpsimplification", "[", "myinput_", "]"}], ":=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"myinput", ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"Simplify", "[", "form", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5202360002762136`*^9, 3.52023604787567*^9}, 
   3.520236085810807*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myexpsimplification", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"z0q", "^", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"\[Tau]", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}], ")"}]}]}], ")"}]}],
         "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], ")"}], 
   RowBox[{"E", "^", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "q"}], " ", 
       RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
            RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", 
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"z0q", " ", "\[Kappa]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"z0q", " ", "\[Kappa]"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", " ", "I", " ", 
            RowBox[{"Sqrt", "[", "q", "]"}], " ", 
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]", " ", "\[Tau]Dq"}], ")"}],
           "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}], 
           ")"}]}]}], ")"}]}]}], ")"}]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"E", "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", 
          RowBox[{"z0q", "^", "2"}], " ", 
          RowBox[{"\[Kappa]", "^", "2"}], " ", "\[Tau]Dq"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
     "+", 
     RowBox[{"E", "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", "I", " ", 
             RowBox[{"Sqrt", "[", "q", "]"}], " ", "\[Tau]"}], "+", 
            RowBox[{"z0q", " ", "\[Kappa]", " ", "\[Tau]fz"}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          "\[Tau]fz"}], ")"}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", " ", "I", " ", 
           RowBox[{"Sqrt", "[", "q", "]"}], " ", 
           RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
           "\[Tau]", " ", "\[Tau]Dq"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}], 
          ")"}]}], ")"}]}]}]}], ")"}], " ", "N", " ", "z0q", " ", 
   "\[Tau]Dq"}], "]"}]], "Input",
 CellChangeTimes->{{3.520235926681065*^9, 3.520235968747425*^9}, {
   3.520236057184128*^9, 3.520236103040358*^9}, {3.520236152737315*^9, 
   3.520236155726829*^9}, 3.520238278017208*^9, 3.520238447328554*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        FractionBox["\[Tau]", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "+", 
       RowBox[{"q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
          FractionBox[
           SuperscriptBox["Sq", "2"], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]]}]],
      "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", 
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]Dq"}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]], "-", 
       RowBox[{"q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
          FractionBox[
           SuperscriptBox["Sq", "2"], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "-", 
       RowBox[{"z0q", " ", "\[Kappa]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"z0q", " ", "\[Kappa]"}], "+", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
           RowBox[{
            RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
             "\[Tau]fz"}]}]]}], ")"}]}]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Tau]", "2"], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"2", " ", "\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]]}]}], ")"}], " ", "N", " ", 
   "z0q", " ", "\[Tau]Dq"}]}]], "Output",
 CellChangeTimes->{
  3.520235969428918*^9, {3.520236069853796*^9, 3.52023610381421*^9}, 
   3.520236156450061*^9, 3.5202382788839693`*^9, {3.5202384185425673`*^9, 
   3.520238448401115*^9}, 3.520246574036368*^9, {3.520253608955738*^9, 
   3.520253618704651*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im ersten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520236209163476*^9, 3.520236213281708*^9}, {
  3.520310904487686*^9, 3.520310913334012*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"z0q", "^", "2"}], " ", 
         RowBox[{"\[Kappa]", "^", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}], 
       "/", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
    "+", 
    RowBox[{"q", " ", 
     RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
            RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"Sq", "^", "2"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", "I", " ", 
       RowBox[{"Sqrt", "[", "q", "]"}], " ", 
       RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
       " ", "\[Tau]Dq"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}], 
      ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520236197076613*^9, 3.5202362231995287`*^9}, {
   3.5202363745485086`*^9, 3.520236391566465*^9}, {3.520236456646641*^9, 
   3.520236459038261*^9}, 3.520238412108206*^9, 3.5202384711575212`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
    RowBox[{"\[Tau]", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "+", 
  RowBox[{"q", " ", 
   SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
        SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
     FractionBox[
      SuperscriptBox["Sq", "2"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SqrtBox["q"], " ", 
    SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
    " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
     "\[Tau]fz"}]}]]}]], "Output",
 CellChangeTimes->{
  3.5202362244372463`*^9, {3.520236381506599*^9, 3.520236392378119*^9}, 
   3.520236470082122*^9, 3.52023674625251*^9, 3.5202384131109943`*^9, 
   3.520238471875989*^9, 3.520246574832292*^9, {3.5202536092369347`*^9, 
   3.52025361873147*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im1", "=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"Sqrt", "[", "q", "]"}], " ", 
      RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
      " ", "\[Tau]Dq"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}], 
     ")"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.520236490437832*^9, 3.520236493156191*^9}, {
  3.520236605170095*^9, 3.5202366073995237`*^9}, {3.520236698710671*^9, 
  3.5202367019563704`*^9}, {3.52023677678858*^9, 3.520236819753214*^9}, {
  3.520238487638267*^9, 3.520238494621924*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SqrtBox["q"], " ", 
   SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", " ",
    "\[Tau]Dq"}], 
  RowBox[{
   RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
    "\[Tau]fz"}]}]]], "Output",
 CellChangeTimes->{
  3.5202364995729856`*^9, 3.5202366083176117`*^9, 3.52023670235009*^9, 
   3.5202367486397943`*^9, {3.520236795116796*^9, 3.520236820215605*^9}, {
   3.520238491281541*^9, 3.520238494937949*^9}, 3.520246574915934*^9, {
   3.520253609264802*^9, 3.520253618764476*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re1", "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"z0q", "^", "2"}], " ", 
        RowBox[{"\[Kappa]", "^", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Tau]", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], "+", 
   RowBox[{"q", " ", 
    RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
           RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"Sq", "^", "2"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", 
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.52023679830297*^9, 3.520236809192696*^9}, 
   3.520238513540525*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
    RowBox[{"\[Tau]", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "+", 
  RowBox[{"q", " ", 
   SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
        SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
     FractionBox[
      SuperscriptBox["Sq", "2"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.5202368106118526`*^9, 3.520238514560079*^9, 3.520246574933913*^9, {
   3.5202536092951193`*^9, 3.520253618798154*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im zweiten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520236242627125*^9, 3.52023624600128*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"z0q", "^", "2"}], " ", 
       RowBox[{"\[Kappa]", "^", "2"}], " ", "\[Tau]Dq"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"2", " ", 
        RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], "-", 
    RowBox[{"q", " ", 
     RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"Sq", "^", "2"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"z0q", " ", "\[Kappa]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z0q", " ", "\[Kappa]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", " ", "I", " ", 
          RowBox[{"Sqrt", "[", "q", "]"}], " ", 
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]", " ", "\[Tau]Dq"}], ")"}], 
        "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}], 
         ")"}]}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520236256195423*^9, 3.520236261327833*^9}, {
   3.520236461752304*^9, 3.52023646301486*^9}, 3.5202385438314238`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["z0q", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]Dq"}], 
   RowBox[{"\[Tau]", "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]], "-", 
  RowBox[{"q", " ", 
   SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
     FractionBox[
      SuperscriptBox["Sq", "2"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "-", 
  RowBox[{"z0q", " ", "\[Kappa]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"z0q", " ", "\[Kappa]"}], "+", 
     FractionBox[
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SqrtBox["q"], " ", 
       SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
      RowBox[{
       RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.520236262401347*^9, 3.520236472452134*^9, 3.520238544417638*^9, 
   3.5202465753459578`*^9, {3.5202536093285017`*^9, 3.520253618831492*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im2", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "z0q"}], " ", "\[Kappa]", " ", "*", "2", "  ", 
     RowBox[{"Sqrt", "[", "q", "]"}], " ", 
     RowBox[{"Sq", "^", "2"}], " ", "\[Tau]", " ", "\[Tau]Dq"}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.5202368449446507`*^9, 3.520236845824264*^9}, 
   3.5202368764744053`*^9, {3.520237269460312*^9, 3.52023728133043*^9}, {
   3.5202385857013617`*^9, 3.520238600648426*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    SqrtBox["q"], " ", 
    SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
    " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
     "\[Tau]fz"}]}]]}]], "Output",
 CellChangeTimes->{
  3.520237284003077*^9, 3.520238601444724*^9, 3.5202465753660793`*^9, {
   3.5202536093638477`*^9, 3.5202536188683157`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re2", "=", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["Sq", "2"], " ", 
     SuperscriptBox["z0q", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]Dq"}], 
    RowBox[{"\[Tau]", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]], "-", 
   RowBox[{"q", " ", 
    SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
        SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
      FractionBox[
       SuperscriptBox["Sq", "2"], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
        SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}], "-", 
   RowBox[{"z0q", " ", "\[Kappa]", " ", 
    RowBox[{"(", 
     RowBox[{"z0q", " ", "\[Kappa]"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.520237291166688*^9, 3.520237307714487*^9}, {
  3.520238617380138*^9, 3.520238618850706*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["z0q", "2"]}], " ", 
   SuperscriptBox["\[Kappa]", "2"]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["z0q", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]Dq"}], 
   RowBox[{"\[Tau]", "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]], "-", 
  RowBox[{"q", " ", 
   SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
     FractionBox[
      SuperscriptBox["Sq", "2"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.520237308384087*^9, 3.520238620817219*^9, 3.520246575383531*^9, {
   3.5202536094009933`*^9, 3.520253618934792*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im dritten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520236298938504*^9, 3.520236302487431*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term3", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"z0q", "^", "2"}], " ", 
         RowBox[{"\[Kappa]", "^", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Tau]", "^", "2"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"Sq", "^", "2"}]}], ")"}], " ", "\[Tau]", " ", 
            "\[Tau]Dq"}], "+", 
           RowBox[{"4", " ", 
            RowBox[{"Sq", "^", "2"}], " ", 
            RowBox[{"\[Tau]Dq", "^", "2"}]}]}], ")"}], " ", 
         RowBox[{"\[Tau]fr", "^", "2"}], " ", 
         RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
        RowBox[{"q", " ", 
         RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Tau]", " ", 
            RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Tau]", " ", 
               RowBox[{"\[Tau]fr", "^", "2"}]}], "+", 
              RowBox[{"2", " ", "\[Tau]Dq", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Tau]fr", "^", "2"}], "+", 
                 RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
        RowBox[{"\[Tau]fr", "^", "2"}], " ", 
        RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.520236304153289*^9, 3.52023631935196*^9}, {
   3.520236465271242*^9, 3.520236466366663*^9}, 3.520238657491415*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["z0q", "2"]}], " ", 
   SuperscriptBox["\[Kappa]", "2"]}], "+", 
  RowBox[{"q", " ", 
   SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
        SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
     FractionBox[
      SuperscriptBox["Sq", "2"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.520236320367569*^9, 3.520236474887555*^9, 3.520238658058929*^9, 
   3.520246575546249*^9, {3.520253609553296*^9, 3.520253618964581*^9}}]
}, Open  ]],

Cell["this term is real", "Subsection",
 CellChangeTimes->{{3.520237331511047*^9, 3.520237334070162*^9}}],

Cell[CellGroupData[{

Cell["cheking if real term2 - term1 is not the same", "Section",
 CellChangeTimes->{{3.52023869963577*^9, 3.520238711379517*^9}, {
  3.5202387554494753`*^9, 3.520238755969453*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"re1", "-", "re2"}], "]"}]], "Input",
 CellChangeTimes->{{3.520238713513619*^9, 3.520238721379375*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.52023872201478*^9, 3.5202465755781193`*^9, {3.5202536095790987`*^9, 
   3.520253618997965*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["and similarly we see the im are of opposite signs", "Section",
 CellChangeTimes->{{3.520238751793483*^9, 3.52023876931288*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"im1", "+", "im2"}], "]"}]], "Input",
 CellChangeTimes->{{3.520238734555244*^9, 3.520238746834319*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.520238747531067*^9, 3.520246575600973*^9, {3.520253609612344*^9, 
   3.520253619031314*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["combination of the terms", "Section",
 CellChangeTimes->{{3.52023737593359*^9, 3.520237379972723*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"combination", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"E", "^", 
     RowBox[{"(", "re1", ")"}]}], "*", 
    RowBox[{"ExpToTrig", "[", 
     RowBox[{
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{"I", "*", "im1"}], ")"}]}], "+", 
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{"I", "*", "im2"}], ")"}]}]}], "]"}]}], "+", 
   RowBox[{"2", "*", 
    RowBox[{"E", "^", "term3"}]}]}]}]], "Input",
 CellChangeTimes->{{3.520237414824924*^9, 3.520237435196871*^9}, {
  3.5202374720289183`*^9, 3.520237478178241*^9}, {3.520237558729875*^9, 
  3.5202375610005302`*^9}, {3.520238669710429*^9, 3.520238670509037*^9}, {
  3.520238787291554*^9, 3.5202388675038757`*^9}, {3.520239054403302*^9, 
  3.5202390548824787`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["z0q", "2"]}], " ", 
      SuperscriptBox["\[Kappa]", "2"]}], "+", 
     RowBox[{"q", " ", 
      SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
        FractionBox[
         SuperscriptBox["Sq", "2"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
       RowBox[{"\[Tau]", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "+", 
     RowBox[{"q", " ", 
      SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
        FractionBox[
         SuperscriptBox["Sq", "2"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"2", " ", 
      SqrtBox["q"], " ", 
      SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
      " ", "\[Tau]Dq"}], 
     RowBox[{
      RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.5202388682031*^9, 3.520239055535288*^9, 3.520246575635251*^9, {
   3.5202536096288557`*^9, 3.520253619099527*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"combinationplus", "=", 
  RowBox[{"Simplify", "[", "combination", "]"}]}]], "Input",
 CellChangeTimes->{{3.520238881475524*^9, 3.520238888966007*^9}, {
  3.520238924661517*^9, 3.5202389250930243`*^9}, {3.520238980252309*^9, 
  3.5202389949628077`*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0q", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "-", 
    RowBox[{"q", " ", 
     SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
       FractionBox[
        SuperscriptBox["Sq", "2"], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0q", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SuperscriptBox["z0q", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], " ", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"2", " ", 
        SqrtBox["q"], " ", 
        SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]",
         " ", "\[Tau]Dq"}], 
       RowBox[{
        RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
      "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.520238921394456*^9, 3.5202389256313257`*^9}, 
   3.5202389956012573`*^9, 3.5202390588965807`*^9, 3.520246575890469*^9, {
   3.5202536096622267`*^9, 3.520253619166628*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"G1t", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"z0q", "^", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"\[Tau]", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}], ")"}]}]}], ")"}]}],
         "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], ")"}], "*", 
   "combinationplus", "*", "N", " ", "z0q", " ", "\[Tau]Dq"}]}]], "Input",
 CellChangeTimes->{{3.5202390010090446`*^9, 3.520239029977831*^9}, {
  3.520239062741084*^9, 3.52023908745942*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
       RowBox[{"\[Tau]", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "-", 
     RowBox[{"q", " ", 
      SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
        FractionBox[
         SuperscriptBox["Sq", "2"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], " ", "N", " ", 
   "z0q", " ", "\[Tau]Dq", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
       RowBox[{"\[Tau]", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}]}], ")"}]}], 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       FractionBox["\[Tau]", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.520239088431953*^9, 3.520246575985607*^9, {3.520253609697343*^9, 
   3.520253619233592*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myexpsimplification", "[", 
  RowBox[{"G1t", "[", "\[Tau]", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.520246577887415*^9, 3.520246591431384*^9}, 
   3.5202467388988123`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        FractionBox["\[Tau]", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{"2", " ", "N", " ", "z0q", " ", "\[Tau]Dq", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["z0q", "2"]}], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       RowBox[{"q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
          FractionBox[
           SuperscriptBox["Sq", "2"], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "+", 
        RowBox[{"q", " ", 
         SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"\[Tau]", "+", 
                RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
              SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
           FractionBox[
            SuperscriptBox["Sq", "2"], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.520246627800668*^9, 3.5202467401114473`*^9, {3.520253609731148*^9, 
   3.5202536193338614`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TeXForm", "[", 
  RowBox[{"myexpsimplification", "[", 
   RowBox[{"G1t", "[", "\[Tau]", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.520253605891643*^9, 3.5202536059536953`*^9}}],

Cell["\<\
\\frac{2 N \\text{$\\tau $Dq} \\text{z0q} \\left(\\exp \\left(q \\tau ^2 \
\\text{$\\tau $Dq}
   \\left(-\\frac{\\text{Sq}^2}{\\text{$\\tau $fz}^2 \\left(2 \\text{Sq}^2 \
\\text{$\\tau $Dq}+\\tau
   \\right)}-\\frac{1}{\\text{$\\tau $fr}^2 (\\tau +2 \\text{$\\tau \
$Dq})}\\right)-\\kappa ^2 \\text{z0q}^2\\right)+\\cos
   \\left(\\frac{2 \\kappa  \\sqrt{q} \\text{Sq}^2 \\tau  \\text{$\\tau $Dq} \
\\text{z0q}}{2 \\text{Sq}^2 \\text{$\\tau $Dq}
   \\text{$\\tau $fz}+\\tau  \\text{$\\tau $fz}}\\right) \\exp \\left(q \\tau \
^2 \\text{$\\tau $Dq}
   \\left(-\\frac{\\text{Sq}^2}{\\text{$\\tau $fz}^2 \\left(2 \\text{Sq}^2 \
\\text{$\\tau $Dq}+\\tau
   \\right)}-\\frac{1}{\\text{$\\tau $fr}^2 (\\tau +2 \\text{$\\tau \
$Dq})}\\right)-\\frac{\\kappa ^2 \\text{z0q}^2
   \\left(\\text{Sq}^2 \\text{$\\tau $Dq}+\\tau \\right)}{2 \\text{Sq}^2 \
\\text{$\\tau $Dq}+\\tau }\\right)\\right)}{(\\tau +2
   \\text{$\\tau $Dq}) \\sqrt{\\text{z0q}^2 \\left(\\frac{\\tau \
}{\\text{Sq}^2 \\text{$\\tau $Dq}}+2\\right)}}\
\>", "Output",
 CellChangeTimes->{{3.520253609815428*^9, 3.520253619432271*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["assigning the no-flow case", "Section",
 CellChangeTimes->{{3.520238964204406*^9, 3.52023897019488*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"G1noflow", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"z0q", "^", "2"}]}], " ", 
          RowBox[{"\[Kappa]", "^", "2"}]}], ")"}]}], "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"z0q", "^", "2"}], " ", 
              RowBox[{"\[Kappa]", "^", "2"}], " ", 
              RowBox[{"(", 
               RowBox[{"\[Tau]", "+", 
                RowBox[{
                 RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", 
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
           ")"}]}], ")"}]}]}], ")"}], " ", "N", " ", "z0q", " ", "\[Tau]Dq"}],
     ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"z0q", "^", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"\[Tau]", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}], ")"}]}]}], ")"}]}], 
      "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.519375313616087*^9, 3.5193753195442038`*^9}, {
  3.519534192344968*^9, 3.519534199039291*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]]}], ")"}], " ", 
   "N", " ", "z0q", " ", "\[Tau]Dq"}], 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       FractionBox["\[Tau]", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.520238974340892*^9, 3.520239111960196*^9, 3.520246576002173*^9, {
   3.520253609863162*^9, 3.520253619465988*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["division", "Section",
 CellChangeTimes->{{3.520239115103595*^9, 3.520239117205905*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Gfinal1", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"G1t", "[", "\[Tau]", "]"}], "/", 
     RowBox[{"G1noflow", "[", "\[Tau]", "]"}]}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519534489316717*^9, 3.519534514418784*^9}, {
  3.520239242012629*^9, 3.520239249237952*^9}, {3.520239291002108*^9, 
  3.5202392996736603`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "q"}], " ", 
     SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
       FractionBox[
        SuperscriptBox["Sq", "2"], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
       RowBox[{"\[Tau]", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}]}], ")"}]}], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"]}]], "+", 
   SuperscriptBox["\[ExponentialE]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      SuperscriptBox["\[Kappa]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"\[Tau]", "+", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]]}]]], "Output",
 CellChangeTimes->{
  3.5202391214019423`*^9, 3.5202392508855247`*^9, 3.520239300745945*^9, 
   3.52024657753496*^9, {3.520253610891633*^9, 3.520253619499902*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplification of G2", "Title",
 CellChangeTimes->{{3.520237212163966*^9, 3.5202372241859827`*^9}, 
   3.5202399883166018`*^9}],

Cell[CellGroupData[{

Cell["Assumptions", "Section",
 CellChangeTimes->{{3.519097759869207*^9, 3.5190977785960703`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Element", "[", 
     RowBox[{"w0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"b", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"Aq0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Tau]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"cm", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"Dd", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"q", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Kappa]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Dd", ">", "0"}], "&&", 
    RowBox[{"\[Tau]", ">", "0"}], "&&", 
    RowBox[{"w0", ">", "0"}], "&&", 
    RowBox[{"z0", ">", "0"}], "&&", 
    RowBox[{"Aq0", ">", "0"}], "&&", 
    RowBox[{"q", "\[GreaterEqual]", "1"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"vr", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"vz", ",", "Reals"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.519097780783361*^9, 3.519097783919778*^9}, 
   3.5191029105091476`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"b", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Aq0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"\[Tau]", "\[Element]", "Reals"}], "&&", 
   RowBox[{"cm", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Dd", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"q", "\[Element]", "Reals"}], "&&", 
   RowBox[{"\[Kappa]", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Dd", ">", "0"}], "&&", 
   RowBox[{"\[Tau]", ">", "0"}], "&&", 
   RowBox[{"w0", ">", "0"}], "&&", 
   RowBox[{"z0", ">", "0"}], "&&", 
   RowBox[{"Aq0", ">", "0"}], "&&", 
   RowBox[{"q", "\[GreaterEqual]", "1"}], "&&", 
   RowBox[{"vr", "\[Element]", "Reals"}], "&&", 
   RowBox[{"vz", "\[Element]", "Reals"}]}], "}"}]], "Output",
 CellChangeTimes->{3.519097785842445*^9, 3.519098734981737*^9, 
  3.5191616912762346`*^9, 3.519325860368703*^9, 3.51956702706219*^9, 
  3.5196240459598093`*^9, 3.520112769925209*^9, 3.520236738788871*^9, 
  3.5202385120120277`*^9, 3.5202412661244907`*^9, 3.520243410144566*^9, 
  3.5202469370406733`*^9, 3.520253587904265*^9, 3.520253650585032*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"myexpsimplification", "[", "myinput_", "]"}], ":=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"myinput", ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"Simplify", "[", "form", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5202360002762136`*^9, 3.52023604787567*^9}, 
   3.520236085810807*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myexpsimplification", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["cm", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "4"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}], "+", 
             RowBox[{"4", " ", "q", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
              "\[Tau]"}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["q", "2"], " ", 
              SuperscriptBox["vz", "2"], " ", 
              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "q"], "+", 
         RowBox[{"2", " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"12", " ", "Dd", " ", 
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{"q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["vr", "2"]}], "+", 
               RowBox[{"16", " ", "Dd", " ", "\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                  RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], 
              ")"}], " ", "\[Tau]"}], "+", 
            RowBox[{"8", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "vz", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], 
         RowBox[{
          RowBox[{"3", " ", "q", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", 
           SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
            RowBox[{
            "4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", "\[Tau]"}]}],
            ")"}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
             RowBox[{"q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
              "\[Tau]"}]}], ")"}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}],
        "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0", "2"], " ", "\[Kappa]"}], "+", 
             RowBox[{"q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", "\[ImaginaryI]", " ", "vz"}], "+", 
                RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
              "\[Tau]"}]}], ")"}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]]}]}], ")"}], " ", 
     SuperscriptBox["\[Pi]", "3"], " ", 
     SuperscriptBox["w0", "6"], " ", 
     SuperscriptBox["z0", "3"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox["q", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], ")"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.520235926681065*^9, 3.520235968747425*^9}, {
   3.520236057184128*^9, 3.520236103040358*^9}, {3.520236152737315*^9, 
   3.520236155726829*^9}, 3.520238278017208*^9, 3.520238500598899*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "4"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", 
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["q", "2"], " ", 
              SuperscriptBox["vz", "2"], " ", 
              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "q", " ", 
              SuperscriptBox["vr", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"32", " ", 
              SuperscriptBox["Dd", "2"], " ", "q", " ", 
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["z0", "4"], " ", 
                 SuperscriptBox["\[Kappa]", "2"]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["q", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["vr", "2"], "+", 
                   SuperscriptBox["vz", "2"]}], ")"}], " ", 
                 SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["w0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0", "4"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}], "+", 
             RowBox[{"2", " ", "q", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
                RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
              "\[Tau]"}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["q", "2"], " ", 
              SuperscriptBox["vz", "2"], " ", 
              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "q", " ", 
              SuperscriptBox["vr", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"16", " ", 
              SuperscriptBox["Dd", "2"], " ", "q", " ", 
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["z0", "4"], " ", 
                 SuperscriptBox["\[Kappa]", "2"]}], "-", 
                RowBox[{"2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                 SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
                "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["q", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["vr", "2"], "+", 
                   SuperscriptBox["vz", "2"]}], ")"}], " ", 
                 SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["w0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0", "4"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}], "+", 
             RowBox[{"2", " ", "q", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
              "\[Tau]"}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["q", "2"], " ", 
              SuperscriptBox["vz", "2"], " ", 
              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "q", " ", 
              SuperscriptBox["vr", "2"], " ", 
              SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"16", " ", 
              SuperscriptBox["Dd", "2"], " ", "q", " ", 
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", "Dd", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["z0", "4"], " ", 
                 SuperscriptBox["\[Kappa]", "2"]}], "+", 
                RowBox[{"2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                 SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
                "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["q", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["vr", "2"], "+", 
                   SuperscriptBox["vz", "2"]}], ")"}], " ", 
                 SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["w0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["vz", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"4", " ", "Dd", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["z0", "4"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}], "-", 
               RowBox[{"4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
               "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["q", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  SuperscriptBox["vz", "2"]}], ")"}], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SuperscriptBox["w0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{"4", " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
               RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
             "\[Tau]"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["vz", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["Dd", "2"], " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"4", " ", "Dd", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["z0", "4"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}], "+", 
               RowBox[{"4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
               "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["q", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  SuperscriptBox["vz", "2"]}], ")"}], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
     ")"}], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "6"], " ", 
    SuperscriptBox["z0", "3"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.520235969428918*^9, {3.520236069853796*^9, 3.52023610381421*^9}, 
   3.520236156450061*^9, 3.5202382788839693`*^9, {3.520238502134224*^9, 
   3.520238518052491*^9}, 3.5202412666089087`*^9, 3.520243410630189*^9, 
   3.520246937497213*^9, 3.520253588153311*^9, 3.520253650761585*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im ersten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520236209163476*^9, 3.520236213281708*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term1", "=", 
  RowBox[{"FullSimplify", "[", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SuperscriptBox["w0", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "4"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["q", "2"], " ", 
         SuperscriptBox["vz", "2"], " ", 
         SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "-", 
     RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "q", " ", 
         SuperscriptBox["vr", "2"], " ", 
         SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"32", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"4", " ", "Dd", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
    RowBox[{"q", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0", "2"]}], "+", 
       RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.520236197076613*^9, 3.5202362231995287`*^9}, {
   3.5202363745485086`*^9, 3.520236391566465*^9}, {3.520236456646641*^9, 
   3.520236459038261*^9}, 3.520238549342306*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"9", " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "4"], " ", 
     SuperscriptBox["\[Kappa]", "2"]}], "+", 
    RowBox[{"24", " ", "Dd", " ", "q", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       SuperscriptBox["z0", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["vz", "2"], " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["vr", "2"]}], "+", 
          RowBox[{"32", " ", 
           SuperscriptBox["Dd", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox["\[Tau]", "2"]}], "+", 
    RowBox[{"16", " ", "Dd", " ", 
     SuperscriptBox["q", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["vr", "2"], "+", 
       SuperscriptBox["vz", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Tau]", "3"]}]}], 
   RowBox[{"q", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.5202362244372463`*^9, {3.520236381506599*^9, 3.520236392378119*^9}, 
   3.520236470082122*^9, 3.52023674625251*^9, 3.5202385514747066`*^9, 
   3.520241266964636*^9, 3.520243410996114*^9, 3.520246937841213*^9, 
   3.520253588174403*^9, 3.520253650793284*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im zweiten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520236242627125*^9, 3.52023624600128*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["w0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "+", 
         RowBox[{"2", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
            RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
          "\[Tau]"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["vz", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"16", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "-", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], ")"}]}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.520236256195423*^9, 3.520236261327833*^9}, {
   3.520236461752304*^9, 3.52023646301486*^9}, 3.520238607069332*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SuperscriptBox["w0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       RowBox[{"2", " ", "q", " ", 
        SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
          RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}],
        "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["q", "2"], " ", 
        SuperscriptBox["vz", "2"], " ", 
        SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "Dd", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       RowBox[{"q", " ", 
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["vr", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[ImaginaryI]", " ", "vz"}], "-", 
             RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}], 
        " ", "\[Tau]"}], "-", 
       RowBox[{"8", " ", "Dd", " ", 
        SuperscriptBox["q", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["vr", "2"], "+", 
          SuperscriptBox["vz", "2"]}], ")"}], " ", 
        SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"q", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.520236262401347*^9, 3.520236472452134*^9, 
  3.520238608612049*^9, 3.520241267554532*^9, 3.5202434115798197`*^9, 
  3.520246938383793*^9, 3.520253588203807*^9, 3.5202536508598833`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"], "vz", "*", "2", " ", "q", " ", 
       SuperscriptBox["z0", "2"], " ", "\[Kappa]", "*", "\[Tau]"}], "+", 
      RowBox[{"2", " ", "q", " ", "\[Tau]", "*", "q", " ", 
       SuperscriptBox["z0", "2"], " ", "*", "8", " ", "Dd", " ", "\[Kappa]", 
       " ", "*", "vz", "*", " ", "\[Tau]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], ")"}]}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.5202368449446507`*^9, 3.520236845824264*^9}, 
   3.5202368764744053`*^9, {3.520237269460312*^9, 3.52023728133043*^9}, {
   3.5202386159749804`*^9, 3.520238629036304*^9}, {3.52023870899823*^9, 
   3.5202388333973303`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "vz", " ", 
   SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["z0", "2"]}], "+", 
   RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]], "Output",
 CellChangeTimes->{
  3.520237284003077*^9, {3.5202386202762747`*^9, 3.5202386294245567`*^9}, 
   3.520238834079586*^9, 3.520241267590859*^9, 3.520243411645727*^9, 
   3.520246938477656*^9, 3.520253588239349*^9, 3.5202536509261208`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"term2", "-", 
    RowBox[{"I", "*", "im2"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520237291166688*^9, 3.520237307714487*^9}, {
  3.520238843450965*^9, 3.52023885166718*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["w0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       RowBox[{"4", " ", "Dd", " ", "q", " ", 
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["q", "2"], " ", 
        SuperscriptBox["vz", "2"], " ", 
        SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "Dd", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       RowBox[{"q", " ", 
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["vr", "2"]}], "+", 
          RowBox[{"16", " ", 
           SuperscriptBox["Dd", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
       RowBox[{"8", " ", "Dd", " ", 
        SuperscriptBox["q", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["vr", "2"], "+", 
          SuperscriptBox["vz", "2"]}], ")"}], " ", 
        SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
   RowBox[{"q", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.520237308384087*^9, 3.520238852784091*^9, 
  3.520241267905554*^9, 3.5202434119523582`*^9, 3.520246938784667*^9, 
  3.52025358827092*^9, 3.520253650993713*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im dritten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520236298938504*^9, 3.520236302487431*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term3", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["w0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "+", 
         RowBox[{"2", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
            RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
          "\[Tau]"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["vz", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"16", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], ")"}]}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.520236304153289*^9, 3.52023631935196*^9}, {
   3.520236465271242*^9, 3.520236466366663*^9}, 3.520238932096384*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SuperscriptBox["w0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["z0", "4"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "+", 
      RowBox[{"2", " ", "q", " ", 
       SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
         RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["q", "2"], " ", 
       SuperscriptBox["vz", "2"], " ", 
       SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
   RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", "Dd", " ", 
       SuperscriptBox["z0", "4"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "-", 
      RowBox[{"q", " ", 
       SuperscriptBox["z0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["vr", "2"]}], "+", 
         RowBox[{"8", " ", "Dd", " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
            RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}], 
       " ", "\[Tau]"}], "-", 
      RowBox[{"8", " ", "Dd", " ", 
       SuperscriptBox["q", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["vr", "2"], "+", 
         SuperscriptBox["vz", "2"]}], ")"}], " ", 
       SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
  RowBox[{"q", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["w0", "2"]}], "+", 
     RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["z0", "2"]}], "+", 
     RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.520236320367569*^9, 3.520236474887555*^9, 
  3.520238933388837*^9, 3.520241268423123*^9, 3.5202434124010553`*^9, 
  3.520246939269209*^9, 3.5202535883044167`*^9, 3.5202536510275583`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im3", "=", 
  RowBox[{"-", "im2"}]}]], "Input",
 CellChangeTimes->{{3.520238945099564*^9, 3.5202389811669893`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "vz", " ", 
    SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["z0", "2"]}], "+", 
    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], "Output",
 CellChangeTimes->{3.5202389833432417`*^9, 3.520241268446697*^9, 
  3.52024341241527*^9, 3.520246939295686*^9, 3.520253588337347*^9, 
  3.520253651059691*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re3", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"term3", "-", 
    RowBox[{"I", "*", "im3"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520238987369052*^9, 3.52023899815956*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["w0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       RowBox[{"4", " ", "Dd", " ", "q", " ", 
        SuperscriptBox["z0", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["q", "2"], " ", 
        SuperscriptBox["vz", "2"], " ", 
        SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "Dd", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       RowBox[{"q", " ", 
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["vr", "2"]}], "+", 
          RowBox[{"16", " ", 
           SuperscriptBox["Dd", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
       RowBox[{"8", " ", "Dd", " ", 
        SuperscriptBox["q", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["vr", "2"], "+", 
          SuperscriptBox["vz", "2"]}], ")"}], " ", 
        SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
   RowBox[{"q", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.520238998935872*^9, 3.520241268476529*^9, 
  3.5202434124492807`*^9, 3.5202469393296213`*^9, 3.520253588371067*^9, 
  3.5202536510966387`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im vierten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520239028096367*^9, 3.520239037326387*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term4", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["w0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "+", 
         RowBox[{"4", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
            RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
          "\[Tau]"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["vz", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "-", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], ")"}]}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.520239040724605*^9, 3.520239059528193*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SuperscriptBox["w0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       RowBox[{"4", " ", "q", " ", 
        SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
          RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}],
        "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["q", "2"], " ", 
        SuperscriptBox["vz", "2"], " ", 
        SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "Dd", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       RowBox[{"q", " ", 
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["vr", "2"]}], "+", 
          RowBox[{"16", " ", "Dd", " ", "\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[ImaginaryI]", " ", "vz"}], "-", 
             RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}], 
        " ", "\[Tau]"}], "-", 
       RowBox[{"8", " ", "Dd", " ", 
        SuperscriptBox["q", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["vr", "2"], "+", 
          SuperscriptBox["vz", "2"]}], ")"}], " ", 
        SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"q", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.52023906073181*^9, 3.5202412690380297`*^9, 
  3.520243412995144*^9, 3.520246939852566*^9, 3.520253588404293*^9, 
  3.520253651134494*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im4", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"], " ", "*", "4", " ", "q", " ", 
       SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "*", "vz", "*", 
       "\[Tau]"}], "+", 
      RowBox[{"2", " ", "q", " ", "\[Tau]", "*", "q", " ", 
       SuperscriptBox["z0", "2"], "*", "16", " ", "Dd", " ", "\[Kappa]", "*", 
       "vz", "*", "\[Tau]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], ")"}]}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.5202390837627783`*^9, 3.520239097240176*^9}, {
  3.520239157437709*^9, 3.520239247825962*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", "vz", " ", 
   SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["z0", "2"]}], "+", 
   RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]], "Output",
 CellChangeTimes->{3.520239248583332*^9, 3.5202412690946627`*^9, 
  3.520243413065207*^9, 3.520246939929873*^9, 3.520253588437666*^9, 
  3.5202536511603518`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re4", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"term4", "-", 
    RowBox[{"I", "*", "im4"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5202392524891367`*^9, 3.5202392640276213`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "4"], " ", 
     SuperscriptBox["\[Kappa]", "2"]}], "+", 
    RowBox[{"8", " ", "Dd", " ", "q", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       SuperscriptBox["z0", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["vz", "2"], " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["vr", "2"]}], "+", 
          RowBox[{"32", " ", 
           SuperscriptBox["Dd", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox["\[Tau]", "2"]}], "+", 
    RowBox[{"16", " ", "Dd", " ", 
     SuperscriptBox["q", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["vr", "2"], "+", 
       SuperscriptBox["vz", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Tau]", "3"]}]}], 
   RowBox[{"q", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.520239264949192*^9, 3.520241269281362*^9, 
  3.520243413244055*^9, 3.520246940108637*^9, 3.520253588471114*^9, 
  3.520253651194635*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im f\[UDoubleDot]nften exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520239279599411*^9, 3.520239284245871*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term5", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["w0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "+", 
         RowBox[{"4", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
            RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
          "\[Tau]"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["vz", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "q", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], ")"}]}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.5202392875470552`*^9, 3.520239311454064*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SuperscriptBox["w0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       RowBox[{"4", " ", "q", " ", 
        SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
          RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}],
        "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["q", "2"], " ", 
        SuperscriptBox["vz", "2"], " ", 
        SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "Dd", " ", 
        SuperscriptBox["z0", "4"], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "-", 
       RowBox[{"q", " ", 
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["vr", "2"]}], "+", 
          RowBox[{"16", " ", "Dd", " ", "\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
             RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}], 
        " ", "\[Tau]"}], "-", 
       RowBox[{"8", " ", "Dd", " ", 
        SuperscriptBox["q", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["vr", "2"], "+", 
          SuperscriptBox["vz", "2"]}], ")"}], " ", 
        SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"q", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.520239313132818*^9, 3.520241269809012*^9, 
  3.520243413776732*^9, 3.520246940601445*^9, 3.520253588591317*^9, 
  3.520253651262762*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im5", "=", 
  RowBox[{"-", "im4"}]}]], "Input",
 CellChangeTimes->{{3.520239317116096*^9, 3.520239320543622*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", "vz", " ", 
    SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["z0", "2"]}], "+", 
    RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], "Output",
 CellChangeTimes->{3.520239321773467*^9, 3.520241269832941*^9, 
  3.520243413800065*^9, 3.5202469406189327`*^9, 3.520253588608076*^9, 
  3.520253651330679*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re5", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"term5", "-", 
    RowBox[{"I", "*", "im5"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520239325212759*^9, 3.52023933499199*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "4"], " ", 
     SuperscriptBox["\[Kappa]", "2"]}], "+", 
    RowBox[{"8", " ", "Dd", " ", "q", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       SuperscriptBox["z0", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["vz", "2"], " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["vr", "2"]}], "+", 
          RowBox[{"32", " ", 
           SuperscriptBox["Dd", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox["\[Tau]", "2"]}], "+", 
    RowBox[{"16", " ", "Dd", " ", 
     SuperscriptBox["q", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["vr", "2"], "+", 
       SuperscriptBox["vz", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Tau]", "3"]}]}], 
   RowBox[{"q", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.520239335713211*^9, 3.520241269862797*^9, 
  3.520243413835601*^9, 3.520246940650392*^9, 3.5202535886408377`*^9, 
  3.5202536513942223`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["combination of the terms", "Section",
 CellChangeTimes->{{3.52023737593359*^9, 3.520237379972723*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"combination", "=", 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", "term1", ")"}]}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", "re2", ")"}]}], "*", 
       RowBox[{"ExpToTrig", "[", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"I", "*", "im2"}], ")"}]}], "+", 
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"I", "*", "im3"}], ")"}]}]}], ")"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"E", "^", 
        RowBox[{"(", "re4", ")"}]}], "*", 
       RowBox[{"ExpToTrig", "[", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"I", "*", "im4"}], ")"}]}], "+", 
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"I", "*", "im5"}], ")"}]}]}], ")"}], "]"}]}]}], ")"}], 
    "]"}], "*", 
   SuperscriptBox["\[Pi]", "3"], " ", 
   SuperscriptBox["w0", "6"], " ", 
   RowBox[{
    SuperscriptBox["z0", "3"], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox["q", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["z0", "2"]}], "+", 
        RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.520237414824924*^9, 3.520237435196871*^9}, {
   3.5202374720289183`*^9, 3.520237478178241*^9}, {3.520237558729875*^9, 
   3.5202375610005302`*^9}, {3.520239440164752*^9, 3.520239448715104*^9}, {
   3.520239628620366*^9, 3.520239750558869*^9}, {3.52023979131948*^9, 
   3.520239821115542*^9}, 3.52023985249104*^9, 3.5202412803154593`*^9, {
   3.5202413132038937`*^9, 3.5202413239886427`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "6"], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"24", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["w0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["vr", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
            
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{"16", " ", "Dd", " ", 
            SuperscriptBox["q", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "3"]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["q", "2"], " ", 
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "Dd", " ", 
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["vr", "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}],
               "+", 
              RowBox[{"8", " ", "Dd", " ", 
               SuperscriptBox["q", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["vr", "2"], "+", 
                 SuperscriptBox["vz", "2"]}], ")"}], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]],
        " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"2", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "]"}]}], "+", 
      
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["w0", "2"]}], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["w0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["vr", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
            
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{"16", " ", "Dd", " ", 
            SuperscriptBox["q", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "3"]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]],
        " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"4", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "]"}]}]}], 
     ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.520239722924684*^9, 3.520239751704389*^9}, 
   3.520239853239217*^9, {3.520241269879414*^9, 3.5202412814182463`*^9}, 
   3.520241326225669*^9, 3.520243415707716*^9, 3.5202469424848213`*^9, 
   3.520253588671781*^9, 3.5202536514619083`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"combinationplus", "=", 
  RowBox[{"Simplify", "[", "combination", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "6"], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"24", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["w0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["vr", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
            
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{"16", " ", "Dd", " ", 
            SuperscriptBox["q", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "3"]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["q", "2"], " ", 
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "Dd", " ", 
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["vr", "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}],
               "+", 
              RowBox[{"8", " ", "Dd", " ", 
               SuperscriptBox["q", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["vr", "2"], "+", 
                 SuperscriptBox["vz", "2"]}], ")"}], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]],
        " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"2", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "]"}]}], "+", 
      
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["w0", "2"]}], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["w0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["vr", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
            
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{"16", " ", "Dd", " ", 
            SuperscriptBox["q", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "3"]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]],
        " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"4", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "]"}]}]}], 
     ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5202412968474503`*^9, 3.520241334040923*^9, 
  3.5202434165715322`*^9, 3.5202469433603697`*^9, 3.520253588705305*^9, 
  3.520253651498206*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g2", "[", "\[Tau]_", "]"}], "=", "combinationplus"}]], "Input",
 CellChangeTimes->{{3.5202413497369843`*^9, 3.520241355617032*^9}, {
  3.520243421960579*^9, 3.520243422678643*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "6"], " ", 
    SuperscriptBox["z0", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"24", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["w0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["vr", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
            
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{"16", " ", "Dd", " ", 
            SuperscriptBox["q", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "3"]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"4", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["q", "2"], " ", 
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "Dd", " ", 
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["vr", "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}]}], ")"}], " ", "\[Tau]"}],
               "+", 
              RowBox[{"8", " ", "Dd", " ", 
               SuperscriptBox["q", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["vr", "2"], "+", 
                 SuperscriptBox["vz", "2"]}], ")"}], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]],
        " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"2", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "]"}]}], "+", 
      
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"8", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["w0", "2"]}], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["w0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["vr", "2"]}], "+", 
                 RowBox[{"32", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
            
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{"16", " ", "Dd", " ", 
            SuperscriptBox["q", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "3"]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["w0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["z0", "2"]}], "+", 
             RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]],
        " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"4", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["z0", "2"]}], "+", 
          RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "]"}]}]}], 
     ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["w0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["z0", "2"]}], "+", 
      RowBox[{"8", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.520241356585251*^9, {3.5202434165909243`*^9, 3.520243423290986*^9}, 
   3.520246943391672*^9, 3.520253588739422*^9, 3.520253651531372*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define some replacement-formulas for simplification", "Section",
 CellChangeTimes->{{3.519225761123719*^9, 3.51922576749866*^9}, {
  3.519227847963977*^9, 3.519227866401497*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"z0qexp", "=", 
  RowBox[{"{", 
   RowBox[{"z0", "\[Rule]", 
    RowBox[{"z0q", "*", 
     RowBox[{"Sqrt", "[", "q", "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"w0qexp", "=", 
  RowBox[{"{", 
   RowBox[{"w0", "\[Rule]", 
    RowBox[{"w0q", "*", 
     RowBox[{"Sqrt", "[", "q", "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Nexp", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"cm", "\[Rule]", 
     RowBox[{"N", "*", 
      RowBox[{
       RowBox[{"q", "^", 
        RowBox[{"(", 
         RowBox[{"3", "/", "2"}], ")"}]}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Pi]", "^", 
          RowBox[{"(", 
           RowBox[{"3", "/", "2"}], ")"}]}], "*", 
         RowBox[{"w0", "^", "2"}], "*", "z0"}], ")"}]}]}]}], ",", 
    RowBox[{"cm", "\[Rule]", 
     RowBox[{"N", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Pi]", "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}], "*", 
        RowBox[{"w0q", "^", "2"}], "*", "z0q"}], ")"}]}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"tauDexp", "=", 
  RowBox[{"{", 
   RowBox[{"Dd", "\[Rule]", " ", 
    RowBox[{
     RowBox[{"w0q", "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", "*", "\[Tau]Dq"}], ")"}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"sparamexp", " ", "=", 
  RowBox[{"{", 
   RowBox[{"w0q", "\[Rule]", 
    RowBox[{"z0q", "/", "Sq"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"taufrexp", "=", 
  RowBox[{"{", 
   RowBox[{"vr", "\[Rule]", 
    RowBox[{"w0", "/", "\[Tau]fr"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"taufzexp", "=", 
  RowBox[{"{", 
   RowBox[{"vz", "\[Rule]", 
    RowBox[{"z0", "/", "\[Tau]fz"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"allexp", " ", "=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{
   "z0qexp", ",", "w0qexp", ",", "Nexp", ",", "tauDexp", ",", "sparamexp", 
    ",", "taufrexp", ",", " ", "taufzexp"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allexpreplace", "[", "e_", "]"}], ":=", 
  RowBox[{"ReplaceRepeated", "[", 
   RowBox[{"e", ",", "allexp"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"dividerToGetToG", "=", 
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "N"}]}]}], "Input",
 CellChangeTimes->{{3.5192278796347857`*^9, 3.51922788373866*^9}, {
   3.5192280404721327`*^9, 3.5192280865816793`*^9}, {3.519228235085371*^9, 
   3.519228453356268*^9}, {3.519228486264221*^9, 3.519228543561183*^9}, {
   3.5192286432937593`*^9, 3.519228650816778*^9}, {3.519228741300831*^9, 
   3.51922874432421*^9}, {3.5192330404786386`*^9, 3.519233075199617*^9}, {
   3.51923311113347*^9, 3.519233156785954*^9}, {3.519233336131023*^9, 
   3.519233460274477*^9}, {3.519233502449368*^9, 3.5192335663150063`*^9}, {
   3.5192340194292088`*^9, 3.5192340197572527`*^9}, {3.519234120625125*^9, 
   3.519234145800989*^9}, {3.519234472314494*^9, 3.519234483344946*^9}, {
   3.519235101453726*^9, 3.519235104749152*^9}, 3.519235136013392*^9, {
   3.519235234935113*^9, 3.519235236259161*^9}, {3.519236384687229*^9, 
   3.519236384966714*^9}, {3.519325426318248*^9, 3.5193254362177763`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"z0", "\[Rule]", 
   RowBox[{
    SqrtBox["q"], " ", "z0q"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.520246943420154*^9, 
   3.5202535887709837`*^9, 3.520253651564456*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"w0", "\[Rule]", 
   RowBox[{
    SqrtBox["q"], " ", "w0q"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.520246943420154*^9, 
   3.5202535887709837`*^9, 3.520253651566111*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cm", "\[Rule]", 
    FractionBox[
     RowBox[{"N", " ", 
      SuperscriptBox["q", 
       RowBox[{"3", "/", "2"}]]}], 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0", "2"], " ", "z0"}]]}], ",", 
   RowBox[{"cm", "\[Rule]", 
    FractionBox["N", 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0q", "2"], " ", "z0q"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.520246943420154*^9, 
   3.5202535887709837`*^9, 3.5202536515674343`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Dd", "\[Rule]", 
   FractionBox[
    SuperscriptBox["w0q", "2"], 
    RowBox[{"4", " ", "\[Tau]Dq"}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.520246943420154*^9, 
   3.5202535887709837`*^9, 3.520253651568766*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"w0q", "\[Rule]", 
   FractionBox["z0q", "Sq"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.520246943420154*^9, 
   3.5202535887709837`*^9, 3.5202536515699787`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"vr", "\[Rule]", 
   FractionBox["w0", "\[Tau]fr"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.520246943420154*^9, 
   3.5202535887709837`*^9, 3.520253651571135*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"vz", "\[Rule]", 
   FractionBox["z0", "\[Tau]fz"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.520246943420154*^9, 
   3.5202535887709837`*^9, 3.520253651572348*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"z0", "\[Rule]", 
    RowBox[{
     SqrtBox["q"], " ", "z0q"}]}], ",", 
   RowBox[{"w0", "\[Rule]", 
    RowBox[{
     SqrtBox["q"], " ", "w0q"}]}], ",", 
   RowBox[{"cm", "\[Rule]", 
    FractionBox[
     RowBox[{"N", " ", 
      SuperscriptBox["q", 
       RowBox[{"3", "/", "2"}]]}], 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0", "2"], " ", "z0"}]]}], ",", 
   RowBox[{"cm", "\[Rule]", 
    FractionBox["N", 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0q", "2"], " ", "z0q"}]]}], ",", 
   RowBox[{"Dd", "\[Rule]", 
    FractionBox[
     SuperscriptBox["w0q", "2"], 
     RowBox[{"4", " ", "\[Tau]Dq"}]]}], ",", 
   RowBox[{"w0q", "\[Rule]", 
    FractionBox["z0q", "Sq"]}], ",", 
   RowBox[{"vr", "\[Rule]", 
    FractionBox["w0", "\[Tau]fr"]}], ",", 
   RowBox[{"vz", "\[Rule]", 
    FractionBox["z0", "\[Tau]fz"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.520246943420154*^9, 
   3.5202535887709837`*^9, 3.5202536515736523`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Aq0", "2"], " ", 
  SuperscriptBox["chi", "2"], " ", "N"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.520246943420154*^9, 
   3.5202535887709837`*^9, 3.520253651575082*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"G2t", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"allexpreplace", "[", 
     RowBox[{
      RowBox[{"g2", "[", "\[Tau]", "]"}], "/", 
      RowBox[{"dividerToGetToG", "^", "2"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.52024222171069*^9, 3.5202422221489477`*^9}, {
  3.520243439284052*^9, 3.52024344209485*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        FractionBox[
         RowBox[{"2", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "\[Tau]"}], "+", 
      RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"5", " ", 
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["\[Tau]", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["Sq", "2"]}]}], ")"}], " ", "\[Tau]", " ", 
           "\[Tau]Dq"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", 
           SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
        SuperscriptBox["\[Tau]fr", "2"], " ", 
        SuperscriptBox["\[Tau]fz", "2"]}], "+", 
       RowBox[{"2", " ", "q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]", " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[Tau]", " ", 
              SuperscriptBox["\[Tau]fr", "2"]}], "+", 
             RowBox[{"3", " ", "\[Tau]Dq", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["\[Tau]fr", "2"], "+", 
                SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fr", "2"], " ", 
       SuperscriptBox["\[Tau]fz", "2"]}]]}]], " ", "z0q", " ", "\[Tau]Dq", 
   " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Tau]"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"2", " ", "\[Tau]"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Tau]"}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"4", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.520242219208866*^9, 3.520242226140377*^9}, 
   3.520243446964974*^9, 3.520246947549204*^9, 3.520253588807873*^9, 
   3.520253651596476*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myexpsimplification", "[", 
  RowBox[{"G2t", "[", "\[Tau]", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.520246931683627*^9, 3.520246931772641*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        FractionBox[
         RowBox[{"2", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "\[Tau]"}], "+", 
      RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{"z0q", " ", "\[Tau]Dq", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{"6", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
             "\[Tau]Dq"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Sq", "2"], " ", 
             SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}], "+", 
         RowBox[{"2", " ", "q", " ", 
          SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]", " ", 
             SuperscriptBox["\[Tau]fz", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "\[Tau]", " ", 
                SuperscriptBox["\[Tau]fr", "2"]}], "+", 
               RowBox[{"3", " ", "\[Tau]Dq", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Tau]fr", "2"], "+", 
                  SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fr", "2"], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["\[Tau]", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["Sq", "2"]}]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"3", " ", "\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SuperscriptBox["\[Tau]", "2"]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"3", " ", "\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"4", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.5202469321803503`*^9, 3.52024694782981*^9}, 
   3.520253588860108*^9, 3.520253651677538*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TeXForm", "[", 
  RowBox[{"myexpsimplification", "[", 
   RowBox[{"G2t", "[", "\[Tau]", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.520253582990769*^9, 3.5202535830589046`*^9}}],

Cell["\<\
\\frac{\\text{$\\tau $Dq} \\text{z0q} \\left(\\exp \\left(-\\frac{2 q \\tau \
^2 \\text{$\\tau $Dq} \\left(\\text{Sq}^2 \\left(2
   \\tau  \\text{$\\tau $fr}^2+3 \\text{$\\tau $Dq} \\left(\\text{$\\tau \
$fr}^2+\\text{$\\tau $fz}^2\\right)\\right)+2 \\tau 
   \\text{$\\tau $fz}^2\\right)+\\kappa ^2 \\text{$\\tau $fr}^2 \\text{$\\tau \
$fz}^2 \\text{z0q}^2 \\left(6
   \\left(\\text{Sq}^2+1\\right) \\tau  \\text{$\\tau $Dq}+9 \\text{Sq}^2 \
\\text{$\\tau $Dq}^2+4 \\tau ^2\\right)}{\\text{$\\tau
   $fr}^2 \\text{$\\tau $fz}^2 (2 \\tau +3 \\text{$\\tau $Dq}) \\left(3 \
\\text{Sq}^2 \\text{$\\tau $Dq}+2 \\tau
   \\right)}\\right)+2 \\cos \\left(\\frac{2 \\kappa  \\sqrt{q} \\text{Sq}^2 \
\\tau  \\text{$\\tau $Dq} \\text{z0q}}{3
   \\text{Sq}^2 \\text{$\\tau $Dq} \\text{$\\tau $fz}+2 \\tau  \\text{$\\tau \
$fz}}\\right) \\exp \\left(-\\frac{2 q \\tau ^2
   \\text{$\\tau $Dq} \\left(\\text{Sq}^2 \\left(2 \\tau  \\text{$\\tau \
$fr}^2+3 \\text{$\\tau $Dq} \\left(\\text{$\\tau
   $fr}^2+\\text{$\\tau $fz}^2\\right)\\right)+2 \\tau  \\text{$\\tau \
$fz}^2\\right)+\\kappa ^2 \\text{$\\tau $fr}^2
   \\text{$\\tau $fz}^2 \\text{z0q}^2 \\left(\\left(2 \\text{Sq}^2+3\\right) \
\\tau  \\text{$\\tau $Dq}+3 \\text{Sq}^2
   \\text{$\\tau $Dq}^2+2 \\tau ^2\\right)}{\\text{$\\tau $fr}^2 \
\\text{$\\tau $fz}^2 (2 \\tau +3 \\text{$\\tau $Dq}) \\left(3
   \\text{Sq}^2 \\text{$\\tau $Dq}+2 \\tau \\right)}\\right)+\\cos \
\\left(\\frac{4 \\kappa  \\sqrt{q} \\text{Sq}^2 \\tau 
   \\text{$\\tau $Dq} \\text{z0q}}{3 \\text{Sq}^2 \\text{$\\tau $Dq} \\text{$\
\\tau $fz}+2 \\tau  \\text{$\\tau $fz}}\\right)
   \\exp \\left(-\\frac{2 q \\tau ^2 \\text{$\\tau $Dq} \\left(\\text{Sq}^2 \
\\left(2 \\tau  \\text{$\\tau $fr}^2+3 \\text{$\\tau
   $Dq} \\left(\\text{$\\tau $fr}^2+\\text{$\\tau $fz}^2\\right)\\right)+2 \
\\tau  \\text{$\\tau $fz}^2\\right)+\\kappa ^2
   \\text{$\\tau $fr}^2 \\text{$\\tau $fz}^2 \\text{z0q}^2 \\left(2 \
\\left(\\text{Sq}^2+3\\right) \\tau  \\text{$\\tau $Dq}+3
   \\text{Sq}^2 \\text{$\\tau $Dq}^2+4 \\tau ^2\\right)}{\\text{$\\tau $fr}^2 \
\\text{$\\tau $fz}^2 (2 \\tau +3 \\text{$\\tau
   $Dq}) \\left(3 \\text{Sq}^2 \\text{$\\tau $Dq}+2 \\tau \
\\right)}\\right)\\right)}{(2 \\tau +3 \\text{$\\tau $Dq})
   \\sqrt{\\text{z0q}^2 \\left(\\frac{2 \\tau }{\\text{Sq}^2 \\text{$\\tau \
$Dq}}+3\\right)}}\
\>", "Output",
 CellChangeTimes->{3.520253589035089*^9, 3.5202536518515263`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["assigning the no-flow case", "Section",
 CellChangeTimes->{{3.520238964204406*^9, 3.52023897019488*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"G2noflow", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"z0q", "^", "2"}]}], " ", 
          RowBox[{"\[Kappa]", "^", "2"}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"z0q", "^", "2"}], " ", 
               RowBox[{"\[Kappa]", "^", "2"}], " ", 
               RowBox[{"(", 
                RowBox[{"\[Tau]", "+", 
                 RowBox[{
                  RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "\[Tau]"}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
            ")"}]}], ")"}]}]}], "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"z0q", "^", "2"}], " ", 
              RowBox[{"\[Kappa]", "^", "2"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "\[Tau]"}], "+", 
                RowBox[{
                 RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "\[Tau]"}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
           ")"}]}], ")"}]}]}], ")"}], " ", "z0q", " ", "\[Tau]Dq"}], ")"}], 
   "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"z0q", "^", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", " ", "\[Tau]"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}], ")"}]}]}], ")"}]}], 
      "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "\[Tau]"}], "+", 
       RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.519375333293635*^9, 3.519375340753675*^9}, 
   3.519375951327013*^9, 3.519534209609029*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]]}], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]]}], ")"}], " ", 
   "z0q", " ", "\[Tau]Dq"}], 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       FractionBox[
        RowBox[{"2", " ", "\[Tau]"}], 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "\[Tau]"}], "+", 
     RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.519375342028802*^9, 3.519375942687126*^9, 
  3.5193760363880796`*^9, 3.5193760869743557`*^9, 3.519376261361064*^9, 
  3.519534210754714*^9, 3.5195827008996325`*^9, 3.5202093362988997`*^9, 
  3.520241390097769*^9, 3.520243416660466*^9, 3.5202434585556183`*^9, 
  3.5202469478494883`*^9, 3.52025358908777*^9, 3.520253651881938*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["division", "Section",
 CellChangeTimes->{{3.520239115103595*^9, 3.520239117205905*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Gfinal2", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"G2t", "[", "\[Tau]", "]"}], "/", 
     RowBox[{"G2noflow", "[", "\[Tau]", "]"}]}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519534489316717*^9, 3.519534514418784*^9}, {
  3.520239242012629*^9, 3.520239249237952*^9}, {3.520239291002108*^9, 
  3.5202392996736603`*^9}, {3.5202410335797787`*^9, 3.520241040882122*^9}, {
  3.520242264692437*^9, 3.520242269811656*^9}, {3.520243470214696*^9, 
  3.520243475045635*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "q", " ", 
      SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
        FractionBox[
         SuperscriptBox["Sq", "2"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Tau]"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]", " ", "\[Tau]Dq"}], 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
        "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "\[Tau]"}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"4", " ", 
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]", " ", "\[Tau]Dq"}], 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
        "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"2", " ", "\[Tau]"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]]}], "+", 
    SuperscriptBox["\[ExponentialE]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0q", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Tau]"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"2", " ", "\[Tau]"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], "+", 
    SuperscriptBox["\[ExponentialE]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0q", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"2", " ", "\[Tau]"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]]}], ")"}]}]], "Output",\

 CellChangeTimes->{3.520242330233901*^9, 3.520243481673284*^9, 
  3.520246953086646*^9, 3.52025358910575*^9, 3.520253651913702*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplification of G3", "Title",
 CellChangeTimes->{{3.520237212163966*^9, 3.5202372241859827`*^9}, {
  3.5202395071094713`*^9, 3.520239511833795*^9}}],

Cell[CellGroupData[{

Cell["Assumptions", "Section",
 CellChangeTimes->{{3.519097759869207*^9, 3.5190977785960703`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Element", "[", 
     RowBox[{"w0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"b", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"Aq0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Tau]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"cm", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"Dd", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"q", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Kappa]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Dd", ">", "0"}], "&&", 
    RowBox[{"\[Tau]", ">", "0"}], "&&", 
    RowBox[{"w0", ">", "0"}], "&&", 
    RowBox[{"z0", ">", "0"}], "&&", 
    RowBox[{"Aq0", ">", "0"}], "&&", 
    RowBox[{"q", "\[GreaterEqual]", "1"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"vr", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"vz", ",", "Reals"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.519097780783361*^9, 3.519097783919778*^9}, 
   3.5191029105091476`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"b", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Aq0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"\[Tau]", "\[Element]", "Reals"}], "&&", 
   RowBox[{"cm", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Dd", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"q", "\[Element]", "Reals"}], "&&", 
   RowBox[{"\[Kappa]", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Dd", ">", "0"}], "&&", 
   RowBox[{"\[Tau]", ">", "0"}], "&&", 
   RowBox[{"w0", ">", "0"}], "&&", 
   RowBox[{"z0", ">", "0"}], "&&", 
   RowBox[{"Aq0", ">", "0"}], "&&", 
   RowBox[{"q", "\[GreaterEqual]", "1"}], "&&", 
   RowBox[{"vr", "\[Element]", "Reals"}], "&&", 
   RowBox[{"vz", "\[Element]", "Reals"}]}], "}"}]], "Output",
 CellChangeTimes->{3.519097785842445*^9, 3.519098734981737*^9, 
  3.5191616912762346`*^9, 3.519325860368703*^9, 3.51956702706219*^9, 
  3.5196240459598093`*^9, 3.520112769925209*^9, 3.520236738788871*^9, 
  3.52023951468224*^9, 3.5202470159798613`*^9, 3.520253419986782*^9, 
  3.520253677901742*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"myexpsimplification", "[", "myinput_", "]"}], ":=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"myinput", ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"Simplify", "[", "form", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5202360002762136`*^9, 3.52023604787567*^9}, 
   3.520236085810807*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myexpsimplification", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"128", " ", "N", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"z0q", "^", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[Tau]", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}], ")"}]}]}], ")"}]}],
         "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}], ")"}]}], ")"}], 
   RowBox[{"E", "^", 
    RowBox[{"(", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"z0q", "^", "2"}], " ", 
           RowBox[{"\[Kappa]", "^", "2"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", "\[Tau]"}], "+", 
             RowBox[{"9", " ", 
              RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
          RowBox[{"4", " ", "q", " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", "^", "2"}], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Tau]", "+", 
                  RowBox[{
                   RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
               ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
                RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Sq", "^", "2"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Tau]", "^", "2"}], "+", 
                  RowBox[{
                   RowBox[{"Sq", "^", "2"}], " ", "\[Tau]", " ", "\[Tau]Dq"}],
                   "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"Sq", "^", "4"}], " ", 
                   RowBox[{"\[Tau]Dq", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
              RowBox[{"\[Tau]fz", "^", "2"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", " ", "I", " ", 
             RowBox[{"Sqrt", "[", "q", "]"}], " ", 
             RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
             "\[Tau]Dq", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "\[Tau]"}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}],
            "/", "\[Tau]fz"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
       ")"}]}], ")"}]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", "q", " ", 
              RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq", " ", 
              RowBox[{"(", 
               RowBox[{"\[Tau]", "+", 
                RowBox[{"4", " ", 
                 RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
             
             RowBox[{"4", " ", "I", " ", 
              RowBox[{"Sqrt", "[", "q", "]"}], " ", "z0q", " ", "\[Kappa]", 
              " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "\[Tau]"}], "+", 
                RowBox[{"3", " ", 
                 RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
              "\[Tau]fz"}], "+", 
             RowBox[{"5", " ", 
              RowBox[{"z0q", "^", "2"}], " ", 
              RowBox[{"\[Kappa]", "^", "2"}], " ", 
              RowBox[{"\[Tau]fz", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}]}], "+", 
     RowBox[{"E", "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", "q", " ", 
             RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq", " ", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"4", " ", 
                RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
            RowBox[{"12", " ", "I", " ", 
             RowBox[{"Sqrt", "[", "q", "]"}], " ", 
             RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
             "\[Tau]Dq", " ", "\[Tau]fz"}], "+", 
            RowBox[{"9", " ", 
             RowBox[{"z0q", "^", "2"}], " ", 
             RowBox[{"\[Kappa]", "^", "2"}], " ", 
             RowBox[{"\[Tau]fz", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}], "+", 
     RowBox[{"E", "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", "q", " ", 
             RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq", " ", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"4", " ", 
                RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
            RowBox[{"4", " ", "I", " ", 
             RowBox[{"Sqrt", "[", "q", "]"}], " ", "z0q", " ", "\[Kappa]", 
             " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", "\[Tau]"}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
             "\[Tau]fz"}], "+", 
            RowBox[{"9", " ", 
             RowBox[{"z0q", "^", "2"}], " ", 
             RowBox[{"\[Kappa]", "^", "2"}], " ", 
             RowBox[{"\[Tau]fz", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "q", " ", 
            RowBox[{"Sq", "^", "4"}], " ", 
            RowBox[{"\[Tau]Dq", "^", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"4", " ", 
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
           RowBox[{"6", " ", "I", " ", 
            RowBox[{"Sqrt", "[", "q", "]"}], " ", 
            RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            "\[Tau]fz"}], "+", 
           RowBox[{
            RowBox[{"z0q", "^", "2"}], " ", 
            RowBox[{"\[Kappa]", "^", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"4", " ", 
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            RowBox[{"\[Tau]fz", "^", "2"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "q", " ", 
            RowBox[{"Sq", "^", "4"}], " ", 
            RowBox[{"\[Tau]Dq", "^", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"4", " ", 
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
           RowBox[{"2", " ", "I", " ", 
            RowBox[{"Sqrt", "[", "q", "]"}], " ", 
            RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"3", " ", 
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            "\[Tau]fz"}], "+", 
           RowBox[{
            RowBox[{"z0q", "^", "2"}], " ", 
            RowBox[{"\[Kappa]", "^", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"4", " ", 
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            RowBox[{"\[Tau]fz", "^", "2"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "q", " ", 
            RowBox[{"Sq", "^", "4"}], " ", 
            RowBox[{"\[Tau]Dq", "^", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"4", " ", 
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
           RowBox[{"4", " ", "I", " ", 
            RowBox[{"Sqrt", "[", "q", "]"}], " ", 
            RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "\[Tau]"}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            "\[Tau]fz"}], "+", 
           RowBox[{
            RowBox[{"z0q", "^", "2"}], " ", 
            RowBox[{"\[Kappa]", "^", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "\[Tau]"}], "+", 
              RowBox[{"9", " ", 
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            RowBox[{"\[Tau]fz", "^", "2"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}]}]}], ")"}], " ",
    "z0q", " ", "\[Tau]Dq"}], "]"}]], "Input",
 CellChangeTimes->{{3.520235926681065*^9, 3.520235968747425*^9}, {
   3.520236057184128*^9, 3.520236103040358*^9}, {3.520236152737315*^9, 
   3.520236155726829*^9}, 3.520238278017208*^9, 3.520238447328554*^9, 
   3.52023956416857*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
             SqrtBox["q"], " ", 
             SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
             "\[Tau]Dq", " ", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"], " ", "\[Tau]fz"}], "+", 
            RowBox[{
             SuperscriptBox["z0q", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"], " ", 
             SuperscriptBox["\[Tau]fz", "2"]}], "+", 
            RowBox[{"q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Tau]", " ", 
                SuperscriptBox["\[Tau]fz", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["Sq", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Tau]", " ", 
                   SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                  RowBox[{"\[Tau]Dq", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SqrtBox["q"], " ", 
             SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
             "\[Tau]Dq", " ", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"], " ", "\[Tau]fz"}], "+", 
            RowBox[{
             SuperscriptBox["z0q", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"], " ", 
             SuperscriptBox["\[Tau]fz", "2"]}], "+", 
            RowBox[{"q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Tau]", " ", 
                SuperscriptBox["\[Tau]fz", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["Sq", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Tau]", " ", 
                   SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                  RowBox[{"\[Tau]Dq", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Tau]", "2"], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
               "\[Tau]Dq"}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", 
               SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}], "+", 
           RowBox[{"q", " ", 
            SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Tau]", " ", 
               SuperscriptBox["\[Tau]fz", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Tau]", " ", 
                  SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                 RowBox[{"\[Tau]Dq", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]", " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", "\[Tau]fz"}], "+", 
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["\[Tau]", "2"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
               "\[Tau]Dq"}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", 
               SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}], "+", 
           RowBox[{"4", " ", "q", " ", 
            SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Tau]", " ", 
               SuperscriptBox["\[Tau]fz", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Tau]", " ", 
                  SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                 RowBox[{"\[Tau]Dq", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"4", " ", "\[ImaginaryI]", " ", 
            SqrtBox["q"], " ", 
            SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]", " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", "\[Tau]fz"}], "+", 
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["\[Tau]", "2"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
               "\[Tau]Dq"}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", 
               SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}], "+", 
           RowBox[{"4", " ", "q", " ", 
            SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Tau]", " ", 
               SuperscriptBox["\[Tau]fz", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Tau]", " ", 
                  SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                 RowBox[{"\[Tau]Dq", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]]}]]}]}], ")"}], " ", "z0q", " ", 
    "\[Tau]Dq"}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"128", " ", "N", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox["\[Tau]", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.520235969428918*^9, {3.520236069853796*^9, 3.52023610381421*^9}, 
   3.520236156450061*^9, 3.5202382788839693`*^9, {3.5202384185425673`*^9, 
   3.520238448401115*^9}, 3.520239565713725*^9, 3.5202470166595583`*^9, 
   3.520253420443252*^9, 3.520253678308262*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im ersten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520236209163476*^9, 3.520236213281708*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"q", " ", 
        RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Tau]", " ", 
           RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
          RowBox[{
           RowBox[{"Sq", "^", "2"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              RowBox[{"\[Tau]fr", "^", "2"}]}], "+", 
             RowBox[{"\[Tau]Dq", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]fr", "^", "2"}], "+", 
                RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
        RowBox[{"\[Tau]fr", "^", "2"}], " ", 
        RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.520236197076613*^9, 3.5202362231995287`*^9}, {
   3.5202363745485086`*^9, 3.520236391566465*^9}, {3.520236456646641*^9, 
   3.520236459038261*^9}, 3.520238412108206*^9, 3.5202384711575212`*^9, 
   3.520239592237444*^9}],

Cell[BoxData[
 RowBox[{"q", " ", 
  SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
    FractionBox[
     SuperscriptBox["Sq", "2"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Tau]", "+", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
      SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.5202362244372463`*^9, {3.520236381506599*^9, 3.520236392378119*^9}, 
   3.520236470082122*^9, 3.52023674625251*^9, 3.5202384131109943`*^9, 
   3.520238471875989*^9, 3.520239593800034*^9, 3.520247016881032*^9, 
   3.520253420476696*^9, 3.520253678334778*^9}]
}, Open  ]],

Cell["this term is real", "Subsection",
 CellChangeTimes->{{3.520239610616016*^9, 3.5202396124233007`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im zweiten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520236242627125*^9, 3.52023624600128*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term2", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "I", " ", 
            RowBox[{"Sqrt", "[", "q", "]"}], " ", 
            RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
            RowBox[{"\[Tau]fr", "^", "2"}], " ", "\[Tau]fz"}], "+", 
           RowBox[{
            RowBox[{"z0q", "^", "2"}], " ", 
            RowBox[{"\[Kappa]", "^", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
            RowBox[{"\[Tau]fr", "^", "2"}], " ", 
            RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
           RowBox[{"q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Tau]", " ", 
               RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
              RowBox[{
               RowBox[{"Sq", "^", "2"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Tau]", " ", 
                  RowBox[{"\[Tau]fr", "^", "2"}]}], "+", 
                 RowBox[{"\[Tau]Dq", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[Tau]fr", "^", "2"}], "+", 
                    RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         RowBox[{"\[Tau]fr", "^", "2"}], " ", 
         RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.520236256195423*^9, 3.520236261327833*^9}, {
   3.520236461752304*^9, 3.52023646301486*^9}, 3.5202385438314238`*^9, 
   3.520239643737035*^9, {3.520239743526371*^9, 3.520239747909748*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", 
     SuperscriptBox["\[Tau]", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["z0q", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["\[Tau]", "3"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fr", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fr", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "3"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fz", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fz", "2"]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SqrtBox["q"], " ", 
    SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
    SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    "\[Tau]fz"}]], "+", 
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SqrtBox["q"], " ", 
    SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
    " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    "\[Tau]fz"}]]}]], "Output",
 CellChangeTimes->{3.520236262401347*^9, 3.520236472452134*^9, 
  3.520238544417638*^9, 3.520239644999887*^9, 3.520239748522484*^9, 
  3.5202470171517677`*^9, 3.52025342051044*^9, 3.520253678389826*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "  ", 
       RowBox[{"Sqrt", "[", "q", "]"}], " ", 
       RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
       RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       "\[Tau]fz"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"Sqrt", "[", "q", "]"}], " ", 
       RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
       " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       "\[Tau]fz"}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5202368449446507`*^9, 3.520236845824264*^9}, 
   3.5202368764744053`*^9, {3.520237269460312*^9, 3.52023728133043*^9}, {
   3.5202385857013617`*^9, 3.520238600648426*^9}, {3.520239688608677*^9, 
   3.520239722982113*^9}, {3.520239787834908*^9, 3.520239813538733*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SqrtBox["q"], " ", 
   SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", " ",
    "\[Tau]Dq"}], 
  RowBox[{
   RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
   RowBox[{
    SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
    "\[Tau]fz"}]}]]], "Output",
 CellChangeTimes->{
  3.520237284003077*^9, 3.520238601444724*^9, 3.5202397237750607`*^9, {
   3.5202397946455317`*^9, 3.520239814501996*^9}, 3.5202470172141123`*^9, 
   3.520253420542655*^9, 3.520253678418029*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"z0q", "^", "2"}], " ", 
         RowBox[{"\[Kappa]", "^", "2"}], " ", 
         RowBox[{"\[Tau]", "^", "2"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
      ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z0q", "^", "2"}], " ", 
       RowBox[{"\[Kappa]", "^", "2"}], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"\[Tau]", "^", "3"}], " ", "\[Tau]Dq"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"\[Tau]", "^", "2"}], " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"\[Tau]", "^", "3"}], " ", "\[Tau]Dq"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"\[Tau]", "^", "2"}], " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520237291166688*^9, 3.520237307714487*^9}, {
  3.520238617380138*^9, 3.520238618850706*^9}, {3.520239833641798*^9, 
  3.5202398376618977`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Tau]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "q"}], " ", 
      SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
      RowBox[{"(", 
       RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
      SuperscriptBox["\[Tau]fr", "2"]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         SuperscriptBox["\[Tau]fr", "2"]}]}], ")"}], " ", 
      SuperscriptBox["\[Tau]fz", "2"]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{
      SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
   SuperscriptBox["\[Tau]fr", "2"], " ", 
   SuperscriptBox["\[Tau]fz", "2"]}]]], "Output",
 CellChangeTimes->{3.520237308384087*^9, 3.520238620817219*^9, 
  3.520239838410522*^9, 3.5202470172971497`*^9, 3.520253420576494*^9, 
  3.5202536784679823`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im dritten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520236298938504*^9, 3.520236302487431*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term3", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "I", " ", 
            RowBox[{"Sqrt", "[", "q", "]"}], " ", 
            RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
            "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
            RowBox[{"\[Tau]fr", "^", "2"}], " ", "\[Tau]fz"}], "+", 
           RowBox[{
            RowBox[{"z0q", "^", "2"}], " ", 
            RowBox[{"\[Kappa]", "^", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
            RowBox[{"\[Tau]fr", "^", "2"}], " ", 
            RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
           RowBox[{"q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Tau]", " ", 
               RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
              RowBox[{
               RowBox[{"Sq", "^", "2"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Tau]", " ", 
                  RowBox[{"\[Tau]fr", "^", "2"}]}], "+", 
                 RowBox[{"\[Tau]Dq", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[Tau]fr", "^", "2"}], "+", 
                    RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         RowBox[{"\[Tau]fr", "^", "2"}], " ", 
         RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.520236304153289*^9, 3.52023631935196*^9}, {
   3.520236465271242*^9, 3.520236466366663*^9}, 3.520238657491415*^9, {
   3.520239873369677*^9, 3.520239887420891*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", 
     SuperscriptBox["\[Tau]", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["z0q", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["\[Tau]", "3"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fr", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fr", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "3"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fz", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fz", "2"]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SqrtBox["q"], " ", 
    SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
    SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    "\[Tau]fz"}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SqrtBox["q"], " ", 
    SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
    " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    "\[Tau]fz"}]]}]], "Output",
 CellChangeTimes->{
  3.520236320367569*^9, 3.520236474887555*^9, 3.520238658058929*^9, {
   3.5202398744306393`*^9, 3.520239888061915*^9}, 3.5202470176513567`*^9, 
   3.520253420610593*^9, 3.520253678497943*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im3", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "  ", 
         RowBox[{"Sqrt", "[", "q", "]"}], " ", 
         RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
         RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         "\[Tau]fz"}], ")"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "  ", 
       RowBox[{"Sqrt", "[", "q", "]"}], " ", 
       RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
       " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       "\[Tau]fz"}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520239900218246*^9, 3.520239932342924*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    SqrtBox["q"], " ", 
    SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
    " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
    RowBox[{
     SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
     "\[Tau]fz"}]}]]}]], "Output",
 CellChangeTimes->{3.5202399326641703`*^9, 3.520247017681592*^9, 
  3.52025342064281*^9, 3.5202536785847*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re3", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"z0q", "^", "2"}], " ", 
         RowBox[{"\[Kappa]", "^", "2"}], " ", 
         RowBox[{"\[Tau]", "^", "2"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
      ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z0q", "^", "2"}], " ", 
       RowBox[{"\[Kappa]", "^", "2"}], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"\[Tau]", "^", "3"}], " ", "\[Tau]Dq"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"\[Tau]", "^", "2"}], " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"\[Tau]", "^", "3"}], " ", "\[Tau]Dq"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"\[Tau]", "^", "2"}], " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5202399491132183`*^9, 3.520239954457727*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Tau]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "q"}], " ", 
      SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
      RowBox[{"(", 
       RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
      SuperscriptBox["\[Tau]fr", "2"]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         SuperscriptBox["\[Tau]fr", "2"]}]}], ")"}], " ", 
      SuperscriptBox["\[Tau]fz", "2"]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{
      SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
   SuperscriptBox["\[Tau]fr", "2"], " ", 
   SuperscriptBox["\[Tau]fz", "2"]}]]], "Output",
 CellChangeTimes->{3.520239955225993*^9, 3.520247017715879*^9, 
  3.520253420677018*^9, 3.520253678667685*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im vierten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520240077633556*^9, 3.5202400828154917`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term4", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"z0q", "^", "2"}], " ", 
          RowBox[{"\[Kappa]", "^", "2"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Tau]", "^", "2"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"Sq", "^", "2"}]}], ")"}], " ", "\[Tau]", " ", 
             "\[Tau]Dq"}], "+", 
            RowBox[{
             RowBox[{"Sq", "^", "2"}], " ", 
             RowBox[{"\[Tau]Dq", "^", "2"}]}]}], ")"}], " ", 
          RowBox[{"\[Tau]fr", "^", "2"}], " ", 
          RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
         RowBox[{"q", " ", 
          RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Tau]", " ", 
             RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
            RowBox[{
             RowBox[{"Sq", "^", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Tau]", " ", 
                RowBox[{"\[Tau]fr", "^", "2"}]}], "+", 
               RowBox[{"\[Tau]Dq", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Tau]fr", "^", "2"}], "+", 
                  RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         RowBox[{"\[Tau]fr", "^", "2"}], " ", 
         RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5202400840780697`*^9, 3.520240093579554*^9}, {
  3.520240124523521*^9, 3.5202401492059307`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["z0q", "2"]}], " ", 
   SuperscriptBox["\[Kappa]", "2"]}], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    SuperscriptBox["\[Tau]fr", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fz", "2"]}]]}]], "Output",
 CellChangeTimes->{{3.520240125747489*^9, 3.520240150707653*^9}, 
   3.5202470179173927`*^9, 3.5202534207144823`*^9, 3.520253678734435*^9}]
}, Open  ]],

Cell["this term is real again", "Subsection",
 CellChangeTimes->{{3.5202401545346813`*^9, 3.520240156765087*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im f\[UDoubleDot]nften exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520240160572915*^9, 3.520240165820717*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term5", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", "I", " ", 
          RowBox[{"Sqrt", "[", "q", "]"}], " ", 
          RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]", " ", "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
          RowBox[{"\[Tau]fr", "^", "2"}], " ", "\[Tau]fz"}], "+", 
         RowBox[{
          RowBox[{"z0q", "^", "2"}], " ", 
          RowBox[{"\[Kappa]", "^", "2"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"\[Tau]", "^", "2"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{"Sq", "^", "2"}]}], ")"}], " ", "\[Tau]", " ", 
             "\[Tau]Dq"}], "+", 
            RowBox[{
             RowBox[{"Sq", "^", "2"}], " ", 
             RowBox[{"\[Tau]Dq", "^", "2"}]}]}], ")"}], " ", 
          RowBox[{"\[Tau]fr", "^", "2"}], " ", 
          RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Tau]", " ", 
             RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
            RowBox[{
             RowBox[{"Sq", "^", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Tau]", " ", 
                RowBox[{"\[Tau]fr", "^", "2"}]}], "+", 
               RowBox[{"\[Tau]Dq", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Tau]fr", "^", "2"}], "+", 
                  RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         RowBox[{"\[Tau]fr", "^", "2"}], " ", 
         RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.520240193156609*^9, 3.520240204303752*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", 
     SuperscriptBox["\[Tau]", "2"]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["z0q", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["z0q", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["z0q", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["\[Tau]", "3"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fr", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fr", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "3"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fz", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fz", "2"]}]], "+", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SqrtBox["q"], " ", 
    SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
    SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    "\[Tau]fz"}]], "+", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SqrtBox["q"], " ", 
    SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
    " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    "\[Tau]fz"}]]}]], "Output",
 CellChangeTimes->{3.5202402057307158`*^9, 3.5202470182033777`*^9, 
  3.520253420743483*^9, 3.520253678768692*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im5", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"Sqrt", "[", "q", "]"}], " ", 
       RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
       RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       "\[Tau]fz"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"Sqrt", "[", "q", "]"}], " ", 
       RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
       " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       "\[Tau]fz"}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5202403034498167`*^9, 3.5202403188751307`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SqrtBox["q"], " ", 
   SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", " ",
    "\[Tau]Dq"}], 
  RowBox[{
   RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
   RowBox[{
    SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
    "\[Tau]fz"}]}]]], "Output",
 CellChangeTimes->{3.520240320071587*^9, 3.520247018265203*^9, 
  3.520253420776012*^9, 3.52025367879741*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re5", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"z0q", "^", "2"}], " ", 
         RowBox[{"\[Kappa]", "^", "2"}], " ", 
         RowBox[{"\[Tau]", "^", "2"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
      ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z0q", "^", "2"}], " ", 
       RowBox[{"\[Kappa]", "^", "2"}], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"z0q", "^", "2"}], " ", 
       RowBox[{"\[Kappa]", "^", "2"}], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"z0q", "^", "2"}], " ", 
       RowBox[{"\[Kappa]", "^", "2"}], " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"\[Tau]", "^", "3"}], " ", "\[Tau]Dq"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"\[Tau]", "^", "2"}], " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"\[Tau]", "^", "3"}], " ", "\[Tau]Dq"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"\[Tau]", "^", "2"}], " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520240324747163*^9, 3.520240341183201*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["z0q", "2"]}], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "\[Tau]"}], "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fr", "2"], " ", 
    SuperscriptBox["\[Tau]fz", "2"]}], "+", 
   RowBox[{"4", " ", "q", " ", 
    SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["Sq", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       SuperscriptBox["\[Tau]fr", "2"]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fz", "2"]}]}], ")"}]}]}], 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{
      SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
   SuperscriptBox["\[Tau]fr", "2"], " ", 
   SuperscriptBox["\[Tau]fz", "2"]}]]], "Output",
 CellChangeTimes->{3.52024034176656*^9, 3.520247018336121*^9, 
  3.52025342081117*^9, 3.520253678834443*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im sechsten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.5202403671836033`*^9, 3.52024037031008*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term6", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "I", " ", 
          RowBox[{"Sqrt", "[", "q", "]"}], " ", 
          RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]", " ", "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
          RowBox[{"\[Tau]fr", "^", "2"}], " ", "\[Tau]fz"}], "+", 
         RowBox[{
          RowBox[{"z0q", "^", "2"}], " ", 
          RowBox[{"\[Kappa]", "^", "2"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"\[Tau]", "^", "2"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{"Sq", "^", "2"}]}], ")"}], " ", "\[Tau]", " ", 
             "\[Tau]Dq"}], "+", 
            RowBox[{
             RowBox[{"Sq", "^", "2"}], " ", 
             RowBox[{"\[Tau]Dq", "^", "2"}]}]}], ")"}], " ", 
          RowBox[{"\[Tau]fr", "^", "2"}], " ", 
          RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
         RowBox[{"4", " ", "q", " ", 
          RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Tau]", " ", 
             RowBox[{"\[Tau]fz", "^", "2"}]}], "+", 
            RowBox[{
             RowBox[{"Sq", "^", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Tau]", " ", 
                RowBox[{"\[Tau]fr", "^", "2"}]}], "+", 
               RowBox[{"\[Tau]Dq", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Tau]fr", "^", "2"}], "+", 
                  RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         RowBox[{"\[Tau]fr", "^", "2"}], " ", 
         RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], ")"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5202403720902452`*^9, 3.520240396233892*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", 
     SuperscriptBox["\[Tau]", "2"]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["z0q", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["z0q", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["z0q", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["\[Tau]", "3"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fr", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fr", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "3"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fz", "2"]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["Sq", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"], " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fz", "2"]}]], "-", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SqrtBox["q"], " ", 
    SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
    SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    "\[Tau]fz"}]], "-", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SqrtBox["q"], " ", 
    SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
    " ", 
    SuperscriptBox["\[Tau]Dq", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    "\[Tau]fz"}]]}]], "Output",
 CellChangeTimes->{{3.5202403847328672`*^9, 3.520240396909937*^9}, 
   3.520247018740705*^9, 3.520253420843361*^9, 3.520253678865527*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im6", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{"Sqrt", "[", "q", "]"}], " ", 
         RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", 
         RowBox[{"\[Tau]", "^", "2"}], " ", "\[Tau]Dq"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         "\[Tau]fz"}], ")"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"Sqrt", "[", "q", "]"}], " ", 
       RowBox[{"Sq", "^", "2"}], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
       " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       "\[Tau]fz"}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520240400879101*^9, 3.5202404217298613`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SqrtBox["q"], " ", 
    SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
    " ", "\[Tau]Dq"}], 
   RowBox[{
    RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
    RowBox[{
     SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", 
     "\[Tau]fz"}]}]]}]], "Output",
 CellChangeTimes->{3.520240422104512*^9, 3.5202470187674*^9, 
  3.520253420876145*^9, 3.5202536789214354`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re6", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"z0q", "^", "2"}], " ", 
         RowBox[{"\[Kappa]", "^", "2"}], " ", 
         RowBox[{"\[Tau]", "^", "2"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
      ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z0q", "^", "2"}], " ", 
       RowBox[{"\[Kappa]", "^", "2"}], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"z0q", "^", "2"}], " ", 
       RowBox[{"\[Kappa]", "^", "2"}], " ", "\[Tau]", " ", "\[Tau]Dq"}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"z0q", "^", "2"}], " ", 
       RowBox[{"\[Kappa]", "^", "2"}], " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], ")"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"\[Tau]", "^", "3"}], " ", "\[Tau]Dq"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"\[Tau]", "^", "2"}], " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fr", "^", "2"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"\[Tau]", "^", "3"}], " ", "\[Tau]Dq"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", " ", 
       RowBox[{"Sq", "^", "2"}], " ", 
       RowBox[{"\[Tau]", "^", "2"}], " ", 
       RowBox[{"\[Tau]Dq", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"\[Tau]fz", "^", "2"}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520240424592664*^9, 3.520240438059618*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["z0q", "2"]}], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "\[Tau]"}], "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
    SuperscriptBox["\[Tau]fr", "2"], " ", 
    SuperscriptBox["\[Tau]fz", "2"]}], "+", 
   RowBox[{"4", " ", "q", " ", 
    SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["Sq", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       SuperscriptBox["\[Tau]fr", "2"]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fz", "2"]}]}], ")"}]}]}], 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{
      SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
   SuperscriptBox["\[Tau]fr", "2"], " ", 
   SuperscriptBox["\[Tau]fz", "2"]}]]], "Output",
 CellChangeTimes->{3.520240438587783*^9, 3.520247018800763*^9, 
  3.520253420910898*^9, 3.520253679031623*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["cheking if real term2&3 and 5&6 are not the same", "Section",
 CellChangeTimes->{{3.52023869963577*^9, 3.520238711379517*^9}, {
  3.5202387554494753`*^9, 3.520238755969453*^9}, {3.520240751482595*^9, 
  3.520240756658235*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"re2", "-", "re3"}], "]"}]], "Input",
 CellChangeTimes->{{3.520238713513619*^9, 3.520238721379375*^9}, {
  3.520240714998164*^9, 3.5202407165402317`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.52023872201478*^9, 3.520240717481901*^9, 
  3.520247018834096*^9, 3.520253420976079*^9, 3.520253679120328*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"re5", "-", "re6"}], "]"}]], "Input",
 CellChangeTimes->{{3.520240724876561*^9, 3.5202407270685463`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.520240727869021*^9, 3.5202470188664*^9, 
  3.5202534210102873`*^9, 3.520253679146824*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["and similarly we see the im are of opposite signs", "Section",
 CellChangeTimes->{{3.520238751793483*^9, 3.52023876931288*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"im2", "+", "im3"}], "]"}]], "Input",
 CellChangeTimes->{{3.520238734555244*^9, 3.520238746834319*^9}, {
  3.5202407315565*^9, 3.5202407330916843`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.520238747531067*^9, 3.520240733613174*^9, 
  3.520247018901531*^9, 3.520253421077626*^9, 3.520253679203774*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"im5", "+", "im6"}], "]"}]], "Input",
 CellChangeTimes->{{3.520240739939517*^9, 3.520240741981227*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5202407424137793`*^9, 3.5202470189355907`*^9, 
  3.5202534211105328`*^9, 3.5202536792311163`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["combination of the terms", "Section",
 CellChangeTimes->{{3.52023737593359*^9, 3.520237379972723*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"combination", "=", 
  RowBox[{
   RowBox[{"4", "*", 
    RowBox[{"E", "^", 
     RowBox[{"(", "term1", ")"}]}]}], "+", 
   RowBox[{
    RowBox[{"E", "^", "re2"}], "*", 
    RowBox[{"ExpToTrig", "[", 
     RowBox[{
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{"I", "*", "im2"}], ")"}]}], "+", 
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{"I", "*", "im3"}], ")"}]}]}], "]"}]}], "+", 
   RowBox[{"2", "*", 
    RowBox[{"E", "^", 
     RowBox[{"(", "term4", ")"}]}]}], "+", 
   RowBox[{"4", "*", 
    RowBox[{"E", "^", "re5"}], "*", 
    RowBox[{"ExpToTrig", "[", 
     RowBox[{
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{"I", "*", "im5"}], ")"}]}], "+", 
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{"I", "*", "im6"}], ")"}]}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.520237414824924*^9, 3.520237435196871*^9}, {
  3.5202374720289183`*^9, 3.520237478178241*^9}, {3.520237558729875*^9, 
  3.5202375610005302`*^9}, {3.520238669710429*^9, 3.520238670509037*^9}, {
  3.520238787291554*^9, 3.5202388675038757`*^9}, {3.520239054403302*^9, 
  3.5202390548824787`*^9}, {3.520240770661677*^9, 3.5202409354144287`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"q", " ", 
     SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
       FractionBox[
        SuperscriptBox["Sq", "2"], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["z0q", "2"]}], " ", 
      SuperscriptBox["\[Kappa]", "2"]}], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       SuperscriptBox["\[Tau]fr", "2"]}]], "-", 
     FractionBox[
      RowBox[{"q", " ", 
       SuperscriptBox["Sq", "2"], " ", 
       SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fz", "2"]}]]}]]}], "+", 
  RowBox[{"8", " ", 
   SuperscriptBox["\[ExponentialE]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fr", "2"], " ", 
       SuperscriptBox["\[Tau]fz", "2"]}], "+", 
      RowBox[{"4", " ", "q", " ", 
       SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["Sq", "2"]}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]}], ")"}]}]}], 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Tau]", "+", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
      SuperscriptBox["\[Tau]fr", "2"], " ", 
      SuperscriptBox["\[Tau]fz", "2"]}]]], " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{
      SqrtBox["q"], " ", 
      SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
      " ", "\[Tau]Dq"}], 
     RowBox[{
      RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
    "]"}]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    FractionBox[
     RowBox[{"\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "q"}], " ", 
         SuperscriptBox["Sq", "2"], " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         SuperscriptBox["\[Tau]fr", "2"]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Tau]", "+", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
      SuperscriptBox["\[Tau]fr", "2"], " ", 
      SuperscriptBox["\[Tau]fz", "2"]}]]], " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"2", " ", 
      SqrtBox["q"], " ", 
      SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]", 
      " ", "\[Tau]Dq"}], 
     RowBox[{
      RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
      RowBox[{
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.5202388682031*^9, 3.520239055535288*^9, 3.5202408659733753`*^9, {
   3.520240923757646*^9, 3.5202409368797483`*^9}, 3.520247018969111*^9, 
   3.520253421148657*^9, 3.520253679272138*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"combinationplus", "=", 
  RowBox[{"Simplify", "[", "combination", "]"}]}]], "Input",
 CellChangeTimes->{{3.520238881475524*^9, 3.520238888966007*^9}, {
  3.520238924661517*^9, 3.5202389250930243`*^9}, {3.520238980252309*^9, 
  3.5202389949628077`*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0q", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", "\[Tau]"}], "+", 
         RowBox[{"5", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}], "-", 
    RowBox[{"q", " ", 
     SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
         SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
       FractionBox[
        SuperscriptBox["Sq", "2"], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z0q", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "+", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", "\[Tau]"}], "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SuperscriptBox["z0q", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], " ", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{
        SqrtBox["q"], " ", 
        SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]",
         " ", "\[Tau]Dq"}], 
       RowBox[{
        RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
      "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]"}], "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]], " ", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"2", " ", 
        SqrtBox["q"], " ", 
        SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", "\[Tau]",
         " ", "\[Tau]Dq"}], 
       RowBox[{
        RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
      "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.520238921394456*^9, 3.5202389256313257`*^9}, 
   3.5202389956012573`*^9, 3.5202390588965807`*^9, 3.520240948863155*^9, 
   3.520247020139681*^9, 3.5202534213483667`*^9, 3.520253679300881*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"G3t", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"combinationplus", "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"z0q", " ", "\[Tau]Dq"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"128", " ", "N", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"z0q", "^", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[Tau]", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}], ")"}]}]}], ")"}]}], 
       "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5202390010090446`*^9, 3.520239029977831*^9}, {
  3.520239062741084*^9, 3.52023908745942*^9}, {3.5202409805577374`*^9, 
  3.5202409958449697`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", "\[Tau]"}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}], "-", 
      RowBox[{"q", " ", 
       SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
         FractionBox[
          SuperscriptBox["Sq", "2"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], " ", "z0q", " ", 
    "\[Tau]Dq", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", "\[Tau]"}], "+", 
            RowBox[{"5", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]", " ", "\[Tau]Dq"}], 
         RowBox[{
          RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
        "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"5", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]", " ", "\[Tau]Dq"}], 
         RowBox[{
          RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
        "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", "N", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox["\[Tau]", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.520239088431953*^9, 3.520240996814343*^9, 
  3.5202470202387323`*^9, 3.520253421380097*^9, 3.520253679338643*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myexpsimplification", "[", 
  RowBox[{"G3t", "[", "\[Tau]", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.52024701103344*^9, 3.5202470111126623`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"z0q", " ", "\[Tau]Dq", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "q"}], " ", 
         SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
           FractionBox[
            SuperscriptBox["Sq", "2"], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{
                SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Tau]", "2"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "\[Tau]"}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}], 
         "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
               SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
            FractionBox[
             SuperscriptBox["Sq", "2"], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"\[Tau]", "+", 
                RowBox[{
                 SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
              SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]", " ", "\[Tau]Dq"}], 
         RowBox[{
          RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
        "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0q", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
              SuperscriptBox["\[Tau]fr", "2"], " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{"q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fz", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["Sq", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Tau]", " ", 
                    SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                   RowBox[{"\[Tau]Dq", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]]}]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]", " ", "\[Tau]Dq"}], 
         RowBox[{
          RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
        "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", "N", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox["\[Tau]", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.520247020400457*^9, 3.520253421432692*^9, 
  3.5202536793874063`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TeXForm", "[", 
  RowBox[{"myexpsimplification", "[", 
   RowBox[{"G3t", "[", "\[Tau]", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5202531962673283`*^9, 3.52025319946623*^9}, {
  3.520253410506275*^9, 3.520253412825107*^9}}],

Cell["\<\
\\frac{\\text{$\\tau $Dq} \\text{z0q} \\left(2 \\exp \\left(-q \\tau ^2 \
\\text{$\\tau $Dq}
   \\left(\\frac{\\text{Sq}^2}{\\text{$\\tau $fz}^2 \\left(\\text{Sq}^2 \
\\text{$\\tau $Dq}+\\tau
   \\right)}+\\frac{1}{\\text{$\\tau $fr}^2 (\\tau +\\text{$\\tau \
$Dq})}\\right)\\right)+\\exp \\left(-\\frac{q \\tau ^2
   \\text{$\\tau $Dq} \\left(\\text{Sq}^2 \\left(\\tau  \\text{$\\tau $fr}^2+\
\\text{$\\tau $Dq} \\left(\\text{$\\tau
   $fr}^2+\\text{$\\tau $fz}^2\\right)\\right)+\\tau  \\text{$\\tau \
$fz}^2\\right)+\\kappa ^2 \\text{$\\tau $fr}^2
   \\text{$\\tau $fz}^2 \\text{z0q}^2 \\left(\\left(\\text{Sq}^2+1\\right) \
\\tau  \\text{$\\tau $Dq}+\\text{Sq}^2
   \\text{$\\tau $Dq}^2+\\tau ^2\\right)}{\\text{$\\tau $fr}^2 \\text{$\\tau \
$fz}^2 (\\tau +\\text{$\\tau $Dq})
   \\left(\\text{Sq}^2 \\text{$\\tau $Dq}+\\tau \\right)}\\right)+4 \\cos \
\\left(\\frac{\\kappa  \\sqrt{q} \\text{Sq}^2 \\tau
    \\text{$\\tau $Dq} \\text{z0q}}{\\text{Sq}^2 \\text{$\\tau $Dq} \
\\text{$\\tau $fz}+\\tau  \\text{$\\tau $fz}}\\right)
   \\exp \\left(q \\tau ^2 \\text{$\\tau $Dq} \
\\left(-\\frac{\\text{Sq}^2}{\\text{$\\tau $fz}^2 \\left(\\text{Sq}^2
   \\text{$\\tau $Dq}+\\tau \\right)}-\\frac{1}{\\text{$\\tau $fr}^2 (\\tau +\
\\text{$\\tau $Dq})}\\right)-\\frac{\\kappa ^2
   \\text{z0q}^2 \\left(\\text{Sq}^2 \\text{$\\tau $Dq}+2 \\tau \\right)}{4 \
\\left(\\text{Sq}^2 \\text{$\\tau $Dq}+\\tau
   \\right)}\\right)+\\cos \\left(\\frac{2 \\kappa  \\sqrt{q} \\text{Sq}^2 \
\\tau  \\text{$\\tau $Dq}
   \\text{z0q}}{\\text{Sq}^2 \\text{$\\tau $Dq} \\text{$\\tau $fz}+\\tau  \
\\text{$\\tau $fz}}\\right) \\exp
   \\left(-\\frac{\\tau  \\left(q \\tau  \\text{$\\tau $Dq} \
\\left(\\text{Sq}^2 \\left(\\tau  \\text{$\\tau
   $fr}^2+\\text{$\\tau $Dq} \\left(\\text{$\\tau $fr}^2+\\text{$\\tau $fz}^2\
\\right)\\right)+\\tau  \\text{$\\tau
   $fz}^2\\right)+\\kappa ^2 \\text{$\\tau $fr}^2 \\text{$\\tau $fz}^2 \
\\text{z0q}^2 (\\tau +\\text{$\\tau
   $Dq})\\right)}{\\text{$\\tau $fr}^2 \\text{$\\tau $fz}^2 (\\tau \
+\\text{$\\tau $Dq}) \\left(\\text{Sq}^2 \\text{$\\tau
   $Dq}+\\tau \\right)}\\right)\\right)}{64 N (\\tau +\\text{$\\tau $Dq}) \
\\sqrt{\\text{z0q}^2 \\left(\\frac{\\tau
   }{\\text{Sq}^2 \\text{$\\tau $Dq}}+1\\right)}}\
\>", "Output",
 CellChangeTimes->{
  3.520253200298908*^9, {3.5202534139126663`*^9, 3.520253421595168*^9}, 
   3.520253679583518*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["assigning the no-flow case", "Section",
 CellChangeTimes->{{3.520238964204406*^9, 3.52023897019488*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"G3noflow", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"z0q", "^", "2"}]}], " ", 
          RowBox[{"\[Kappa]", "^", "2"}]}], ")"}]}], "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"z0q", "^", "2"}], " ", 
              RowBox[{"\[Kappa]", "^", "2"}], " ", "\[Tau]"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
           ")"}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"z0q", "^", "2"}], " ", 
               RowBox[{"\[Kappa]", "^", "2"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", "\[Tau]"}], "+", 
                 RowBox[{
                  RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"4", " ", 
               RowBox[{"(", 
                RowBox[{"\[Tau]", "+", 
                 RowBox[{
                  RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
              ")"}]}], ")"}]}], ")"}]}]}]}], ")"}], " ", "z0q", " ", 
     "\[Tau]Dq"}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"64", " ", "N", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"z0q", "^", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Tau]", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}], ")"}]}]}], ")"}]}], 
      "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.519375352278948*^9, 3.5193753523499193`*^9}, 
   3.519375387849145*^9, 3.519375955029749*^9, 3.519534213208435*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}]]}]}], 
    ")"}], " ", "z0q", " ", "\[Tau]Dq"}], 
  RowBox[{"64", " ", "N", " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["z0q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox["\[Tau]", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}]]], "Output",
 CellChangeTimes->{3.520241027922789*^9, 3.5202470204257298`*^9, 
  3.520253421615632*^9, 3.520253679599531*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["division", "Section",
 CellChangeTimes->{{3.520239115103595*^9, 3.520239117205905*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Gfinal3", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"G3t", "[", "\[Tau]", "]"}], "/", 
     RowBox[{"G3noflow", "[", "\[Tau]", "]"}]}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519534489316717*^9, 3.519534514418784*^9}, {
  3.520239242012629*^9, 3.520239249237952*^9}, {3.520239291002108*^9, 
  3.5202392996736603`*^9}, {3.5202410335797787`*^9, 3.520241040882122*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", "\[Tau]"}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}], "-", 
      RowBox[{"q", " ", 
       SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
         FractionBox[
          SuperscriptBox["Sq", "2"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", "\[Tau]"}], "+", 
            RowBox[{"5", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"]}]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]", " ", "\[Tau]Dq"}], 
         RowBox[{
          RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
        "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"5", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]", " ", "\[Tau]Dq"}], 
         RowBox[{
          RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
        "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["z0q", "2"]}], " ", 
      SuperscriptBox["\[Kappa]", "2"]}]], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
       RowBox[{"\[Tau]", "+", 
        RowBox[{
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}]]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5202391214019423`*^9, 3.5202392508855247`*^9, 
  3.520239300745945*^9, 3.520241047920493*^9, 3.520247026875379*^9, 
  3.52025342164818*^9, 3.520253679633504*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplification of G4", "Title",
 CellChangeTimes->{{3.520237212163966*^9, 3.5202372241859827`*^9}, 
   3.520241744220941*^9}],

Cell[CellGroupData[{

Cell["Assumptions", "Section",
 CellChangeTimes->{{3.519097759869207*^9, 3.5190977785960703`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Element", "[", 
     RowBox[{"w0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"b", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z1", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z2", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"x4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"y4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z3", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z4", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"Aq0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Tau]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"cm", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"Dd", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"z0", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"q", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Kappa]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Dd", ">", "0"}], "&&", 
    RowBox[{"\[Tau]", ">", "0"}], "&&", 
    RowBox[{"w0", ">", "0"}], "&&", 
    RowBox[{"z0", ">", "0"}], "&&", 
    RowBox[{"Aq0", ">", "0"}], "&&", 
    RowBox[{"q", "\[GreaterEqual]", "1"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"vr", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"vz", ",", "Reals"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.519097780783361*^9, 3.519097783919778*^9}, 
   3.5191029105091476`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"b", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z1", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z2", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"x4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"y4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z3", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z4", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Aq0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"\[Tau]", "\[Element]", "Reals"}], "&&", 
   RowBox[{"cm", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Dd", "\[Element]", "Reals"}], "&&", 
   RowBox[{"z0", "\[Element]", "Reals"}], "&&", 
   RowBox[{"q", "\[Element]", "Reals"}], "&&", 
   RowBox[{"\[Kappa]", "\[Element]", "Reals"}], "&&", 
   RowBox[{"Dd", ">", "0"}], "&&", 
   RowBox[{"\[Tau]", ">", "0"}], "&&", 
   RowBox[{"w0", ">", "0"}], "&&", 
   RowBox[{"z0", ">", "0"}], "&&", 
   RowBox[{"Aq0", ">", "0"}], "&&", 
   RowBox[{"q", "\[GreaterEqual]", "1"}], "&&", 
   RowBox[{"vr", "\[Element]", "Reals"}], "&&", 
   RowBox[{"vz", "\[Element]", "Reals"}]}], "}"}]], "Output",
 CellChangeTimes->{3.519097785842445*^9, 3.519098734981737*^9, 
  3.5191616912762346`*^9, 3.519325860368703*^9, 3.51956702706219*^9, 
  3.5196240459598093`*^9, 3.520112769925209*^9, 3.520236738788871*^9, 
  3.5202385120120277`*^9, 3.520240296576323*^9, 3.520241864258646*^9, 
  3.520247089723164*^9, 3.520248229000201*^9, 3.520253228500761*^9, 
  3.520253709274794*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"myexpsimplification", "[", "myinput_", "]"}], ":=", 
  RowBox[{"ReplaceAll", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"myinput", ",", "E"}], "]"}], ",", 
      RowBox[{"ExcludedForms", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"E", "^", "_"}], "}"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"form_", "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"form", ",", "E"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"Simplify", "[", "form", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5202360002762136`*^9, 3.52023604787567*^9}, 
   3.520236085810807*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myexpsimplification", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Aq0", "4"], " ", 
     SuperscriptBox["chi", "4"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0", "4"], " ", 
              SuperscriptBox["\[Kappa]", "2"]}], "+", 
             RowBox[{"2", " ", "q", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                RowBox[{"Dd", " ", "\[Kappa]"}]}], ")"}], " ", "\[Tau]"}], 
             "+", 
             RowBox[{
              SuperscriptBox["q", "2"], " ", 
              SuperscriptBox["vz", "2"], " ", 
              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "q"], "+", 
         RowBox[{"\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "Dd", " ", 
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{"q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               RowBox[{"4", " ", "Dd", " ", "\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                  RowBox[{"Dd", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}], " ", 
             "\[Tau]"}], "+", 
            RowBox[{"2", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["w0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z0", "2"], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
     " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "cm", " ", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], "+", 
        RowBox[{"cm", " ", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], 
           RowBox[{
            RowBox[{"2", " ", "q", " ", 
             SuperscriptBox["z0", "2"]}], "+", 
            RowBox[{"4", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", "\[Tau]"}]}]]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
              SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
             RowBox[{
              SuperscriptBox["z0", "2"], "+", 
              RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]]}], 
          ")"}]}]}], ")"}], "2"], " ", 
     SuperscriptBox["\[Pi]", "3"], " ", 
     SuperscriptBox["w0", "7"], " ", 
     SuperscriptBox["z0", "4"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"64", " ", 
     SuperscriptBox["q", 
      RowBox[{"5", "/", "2"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     SqrtBox[
      RowBox[{"q", "+", 
       FractionBox[
        RowBox[{"2", " ", "Dd", " ", 
         SuperscriptBox["q", "2"], " ", "\[Tau]"}], 
        SuperscriptBox["w0", "2"]]}]]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.520235926681065*^9, 3.520235968747425*^9}, {
   3.520236057184128*^9, 3.520236103040358*^9}, {3.520236152737315*^9, 
   3.520236155726829*^9}, 3.520238278017208*^9, 3.520238500598899*^9, 
   3.520240288672665*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["Dd", "2"], " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "-", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["w0", "2"], "+", 
               RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
            "+", 
            RowBox[{"q", " ", 
             SuperscriptBox["vz", "2"], " ", "\[Tau]", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["w0", "2"], "+", 
               RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
            "+", 
            RowBox[{"2", " ", "Dd", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z0", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["q", "2"], " ", 
                SuperscriptBox["vr", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
      "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"q", " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["Dd", "2"], " ", "q", " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
             SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["w0", "2"], "+", 
               RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
            "+", 
            RowBox[{"q", " ", 
             SuperscriptBox["vz", "2"], " ", "\[Tau]", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["w0", "2"], "+", 
               RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
            "+", 
            RowBox[{"2", " ", "Dd", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["w0", "2"], " ", 
                SuperscriptBox["z0", "2"], " ", 
                SuperscriptBox["\[Kappa]", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["q", "2"], " ", 
                SuperscriptBox["vr", "2"], " ", 
                SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["vz", "2"], " ", 
                 SuperscriptBox["w0", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["vr", "2"], " ", 
                 SuperscriptBox["z0", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["Dd", "2"], " ", "q", " ", 
              SuperscriptBox["z0", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
             RowBox[{"2", " ", "Dd", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["w0", "2"], " ", 
                 SuperscriptBox["z0", "2"], " ", 
                 SuperscriptBox["\[Kappa]", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["q", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["vr", "2"], "+", 
                   SuperscriptBox["vz", "2"]}], ")"}], " ", 
                 SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"2", " ", "Dd", " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{
               SuperscriptBox["q", "2"], " ", 
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
           RowBox[{"q", " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"q", " ", 
               SuperscriptBox["vr", "2"], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["Dd", "2"], " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"2", " ", "Dd", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["z0", "4"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["q", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["vr", "2"], "+", 
                    SuperscriptBox["vz", "2"]}], ")"}], " ", 
                  SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"2", " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
                 RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
               "\[Tau]"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["q", "2"], " ", 
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"q", " ", 
               SuperscriptBox["vr", "2"], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["Dd", "2"], " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"Dd", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["z0", "4"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}], "-", 
                 RowBox[{
                 "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}],
                  "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["q", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["vr", "2"], "+", 
                    SuperscriptBox["vz", "2"]}], ")"}], " ", 
                  SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
          RowBox[{"2", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"2", " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
                 RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
               "\[Tau]"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["q", "2"], " ", 
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"q", " ", 
               SuperscriptBox["vr", "2"], " ", 
               SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["Dd", "2"], " ", "q", " ", 
               SuperscriptBox["z0", "2"], " ", 
               SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
              RowBox[{"Dd", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["z0", "4"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}], "+", 
                 RowBox[{
                 "2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
                  SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}],
                  "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["q", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["vr", "2"], "+", 
                    SuperscriptBox["vz", "2"]}], ")"}], " ", 
                  SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
          RowBox[{"2", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]}]]}]}], ")"}], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "8"], " ", 
    SuperscriptBox["z0", "4"]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", 
    SuperscriptBox["q", "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], "2"], " ", 
    
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.520235969428918*^9, {3.520236069853796*^9, 3.52023610381421*^9}, 
   3.520236156450061*^9, 3.5202382788839693`*^9, {3.520238502134224*^9, 
   3.520238518052491*^9}, {3.520240291459385*^9, 3.520240301042639*^9}, 
   3.520241864705724*^9, 3.5202470901552553`*^9, 3.520248229182446*^9, 
   3.520253228681993*^9, 3.5202537094589033`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im ersten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520236209163476*^9, 3.520236213281708*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term1", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"q", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "-", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["vz", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
         RowBox[{"2", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520236197076613*^9, 3.5202362231995287`*^9}, {
   3.5202363745485086`*^9, 3.520236391566465*^9}, {3.520236456646641*^9, 
   3.520236459038261*^9}, 3.520238549342306*^9, {3.520240322396968*^9, 
   3.520240331248336*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["vz", "2"], " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["vr", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"4", " ", "\[ImaginaryI]", " ", "Dd", " ", "q", " ", "vz", " ", 
    SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["Dd", "2"], " ", "q", " ", 
    SuperscriptBox["z0", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["q", "2"], " ", 
    SuperscriptBox["vr", "2"], " ", 
    SuperscriptBox["\[Tau]", "3"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["q", "2"], " ", 
    SuperscriptBox["vz", "2"], " ", 
    SuperscriptBox["\[Tau]", "3"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.5202362244372463`*^9, {3.520236381506599*^9, 3.520236392378119*^9}, 
   3.520236470082122*^9, 3.52023674625251*^9, 3.5202385514747066`*^9, {
   3.520240323669771*^9, 3.520240332002397*^9}, 3.520241865007188*^9, 
   3.520247090439756*^9, 3.520248229216916*^9, 3.520253228705965*^9, 
   3.520253709492247*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "vz", " ", 
      SuperscriptBox["w0", "2"], " ", 
      SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "+", 
    FractionBox[
     RowBox[{"4", " ", "Dd", " ", "q", " ", "vz", " ", 
      SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
      SuperscriptBox["\[Tau]", "2"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5202403440014057`*^9, 3.5202403727025948`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "vz", " ", 
   SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
  RowBox[{
   SuperscriptBox["z0", "2"], "+", 
   RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]], "Output",
 CellChangeTimes->{3.520240374685256*^9, 3.520241865024778*^9, 
  3.520247090461988*^9, 3.5202482292499237`*^9, 3.520253228734474*^9, 
  3.520253709558421*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"term1", "-", 
    RowBox[{"I", "*", "im1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5202403764919558`*^9, 3.520240390165092*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Tau]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "Dd", " ", 
      SuperscriptBox["w0", "2"], " ", 
      SuperscriptBox["z0", "2"], " ", 
      SuperscriptBox["\[Kappa]", "2"]}], "-", 
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["vz", "2"], " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vr", "2"], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
      "\[Tau]"}], "-", 
     RowBox[{"2", " ", "Dd", " ", 
      SuperscriptBox["q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["vr", "2"], "+", 
        SuperscriptBox["vz", "2"]}], ")"}], " ", 
      SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["w0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["z0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "Output",\

 CellChangeTimes->{3.520240391224388*^9, 3.520241865146578*^9, 
  3.5202470905790873`*^9, 3.520248229283148*^9, 3.5202532287681828`*^9, 
  3.52025370965938*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im zweiten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520236242627125*^9, 3.52023624600128*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term2", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"q", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["vz", "2"], " ", "\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], "+", 
         RowBox[{"2", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["q", "2"], " ", 
             SuperscriptBox["vr", "2"], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520236256195423*^9, 3.520236261327833*^9}, {
   3.520236461752304*^9, 3.52023646301486*^9}, 3.520238607069332*^9, {
   3.520240408498163*^9, 3.520240414642558*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "vz", " ", 
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], "-", 
  FractionBox[
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["vz", "2"], " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["vr", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"4", " ", "\[ImaginaryI]", " ", "Dd", " ", "q", " ", "vz", " ", 
    SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["Dd", "2"], " ", "q", " ", 
    SuperscriptBox["z0", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["q", "2"], " ", 
    SuperscriptBox["vr", "2"], " ", 
    SuperscriptBox["\[Tau]", "3"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["q", "2"], " ", 
    SuperscriptBox["vz", "2"], " ", 
    SuperscriptBox["\[Tau]", "3"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.520236262401347*^9, 3.520236472452134*^9, 
  3.520238608612049*^9, 3.520240415551325*^9, 3.520241865386622*^9, 
  3.520247090807062*^9, 3.520248229317074*^9, 3.520253228801735*^9, 
  3.520253709760186*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", "vz", " ", 
       SuperscriptBox["w0", "2"], " ", 
       SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], "-", 
    FractionBox[
     RowBox[{"4", " ", "Dd", " ", "q", " ", "vz", " ", 
      SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
      SuperscriptBox["\[Tau]", "2"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5202368449446507`*^9, 3.520236845824264*^9}, 
   3.5202368764744053`*^9, {3.520237269460312*^9, 3.52023728133043*^9}, {
   3.5202386159749804`*^9, 3.520238629036304*^9}, {3.52023870899823*^9, 
   3.5202388333973303`*^9}, {3.520240425092065*^9, 3.520240440999826*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "vz", " ", 
    SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
   RowBox[{
    SuperscriptBox["z0", "2"], "+", 
    RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], "Output",
 CellChangeTimes->{
  3.520237284003077*^9, {3.5202386202762747`*^9, 3.5202386294245567`*^9}, 
   3.520238834079586*^9, {3.520240436140749*^9, 3.520240441748022*^9}, 
   3.520241865425611*^9, 3.52024709085846*^9, 3.520248229350813*^9, 
   3.520253228833982*^9, 3.520253709792589*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"term2", "-", 
    RowBox[{"I", "*", "im2"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520237291166688*^9, 3.520237307714487*^9}, {
  3.520238843450965*^9, 3.52023885166718*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Tau]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "Dd", " ", 
      SuperscriptBox["w0", "2"], " ", 
      SuperscriptBox["z0", "2"], " ", 
      SuperscriptBox["\[Kappa]", "2"]}], "-", 
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["vz", "2"], " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vr", "2"], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
      "\[Tau]"}], "-", 
     RowBox[{"2", " ", "Dd", " ", 
      SuperscriptBox["q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["vr", "2"], "+", 
        SuperscriptBox["vz", "2"]}], ")"}], " ", 
      SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["w0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["z0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "Output",\

 CellChangeTimes->{3.520237308384087*^9, 3.520238852784091*^9, 
  3.520240452232168*^9, 3.52024186545901*^9, 3.5202470908755093`*^9, 
  3.520248229384117*^9, 3.5202532288508043`*^9, 3.520253709830213*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im dritten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520236298938504*^9, 3.520236302487431*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term3", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[Tau]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["vz", "2"], " ", 
            SuperscriptBox["w0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["vr", "2"], " ", 
            SuperscriptBox["z0", "2"]}]}], ")"}], " ", "\[Tau]"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["Dd", "2"], " ", "q", " ", 
         SuperscriptBox["z0", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
        RowBox[{"2", " ", "Dd", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.520236304153289*^9, 3.52023631935196*^9}, {
   3.520236465271242*^9, 3.520236466366663*^9}, 3.520238932096384*^9, {
   3.52024047501038*^9, 3.520240502378227*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Tau]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "Dd", " ", 
      SuperscriptBox["w0", "2"], " ", 
      SuperscriptBox["z0", "2"], " ", 
      SuperscriptBox["\[Kappa]", "2"]}], "-", 
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["vz", "2"], " ", 
         SuperscriptBox["w0", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["z0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vr", "2"], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["Dd", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
      "\[Tau]"}], "-", 
     RowBox[{"2", " ", "Dd", " ", 
      SuperscriptBox["q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["vr", "2"], "+", 
        SuperscriptBox["vz", "2"]}], ")"}], " ", 
      SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["w0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["z0", "2"], "+", 
     RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], "Output",\

 CellChangeTimes->{
  3.520236320367569*^9, 3.520236474887555*^9, 3.520238933388837*^9, {
   3.520240480733059*^9, 3.52024050278484*^9}, 3.520241865475869*^9, 
   3.520247090908503*^9, 3.520248229416523*^9, 3.52025322888509*^9, 
   3.520253709859173*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im vierten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520239028096367*^9, 3.520239037326387*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term4", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["w0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["z0", "4"], " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["vz", "2"], " ", 
          SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
      RowBox[{"q", " ", "\[Tau]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"q", " ", 
          SuperscriptBox["vr", "2"], " ", 
          SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["Dd", "2"], " ", "q", " ", 
          SuperscriptBox["z0", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
         RowBox[{"2", " ", "Dd", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0", "4"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.520239040724605*^9, 3.520239059528193*^9}, 
   3.520240527925456*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "4"], " ", 
     SuperscriptBox["\[Kappa]", "2"]}], "+", 
    RowBox[{"2", " ", "Dd", " ", "q", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       SuperscriptBox["z0", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
    RowBox[{
     SuperscriptBox["q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["vz", "2"], " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["vr", "2"], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["Dd", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox["\[Tau]", "2"]}], "+", 
    RowBox[{"2", " ", "Dd", " ", 
     SuperscriptBox["q", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["vr", "2"], "+", 
       SuperscriptBox["vz", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Tau]", "3"]}]}], 
   RowBox[{"q", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.52023906073181*^9, 3.52024053300485*^9, 
  3.520241865726424*^9, 3.520247091155075*^9, 3.520248229451076*^9, 
  3.5202532289016237`*^9, 3.520253709894669*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im f\[UDoubleDot]nften exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520239279599411*^9, 3.520239284245871*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term5", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "\[ImaginaryI]"}], " ", "vz"}], "+", 
              RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
            "\[Tau]"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["q", "2"], " ", 
            SuperscriptBox["vz", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"q", " ", 
            SuperscriptBox["vr", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["Dd", "2"], " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"Dd", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "-", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
               SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
              "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["q", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["vr", "2"], "+", 
                 SuperscriptBox["vz", "2"]}], ")"}], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}],
       "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
       ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5202392875470552`*^9, 3.520239311454064*^9}, {
  3.5202405973186083`*^9, 3.520240606734579*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "4"], " ", 
     SuperscriptBox["\[Kappa]", "2"]}], 
    RowBox[{"2", " ", "q", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], "+", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"Dd", " ", 
    SuperscriptBox["z0", "4"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["vz", "2"], " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["vr", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "Dd", " ", "q", " ", "vz", " ", 
    SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["Dd", "2"], " ", "q", " ", 
    SuperscriptBox["z0", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["q", "2"], " ", 
    SuperscriptBox["vr", "2"], " ", 
    SuperscriptBox["\[Tau]", "3"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["q", "2"], " ", 
    SuperscriptBox["vz", "2"], " ", 
    SuperscriptBox["\[Tau]", "3"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.520239313132818*^9, {3.5202405991839952`*^9, 3.5202406073764133`*^9}, 
   3.5202418662375813`*^9, 3.520247091633855*^9, 3.5202482294844713`*^9, 
   3.520253228935433*^9, 3.520253709929912*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im5", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{" ", 
      RowBox[{"vz", " ", 
       SuperscriptBox["w0", "2"], " ", 
       SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "+", 
    FractionBox[
     RowBox[{"2", "  ", "Dd", " ", "q", " ", "vz", " ", 
      SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
      SuperscriptBox["\[Tau]", "2"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.520239317116096*^9, 3.520239320543622*^9}, {
  3.520240615013299*^9, 3.520240639206312*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"vz", " ", 
   SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
  RowBox[{
   SuperscriptBox["z0", "2"], "+", 
   RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]], "Output",
 CellChangeTimes->{
  3.520239321773467*^9, {3.520240632516962*^9, 3.520240640177185*^9}, 
   3.520241866260725*^9, 3.5202470916599617`*^9, 3.520248229517456*^9, 
   3.520253228967458*^9, 3.5202537099581337`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re5", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"term5", "-", 
    RowBox[{"I", "*", "im5"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520239325212759*^9, 3.52023933499199*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "4"], " ", 
     SuperscriptBox["\[Kappa]", "2"]}], "+", 
    RowBox[{"2", " ", "Dd", " ", "q", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       SuperscriptBox["z0", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["vz", "2"], " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["vr", "2"], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["Dd", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox["\[Tau]", "2"]}], "+", 
    RowBox[{"4", " ", "Dd", " ", 
     SuperscriptBox["q", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["vr", "2"], "+", 
       SuperscriptBox["vz", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Tau]", "3"]}]}], 
   RowBox[{"2", " ", "q", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.520239335713211*^9, 3.5202406483916807`*^9, 
  3.520241866493614*^9, 3.520247091882003*^9, 3.520248229551012*^9, 
  3.5202532289841413`*^9, 3.520253709993004*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["term im sechsten exponenten", "Subsubtitle",
 CellChangeTimes->{{3.520240657580947*^9, 3.5202406631866503`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term6", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"2", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[ImaginaryI]", " ", "vz"}], "+", 
              RowBox[{"2", " ", "Dd", " ", "\[Kappa]"}]}], ")"}], " ", 
            "\[Tau]"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["q", "2"], " ", 
            SuperscriptBox["vz", "2"], " ", 
            SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", "q", " ", "\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"q", " ", 
            SuperscriptBox["vr", "2"], " ", 
            SuperscriptBox["z0", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["Dd", "2"], " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"Dd", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["z0", "4"], " ", 
               SuperscriptBox["\[Kappa]", "2"]}], "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", "q", " ", "vz", " ", 
               SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
              "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["q", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["vr", "2"], "+", 
                 SuperscriptBox["vz", "2"]}], ")"}], " ", 
               SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}],
       "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", "q", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["w0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
       ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520240665151081*^9, 3.520240691481543*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "4"], " ", 
     SuperscriptBox["\[Kappa]", "2"]}], 
    RowBox[{"2", " ", "q", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], "-", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "vz", " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"Dd", " ", 
    SuperscriptBox["z0", "4"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["vz", "2"], " ", 
    SuperscriptBox["w0", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"q", " ", 
    SuperscriptBox["vr", "2"], " ", 
    SuperscriptBox["z0", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "Dd", " ", "q", " ", "vz", " ", 
    SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["Dd", "2"], " ", "q", " ", 
    SuperscriptBox["z0", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    SuperscriptBox["\[Tau]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["q", "2"], " ", 
    SuperscriptBox["vr", "2"], " ", 
    SuperscriptBox["\[Tau]", "3"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "Dd", " ", 
    SuperscriptBox["q", "2"], " ", 
    SuperscriptBox["vz", "2"], " ", 
    SuperscriptBox["\[Tau]", "3"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.5202406929755287`*^9, 3.520241866981266*^9, 
  3.520247092335465*^9, 3.520248229617785*^9, 3.520253229019104*^9, 
  3.5202537100287*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im6", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"vz", " ", 
        SuperscriptBox["w0", "2"], " ", 
        SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], "-", 
    FractionBox[
     RowBox[{"2", "  ", "Dd", " ", "q", " ", "vz", " ", 
      SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", 
      SuperscriptBox["\[Tau]", "2"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5202406954884033`*^9, 3.520240719368013*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"vz", " ", 
    SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
   RowBox[{
    SuperscriptBox["z0", "2"], "+", 
    RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]]}]], "Output",
 CellChangeTimes->{3.5202407209782667`*^9, 3.520241866999248*^9, 
  3.5202470923604507`*^9, 3.5202482296843452`*^9, 3.520253229052175*^9, 
  3.52025371009151*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"re6", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"term6", "-", 
    RowBox[{"I", "*", "im6"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520240723484602*^9, 3.520240735662116*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["w0", "2"], " ", 
     SuperscriptBox["z0", "4"], " ", 
     SuperscriptBox["\[Kappa]", "2"]}], "+", 
    RowBox[{"2", " ", "Dd", " ", "q", " ", 
     SuperscriptBox["z0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       SuperscriptBox["z0", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["q", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["vz", "2"], " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["z0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["vr", "2"], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["Dd", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox["\[Tau]", "2"]}], "+", 
    RowBox[{"4", " ", "Dd", " ", 
     SuperscriptBox["q", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["vr", "2"], "+", 
       SuperscriptBox["vz", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Tau]", "3"]}]}], 
   RowBox[{"2", " ", "q", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["w0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.520240736687581*^9, 3.520241867062378*^9, 
  3.520247092378518*^9, 3.520248229734685*^9, 3.520253229084367*^9, 
  3.520253710160136*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["combination of the terms", "Section",
 CellChangeTimes->{{3.52023737593359*^9, 3.520237379972723*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{
   SuperscriptBox["Aq0", "4"], " ", 
   SuperscriptBox["chi", "4"], " ", 
   SuperscriptBox["cm", "2"], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"E", "^", 
       RowBox[{"(", "re1", ")"}]}], "*", 
      RowBox[{"ExpToTrig", "[", 
       RowBox[{
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"I", "*", "im1"}], ")"}]}], "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"I", "*", "im2"}], ")"}]}]}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{"E", "^", 
       RowBox[{"(", "term3", ")"}]}]}], "+", 
     RowBox[{"4", "*", 
      RowBox[{"E", "^", 
       RowBox[{"(", "term4", ")"}]}]}], "+", 
     RowBox[{"4", "*", 
      RowBox[{"E", "^", 
       RowBox[{"(", "re5", ")"}]}], "*", 
      RowBox[{"ExpToTrig", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{"I", "*", "im5"}], ")"}]}], "+", 
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{"I", "*", "im6"}], ")"}]}]}], ")"}], "]"}]}]}], ")"}], "*", 
   SuperscriptBox["\[Pi]", "3"], " ", 
   SuperscriptBox["w0", "8"], " ", 
   RowBox[{
    SuperscriptBox["z0", "4"], "/", 
    RowBox[{"(", 
     RowBox[{"64", " ", 
      SuperscriptBox["q", "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w0", "2"], "+", 
         RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], "2"], 
      " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z0", "2"], "+", 
        RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.520237414824924*^9, 3.520237435196871*^9}, {
   3.5202374720289183`*^9, 3.520237478178241*^9}, {3.520237558729875*^9, 
   3.5202375610005302`*^9}, {3.520239440164752*^9, 3.520239448715104*^9}, {
   3.520239628620366*^9, 3.520239750558869*^9}, {3.52023979131948*^9, 
   3.520239821115542*^9}, 3.52023985249104*^9, {3.520240757836278*^9, 
   3.5202407912526493`*^9}, {3.520240821490615*^9, 3.520240877209538*^9}, {
   3.520241788247237*^9, 3.520241790596834*^9}, {3.520242046013626*^9, 
   3.520242047024617*^9}, {3.520248186599712*^9, 3.520248209934197*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Aq0", "4"], " ", 
    SuperscriptBox["chi", "4"], " ", 
    SuperscriptBox["cm", "2"], " ", 
    SuperscriptBox["\[Pi]", "3"], " ", 
    SuperscriptBox["w0", "8"], " ", 
    SuperscriptBox["z0", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "Dd", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "-", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["vz", "2"], " ", 
                SuperscriptBox["w0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["z0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  RowBox[{"4", " ", 
                   SuperscriptBox["Dd", "2"], " ", 
                   SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ",
              "\[Tau]"}], "-", 
            RowBox[{"2", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]]}], 
      "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["w0", "2"], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["w0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["vr", "2"], "+", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
            
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{"2", " ", "Dd", " ", 
            SuperscriptBox["q", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "3"]}]}], 
          RowBox[{"q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], 
            ")"}]}]]}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["z0", "4"], " ", 
            SuperscriptBox["\[Kappa]", "2"]}], "+", 
           RowBox[{"2", " ", "Dd", " ", "q", " ", 
            SuperscriptBox["z0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["w0", "2"]}], "+", 
              SuperscriptBox["z0", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["q", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["vz", "2"], " ", 
               SuperscriptBox["w0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["z0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["vr", "2"], "+", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["Dd", "2"], " ", 
                  SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ", 
            
            SuperscriptBox["\[Tau]", "2"]}], "+", 
           RowBox[{"4", " ", "Dd", " ", 
            SuperscriptBox["q", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vr", "2"], "+", 
              SuperscriptBox["vz", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Tau]", "3"]}]}], 
          RowBox[{"2", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["w0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
           
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z0", "2"], "+", 
             RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]}]],
        " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "]"}]}], "+", 
      
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "Dd", " ", 
             SuperscriptBox["w0", "2"], " ", 
             SuperscriptBox["z0", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"]}], "-", 
            RowBox[{"q", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["vz", "2"], " ", 
                SuperscriptBox["w0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["z0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["vr", "2"], "+", 
                  RowBox[{"4", " ", 
                   SuperscriptBox["Dd", "2"], " ", 
                   SuperscriptBox["\[Kappa]", "2"]}]}], ")"}]}]}], ")"}], " ",
              "\[Tau]"}], "-", 
            RowBox[{"2", " ", "Dd", " ", 
             SuperscriptBox["q", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["vr", "2"], "+", 
               SuperscriptBox["vz", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["w0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z0", "2"], "+", 
            RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}]]], 
       " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"2", " ", "vz", " ", 
          SuperscriptBox["z0", "2"], " ", "\[Kappa]", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["z0", "2"], "+", 
          RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}]], "]"}]}]}], 
     ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", 
    SuperscriptBox["q", "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w0", "2"], "+", 
       RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}], "2"], " ", 
    
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z0", "2"], "+", 
      RowBox[{"2", " ", "Dd", " ", "q", " ", "\[Tau]"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.520241791052696*^9, 3.520241867113606*^9, 
  3.520242051089316*^9, 3.520247092412631*^9, 3.520248229788611*^9, 
  3.520253229102899*^9, 3.520253710229244*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define some replacement-formulas for simplification", "Section",
 CellChangeTimes->{{3.519225761123719*^9, 3.51922576749866*^9}, {
  3.519227847963977*^9, 3.519227866401497*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"z0qexp", "=", 
  RowBox[{"{", 
   RowBox[{"z0", "\[Rule]", 
    RowBox[{"z0q", "*", 
     RowBox[{"Sqrt", "[", "q", "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"w0qexp", "=", 
  RowBox[{"{", 
   RowBox[{"w0", "\[Rule]", 
    RowBox[{"w0q", "*", 
     RowBox[{"Sqrt", "[", "q", "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Nexp", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"cm", "\[Rule]", 
     RowBox[{"N", "*", 
      RowBox[{
       RowBox[{"q", "^", 
        RowBox[{"(", 
         RowBox[{"3", "/", "2"}], ")"}]}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Pi]", "^", 
          RowBox[{"(", 
           RowBox[{"3", "/", "2"}], ")"}]}], "*", 
         RowBox[{"w0", "^", "2"}], "*", "z0"}], ")"}]}]}]}], ",", 
    RowBox[{"cm", "\[Rule]", 
     RowBox[{"N", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Pi]", "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}], "*", 
        RowBox[{"w0q", "^", "2"}], "*", "z0q"}], ")"}]}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"tauDexp", "=", 
  RowBox[{"{", 
   RowBox[{"Dd", "\[Rule]", " ", 
    RowBox[{
     RowBox[{"w0q", "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", "*", "\[Tau]Dq"}], ")"}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"sparamexp", " ", "=", 
  RowBox[{"{", 
   RowBox[{"w0q", "\[Rule]", 
    RowBox[{"z0q", "/", "Sq"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"taufrexp", "=", 
  RowBox[{"{", 
   RowBox[{"vr", "\[Rule]", 
    RowBox[{"w0", "/", "\[Tau]fr"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"taufzexp", "=", 
  RowBox[{"{", 
   RowBox[{"vz", "\[Rule]", 
    RowBox[{"z0", "/", "\[Tau]fz"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"allexp", " ", "=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{
   "z0qexp", ",", "w0qexp", ",", "Nexp", ",", "tauDexp", ",", "sparamexp", 
    ",", "taufrexp", ",", " ", "taufzexp"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allexpreplace", "[", "e_", "]"}], ":=", 
  RowBox[{"ReplaceRepeated", "[", 
   RowBox[{"e", ",", "allexp"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"dividerToGetToG", "=", 
  RowBox[{
   SuperscriptBox["Aq0", "2"], " ", 
   SuperscriptBox["chi", "2"], " ", "N"}]}]}], "Input",
 CellChangeTimes->{{3.5192278796347857`*^9, 3.51922788373866*^9}, {
   3.5192280404721327`*^9, 3.5192280865816793`*^9}, {3.519228235085371*^9, 
   3.519228453356268*^9}, {3.519228486264221*^9, 3.519228543561183*^9}, {
   3.5192286432937593`*^9, 3.519228650816778*^9}, {3.519228741300831*^9, 
   3.51922874432421*^9}, {3.5192330404786386`*^9, 3.519233075199617*^9}, {
   3.51923311113347*^9, 3.519233156785954*^9}, {3.519233336131023*^9, 
   3.519233460274477*^9}, {3.519233502449368*^9, 3.5192335663150063`*^9}, {
   3.5192340194292088`*^9, 3.5192340197572527`*^9}, {3.519234120625125*^9, 
   3.519234145800989*^9}, {3.519234472314494*^9, 3.519234483344946*^9}, {
   3.519235101453726*^9, 3.519235104749152*^9}, 3.519235136013392*^9, {
   3.519235234935113*^9, 3.519235236259161*^9}, {3.519236384687229*^9, 
   3.519236384966714*^9}, {3.519325426318248*^9, 3.5193254362177763`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"z0", "\[Rule]", 
   RowBox[{
    SqrtBox["q"], " ", "z0q"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.5202470924444437`*^9, 
   3.520248229817915*^9, 3.5202532291350594`*^9, 3.5202537102955103`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"w0", "\[Rule]", 
   RowBox[{
    SqrtBox["q"], " ", "w0q"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.5202470924444437`*^9, 
   3.520248229817915*^9, 3.5202532291350594`*^9, 3.5202537102970667`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cm", "\[Rule]", 
    FractionBox[
     RowBox[{"N", " ", 
      SuperscriptBox["q", 
       RowBox[{"3", "/", "2"}]]}], 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0", "2"], " ", "z0"}]]}], ",", 
   RowBox[{"cm", "\[Rule]", 
    FractionBox["N", 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0q", "2"], " ", "z0q"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.5202470924444437`*^9, 
   3.520248229817915*^9, 3.5202532291350594`*^9, 3.520253710298437*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Dd", "\[Rule]", 
   FractionBox[
    SuperscriptBox["w0q", "2"], 
    RowBox[{"4", " ", "\[Tau]Dq"}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.5202470924444437`*^9, 
   3.520248229817915*^9, 3.5202532291350594`*^9, 3.520253710299799*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"w0q", "\[Rule]", 
   FractionBox["z0q", "Sq"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.5202470924444437`*^9, 
   3.520248229817915*^9, 3.5202532291350594`*^9, 3.520253710301034*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"vr", "\[Rule]", 
   FractionBox["w0", "\[Tau]fr"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.5202470924444437`*^9, 
   3.520248229817915*^9, 3.5202532291350594`*^9, 3.520253710302227*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"vz", "\[Rule]", 
   FractionBox["z0", "\[Tau]fz"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.5202470924444437`*^9, 
   3.520248229817915*^9, 3.5202532291350594`*^9, 3.5202537103034353`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"z0", "\[Rule]", 
    RowBox[{
     SqrtBox["q"], " ", "z0q"}]}], ",", 
   RowBox[{"w0", "\[Rule]", 
    RowBox[{
     SqrtBox["q"], " ", "w0q"}]}], ",", 
   RowBox[{"cm", "\[Rule]", 
    FractionBox[
     RowBox[{"N", " ", 
      SuperscriptBox["q", 
       RowBox[{"3", "/", "2"}]]}], 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0", "2"], " ", "z0"}]]}], ",", 
   RowBox[{"cm", "\[Rule]", 
    FractionBox["N", 
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["w0q", "2"], " ", "z0q"}]]}], ",", 
   RowBox[{"Dd", "\[Rule]", 
    FractionBox[
     SuperscriptBox["w0q", "2"], 
     RowBox[{"4", " ", "\[Tau]Dq"}]]}], ",", 
   RowBox[{"w0q", "\[Rule]", 
    FractionBox["z0q", "Sq"]}], ",", 
   RowBox[{"vr", "\[Rule]", 
    FractionBox["w0", "\[Tau]fr"]}], ",", 
   RowBox[{"vz", "\[Rule]", 
    FractionBox["z0", "\[Tau]fz"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.5202470924444437`*^9, 
   3.520248229817915*^9, 3.5202532291350594`*^9, 3.5202537103048153`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Aq0", "2"], " ", 
  SuperscriptBox["chi", "2"], " ", "N"}]], "Output",
 CellChangeTimes->{
  3.51922808922537*^9, 3.519228282901822*^9, 3.5192283154152527`*^9, 
   3.519228430790887*^9, 3.519228509628227*^9, 3.519228544896884*^9, 
   3.5192286514073963`*^9, 3.519228793115946*^9, 3.519229807749937*^9, 
   3.519233159450952*^9, {3.5192335185361958`*^9, 3.519233572107587*^9}, {
   3.5192340211679993`*^9, 3.51923403800362*^9}, 3.519234150773581*^9, 
   3.51923449279029*^9, 3.519234983833067*^9, 3.5192350596648684`*^9, 
   3.519235105238105*^9, 3.51923513755095*^9, 3.519235178330662*^9, 
   3.519235240301165*^9, 3.519236385840632*^9, 3.519240823632946*^9, 
   3.5192422823673677`*^9, 3.5193602732201233`*^9, 3.519582689243532*^9, 
   3.520172899808483*^9, 3.520242056916877*^9, 3.5202470924444437`*^9, 
   3.520248229817915*^9, 3.5202532291350594`*^9, 3.520253710306218*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"G4t", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"allexpreplace", "[", 
     RowBox[{
      RowBox[{"g4", "[", "\[Tau]", "]"}], "/", 
      RowBox[{"dividerToGetToG", "^", "2"}]}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.52024222171069*^9, 3.5202422221489477`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Tau]", "2"], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "+", 
             SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
           "\[Tau]Dq"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["Sq", "2"], " ", 
           SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
        SuperscriptBox["\[Tau]fr", "2"], " ", 
        SuperscriptBox["\[Tau]fz", "2"]}], "+", 
       RowBox[{"2", " ", "q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Tau]", " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fr", "2"]}], "+", 
             RowBox[{"2", " ", "\[Tau]Dq", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["\[Tau]fr", "2"], "+", 
                SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
       SuperscriptBox["\[Tau]fr", "2"], " ", 
       SuperscriptBox["\[Tau]fz", "2"]}]]}]], " ", 
   SuperscriptBox["Sq", "2"], " ", 
   SuperscriptBox["\[Tau]Dq", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]]}], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
       RowBox[{"\[Tau]", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"4", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.520242219208866*^9, 3.520242226140377*^9}, 
   3.520247100578216*^9, 3.520248231616716*^9, 3.520253229171734*^9, 
   3.520253710395061*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myexpsimplification", "[", 
  RowBox[{"G4t", "[", "\[Tau]", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.520247084568202*^9, 3.52024708548624*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{
   SuperscriptBox["Sq", "2"], " ", 
   SuperscriptBox["\[Tau]Dq", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}], "+", 
           RowBox[{"2", " ", "q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Tau]", " ", 
               SuperscriptBox["\[Tau]fz", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Tau]", " ", 
                  SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                 RowBox[{"2", " ", "\[Tau]Dq", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fr", "2"], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Tau]", "2"], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"2", " ", "\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Tau]", "2"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"2", " ", "\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0q", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"], " ", 
             SuperscriptBox["\[Tau]fz", "2"]}], "+", 
            RowBox[{"2", " ", "q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Tau]", " ", 
                SuperscriptBox["\[Tau]fz", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["Sq", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Tau]", " ", 
                   SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                  RowBox[{"2", " ", "\[Tau]Dq", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"4", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.520247086850233*^9, 3.520247100818907*^9}, 
   3.520248231715261*^9, 3.5202532292062893`*^9, 3.5202537104297457`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TeXForm", "[", 
  RowBox[{"myexpsimplification", "[", 
   RowBox[{"G4t", "[", "\[Tau]", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5202531264000607`*^9, 3.520253139172021*^9}, {
  3.520253213432293*^9, 3.520253222370088*^9}}],

Cell["\<\
\\frac{\\text{Sq}^2 \\text{$\\tau $Dq}^3 \\left(2 \\exp \\left(-\\frac{2 q \
\\tau ^2 \\text{$\\tau $Dq} \\left(\\text{Sq}^2
   \\left(\\tau  \\text{$\\tau $fr}^2+2 \\text{$\\tau $Dq} \
\\left(\\text{$\\tau $fr}^2+\\text{$\\tau $fz}^2\\right)\\right)+\\tau
    \\text{$\\tau $fz}^2\\right)+\\kappa ^2 \\text{$\\tau $fr}^2 \
\\text{$\\tau $fz}^2 \\text{z0q}^2 \\left(2
   \\left(\\text{Sq}^2+1\\right) \\tau  \\text{$\\tau $Dq}+4 \\text{Sq}^2 \
\\text{$\\tau $Dq}^2+\\tau ^2\\right)}{\\text{$\\tau
   $fr}^2 \\text{$\\tau $fz}^2 (\\tau +2 \\text{$\\tau $Dq}) \\left(2 \
\\text{Sq}^2 \\text{$\\tau $Dq}+\\tau \\right)}\\right)+4
   \\cos \\left(\\frac{2 \\kappa  \\sqrt{q} \\text{Sq}^2 \\tau  \\text{$\\tau \
$Dq} \\text{z0q}}{2 \\text{Sq}^2 \\text{$\\tau
   $Dq} \\text{$\\tau $fz}+\\tau  \\text{$\\tau $fz}}\\right) \\exp \
\\left(-\\frac{2 q \\tau ^2 \\text{$\\tau $Dq}
   \\left(\\text{Sq}^2 \\left(\\tau  \\text{$\\tau $fr}^2+2 \\text{$\\tau \
$Dq} \\left(\\text{$\\tau $fr}^2+\\text{$\\tau
   $fz}^2\\right)\\right)+\\tau  \\text{$\\tau $fz}^2\\right)+\\kappa ^2 \
\\text{$\\tau $fr}^2 \\text{$\\tau $fz}^2
   \\text{z0q}^2 \\left(\\left(\\text{Sq}^2+2\\right) \\tau  \\text{$\\tau \
$Dq}+2 \\text{Sq}^2 \\text{$\\tau $Dq}^2+\\tau
   ^2\\right)}{\\text{$\\tau $fr}^2 \\text{$\\tau $fz}^2 (\\tau +2 \
\\text{$\\tau $Dq}) \\left(2 \\text{Sq}^2 \\text{$\\tau
   $Dq}+\\tau \\right)}\\right)+\\exp \\left(-\\frac{\\tau  \\left(2 q \\tau  \
\\text{$\\tau $Dq} \\left(\\text{Sq}^2 \\left(\\tau 
   \\text{$\\tau $fr}^2+2 \\text{$\\tau $Dq} \\left(\\text{$\\tau \
$fr}^2+\\text{$\\tau $fz}^2\\right)\\right)+\\tau 
   \\text{$\\tau $fz}^2\\right)+\\kappa ^2 \\text{$\\tau $fr}^2 \\text{$\\tau \
$fz}^2 \\text{z0q}^2 (\\tau +2 \\text{$\\tau
   $Dq})\\right)}{\\text{$\\tau $fr}^2 \\text{$\\tau $fz}^2 (\\tau +2 \
\\text{$\\tau $Dq}) \\left(2 \\text{Sq}^2 \\text{$\\tau
   $Dq}+\\tau \\right)}\\right)+\\cos \\left(\\frac{4 \\kappa  \\sqrt{q} \
\\text{Sq}^2 \\tau  \\text{$\\tau $Dq} \\text{z0q}}{2
   \\text{Sq}^2 \\text{$\\tau $Dq} \\text{$\\tau $fz}+\\tau  \\text{$\\tau \
$fz}}\\right) \\exp \\left(-\\frac{\\tau  \\left(2 q
   \\tau  \\text{$\\tau $Dq} \\left(\\text{Sq}^2 \\left(\\tau  \\text{$\\tau \
$fr}^2+2 \\text{$\\tau $Dq} \\left(\\text{$\\tau
   $fr}^2+\\text{$\\tau $fz}^2\\right)\\right)+\\tau  \\text{$\\tau \
$fz}^2\\right)+\\kappa ^2 \\text{$\\tau $fr}^2 \\text{$\\tau
   $fz}^2 \\text{z0q}^2 (\\tau +2 \\text{$\\tau $Dq})\\right)}{\\text{$\\tau \
$fr}^2 \\text{$\\tau $fz}^2 (\\tau +2
   \\text{$\\tau $Dq}) \\left(2 \\text{Sq}^2 \\text{$\\tau $Dq}+\\tau \
\\right)}\\right)\\right)}{4 (\\tau +2 \\text{$\\tau
   $Dq})^2 \\left(2 \\text{Sq}^2 \\text{$\\tau $Dq}+\\tau \\right)}\
\>", "Output",
 CellChangeTimes->{3.520253140018643*^9, 3.520253229354435*^9, 
  3.520253710580501*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["assigning the no-flow case", "Section",
 CellChangeTimes->{{3.520238964204406*^9, 3.52023897019488*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"G4noflow", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"z0q", "^", "2"}]}], " ", 
          RowBox[{"\[Kappa]", "^", "2"}]}], ")"}]}], "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"z0q", "^", "2"}], " ", 
              RowBox[{"\[Kappa]", "^", "2"}], " ", "\[Tau]"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", 
               RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
           ")"}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"z0q", "^", "2"}], " ", 
               RowBox[{"\[Kappa]", "^", "2"}], " ", 
               RowBox[{"(", 
                RowBox[{"\[Tau]", "+", 
                 RowBox[{
                  RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"2", " ", 
                RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
            ")"}]}], ")"}]}]}]}], ")"}], " ", 
     RowBox[{"Sq", "^", "2"}], " ", 
     RowBox[{"\[Tau]Dq", "^", "3"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Tau]", "+", 
        RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], "^", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"2", " ", 
        RowBox[{"Sq", "^", "2"}], " ", "\[Tau]Dq"}]}], ")"}]}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.519375355037898*^9, 3.519375355229719*^9}, 
   3.51937539791216*^9, 3.5193759584935007`*^9, 3.519534216936241*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["z0q", "2"]}], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]"}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]]}]}], ")"}], " ", 
   SuperscriptBox["Sq", "2"], " ", 
   SuperscriptBox["\[Tau]Dq", "3"]}], 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{"\[Tau]", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.519375398940763*^9, 3.519376036458522*^9, 
  3.519376087036509*^9, 3.5193762614266148`*^9, 3.51953421800255*^9, 
  3.5195827010558805`*^9, 3.520209336310809*^9, 3.520242254167913*^9, 
  3.520247100844274*^9, 3.520248231738081*^9, 3.5202532293725452`*^9, 
  3.520253710613312*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["division", "Section",
 CellChangeTimes->{{3.520239115103595*^9, 3.520239117205905*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Gfinal4", "[", "\[Tau]_", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"G4t", "[", "\[Tau]", "]"}], "/", 
     RowBox[{"G4noflow", "[", "\[Tau]", "]"}]}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "700"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.519534489316717*^9, 3.519534514418784*^9}, {
  3.520239242012629*^9, 3.520239249237952*^9}, {3.520239291002108*^9, 
  3.5202392996736603`*^9}, {3.5202410335797787`*^9, 3.520241040882122*^9}, {
  3.520242264692437*^9, 3.520242269811656*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", 
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Tau]Dq"}], 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]]}], ")"}], "2"]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["z0q", "2"], " ", 
        SuperscriptBox["\[Kappa]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[Tau]"}], "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], "+", 
       RowBox[{"2", " ", "q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
          FractionBox[
           SuperscriptBox["Sq", "2"], 
           SuperscriptBox["\[Tau]fz", "2"]]}], ")"}]}]}], 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z0q", "2"], " ", 
         SuperscriptBox["\[Kappa]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{"4", " ", 
           SqrtBox["q"], " ", 
           SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
           "\[Tau]", " ", "\[Tau]Dq"}], 
          RowBox[{
           RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
         "]"}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.520242330233901*^9, 3.520247160214301*^9, 
  3.520248242592692*^9, 3.5202532294353943`*^9, 3.520253710652491*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
NLCS with flow \[Dash]\[NonBreakingSpace]Summary of results employed in the \
thesis as model\
\>", "Title",
 CellFrame->{{0, 0}, {0, 3}},
 CellChangeTimes->{{3.519533817506448*^9, 3.519533842505031*^9}, {
  3.5203111153543577`*^9, 3.520311116311019*^9}}],

Cell["G1", "Title",
 CellChangeTimes->{{3.5203110159962807`*^9, 3.5203110162742147`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        FractionBox["\[Tau]", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{"2", " ", "N", " ", "z0q", " ", "\[Tau]Dq", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["z0q", "2"]}], " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "+", 
       RowBox[{"q", " ", 
        SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
          FractionBox[
           SuperscriptBox["Sq", "2"], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}]]}], "+", 
        RowBox[{"q", " ", 
         SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"\[Tau]", "+", 
                RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
              SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
           FractionBox[
            SuperscriptBox["Sq", "2"], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.520246627800668*^9, 3.5202467401114473`*^9, {3.520253609731148*^9, 
   3.5202536193338614`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["G2", "Title",
 CellChangeTimes->{{3.52031104585109*^9, 3.5203110478093348`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        FractionBox[
         RowBox[{"2", " ", "\[Tau]"}], 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "\[Tau]"}], "+", 
      RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{"z0q", " ", "\[Tau]Dq", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["z0q", "2"], " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox["\[Tau]", "2"]}], "+", 
            RowBox[{"6", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
             "\[Tau]Dq"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Sq", "2"], " ", 
             SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}], "+", 
         RowBox[{"2", " ", "q", " ", 
          SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]", " ", 
             SuperscriptBox["\[Tau]fz", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "\[Tau]", " ", 
                SuperscriptBox["\[Tau]fr", "2"]}], "+", 
               RowBox[{"3", " ", "\[Tau]Dq", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Tau]fr", "2"], "+", 
                  SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Tau]"}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fr", "2"], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["\[Tau]", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["Sq", "2"]}]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"3", " ", "\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SuperscriptBox["\[Tau]", "2"]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"3", " ", "\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Tau]"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"4", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"2", " ", "\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.5202469321803503`*^9, 3.52024694782981*^9}, 
   3.520253588860108*^9, 3.520253651677538*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["G3", "Title",
 CellChangeTimes->{{3.520311081328456*^9, 3.520311082152361*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"z0q", " ", "\[Tau]Dq", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "q"}], " ", 
         SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"]}]], "+", 
           FractionBox[
            SuperscriptBox["Sq", "2"], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{
                SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Tau]", "2"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "\[Tau]"}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}], 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]]}], 
         "+", 
         RowBox[{"q", " ", 
          SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
               SuperscriptBox["\[Tau]fr", "2"]}]]}], "-", 
            FractionBox[
             SuperscriptBox["Sq", "2"], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"\[Tau]", "+", 
                RowBox[{
                 SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
              SuperscriptBox["\[Tau]fz", "2"]}]]}], ")"}]}]}]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]", " ", "\[Tau]Dq"}], 
         RowBox[{
          RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
        "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[Tau]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["z0q", "2"], " ", 
              SuperscriptBox["\[Kappa]", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
              SuperscriptBox["\[Tau]fr", "2"], " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{"q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fz", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["Sq", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Tau]", " ", 
                    SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                   RowBox[{"\[Tau]Dq", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}]]}]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["q"], " ", 
          SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
          "\[Tau]", " ", "\[Tau]Dq"}], 
         RowBox[{
          RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
          RowBox[{
           SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
        "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"64", " ", "N", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z0q", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox["\[Tau]", 
         RowBox[{
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", "\[Tau]Dq"}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.520247020400457*^9, 3.520253421432692*^9, 
  3.5202536793874063`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["G4", "Title",
 CellChangeTimes->{{3.520311099738076*^9, 3.520311101039605*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Tau]", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}]}]], 
  RowBox[{
   SuperscriptBox["Sq", "2"], " ", 
   SuperscriptBox["\[Tau]Dq", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Tau]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["z0q", "2"], " ", 
            SuperscriptBox["\[Kappa]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "+", 
              RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
            SuperscriptBox["\[Tau]fr", "2"], " ", 
            SuperscriptBox["\[Tau]fz", "2"]}], "+", 
           RowBox[{"2", " ", "q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Tau]", " ", 
               SuperscriptBox["\[Tau]fz", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["Sq", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Tau]", " ", 
                  SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                 RowBox[{"2", " ", "\[Tau]Dq", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
         SuperscriptBox["\[Tau]fr", "2"], " ", 
         SuperscriptBox["\[Tau]fz", "2"]}]]}]], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Tau]", "2"], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"2", " ", "\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["z0q", "2"], " ", 
           SuperscriptBox["\[Kappa]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Tau]", "2"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", 
                SuperscriptBox["Sq", "2"]}], ")"}], " ", "\[Tau]", " ", 
              "\[Tau]Dq"}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["Sq", "2"], " ", 
              SuperscriptBox["\[Tau]Dq", "2"]}]}], ")"}], " ", 
           SuperscriptBox["\[Tau]fr", "2"], " ", 
           SuperscriptBox["\[Tau]fz", "2"]}], "+", 
          RowBox[{"2", " ", "q", " ", 
           SuperscriptBox["\[Tau]", "2"], " ", "\[Tau]Dq", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Tau]", " ", 
              SuperscriptBox["\[Tau]fz", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["Sq", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Tau]", " ", 
                 SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                RowBox[{"2", " ", "\[Tau]Dq", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Tau]fr", "2"], "+", 
                   SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Tau]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z0q", "2"], " ", 
             SuperscriptBox["\[Kappa]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "+", 
               RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
             SuperscriptBox["\[Tau]fr", "2"], " ", 
             SuperscriptBox["\[Tau]fz", "2"]}], "+", 
            RowBox[{"2", " ", "q", " ", "\[Tau]", " ", "\[Tau]Dq", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Tau]", " ", 
                SuperscriptBox["\[Tau]fz", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["Sq", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Tau]", " ", 
                   SuperscriptBox["\[Tau]fr", "2"]}], "+", 
                  RowBox[{"2", " ", "\[Tau]Dq", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Tau]fr", "2"], "+", 
                    SuperscriptBox["\[Tau]fz", "2"]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", "\[Tau]Dq"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq"}]}], ")"}], " ", 
          SuperscriptBox["\[Tau]fr", "2"], " ", 
          SuperscriptBox["\[Tau]fz", "2"]}]]}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"4", " ", 
         SqrtBox["q"], " ", 
         SuperscriptBox["Sq", "2"], " ", "z0q", " ", "\[Kappa]", " ", 
         "\[Tau]", " ", "\[Tau]Dq"}], 
        RowBox[{
         RowBox[{"\[Tau]", " ", "\[Tau]fz"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Sq", "2"], " ", "\[Tau]Dq", " ", "\[Tau]fz"}]}]], 
       "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.520247086850233*^9, 3.520247100818907*^9}, 
   3.520248231715261*^9, 3.5202532292062893`*^9, 3.5202537104297457`*^9}]
}, Open  ]]
},
WindowSize->{1272, 907},
WindowMargins->{{30, Automatic}, {Automatic, 0}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 373, 7, 154, "Title"],
Cell[943, 31, 203, 4, 57, "Subtitle"],
Cell[1149, 37, 237, 5, 32, "Subsubtitle"],
Cell[1389, 44, 239, 4, 30, "Subsubsection"],
Cell[1631, 50, 497, 8, 54, "Subsubsection"],
Cell[2131, 60, 142, 3, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[2298, 67, 178, 3, 68, "Subtitle"],
Cell[CellGroupData[{
Cell[2501, 74, 158, 3, 42, "Subsection"],
Cell[2662, 79, 804, 24, 33, "Input"],
Cell[CellGroupData[{
Cell[3491, 107, 2620, 68, 118, "Input"],
Cell[6114, 177, 3788, 111, 108, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9939, 293, 2745, 73, 221, "Input"],
Cell[12687, 368, 3944, 115, 108, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16668, 488, 2882, 75, 191, "Input"],
Cell[19553, 565, 4087, 119, 144, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23677, 689, 3323, 88, 202, "Input"],
Cell[27003, 779, 4200, 122, 140, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[31252, 907, 143, 3, 83, "Section"],
Cell[CellGroupData[{
Cell[31420, 914, 661, 18, 33, "Input"],
Cell[32084, 934, 1713, 50, 72, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33834, 989, 565, 16, 33, "Input"],
Cell[34402, 1007, 1128, 31, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[35579, 1044, 98, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[35702, 1049, 2223, 57, 129, "Input"],
Cell[37928, 1108, 1605, 34, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39582, 1148, 119, 2, 83, "Section"],
Cell[39704, 1152, 273, 9, 7, "Text"],
Cell[CellGroupData[{
Cell[40002, 1165, 103, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[40130, 1170, 1200, 26, 53, "Input"],
Cell[41333, 1198, 595, 11, 47, "Message"],
Cell[41931, 1211, 593, 11, 47, "Message"],
Cell[42527, 1224, 593, 11, 47, "Message"],
Cell[43123, 1237, 535, 11, 26, "Message"],
Cell[43661, 1250, 4730, 128, 215, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48428, 1383, 909, 21, 72, "Input"],
Cell[49340, 1406, 593, 11, 47, "Message"],
Cell[49936, 1419, 4638, 130, 236, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54611, 1554, 878, 20, 53, "Input"],
Cell[55492, 1576, 6238, 166, 228, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61767, 1747, 884, 20, 66, "Input"],
Cell[62654, 1769, 5340, 142, 285, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[68043, 1917, 101, 1, 52, "Subsection"],
Cell[CellGroupData[{
Cell[68169, 1922, 832, 20, 66, "Input"],
Cell[69004, 1944, 5141, 135, 548, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74182, 2084, 812, 20, 66, "Input"],
Cell[74997, 2106, 5122, 135, 548, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80156, 2246, 783, 20, 66, "Input"],
Cell[80942, 2268, 4580, 120, 412, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85559, 2393, 707, 18, 66, "Input"],
Cell[86269, 2413, 4590, 121, 412, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[90908, 2540, 101, 1, 52, "Subsection"],
Cell[CellGroupData[{
Cell[91034, 2545, 722, 17, 66, "Input"],
Cell[91759, 2564, 4960, 139, 250, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96756, 2708, 691, 16, 41, "Input"],
Cell[97450, 2726, 4891, 138, 250, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[102378, 2869, 672, 16, 41, "Input"],
Cell[103053, 2887, 595, 11, 58, "Message"],
Cell[103651, 2900, 593, 11, 58, "Message"],
Cell[104247, 2913, 3871, 109, 250, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108155, 3027, 630, 15, 41, "Input"],
Cell[108788, 3044, 593, 11, 58, "Message"],
Cell[109384, 3057, 593, 11, 58, "Message"],
Cell[109980, 3070, 593, 11, 58, "Message"],
Cell[110576, 3083, 535, 11, 32, "Message"],
Cell[111114, 3096, 4243, 114, 301, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115394, 3215, 373, 8, 41, "Input"],
Cell[115770, 3225, 595, 11, 58, "Message"],
Cell[116368, 3238, 593, 11, 58, "Message"],
Cell[116964, 3251, 592, 11, 58, "Message"],
Cell[117559, 3264, 535, 11, 32, "Message"],
Cell[118097, 3277, 4239, 114, 301, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[122397, 3398, 197, 3, 103, "Section"],
Cell[CellGroupData[{
Cell[122619, 3405, 153, 2, 52, "Subsection"],
Cell[CellGroupData[{
Cell[122797, 3411, 1285, 27, 66, "Input"],
Cell[124085, 3440, 6981, 176, 375, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131103, 3621, 1352, 27, 66, "Input"],
Cell[132458, 3650, 595, 11, 58, "Message"],
Cell[133056, 3663, 593, 11, 58, "Message"],
Cell[133652, 3676, 595, 11, 58, "Message"],
Cell[134250, 3689, 537, 11, 26, "Message"],
Cell[134790, 3702, 8345, 225, 414, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143172, 3932, 975, 21, 53, "Input"],
Cell[144150, 3955, 16733, 446, 697, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[160920, 4406, 804, 19, 53, "Input"],
Cell[161727, 4427, 14613, 388, 574, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[176389, 4821, 102, 1, 52, "Subsection"],
Cell[CellGroupData[{
Cell[176516, 4826, 833, 20, 66, "Input"],
Cell[177352, 4848, 14315, 382, 717, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[191704, 5235, 804, 20, 66, "Input"],
Cell[192511, 5257, 593, 11, 58, "Message"],
Cell[193107, 5270, 13213, 350, 1188, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[206357, 5625, 781, 20, 66, "Input"],
Cell[207141, 5647, 12579, 343, 988, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[219757, 5995, 705, 18, 66, "Input"],
Cell[220465, 6015, 12458, 346, 753, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[232972, 6367, 127, 2, 52, "Subsection"],
Cell[CellGroupData[{
Cell[233124, 6373, 726, 17, 66, "Input"],
Cell[233853, 6392, 592, 11, 58, "Message"],
Cell[234448, 6405, 6569, 182, 335, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241054, 6592, 690, 16, 41, "Input"],
Cell[241747, 6610, 6757, 190, 335, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[248541, 6805, 660, 16, 41, "Input"],
Cell[249204, 6823, 6167, 171, 335, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255408, 6999, 631, 15, 41, "Input"],
Cell[256042, 7016, 6236, 169, 456, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[262315, 7190, 401, 9, 41, "Input"],
Cell[262719, 7201, 6304, 170, 456, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[269084, 7378, 195, 3, 103, "Section"],
Cell[CellGroupData[{
Cell[269304, 7385, 141, 2, 52, "Subsection"],
Cell[CellGroupData[{
Cell[269470, 7391, 953, 22, 66, "Input"],
Cell[270426, 7415, 6963, 178, 375, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[277426, 7598, 910, 21, 66, "Input"],
Cell[278339, 7621, 593, 11, 58, "Message"],
Cell[278935, 7634, 593, 11, 58, "Message"],
Cell[279531, 7647, 593, 11, 58, "Message"],
Cell[280127, 7660, 535, 11, 32, "Message"],
Cell[280665, 7673, 8433, 230, 550, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[289135, 7908, 881, 20, 66, "Input"],
Cell[290019, 7930, 12710, 349, 556, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302766, 8284, 806, 19, 66, "Input"],
Cell[303575, 8305, 593, 11, 58, "Message"],
Cell[304171, 8318, 593, 11, 58, "Message"],
Cell[304767, 8331, 593, 11, 58, "Message"],
Cell[305363, 8344, 535, 11, 32, "Message"],
Cell[305901, 8357, 18151, 496, 1085, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[324101, 8859, 102, 1, 52, "Subsection"],
Cell[CellGroupData[{
Cell[324228, 8864, 887, 21, 66, "Input"],
Cell[325118, 8887, 593, 11, 58, "Message"],
Cell[325714, 8900, 593, 11, 58, "Message"],
Cell[326310, 8913, 593, 11, 58, "Message"],
Cell[326906, 8926, 535, 11, 26, "Message"],
Cell[327444, 8939, 18411, 501, 799, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[345892, 9445, 808, 20, 53, "Input"],
Cell[346703, 9467, 593, 11, 47, "Message"],
Cell[347299, 9480, 593, 11, 47, "Message"],
Cell[347895, 9493, 593, 11, 47, "Message"],
Cell[348491, 9506, 535, 11, 26, "Message"],
Cell[349029, 9519, 19227, 523, 1089, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[368293, 10047, 786, 20, 66, "Input"],
Cell[369082, 10069, 592, 11, 58, "Message"],
Cell[369677, 10082, 593, 11, 58, "Message"],
Cell[370273, 10095, 18923, 518, 1401, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[389233, 10618, 704, 18, 66, "Input"],
Cell[389940, 10638, 592, 11, 58, "Message"],
Cell[390535, 10651, 593, 11, 58, "Message"],
Cell[391131, 10664, 595, 11, 58, "Message"],
Cell[391729, 10677, 537, 11, 26, "Message"],
Cell[392269, 10690, 17770, 486, 1165, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[410088, 11182, 127, 2, 42, "Subsection"],
Cell[CellGroupData[{
Cell[410240, 11188, 769, 18, 53, "Input"],
Cell[411012, 11208, 593, 11, 47, "Message"],
Cell[411608, 11221, 593, 11, 47, "Message"],
Cell[412204, 11234, 593, 11, 47, "Message"],
Cell[412800, 11247, 537, 11, 26, "Message"],
Cell[413340, 11260, 17502, 480, 1066, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[430879, 11745, 689, 16, 33, "Input"],
Cell[431571, 11763, 593, 11, 47, "Message"],
Cell[432167, 11776, 595, 11, 47, "Message"],
Cell[432765, 11789, 592, 11, 47, "Message"],
Cell[433360, 11802, 537, 11, 26, "Message"],
Cell[433900, 11815, 17781, 494, 787, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[451718, 12314, 666, 16, 33, "Input"],
Cell[452387, 12332, 595, 11, 47, "Message"],
Cell[452985, 12345, 592, 11, 47, "Message"],
Cell[453580, 12358, 595, 11, 47, "Message"],
Cell[454178, 12371, 535, 11, 26, "Message"],
Cell[454716, 12384, 10039, 274, 541, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[464792, 12663, 634, 15, 33, "Input"],
Cell[465429, 12680, 593, 11, 47, "Message"],
Cell[466025, 12693, 595, 11, 47, "Message"],
Cell[466623, 12706, 593, 11, 47, "Message"],
Cell[467219, 12719, 535, 11, 26, "Message"],
Cell[467757, 12732, 9438, 254, 585, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[477232, 12991, 331, 8, 41, "Input"],
Cell[477566, 13001, 593, 11, 58, "Message"],
Cell[478162, 13014, 593, 11, 58, "Message"],
Cell[478758, 13027, 595, 11, 58, "Message"],
Cell[479356, 13040, 537, 11, 32, "Message"],
Cell[479896, 13053, 9438, 254, 585, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[489395, 13314, 219, 3, 83, "Section"],
Cell[CellGroupData[{
Cell[489639, 13321, 163, 2, 42, "Subsection"],
Cell[CellGroupData[{
Cell[489827, 13327, 108, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[489960, 13332, 1083, 24, 72, "Input"],
Cell[491046, 13358, 595, 11, 47, "Message"],
Cell[491644, 13371, 593, 11, 47, "Message"],
Cell[492240, 13384, 593, 11, 47, "Message"],
Cell[492836, 13397, 537, 11, 26, "Message"],
Cell[493376, 13410, 5332, 147, 314, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[498745, 13562, 987, 22, 72, "Input"],
Cell[499735, 13586, 593, 11, 47, "Message"],
Cell[500331, 13599, 593, 11, 47, "Message"],
Cell[500927, 13612, 6100, 173, 209, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[507064, 13790, 949, 21, 53, "Input"],
Cell[508016, 13813, 593, 11, 47, "Message"],
Cell[508612, 13826, 593, 11, 47, "Message"],
Cell[509208, 13839, 595, 11, 47, "Message"],
Cell[509806, 13852, 535, 11, 26, "Message"],
Cell[510344, 13865, 6438, 174, 367, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[516819, 14044, 858, 20, 53, "Input"],
Cell[517680, 14066, 5809, 152, 223, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[523538, 14224, 104, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[523667, 14229, 904, 21, 53, "Input"],
Cell[524574, 14252, 5301, 138, 439, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[529912, 14395, 880, 21, 53, "Input"],
Cell[530795, 14418, 5110, 133, 439, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[535942, 14556, 859, 21, 53, "Input"],
Cell[536804, 14579, 593, 11, 47, "Message"],
Cell[537400, 14592, 595, 11, 47, "Message"],
Cell[537998, 14605, 5570, 148, 509, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[543605, 14758, 753, 19, 53, "Input"],
Cell[544361, 14779, 4394, 115, 326, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[548804, 14900, 104, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[548933, 14905, 791, 18, 53, "Input"],
Cell[549727, 14925, 4479, 125, 200, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[554243, 15055, 766, 17, 33, "Input"],
Cell[555012, 15074, 4301, 118, 200, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[559350, 15197, 739, 17, 33, "Input"],
Cell[560092, 15216, 4417, 123, 200, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[564546, 15344, 727, 16, 33, "Input"],
Cell[565276, 15362, 593, 11, 47, "Message"],
Cell[565872, 15375, 595, 11, 47, "Message"],
Cell[566470, 15388, 593, 11, 47, "Message"],
Cell[567066, 15401, 537, 11, 26, "Message"],
Cell[567606, 15414, 4518, 120, 263, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[572161, 15539, 370, 8, 33, "Input"],
Cell[572534, 15549, 593, 11, 47, "Message"],
Cell[573130, 15562, 593, 11, 47, "Message"],
Cell[573726, 15575, 595, 11, 47, "Message"],
Cell[574324, 15588, 537, 11, 26, "Message"],
Cell[574864, 15601, 4512, 120, 263, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[579449, 15729, 91, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[579565, 15734, 94, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[579684, 15739, 106, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[579815, 15744, 658, 18, 33, "Input"],
Cell[580476, 15764, 1314, 38, 86, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[581827, 15807, 630, 17, 33, "Input"],
Cell[582460, 15826, 906, 26, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[583403, 15857, 641, 16, 33, "Input"],
Cell[584047, 15875, 996, 29, 87, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[585080, 15909, 563, 14, 33, "Input"],
Cell[585646, 15925, 906, 27, 87, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[586589, 15957, 542, 14, 33, "Input"],
Cell[587134, 15973, 858, 26, 83, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[588029, 16004, 486, 13, 33, "Input"],
Cell[588518, 16019, 673, 19, 79, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[589252, 16045, 96, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[589373, 16050, 594, 15, 33, "Input"],
Cell[589970, 16067, 1107, 34, 106, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[591114, 16106, 571, 15, 33, "Input"],
Cell[591688, 16123, 973, 29, 99, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[592698, 16157, 509, 13, 33, "Input"],
Cell[593210, 16172, 965, 29, 98, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[594224, 16207, 97, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[594346, 16212, 356, 8, 33, "Input"],
Cell[594705, 16222, 1244, 37, 97, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[595998, 16265, 98, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[596121, 16270, 194, 4, 33, "Input"],
Cell[596318, 16276, 1293, 38, 98, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[597650, 16319, 19, 0, 83, "Section"]
}, Open  ]],
Cell[CellGroupData[{
Cell[597706, 16324, 96, 1, 57, "Subtitle"],
Cell[CellGroupData[{
Cell[597827, 16329, 124, 2, 33, "Input"],
Cell[597954, 16333, 4165, 113, 241, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[602156, 16451, 154, 3, 33, "Input"],
Cell[602313, 16456, 6260, 169, 365, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[608610, 16630, 123, 2, 33, "Input"],
Cell[608736, 16634, 9464, 254, 483, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[618237, 16893, 128, 2, 33, "Input"],
Cell[618368, 16897, 4471, 119, 263, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[622876, 17021, 105, 2, 33, "Input"],
Cell[622984, 17025, 1271, 37, 97, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[624292, 17067, 184, 2, 83, "Section"],
Cell[CellGroupData[{
Cell[624501, 17073, 3151, 79, 209, "Input"],
Cell[627655, 17154, 809, 15, 41, "Output"],
Cell[628467, 17171, 809, 15, 41, "Output"],
Cell[629279, 17188, 1206, 28, 62, "Output"],
Cell[630488, 17218, 850, 16, 60, "Output"],
Cell[631341, 17236, 795, 14, 56, "Output"],
Cell[632139, 17252, 799, 14, 54, "Output"],
Cell[632941, 17268, 801, 14, 54, "Output"],
Cell[633745, 17284, 1709, 44, 62, "Output"],
Cell[635457, 17330, 801, 14, 38, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[636307, 17350, 327, 8, 83, "Section"],
Cell[636637, 17360, 117, 2, 33, "Input"],
Cell[CellGroupData[{
Cell[636779, 17366, 2141, 44, 53, "Input"],
Cell[638923, 17412, 3544, 96, 205, "Output"],
Cell[642470, 17510, 6005, 158, 271, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[648512, 17673, 1183, 31, 53, "Input"],
Cell[649698, 17706, 5210, 144, 285, "Output"],
Cell[654911, 17852, 10107, 262, 435, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[665055, 18119, 1185, 31, 53, "Input"],
Cell[666243, 18152, 593, 11, 47, "Message"],
Cell[666839, 18165, 593, 11, 47, "Message"],
Cell[667435, 18178, 593, 11, 47, "Message"],
Cell[668031, 18191, 537, 11, 26, "Message"],
Cell[668571, 18204, 10171, 266, 524, "Output"],
Cell[678745, 18472, 11930, 305, 474, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[690712, 18782, 1187, 31, 53, "Input"],
Cell[691902, 18815, 3790, 104, 196, "Output"],
Cell[695695, 18921, 13021, 328, 547, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[708753, 19254, 1341, 33, 53, "Input"],
Cell[710097, 19289, 848, 24, 70, "Output"],
Cell[710948, 19315, 1108, 32, 57, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[712129, 19355, 218, 5, 167, "Title"],
Cell[712350, 19362, 90, 1, 57, "Subtitle"]
}, Open  ]],
Cell[CellGroupData[{
Cell[712477, 19368, 131, 2, 95, "Title"],
Cell[CellGroupData[{
Cell[712633, 19374, 98, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[712756, 19379, 2223, 57, 129, "Input"],
Cell[714982, 19438, 1708, 36, 72, "Output"]
}, Open  ]],
Cell[716705, 19477, 670, 18, 53, "Input"],
Cell[CellGroupData[{
Cell[717400, 19499, 4002, 113, 110, "Input"],
Cell[721405, 19614, 5825, 156, 271, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[727279, 19776, 163, 2, 32, "Subsubtitle"],
Cell[CellGroupData[{
Cell[727467, 19782, 2011, 57, 72, "Input"],
Cell[729481, 19841, 1625, 47, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[731143, 19893, 738, 18, 33, "Input"],
Cell[731884, 19913, 622, 15, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[732543, 19933, 1360, 41, 33, "Input"],
Cell[733906, 19976, 1157, 35, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[735112, 20017, 114, 1, 32, "Subsubtitle"],
Cell[CellGroupData[{
Cell[735251, 20022, 1837, 51, 53, "Input"],
Cell[737091, 20075, 1510, 43, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[738638, 20123, 655, 16, 33, "Input"],
Cell[739296, 20141, 506, 14, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[739839, 20160, 1160, 33, 66, "Input"],
Cell[741002, 20195, 1135, 34, 66, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[742186, 20235, 115, 1, 32, "Subsubtitle"],
Cell[CellGroupData[{
Cell[742326, 20240, 2027, 55, 91, "Input"],
Cell[744356, 20297, 913, 27, 66, "Output"]
}, Open  ]],
Cell[745284, 20327, 105, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[745414, 20332, 180, 2, 45, "Section"],
Cell[CellGroupData[{
Cell[745619, 20338, 158, 3, 33, "Input"],
Cell[745780, 20343, 148, 3, 33, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[745977, 20352, 133, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[746135, 20357, 158, 3, 33, "Input"],
Cell[746296, 20362, 145, 3, 33, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[746490, 20371, 108, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[746623, 20376, 764, 20, 33, "Input"],
Cell[747390, 20398, 2565, 75, 83, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[749992, 20478, 276, 5, 33, "Input"],
Cell[750271, 20485, 2354, 67, 97, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[752662, 20557, 796, 23, 33, "Input"],
Cell[753461, 20582, 2733, 81, 149, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[756231, 20668, 201, 4, 33, "Input"],
Cell[756435, 20674, 3167, 90, 186, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[759639, 20769, 210, 4, 33, "Input"],
Cell[759852, 20775, 1100, 20, 163, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[761001, 20801, 110, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[761136, 20806, 1644, 50, 53, "Input"],
Cell[762783, 20858, 1243, 38, 145, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[764075, 20902, 93, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[764193, 20907, 470, 11, 33, "Input"],
Cell[764666, 20920, 2481, 72, 144, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[767220, 21000, 133, 2, 95, "Title"],
Cell[CellGroupData[{
Cell[767378, 21006, 98, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[767501, 21011, 2223, 57, 129, "Input"],
Cell[769727, 21070, 1771, 36, 72, "Output"]
}, Open  ]],
Cell[771513, 21109, 670, 18, 43, "Input"],
Cell[CellGroupData[{
Cell[772208, 21131, 6468, 170, 286, "Input"],
Cell[778679, 21303, 13283, 328, 389, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[792011, 21637, 114, 1, 26, "Subsubtitle"],
Cell[CellGroupData[{
Cell[792150, 21642, 2162, 57, 100, "Input"],
Cell[794315, 21701, 1931, 55, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[796295, 21762, 114, 1, 26, "Subsubtitle"],
Cell[CellGroupData[{
Cell[796434, 21767, 2515, 66, 87, "Input"],
Cell[798952, 21835, 2341, 66, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[801330, 21906, 1150, 28, 33, "Input"],
Cell[802483, 21936, 501, 11, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[803021, 21952, 259, 6, 27, "Input"],
Cell[803283, 21960, 1944, 54, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[805276, 22020, 115, 1, 26, "Subsubtitle"],
Cell[CellGroupData[{
Cell[805416, 22025, 2486, 65, 87, "Input"],
Cell[807905, 22092, 2180, 61, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[810122, 22158, 139, 3, 27, "Input"],
Cell[810264, 22163, 447, 11, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[810748, 22179, 210, 5, 27, "Input"],
Cell[810961, 22186, 1927, 54, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[812937, 22246, 115, 1, 26, "Subsubtitle"],
Cell[CellGroupData[{
Cell[813077, 22251, 2444, 65, 87, "Input"],
Cell[815524, 22318, 2295, 66, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[817856, 22389, 1032, 27, 33, "Input"],
Cell[818891, 22418, 426, 10, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[819354, 22433, 215, 5, 27, "Input"],
Cell[819572, 22440, 1835, 54, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[821456, 22500, 127, 1, 26, "Subsubtitle"],
Cell[CellGroupData[{
Cell[821608, 22505, 2417, 64, 87, "Input"],
Cell[824028, 22571, 2240, 64, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[826305, 22640, 137, 3, 27, "Input"],
Cell[826445, 22645, 448, 11, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[826930, 22661, 210, 5, 27, "Input"],
Cell[827143, 22668, 1839, 54, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[829019, 22727, 108, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[829152, 22732, 2127, 60, 95, "Input"],
Cell[831282, 22794, 8064, 211, 266, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[839383, 23010, 108, 2, 27, "Input"],
Cell[839494, 23014, 7966, 210, 266, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[847497, 23229, 215, 4, 27, "Input"],
Cell[847715, 23235, 7965, 210, 266, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[855729, 23451, 184, 2, 67, "Section"],
Cell[CellGroupData[{
Cell[855938, 23457, 3151, 79, 166, "Input"],
Cell[859092, 23538, 903, 16, 40, "Output"],
Cell[859998, 23556, 903, 16, 40, "Output"],
Cell[860904, 23574, 1302, 29, 53, "Output"],
Cell[862209, 23605, 945, 17, 52, "Output"],
Cell[863157, 23624, 891, 15, 49, "Output"],
Cell[864051, 23641, 893, 15, 47, "Output"],
Cell[864947, 23658, 893, 15, 47, "Output"],
Cell[865843, 23675, 1806, 45, 53, "Output"],
Cell[867652, 23722, 895, 15, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[868584, 23742, 452, 11, 27, "Input"],
Cell[869039, 23755, 4967, 140, 163, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[874043, 23900, 173, 3, 27, "Input"],
Cell[874219, 23905, 7539, 199, 236, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[881795, 24109, 210, 4, 33, "Input"],
Cell[882008, 24115, 2416, 40, 326, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[884473, 24161, 110, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[884608, 24166, 2523, 76, 72, "Input"],
Cell[887134, 24244, 2085, 59, 145, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[889268, 24309, 93, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[889386, 24314, 616, 13, 33, "Input"],
Cell[890005, 24329, 4957, 139, 283, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[895035, 24476, 156, 2, 95, "Title"],
Cell[CellGroupData[{
Cell[895216, 24482, 98, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[895339, 24487, 2223, 57, 129, "Input"],
Cell[897565, 24546, 1722, 36, 58, "Output"]
}, Open  ]],
Cell[899302, 24585, 670, 18, 43, "Input"],
Cell[CellGroupData[{
Cell[899997, 24607, 11674, 302, 313, "Input"],
Cell[911674, 24911, 12347, 308, 438, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[924070, 25225, 114, 1, 26, "Subsubtitle"],
Cell[CellGroupData[{
Cell[924209, 25230, 1429, 39, 43, "Input"],
Cell[925641, 25271, 851, 23, 55, "Output"]
}, Open  ]],
Cell[926507, 25297, 107, 1, 34, "Subsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[926651, 25303, 114, 1, 26, "Subsubtitle"],
Cell[CellGroupData[{
Cell[926790, 25308, 2258, 56, 88, "Input"],
Cell[929051, 25366, 3450, 104, 102, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[932538, 25475, 1452, 38, 43, "Input"],
Cell[933993, 25515, 539, 14, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[934569, 25534, 3157, 95, 58, "Input"],
Cell[937729, 25631, 1350, 37, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[939128, 25674, 115, 1, 26, "Subsubtitle"],
Cell[CellGroupData[{
Cell[939268, 25679, 2206, 55, 88, "Input"],
Cell[941477, 25736, 3460, 105, 102, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[944974, 25846, 1306, 37, 43, "Input"],
Cell[946283, 25885, 461, 13, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[946781, 25903, 3059, 93, 58, "Input"],
Cell[949843, 25998, 1299, 36, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[951191, 26040, 117, 1, 26, "Subsubtitle"],
Cell[CellGroupData[{
Cell[951333, 26045, 2023, 55, 88, "Input"],
Cell[953359, 26102, 822, 24, 55, "Output"]
}, Open  ]],
Cell[954196, 26129, 113, 1, 34, "Subsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[954346, 26135, 127, 1, 26, "Subsubtitle"],
Cell[CellGroupData[{
Cell[954498, 26140, 2403, 63, 88, "Input"],
Cell[956904, 26205, 4177, 128, 149, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[961118, 26338, 1222, 35, 43, "Input"],
Cell[962343, 26375, 424, 12, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[962804, 26392, 4081, 125, 73, "Input"],
Cell[966888, 26519, 1430, 42, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[968367, 26567, 117, 1, 26, "Subsubtitle"],
Cell[CellGroupData[{
Cell[968509, 26572, 2379, 62, 88, "Input"],
Cell[970891, 26636, 4200, 128, 149, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[975128, 26769, 1296, 37, 43, "Input"],
Cell[976427, 26808, 452, 13, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[976916, 26826, 4081, 125, 73, "Input"],
Cell[981000, 26953, 1432, 42, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[982469, 27000, 232, 3, 67, "Section"],
Cell[CellGroupData[{
Cell[982726, 27007, 209, 4, 27, "Input"],
Cell[982938, 27013, 160, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[983135, 27020, 160, 3, 27, "Input"],
Cell[983298, 27025, 139, 2, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[983486, 27033, 133, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[983644, 27038, 207, 4, 27, "Input"],
Cell[983854, 27044, 161, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[984052, 27051, 158, 3, 27, "Input"],
Cell[984213, 27056, 147, 2, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[984409, 27064, 108, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[984542, 27069, 1208, 33, 43, "Input"],
Cell[985753, 27104, 5237, 149, 182, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[991027, 27258, 276, 5, 27, "Input"],
Cell[991306, 27265, 3928, 114, 134, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[995271, 27384, 819, 23, 27, "Input"],
Cell[996093, 27409, 4498, 128, 246, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1000628, 27542, 174, 3, 33, "Input"],
Cell[1000805, 27547, 6907, 185, 281, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1007749, 27737, 258, 5, 33, "Input"],
Cell[1008010, 27744, 2384, 43, 342, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1010443, 27793, 110, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[1010578, 27798, 2282, 67, 72, "Input"],
Cell[1012863, 27867, 1650, 49, 153, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1014562, 27922, 93, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[1014680, 27927, 518, 11, 33, "Input"],
Cell[1015201, 27940, 5243, 150, 305, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1020517, 28098, 131, 2, 95, "Title"],
Cell[CellGroupData[{
Cell[1020673, 28104, 98, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[1020796, 28109, 2223, 57, 129, "Input"],
Cell[1023022, 28168, 1792, 37, 72, "Output"]
}, Open  ]],
Cell[1024829, 28208, 670, 18, 53, "Input"],
Cell[CellGroupData[{
Cell[1025524, 28230, 4694, 122, 296, "Input"],
Cell[1030221, 28354, 13959, 348, 550, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1044229, 28708, 114, 1, 32, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1044368, 28713, 2094, 52, 90, "Input"],
Cell[1046465, 28767, 4127, 119, 123, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1050629, 28891, 1134, 31, 66, "Input"],
Cell[1051766, 28924, 399, 9, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1052202, 28938, 213, 5, 33, "Input"],
Cell[1052418, 28945, 1456, 44, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1053923, 28995, 114, 1, 32, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1054062, 29000, 2039, 51, 90, "Input"],
Cell[1056104, 29053, 4053, 118, 123, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1060194, 29176, 1387, 35, 66, "Input"],
Cell[1061584, 29213, 546, 12, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1062167, 29230, 259, 6, 33, "Input"],
Cell[1062429, 29238, 1500, 44, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1063978, 29288, 115, 1, 32, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1064118, 29293, 1723, 47, 69, "Input"],
Cell[1065844, 29342, 1550, 46, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1067443, 29394, 115, 1, 32, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1067583, 29399, 1978, 54, 69, "Input"],
Cell[1069564, 29455, 1708, 50, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1071321, 29511, 127, 1, 32, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1071473, 29516, 2582, 66, 135, "Input"],
Cell[1074058, 29584, 4927, 145, 180, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1079022, 29734, 1194, 33, 66, "Input"],
Cell[1080219, 29769, 442, 10, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1080698, 29784, 210, 5, 33, "Input"],
Cell[1080911, 29791, 1761, 51, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1082721, 29848, 118, 1, 32, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1082864, 29853, 2498, 64, 135, "Input"],
Cell[1085365, 29919, 4868, 144, 180, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1090270, 30068, 1181, 33, 66, "Input"],
Cell[1091454, 30103, 415, 10, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1091906, 30118, 211, 5, 33, "Input"],
Cell[1092120, 30125, 1735, 51, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1093892, 30181, 108, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[1094025, 30186, 2299, 63, 83, "Input"],
Cell[1096327, 30251, 8707, 233, 343, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1105083, 30490, 184, 2, 83, "Section"],
Cell[CellGroupData[{
Cell[1105292, 30496, 3151, 79, 209, "Input"],
Cell[1108446, 30577, 929, 16, 41, "Output"],
Cell[1109378, 30595, 929, 16, 41, "Output"],
Cell[1110310, 30613, 1324, 29, 62, "Output"],
Cell[1111637, 30644, 969, 17, 60, "Output"],
Cell[1112609, 30663, 913, 15, 56, "Output"],
Cell[1113525, 30680, 917, 15, 54, "Output"],
Cell[1114445, 30697, 919, 15, 54, "Output"],
Cell[1115367, 30714, 1830, 45, 62, "Output"],
Cell[1117200, 30761, 919, 15, 38, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1118156, 30781, 404, 10, 33, "Input"],
Cell[1118563, 30793, 5141, 143, 247, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1123741, 30941, 172, 3, 33, "Input"],
Cell[1123916, 30946, 8534, 221, 343, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1132487, 31172, 259, 5, 33, "Input"],
Cell[1132749, 31179, 2807, 46, 389, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1135605, 31231, 110, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[1135740, 31236, 2109, 62, 72, "Input"],
Cell[1137852, 31300, 1742, 48, 121, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1139643, 31354, 93, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[1139761, 31359, 567, 12, 33, "Input"],
Cell[1140331, 31373, 4168, 116, 240, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1144572, 31497, 265, 6, 167, "Title"],
Cell[1144840, 31505, 89, 1, 95, "Title"],
Cell[1144932, 31508, 3167, 90, 186, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1148136, 31603, 86, 1, 95, "Title"],
Cell[1148225, 31606, 7539, 199, 291, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1155801, 31810, 85, 1, 95, "Title"],
Cell[1155889, 31813, 6907, 185, 281, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1162833, 32003, 85, 1, 95, "Title"],
Cell[1162921, 32006, 8534, 221, 343, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
